/****************************************************************************
** Meta object code from reading C++ file 'ktfeed.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../ktorrent-26.04.3/plugins/syndication/ktfeed.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ktfeed.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2kt4FeedE_t {};
} // unnamed namespace

template <> constexpr inline auto kt::Feed::qt_create_metaobjectdata<qt_meta_tag_ZN2kt4FeedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "kt::Feed",
        "downloadLink",
        "",
        "QUrl",
        "link",
        "group",
        "location",
        "move_on_completion",
        "silently",
        "Feed*",
        "sender",
        "feedRenamed",
        "f",
        "updated",
        "loadingComplete",
        "Syndication::Loader*",
        "loader",
        "Syndication::FeedPtr",
        "feed",
        "Syndication::ErrorCode",
        "status",
        "loadingFromDiskComplete"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'downloadLink'
        QtMocHelpers::SignalData<void(const QUrl &, const QString &, const QString &, const QString &, bool, Feed *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 }, { QMetaType::QString, 6 }, { QMetaType::QString, 7 },
            { QMetaType::Bool, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Signal 'feedRenamed'
        QtMocHelpers::SignalData<void(Feed *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 12 },
        }}),
        // Signal 'updated'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'loadingComplete'
        QtMocHelpers::SlotData<void(Syndication::Loader *, Syndication::FeedPtr, Syndication::ErrorCode)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 17, 18 }, { 0x80000000 | 19, 20 },
        }}),
        // Slot 'loadingFromDiskComplete'
        QtMocHelpers::SlotData<void(Syndication::Loader *, Syndication::FeedPtr, Syndication::ErrorCode)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 17, 18 }, { 0x80000000 | 19, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Feed, qt_meta_tag_ZN2kt4FeedE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject kt::Feed::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt4FeedE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt4FeedE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2kt4FeedE_t>.metaTypes,
    nullptr
} };

void kt::Feed::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Feed *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->downloadLink((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<Feed*>>(_a[6]))); break;
        case 1: _t->feedRenamed((*reinterpret_cast<std::add_pointer_t<Feed*>>(_a[1]))); break;
        case 2: _t->updated(); break;
        case 3: _t->loadingComplete((*reinterpret_cast<std::add_pointer_t<Syndication::Loader*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Syndication::FeedPtr>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Syndication::ErrorCode>>(_a[3]))); break;
        case 4: _t->loadingFromDiskComplete((*reinterpret_cast<std::add_pointer_t<Syndication::Loader*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Syndication::FeedPtr>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Syndication::ErrorCode>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 5:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Feed* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Feed* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Syndication::Loader* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Syndication::Loader* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Feed::*)(const QUrl & , const QString & , const QString & , const QString & , bool , Feed * )>(_a, &Feed::downloadLink, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Feed::*)(Feed * )>(_a, &Feed::feedRenamed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Feed::*)()>(_a, &Feed::updated, 2))
            return;
    }
}

const QMetaObject *kt::Feed::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kt::Feed::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt4FeedE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int kt::Feed::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void kt::Feed::downloadLink(const QUrl & _t1, const QString & _t2, const QString & _t3, const QString & _t4, bool _t5, Feed * _t6)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4, _t5, _t6);
}

// SIGNAL 1
void kt::Feed::feedRenamed(Feed * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void kt::Feed::updated()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
