/********************************************************************************
** Form generated from reading UI file 'speedlimitsdlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SPEEDLIMITSDLG_H
#define UI_SPEEDLIMITSDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SpeedLimitsDlg
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *m_main_caption;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QLineEdit *m_filter;
    QTreeView *m_speed_limits_view;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLabel *textLabel3;
    QSpinBox *m_download_rate;
    QLabel *textLabel2;
    QSpinBox *m_upload_rate;
    QDialogButtonBox *m_buttonBox;
    QFrame *line1;

    void setupUi(QDialog *SpeedLimitsDlg)
    {
        if (SpeedLimitsDlg->objectName().isEmpty())
            SpeedLimitsDlg->setObjectName("SpeedLimitsDlg");
        SpeedLimitsDlg->resize(546, 372);
        verticalLayout = new QVBoxLayout(SpeedLimitsDlg);
        verticalLayout->setSpacing(6);
        verticalLayout->setContentsMargins(11, 11, 11, 11);
        verticalLayout->setObjectName("verticalLayout");
        m_main_caption = new QLabel(SpeedLimitsDlg);
        m_main_caption->setObjectName("m_main_caption");
        m_main_caption->setWordWrap(false);

        verticalLayout->addWidget(m_main_caption);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(SpeedLimitsDlg);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        m_filter = new QLineEdit(SpeedLimitsDlg);
        m_filter->setObjectName("m_filter");
        m_filter->setClearButtonEnabled(true);

        horizontalLayout->addWidget(m_filter);


        verticalLayout->addLayout(horizontalLayout);

        m_speed_limits_view = new QTreeView(SpeedLimitsDlg);
        m_speed_limits_view->setObjectName("m_speed_limits_view");
        m_speed_limits_view->setAlternatingRowColors(true);
        m_speed_limits_view->setRootIsDecorated(false);
        m_speed_limits_view->setAllColumnsShowFocus(true);

        verticalLayout->addWidget(m_speed_limits_view);

        groupBox = new QGroupBox(SpeedLimitsDlg);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setSpacing(6);
        gridLayout->setContentsMargins(11, 11, 11, 11);
        gridLayout->setObjectName("gridLayout");
        textLabel3 = new QLabel(groupBox);
        textLabel3->setObjectName("textLabel3");
        textLabel3->setWordWrap(false);

        gridLayout->addWidget(textLabel3, 0, 0, 1, 1);

        m_download_rate = new QSpinBox(groupBox);
        m_download_rate->setObjectName("m_download_rate");
        m_download_rate->setMaximum(1000000);

        gridLayout->addWidget(m_download_rate, 0, 1, 1, 1);

        textLabel2 = new QLabel(groupBox);
        textLabel2->setObjectName("textLabel2");
        textLabel2->setWordWrap(false);

        gridLayout->addWidget(textLabel2, 1, 0, 1, 1);

        m_upload_rate = new QSpinBox(groupBox);
        m_upload_rate->setObjectName("m_upload_rate");
        m_upload_rate->setMaximum(1000000);

        gridLayout->addWidget(m_upload_rate, 1, 1, 1, 1);


        verticalLayout->addWidget(groupBox);

        m_buttonBox = new QDialogButtonBox(SpeedLimitsDlg);
        m_buttonBox->setObjectName("m_buttonBox");
        m_buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(m_buttonBox);

        line1 = new QFrame(SpeedLimitsDlg);
        line1->setObjectName("line1");
        line1->setFrameShape(QFrame::HLine);
        line1->setFrameShadow(QFrame::Sunken);

        verticalLayout->addWidget(line1);


        retranslateUi(SpeedLimitsDlg);

        QMetaObject::connectSlotsByName(SpeedLimitsDlg);
    } // setupUi

    void retranslateUi(QDialog *SpeedLimitsDlg)
    {
        SpeedLimitsDlg->setWindowTitle(tr2i18n("Speed Limits", nullptr));
        m_main_caption->setText(tr2i18n("Speed limits for individual torrents (double click to edit):", nullptr));
        label->setText(tr2i18n("Filter:", nullptr));
        groupBox->setTitle(tr2i18n("Global Limits", nullptr));
        textLabel3->setText(tr2i18n("Maximum download speed:", nullptr));
        m_download_rate->setSpecialValueText(tr2i18n("No limit", nullptr));
        m_download_rate->setSuffix(tr2i18n(" KiB/s", nullptr));
        textLabel2->setText(tr2i18n("Maximum upload speed:", nullptr));
        m_upload_rate->setSpecialValueText(tr2i18n("No limit", nullptr));
        m_upload_rate->setSuffix(tr2i18n(" KiB/s", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SpeedLimitsDlg: public Ui_SpeedLimitsDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SPEEDLIMITSDLG_H

