/********************************************************************************
** Form generated from reading UI file 'btpref.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BTPREF_H
#define UI_BTPREF_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_BTPref
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *dhtGroupBox;
    QVBoxLayout *vboxLayout;
    QCheckBox *kcfg_dhtSupport;
    QHBoxLayout *hboxLayout;
    QLabel *label_4;
    QSpinBox *kcfg_dhtPort;
    QCheckBox *kcfg_pexEnabled;
    QCheckBox *kcfg_webseedsEnabled;
    QCheckBox *kcfg_checkWhenFinished;
    QGroupBox *groupBox_4;
    QVBoxLayout *vboxLayout1;
    QCheckBox *kcfg_useEncryption;
    QCheckBox *kcfg_allowUnencryptedConnections;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_useCustomIP;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QLineEdit *kcfg_customIP;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *BTPref)
    {
        if (BTPref->objectName().isEmpty())
            BTPref->setObjectName("BTPref");
        BTPref->resize(628, 477);
        verticalLayout_2 = new QVBoxLayout(BTPref);
        verticalLayout_2->setObjectName("verticalLayout_2");
        dhtGroupBox = new QGroupBox(BTPref);
        dhtGroupBox->setObjectName("dhtGroupBox");
        vboxLayout = new QVBoxLayout(dhtGroupBox);
        vboxLayout->setObjectName("vboxLayout");
        kcfg_dhtSupport = new QCheckBox(dhtGroupBox);
        kcfg_dhtSupport->setObjectName("kcfg_dhtSupport");

        vboxLayout->addWidget(kcfg_dhtSupport);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        label_4 = new QLabel(dhtGroupBox);
        label_4->setObjectName("label_4");

        hboxLayout->addWidget(label_4);

        kcfg_dhtPort = new QSpinBox(dhtGroupBox);
        kcfg_dhtPort->setObjectName("kcfg_dhtPort");
        kcfg_dhtPort->setMinimum(1);
        kcfg_dhtPort->setMaximum(65535);
        kcfg_dhtPort->setValue(4444);

        hboxLayout->addWidget(kcfg_dhtPort);


        vboxLayout->addLayout(hboxLayout);

        kcfg_pexEnabled = new QCheckBox(dhtGroupBox);
        kcfg_pexEnabled->setObjectName("kcfg_pexEnabled");

        vboxLayout->addWidget(kcfg_pexEnabled);

        kcfg_webseedsEnabled = new QCheckBox(dhtGroupBox);
        kcfg_webseedsEnabled->setObjectName("kcfg_webseedsEnabled");

        vboxLayout->addWidget(kcfg_webseedsEnabled);

        kcfg_checkWhenFinished = new QCheckBox(dhtGroupBox);
        kcfg_checkWhenFinished->setObjectName("kcfg_checkWhenFinished");

        vboxLayout->addWidget(kcfg_checkWhenFinished);


        verticalLayout_2->addWidget(dhtGroupBox);

        groupBox_4 = new QGroupBox(BTPref);
        groupBox_4->setObjectName("groupBox_4");
        vboxLayout1 = new QVBoxLayout(groupBox_4);
        vboxLayout1->setObjectName("vboxLayout1");
        kcfg_useEncryption = new QCheckBox(groupBox_4);
        kcfg_useEncryption->setObjectName("kcfg_useEncryption");

        vboxLayout1->addWidget(kcfg_useEncryption);

        kcfg_allowUnencryptedConnections = new QCheckBox(groupBox_4);
        kcfg_allowUnencryptedConnections->setObjectName("kcfg_allowUnencryptedConnections");

        vboxLayout1->addWidget(kcfg_allowUnencryptedConnections);


        verticalLayout_2->addWidget(groupBox_4);

        groupBox = new QGroupBox(BTPref);
        groupBox->setObjectName("groupBox");
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName("verticalLayout");
        kcfg_useCustomIP = new QCheckBox(groupBox);
        kcfg_useCustomIP->setObjectName("kcfg_useCustomIP");

        verticalLayout->addWidget(kcfg_useCustomIP);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(groupBox);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        kcfg_customIP = new QLineEdit(groupBox);
        kcfg_customIP->setObjectName("kcfg_customIP");

        horizontalLayout->addWidget(kcfg_customIP);


        verticalLayout->addLayout(horizontalLayout);


        verticalLayout_2->addWidget(groupBox);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(spacerItem);


        retranslateUi(BTPref);
        QObject::connect(kcfg_dhtSupport, &QCheckBox::toggled, kcfg_dhtPort, &QSpinBox::setEnabled);
        QObject::connect(kcfg_useEncryption, &QCheckBox::toggled, kcfg_allowUnencryptedConnections, &QCheckBox::setEnabled);
        QObject::connect(kcfg_useCustomIP, &QCheckBox::toggled, kcfg_customIP, &QLineEdit::setEnabled);

        QMetaObject::connectSlotsByName(BTPref);
    } // setupUi

    void retranslateUi(QWidget *BTPref)
    {
        dhtGroupBox->setTitle(tr2i18n("Features", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_dhtSupport->setToolTip(tr2i18n("DHT is a trackerless protocol to find peers sharing the same torrents as you do.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_dhtSupport->setText(tr2i18n("Use DHT to get additional peers", nullptr));
        label_4->setText(tr2i18n("UDP port for DHT communications:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_dhtPort->setToolTip(tr2i18n("<p>UDP port to use for the DHT protocol.</p>\n"
"<p><span style=\" font-weight:600;\">Attention:</span> If you are behind a router, this port needs to be forwarded to accept incoming DHT requests. The UPnP plugin can do this for you.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_pexEnabled->setToolTip(tr2i18n("Whether or not to use \302\265Torrent compatible peer exchange.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_pexEnabled->setText(tr2i18n("Use peer exchange", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_webseedsEnabled->setToolTip(tr2i18n("Enable or disable the use of webseeds when they are present in a torrent.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_webseedsEnabled->setText(tr2i18n("Use webseeds", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_checkWhenFinished->setToolTip(tr2i18n("When a torrent has finished downloading, do a full data check on the torrent.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_checkWhenFinished->setText(tr2i18n("Check data when download is finished", nullptr));
        groupBox_4->setTitle(tr2i18n("Encryption", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_useEncryption->setToolTip(tr2i18n("<p>Protocol encryption is useful when your ISP is slowing down bittorrent connections. </p>\n"
"<p>The encryption will prevent your bittorrent traffic to be flagged as bittorrent traffic, and so the ISP will not slow it down.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_useEncryption->setText(tr2i18n("Use protocol encryption", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_allowUnencryptedConnections->setToolTip(tr2i18n("Not all clients support encryption, and some people have encryption disabled. If you want to connect to those peers, you need to have this option enabled.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_allowUnencryptedConnections->setText(tr2i18n("Allow unencrypted connections", nullptr));
        groupBox->setTitle(tr2i18n("Tracker", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_useCustomIP->setToolTip(tr2i18n("Instead of allowing the tracker to determine your IP address, tell the tracker which IP address to use. Use this when you are behind a proxy.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_useCustomIP->setText(tr2i18n("Send the tracker a custom IP address or hostname", nullptr));
        label->setText(tr2i18n("Custom IP address or hostname:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_customIP->setToolTip(tr2i18n("Custom IP address or hostname to send to the tracker. Hostnames will be resolved at runtime and the resolved IP address will be sent to the tracker.", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)BTPref;
    } // retranslateUi

};

namespace Ui {
    class BTPref: public Ui_BTPref {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BTPREF_H

