/********************************************************************************
** Form generated from reading UI file 'generalpref.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GENERALPREF_H
#define UI_GENERALPREF_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_GeneralPref
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLabel *label;
    KUrlRequester *kcfg_tempDir;
    QCheckBox *kcfg_useSaveDir;
    KUrlRequester *kcfg_saveDir;
    QCheckBox *kcfg_useCompletedDir;
    KUrlRequester *kcfg_completedDir;
    QCheckBox *kcfg_useTorrentCopyDir;
    KUrlRequester *kcfg_torrentCopyDir;
    QGroupBox *kcfg_showSystemTrayIcon;
    QVBoxLayout *vboxLayout1;
    QCheckBox *kcfg_alwaysMinimizeToSystemTray;
    QCheckBox *kcfg_showPopups;
    QGroupBox *groupBox_3;
    QVBoxLayout *vboxLayout2;
    QCheckBox *kcfg_openMultipleTorrentsSilently;
    QCheckBox *kcfg_openAllTorrentsSilently;
    QCheckBox *kcfg_suppressSleep;
    QCheckBox *kcfg_autoRenameSingleFileTorrents;
    QCheckBox *kcfg_highlightNewTorrents;
    QCheckBox *kcfg_showTotalSpeedInTitle;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *GeneralPref)
    {
        if (GeneralPref->objectName().isEmpty())
            GeneralPref->setObjectName("GeneralPref");
        GeneralPref->resize(427, 423);
        vboxLayout = new QVBoxLayout(GeneralPref);
        vboxLayout->setObjectName("vboxLayout");
        groupBox = new QGroupBox(GeneralPref);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(groupBox);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        kcfg_tempDir = new KUrlRequester(groupBox);
        kcfg_tempDir->setObjectName("kcfg_tempDir");

        gridLayout->addWidget(kcfg_tempDir, 0, 1, 1, 1);

        kcfg_useSaveDir = new QCheckBox(groupBox);
        kcfg_useSaveDir->setObjectName("kcfg_useSaveDir");

        gridLayout->addWidget(kcfg_useSaveDir, 1, 0, 1, 1);

        kcfg_saveDir = new KUrlRequester(groupBox);
        kcfg_saveDir->setObjectName("kcfg_saveDir");

        gridLayout->addWidget(kcfg_saveDir, 1, 1, 1, 1);

        kcfg_useCompletedDir = new QCheckBox(groupBox);
        kcfg_useCompletedDir->setObjectName("kcfg_useCompletedDir");

        gridLayout->addWidget(kcfg_useCompletedDir, 2, 0, 1, 1);

        kcfg_completedDir = new KUrlRequester(groupBox);
        kcfg_completedDir->setObjectName("kcfg_completedDir");

        gridLayout->addWidget(kcfg_completedDir, 2, 1, 1, 1);

        kcfg_useTorrentCopyDir = new QCheckBox(groupBox);
        kcfg_useTorrentCopyDir->setObjectName("kcfg_useTorrentCopyDir");

        gridLayout->addWidget(kcfg_useTorrentCopyDir, 3, 0, 1, 1);

        kcfg_torrentCopyDir = new KUrlRequester(groupBox);
        kcfg_torrentCopyDir->setObjectName("kcfg_torrentCopyDir");

        gridLayout->addWidget(kcfg_torrentCopyDir, 3, 1, 1, 1);


        vboxLayout->addWidget(groupBox);

        kcfg_showSystemTrayIcon = new QGroupBox(GeneralPref);
        kcfg_showSystemTrayIcon->setObjectName("kcfg_showSystemTrayIcon");
        kcfg_showSystemTrayIcon->setCheckable(true);
        vboxLayout1 = new QVBoxLayout(kcfg_showSystemTrayIcon);
        vboxLayout1->setObjectName("vboxLayout1");
        kcfg_alwaysMinimizeToSystemTray = new QCheckBox(kcfg_showSystemTrayIcon);
        kcfg_alwaysMinimizeToSystemTray->setObjectName("kcfg_alwaysMinimizeToSystemTray");

        vboxLayout1->addWidget(kcfg_alwaysMinimizeToSystemTray);

        kcfg_showPopups = new QCheckBox(kcfg_showSystemTrayIcon);
        kcfg_showPopups->setObjectName("kcfg_showPopups");

        vboxLayout1->addWidget(kcfg_showPopups);


        vboxLayout->addWidget(kcfg_showSystemTrayIcon);

        groupBox_3 = new QGroupBox(GeneralPref);
        groupBox_3->setObjectName("groupBox_3");
        vboxLayout2 = new QVBoxLayout(groupBox_3);
        vboxLayout2->setObjectName("vboxLayout2");
        kcfg_openMultipleTorrentsSilently = new QCheckBox(groupBox_3);
        kcfg_openMultipleTorrentsSilently->setObjectName("kcfg_openMultipleTorrentsSilently");

        vboxLayout2->addWidget(kcfg_openMultipleTorrentsSilently);

        kcfg_openAllTorrentsSilently = new QCheckBox(groupBox_3);
        kcfg_openAllTorrentsSilently->setObjectName("kcfg_openAllTorrentsSilently");

        vboxLayout2->addWidget(kcfg_openAllTorrentsSilently);

        kcfg_suppressSleep = new QCheckBox(groupBox_3);
        kcfg_suppressSleep->setObjectName("kcfg_suppressSleep");

        vboxLayout2->addWidget(kcfg_suppressSleep);

        kcfg_autoRenameSingleFileTorrents = new QCheckBox(groupBox_3);
        kcfg_autoRenameSingleFileTorrents->setObjectName("kcfg_autoRenameSingleFileTorrents");

        vboxLayout2->addWidget(kcfg_autoRenameSingleFileTorrents);

        kcfg_highlightNewTorrents = new QCheckBox(groupBox_3);
        kcfg_highlightNewTorrents->setObjectName("kcfg_highlightNewTorrents");

        vboxLayout2->addWidget(kcfg_highlightNewTorrents);

        kcfg_showTotalSpeedInTitle = new QCheckBox(groupBox_3);
        kcfg_showTotalSpeedInTitle->setObjectName("kcfg_showTotalSpeedInTitle");

        vboxLayout2->addWidget(kcfg_showTotalSpeedInTitle);


        vboxLayout->addWidget(groupBox_3);

        spacerItem = new QSpacerItem(382, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem);


        retranslateUi(GeneralPref);
        QObject::connect(kcfg_useCompletedDir, SIGNAL(toggled(bool)), kcfg_completedDir, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_useSaveDir, SIGNAL(toggled(bool)), kcfg_saveDir, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_useTorrentCopyDir, SIGNAL(toggled(bool)), kcfg_torrentCopyDir, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(GeneralPref);
    } // setupUi

    void retranslateUi(QWidget *GeneralPref)
    {
        groupBox->setTitle(tr2i18n("Folders", nullptr));
        label->setText(tr2i18n("Folder to store torrent information:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_tempDir->setToolTip(tr2i18n("Directory to store information about all torrents currently opened in KTorrent.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_useSaveDir->setToolTip(tr2i18n("Directory to use as a default save location for all data.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_useSaveDir->setText(tr2i18n("Default save location:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_saveDir->setToolTip(tr2i18n("Directory to use as a default save location for all data.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_useCompletedDir->setToolTip(tr2i18n("Directory to move data to when a torrent has finished downloading.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_useCompletedDir->setText(tr2i18n("Move completed downloads to:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_completedDir->setToolTip(tr2i18n("Directory to move data to when a torrent has finished downloading.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_useTorrentCopyDir->setToolTip(tr2i18n("Directory to copy all torrent files in, which are opened by KTorrent.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_useTorrentCopyDir->setText(tr2i18n("Copy torrent files to:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_torrentCopyDir->setToolTip(tr2i18n("Directory to copy all torrent files in, which are opened by KTorrent.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_showSystemTrayIcon->setTitle(tr2i18n("System Tray Icon", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_alwaysMinimizeToSystemTray->setToolTip(tr2i18n("Whether or not to always minimize to system tray on startup.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_alwaysMinimizeToSystemTray->setText(tr2i18n("Always minimize to system tray on startup", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_showPopups->setToolTip(tr2i18n("Whether or not to show system tray popup messages.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_showPopups->setText(tr2i18n("Show system tray popup messages", nullptr));
        groupBox_3->setTitle(tr2i18n("Miscellaneous", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_openMultipleTorrentsSilently->setToolTip(tr2i18n("When you select multiple torrents to be opened at the same time, open them silently.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_openMultipleTorrentsSilently->setText(tr2i18n("Open multiple torrents silently", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_openAllTorrentsSilently->setToolTip(tr2i18n("Open all torrents silently.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_openAllTorrentsSilently->setText(tr2i18n("Open all torrents silently", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_suppressSleep->setToolTip(tr2i18n("Prevent computer from going into a sleep state or locking the screen when torrents are running.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_suppressSleep->setText(tr2i18n("Suppress sleep and automatic screen locking when torrents are running", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_autoRenameSingleFileTorrents->setToolTip(tr2i18n("<p>Rename a single file torrent with the name of its only file. </p>\n"
"<p>If for example the file is named <span style=\" font-weight:600;\">linux-desktop.iso</span>, the torrent will be displayed as <span style=\" font-weight:600;\">linux-desktop.</span></p>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_autoRenameSingleFileTorrents->setText(tr2i18n("Rename single file torrents with the name of its only file", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_highlightNewTorrents->setToolTip(tr2i18n("Whether or not new torrents will be highlighted.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_highlightNewTorrents->setText(tr2i18n("Highlight new torrents", nullptr));
        kcfg_showTotalSpeedInTitle->setText(tr2i18n("Show total speed in the window title", nullptr));
        (void)GeneralPref;
    } // retranslateUi

};

namespace Ui {
    class GeneralPref: public Ui_GeneralPref {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GENERALPREF_H

