/********************************************************************************
** Form generated from reading UI file 'ipblockingprefpage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IPBLOCKINGPREFPAGE_H
#define UI_IPBLOCKINGPREFPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kpluralhandlingspinbox.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_IPBlockingPrefPage
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox1;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *kcfg_useLevel1;
    QHBoxLayout *hboxLayout;
    QLabel *textLabel1_3;
    KUrlRequester *kcfg_filterURL;
    QHBoxLayout *hboxLayout1;
    QSpacerItem *spacerItem;
    QPushButton *m_download;
    QLabel *textLabel1_2;
    QLabel *m_status;
    QGroupBox *m_auto_update_group_box;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QCheckBox *kcfg_autoUpdate;
    KPluralHandlingSpinBox *kcfg_autoUpdateInterval;
    QGridLayout *gridLayout;
    QLabel *label;
    QLabel *m_last_updated;
    QLabel *label_2;
    QLabel *m_next_update;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *IPBlockingPrefPage)
    {
        if (IPBlockingPrefPage->objectName().isEmpty())
            IPBlockingPrefPage->setObjectName("IPBlockingPrefPage");
        IPBlockingPrefPage->resize(564, 444);
        verticalLayout_2 = new QVBoxLayout(IPBlockingPrefPage);
        verticalLayout_2->setSpacing(6);
        verticalLayout_2->setContentsMargins(11, 11, 11, 11);
        verticalLayout_2->setObjectName("verticalLayout_2");
        groupBox1 = new QGroupBox(IPBlockingPrefPage);
        groupBox1->setObjectName("groupBox1");
        groupBox1->setEnabled(true);
        verticalLayout_3 = new QVBoxLayout(groupBox1);
        verticalLayout_3->setSpacing(6);
        verticalLayout_3->setContentsMargins(11, 11, 11, 11);
        verticalLayout_3->setObjectName("verticalLayout_3");
        kcfg_useLevel1 = new QCheckBox(groupBox1);
        kcfg_useLevel1->setObjectName("kcfg_useLevel1");

        verticalLayout_3->addWidget(kcfg_useLevel1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        textLabel1_3 = new QLabel(groupBox1);
        textLabel1_3->setObjectName("textLabel1_3");
        textLabel1_3->setWordWrap(false);

        hboxLayout->addWidget(textLabel1_3);

        kcfg_filterURL = new KUrlRequester(groupBox1);
        kcfg_filterURL->setObjectName("kcfg_filterURL");

        hboxLayout->addWidget(kcfg_filterURL);


        verticalLayout_3->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName("hboxLayout1");
        spacerItem = new QSpacerItem(361, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem);

        m_download = new QPushButton(groupBox1);
        m_download->setObjectName("m_download");

        hboxLayout1->addWidget(m_download);


        verticalLayout_3->addLayout(hboxLayout1);

        textLabel1_2 = new QLabel(groupBox1);
        textLabel1_2->setObjectName("textLabel1_2");
        textLabel1_2->setWordWrap(false);

        verticalLayout_3->addWidget(textLabel1_2);

        m_status = new QLabel(groupBox1);
        m_status->setObjectName("m_status");
        m_status->setWordWrap(false);

        verticalLayout_3->addWidget(m_status);


        verticalLayout_2->addWidget(groupBox1);

        m_auto_update_group_box = new QGroupBox(IPBlockingPrefPage);
        m_auto_update_group_box->setObjectName("m_auto_update_group_box");
        verticalLayout = new QVBoxLayout(m_auto_update_group_box);
        verticalLayout->setSpacing(6);
        verticalLayout->setContentsMargins(11, 11, 11, 11);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_autoUpdate = new QCheckBox(m_auto_update_group_box);
        kcfg_autoUpdate->setObjectName("kcfg_autoUpdate");

        horizontalLayout->addWidget(kcfg_autoUpdate);

        kcfg_autoUpdateInterval = new KPluralHandlingSpinBox(m_auto_update_group_box);
        kcfg_autoUpdateInterval->setObjectName("kcfg_autoUpdateInterval");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_autoUpdateInterval->sizePolicy().hasHeightForWidth());
        kcfg_autoUpdateInterval->setSizePolicy(sizePolicy);
        kcfg_autoUpdateInterval->setMinimumSize(QSize(12, 0));
        kcfg_autoUpdateInterval->setMinimum(1);
        kcfg_autoUpdateInterval->setMaximum(100000);
        kcfg_autoUpdateInterval->setValue(5);

        horizontalLayout->addWidget(kcfg_autoUpdateInterval);


        verticalLayout->addLayout(horizontalLayout);

        gridLayout = new QGridLayout();
        gridLayout->setSpacing(6);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(m_auto_update_group_box);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        m_last_updated = new QLabel(m_auto_update_group_box);
        m_last_updated->setObjectName("m_last_updated");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_last_updated->sizePolicy().hasHeightForWidth());
        m_last_updated->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(m_last_updated, 0, 1, 1, 1);

        label_2 = new QLabel(m_auto_update_group_box);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        m_next_update = new QLabel(m_auto_update_group_box);
        m_next_update->setObjectName("m_next_update");
        sizePolicy1.setHeightForWidth(m_next_update->sizePolicy().hasHeightForWidth());
        m_next_update->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(m_next_update, 1, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);


        verticalLayout_2->addWidget(m_auto_update_group_box);

        spacerItem1 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(spacerItem1);


        retranslateUi(IPBlockingPrefPage);
        QObject::connect(kcfg_autoUpdate, SIGNAL(toggled(bool)), kcfg_autoUpdateInterval, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_useLevel1, &QCheckBox::toggled, m_auto_update_group_box, &QGroupBox::setEnabled);

        QMetaObject::connectSlotsByName(IPBlockingPrefPage);
    } // setupUi

    void retranslateUi(QWidget *IPBlockingPrefPage)
    {
        IPBlockingPrefPage->setWindowTitle(tr2i18n("IPBlocking Preferences", nullptr));
        groupBox1->setTitle(tr2i18n("PeerGuardian Filter File ", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_useLevel1->setToolTip(tr2i18n("Enable this if you want the IP filter plugin to work.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_useLevel1->setText(tr2i18n("Use PeerGuardian filter", nullptr));
#if QT_CONFIG(shortcut)
        kcfg_useLevel1->setShortcut(QString());
#endif // QT_CONFIG(shortcut)
        textLabel1_3->setText(tr2i18n("IP filter file:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_filterURL->setToolTip(tr2i18n("Filter file to use, this can be a local file or a remote file.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        m_download->setToolTip(tr2i18n("Download and convert the IP filter file.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_download->setText(tr2i18n("Dow&nload/Convert", nullptr));
        textLabel1_2->setText(tr2i18n("Download PeerGuardian filter from bluetack.co.uk or iblocklist.org.\n"
"NOTE: archive files like zip and tar.gz or tar.bz2 are supported.", nullptr));
        m_status->setText(QString());
        m_auto_update_group_box->setTitle(tr2i18n("Automatic Update", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_autoUpdate->setToolTip(tr2i18n("Enable this if you want to automatically update the filter file.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_autoUpdate->setText(tr2i18n("Update file every:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_autoUpdateInterval->setToolTip(tr2i18n("Update interval in days.", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Last updated:", nullptr));
        m_last_updated->setText(tr2i18n("TextLabel", "KDE::DoNotExtract"));
        label_2->setText(tr2i18n("Next update:", nullptr));
        m_next_update->setText(tr2i18n("TextLabel", "KDE::DoNotExtract"));
    } // retranslateUi

};

namespace Ui {
    class IPBlockingPrefPage: public Ui_IPBlockingPrefPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IPBLOCKINGPREFPAGE_H

