/********************************************************************************
** Form generated from reading UI file 'fileselectdlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FILESELECTDLG_H
#define UI_FILESELECTDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_FileSelectDlg
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *hboxLayout;
    QLabel *textLabel1_2;
    KUrlRequester *m_downloadLocation;
    QToolButton *m_download_location_history;
    QHBoxLayout *hboxLayout1;
    QCheckBox *m_moveCompleted;
    KUrlRequester *m_completedLocation;
    QToolButton *m_move_when_completed_history;
    QHBoxLayout *horizontalLayout;
    QToolButton *m_tree;
    QToolButton *m_list;
    QLineEdit *m_filter;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *hboxLayout2;
    QTreeView *m_file_view;
    QVBoxLayout *vboxLayout;
    QPushButton *m_select_all;
    QPushButton *m_select_none;
    QPushButton *m_invert_selection;
    QPushButton *m_collapse_all;
    QPushButton *m_expand_all;
    QSpacerItem *spacerItem;
    QLabel *m_existing_found;
    QHBoxLayout *horizontalLayout_3;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_2;
    QLabel *textLabel2;
    QComboBox *m_cmbGroups;
    QSpacerItem *horizontalSpacer_2;
    QCheckBox *m_chkStartTorrent;
    QCheckBox *m_skip_data_check;
    QGroupBox *groupBox1;
    QHBoxLayout *hboxLayout3;
    QVBoxLayout *vboxLayout1;
    QLabel *textLabel1;
    QLabel *textLabel3;
    QLabel *textLabel6;
    QVBoxLayout *vboxLayout2;
    QLabel *lblRequired;
    QLabel *lblFree;
    QLabel *lblStatus;
    QSpacerItem *spacerItem1;
    QDialogButtonBox *buttonBox;
    QFrame *line;

    void setupUi(QWidget *FileSelectDlg)
    {
        if (FileSelectDlg->objectName().isEmpty())
            FileSelectDlg->setObjectName("FileSelectDlg");
        FileSelectDlg->resize(491, 551);
        verticalLayout_2 = new QVBoxLayout(FileSelectDlg);
        verticalLayout_2->setSpacing(6);
        verticalLayout_2->setContentsMargins(11, 11, 11, 11);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(4, 4, 4, 4);
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        textLabel1_2 = new QLabel(FileSelectDlg);
        textLabel1_2->setObjectName("textLabel1_2");
        textLabel1_2->setWordWrap(false);

        hboxLayout->addWidget(textLabel1_2);

        m_downloadLocation = new KUrlRequester(FileSelectDlg);
        m_downloadLocation->setObjectName("m_downloadLocation");

        hboxLayout->addWidget(m_downloadLocation);

        m_download_location_history = new QToolButton(FileSelectDlg);
        m_download_location_history->setObjectName("m_download_location_history");

        hboxLayout->addWidget(m_download_location_history);


        verticalLayout_2->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName("hboxLayout1");
        m_moveCompleted = new QCheckBox(FileSelectDlg);
        m_moveCompleted->setObjectName("m_moveCompleted");

        hboxLayout1->addWidget(m_moveCompleted);

        m_completedLocation = new KUrlRequester(FileSelectDlg);
        m_completedLocation->setObjectName("m_completedLocation");

        hboxLayout1->addWidget(m_completedLocation);

        m_move_when_completed_history = new QToolButton(FileSelectDlg);
        m_move_when_completed_history->setObjectName("m_move_when_completed_history");

        hboxLayout1->addWidget(m_move_when_completed_history);


        verticalLayout_2->addLayout(hboxLayout1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName("horizontalLayout");
        m_tree = new QToolButton(FileSelectDlg);
        m_tree->setObjectName("m_tree");

        horizontalLayout->addWidget(m_tree);

        m_list = new QToolButton(FileSelectDlg);
        m_list->setObjectName("m_list");

        horizontalLayout->addWidget(m_list);

        m_filter = new QLineEdit(FileSelectDlg);
        m_filter->setObjectName("m_filter");

        horizontalLayout->addWidget(m_filter);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout_2->addLayout(horizontalLayout);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setSpacing(6);
        hboxLayout2->setObjectName("hboxLayout2");
        m_file_view = new QTreeView(FileSelectDlg);
        m_file_view->setObjectName("m_file_view");
        m_file_view->setUniformRowHeights(true);

        hboxLayout2->addWidget(m_file_view);

        vboxLayout = new QVBoxLayout();
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName("vboxLayout");
        m_select_all = new QPushButton(FileSelectDlg);
        m_select_all->setObjectName("m_select_all");

        vboxLayout->addWidget(m_select_all);

        m_select_none = new QPushButton(FileSelectDlg);
        m_select_none->setObjectName("m_select_none");

        vboxLayout->addWidget(m_select_none);

        m_invert_selection = new QPushButton(FileSelectDlg);
        m_invert_selection->setObjectName("m_invert_selection");

        vboxLayout->addWidget(m_invert_selection);

        m_collapse_all = new QPushButton(FileSelectDlg);
        m_collapse_all->setObjectName("m_collapse_all");

        vboxLayout->addWidget(m_collapse_all);

        m_expand_all = new QPushButton(FileSelectDlg);
        m_expand_all->setObjectName("m_expand_all");

        vboxLayout->addWidget(m_expand_all);

        spacerItem = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem);


        hboxLayout2->addLayout(vboxLayout);


        verticalLayout_2->addLayout(hboxLayout2);

        m_existing_found = new QLabel(FileSelectDlg);
        m_existing_found->setObjectName("m_existing_found");

        verticalLayout_2->addWidget(m_existing_found);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(6);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        groupBox = new QGroupBox(FileSelectDlg);
        groupBox->setObjectName("groupBox");
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setSpacing(6);
        verticalLayout->setContentsMargins(11, 11, 11, 11);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(6);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        textLabel2 = new QLabel(groupBox);
        textLabel2->setObjectName("textLabel2");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(textLabel2->sizePolicy().hasHeightForWidth());
        textLabel2->setSizePolicy(sizePolicy);
        textLabel2->setWordWrap(false);

        horizontalLayout_2->addWidget(textLabel2);

        m_cmbGroups = new QComboBox(groupBox);
        m_cmbGroups->setObjectName("m_cmbGroups");

        horizontalLayout_2->addWidget(m_cmbGroups);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout_2);

        m_chkStartTorrent = new QCheckBox(groupBox);
        m_chkStartTorrent->setObjectName("m_chkStartTorrent");
        m_chkStartTorrent->setEnabled(true);
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_chkStartTorrent->sizePolicy().hasHeightForWidth());
        m_chkStartTorrent->setSizePolicy(sizePolicy1);
        m_chkStartTorrent->setChecked(true);

        verticalLayout->addWidget(m_chkStartTorrent);

        m_skip_data_check = new QCheckBox(groupBox);
        m_skip_data_check->setObjectName("m_skip_data_check");

        verticalLayout->addWidget(m_skip_data_check);


        horizontalLayout_3->addWidget(groupBox);

        groupBox1 = new QGroupBox(FileSelectDlg);
        groupBox1->setObjectName("groupBox1");
        hboxLayout3 = new QHBoxLayout(groupBox1);
        hboxLayout3->setSpacing(6);
        hboxLayout3->setContentsMargins(11, 11, 11, 11);
        hboxLayout3->setObjectName("hboxLayout3");
        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setSpacing(6);
        vboxLayout1->setObjectName("vboxLayout1");
        textLabel1 = new QLabel(groupBox1);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setWordWrap(false);

        vboxLayout1->addWidget(textLabel1);

        textLabel3 = new QLabel(groupBox1);
        textLabel3->setObjectName("textLabel3");
        textLabel3->setWordWrap(false);

        vboxLayout1->addWidget(textLabel3);

        textLabel6 = new QLabel(groupBox1);
        textLabel6->setObjectName("textLabel6");
        textLabel6->setWordWrap(false);

        vboxLayout1->addWidget(textLabel6);


        hboxLayout3->addLayout(vboxLayout1);

        vboxLayout2 = new QVBoxLayout();
        vboxLayout2->setSpacing(6);
        vboxLayout2->setObjectName("vboxLayout2");
        lblRequired = new QLabel(groupBox1);
        lblRequired->setObjectName("lblRequired");
        lblRequired->setWordWrap(false);

        vboxLayout2->addWidget(lblRequired);

        lblFree = new QLabel(groupBox1);
        lblFree->setObjectName("lblFree");
        lblFree->setWordWrap(false);

        vboxLayout2->addWidget(lblFree);

        lblStatus = new QLabel(groupBox1);
        lblStatus->setObjectName("lblStatus");
        lblStatus->setWordWrap(false);

        vboxLayout2->addWidget(lblStatus);


        hboxLayout3->addLayout(vboxLayout2);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout3->addItem(spacerItem1);


        horizontalLayout_3->addWidget(groupBox1);


        verticalLayout_2->addLayout(horizontalLayout_3);

        buttonBox = new QDialogButtonBox(FileSelectDlg);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        verticalLayout_2->addWidget(buttonBox);

        line = new QFrame(FileSelectDlg);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_2->addWidget(line);

        QWidget::setTabOrder(m_downloadLocation, m_cmbGroups);
        QWidget::setTabOrder(m_cmbGroups, m_chkStartTorrent);
        QWidget::setTabOrder(m_chkStartTorrent, m_select_all);
        QWidget::setTabOrder(m_select_all, m_select_none);
        QWidget::setTabOrder(m_select_none, m_invert_selection);

        retranslateUi(FileSelectDlg);

        QMetaObject::connectSlotsByName(FileSelectDlg);
    } // setupUi

    void retranslateUi(QWidget *FileSelectDlg)
    {
        FileSelectDlg->setWindowTitle(tr2i18n("Select Which Files You Want to Download", nullptr));
        textLabel1_2->setText(tr2i18n("Download to:", nullptr));
#if QT_CONFIG(tooltip)
        m_download_location_history->setToolTip(tr2i18n("History of all recently used download locations", nullptr));
#endif // QT_CONFIG(tooltip)
        m_download_location_history->setText(tr2i18n("...", nullptr));
#if QT_CONFIG(tooltip)
        m_moveCompleted->setToolTip(tr2i18n("Moves the files to the specified location when the torrent finishes downloading.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_moveCompleted->setText(tr2i18n("Move when completed to:", nullptr));
#if QT_CONFIG(tooltip)
        m_move_when_completed_history->setToolTip(tr2i18n("History of all recently used move when completed locations", nullptr));
#endif // QT_CONFIG(tooltip)
        m_move_when_completed_history->setText(tr2i18n("...", nullptr));
        m_tree->setText(tr2i18n("...", nullptr));
        m_list->setText(tr2i18n("...", nullptr));
#if QT_CONFIG(tooltip)
        m_file_view->setToolTip(tr2i18n("All files in the torrent, you can change them by double clicking on them.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_select_all->setText(tr2i18n("Select &All", nullptr));
        m_select_none->setText(tr2i18n("Select &None", nullptr));
        m_invert_selection->setText(tr2i18n("Invert Selection", nullptr));
        m_collapse_all->setText(tr2i18n("Collapse All", nullptr));
        m_expand_all->setText(tr2i18n("Expand All", nullptr));
        m_existing_found->setText(tr2i18n("No existing files are found", nullptr));
        groupBox->setTitle(tr2i18n("Options", nullptr));
        textLabel2->setText(tr2i18n("Group:", nullptr));
        m_chkStartTorrent->setText(tr2i18n("Start torrent", nullptr));
#if QT_CONFIG(tooltip)
        m_skip_data_check->setToolTip(tr2i18n("<p>When existing files have been found, skip the data check and assume that the files are fully downloaded.</p>\n"
"<p><span style=\" font-weight:600;\">Note: </span>only do this when you are absolutely sure.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        m_skip_data_check->setText(tr2i18n("Skip data check if existing files are found", nullptr));
        groupBox1->setTitle(tr2i18n("Disk Space", nullptr));
        textLabel1->setText(tr2i18n("Required:", nullptr));
        textLabel3->setText(tr2i18n("Available:", nullptr));
        textLabel6->setText(tr2i18n("After download:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class FileSelectDlg: public Ui_FileSelectDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FILESELECTDLG_H

