/********************************************************************************
** Form generated from reading UI file 'iwprefpage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IWPREFPAGE_H
#define UI_IWPREFPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_IWPrefPage
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *groupBox;
    QVBoxLayout *vboxLayout1;
    QCheckBox *kcfg_showPeerView;
    QCheckBox *kcfg_showChunkView;
    QCheckBox *kcfg_showTrackersView;
    QCheckBox *kcfg_showWebSeedsTab;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout;
    QLabel *label;
    KColorButton *kcfg_firstColor;
    QLabel *label_3;
    KColorButton *kcfg_lastColor;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *IWPrefPage)
    {
        if (IWPrefPage->objectName().isEmpty())
            IWPrefPage->setObjectName("IWPrefPage");
        IWPrefPage->resize(400, 471);
        vboxLayout = new QVBoxLayout(IWPrefPage);
        vboxLayout->setObjectName("vboxLayout");
        groupBox = new QGroupBox(IWPrefPage);
        groupBox->setObjectName("groupBox");
        vboxLayout1 = new QVBoxLayout(groupBox);
        vboxLayout1->setObjectName("vboxLayout1");
        kcfg_showPeerView = new QCheckBox(groupBox);
        kcfg_showPeerView->setObjectName("kcfg_showPeerView");

        vboxLayout1->addWidget(kcfg_showPeerView);

        kcfg_showChunkView = new QCheckBox(groupBox);
        kcfg_showChunkView->setObjectName("kcfg_showChunkView");

        vboxLayout1->addWidget(kcfg_showChunkView);

        kcfg_showTrackersView = new QCheckBox(groupBox);
        kcfg_showTrackersView->setObjectName("kcfg_showTrackersView");

        vboxLayout1->addWidget(kcfg_showTrackersView);

        kcfg_showWebSeedsTab = new QCheckBox(groupBox);
        kcfg_showWebSeedsTab->setObjectName("kcfg_showWebSeedsTab");

        vboxLayout1->addWidget(kcfg_showWebSeedsTab);


        vboxLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(IWPrefPage);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout = new QGridLayout(groupBox_2);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(groupBox_2);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        kcfg_firstColor = new KColorButton(groupBox_2);
        kcfg_firstColor->setObjectName("kcfg_firstColor");

        gridLayout->addWidget(kcfg_firstColor, 0, 1, 1, 1);

        label_3 = new QLabel(groupBox_2);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        kcfg_lastColor = new KColorButton(groupBox_2);
        kcfg_lastColor->setObjectName("kcfg_lastColor");

        gridLayout->addWidget(kcfg_lastColor, 1, 1, 1, 1);


        vboxLayout->addWidget(groupBox_2);

        spacerItem = new QSpacerItem(392, 51, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem);


        retranslateUi(IWPrefPage);

        QMetaObject::connectSlotsByName(IWPrefPage);
    } // setupUi

    void retranslateUi(QWidget *IWPrefPage)
    {
        groupBox->setTitle(tr2i18n("Tabs", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_showPeerView->setToolTip(tr2i18n("Whether or not to show the peers tab in the bottom of the window.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_showPeerView->setText(tr2i18n("Show list of peers", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_showChunkView->setToolTip(tr2i18n("Whether or not to show the chunks tab in the bottom of the window.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_showChunkView->setText(tr2i18n("Show list of chunks currently downloading", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_showTrackersView->setToolTip(tr2i18n("Whether or not to show the trackers tab in the bottom of the window.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_showTrackersView->setText(tr2i18n("Show list of trackers", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_showWebSeedsTab->setToolTip(tr2i18n("Whether or not to show the webseeds tab at the bottom of the window.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_showWebSeedsTab->setText(tr2i18n("Show list of webseeds", nullptr));
        groupBox_2->setTitle(tr2i18n("File Priority Colors", nullptr));
        label->setText(tr2i18n("First priority:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_firstColor->setToolTip(tr2i18n("Color to use for first priority files.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_3->setText(tr2i18n("Last priority:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_lastColor->setToolTip(tr2i18n("Color to use for last priority files.", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)IWPrefPage;
    } // retranslateUi

};

namespace Ui {
    class IWPrefPage: public Ui_IWPrefPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IWPREFPAGE_H

