/********************************************************************************
** Form generated from reading UI file 'bwprefpage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BWPREFPAGE_H
#define UI_BWPREFPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_BWPrefPage
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_screensaverLimits;
    QHBoxLayout *horizontalLayout;
    QGridLayout *gridLayout_2;
    QLabel *label;
    QSpinBox *kcfg_screensaverUploadLimit;
    QLabel *label_6;
    QSpinBox *kcfg_screensaverDownloadLimit;
    QSpacerItem *horizontalSpacer;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLabel *label_2;
    KColorButton *kcfg_scheduleBackgroundColor;
    QLabel *label_3;
    KColorButton *kcfg_scheduleLineColor;
    QLabel *label_4;
    KColorButton *kcfg_itemColor;
    QLabel *label_5;
    KColorButton *kcfg_suspendedColor;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *BWPrefPage)
    {
        if (BWPrefPage->objectName().isEmpty())
            BWPrefPage->setObjectName("BWPrefPage");
        BWPrefPage->resize(473, 385);
        verticalLayout_2 = new QVBoxLayout(BWPrefPage);
        verticalLayout_2->setObjectName("verticalLayout_2");
        groupBox_2 = new QGroupBox(BWPrefPage);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout = new QVBoxLayout(groupBox_2);
        verticalLayout->setObjectName("verticalLayout");
        kcfg_screensaverLimits = new QCheckBox(groupBox_2);
        kcfg_screensaverLimits->setObjectName("kcfg_screensaverLimits");

        verticalLayout->addWidget(kcfg_screensaverLimits);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        label = new QLabel(groupBox_2);
        label->setObjectName("label");

        gridLayout_2->addWidget(label, 0, 0, 1, 1);

        kcfg_screensaverUploadLimit = new QSpinBox(groupBox_2);
        kcfg_screensaverUploadLimit->setObjectName("kcfg_screensaverUploadLimit");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_screensaverUploadLimit->sizePolicy().hasHeightForWidth());
        kcfg_screensaverUploadLimit->setSizePolicy(sizePolicy);
        kcfg_screensaverUploadLimit->setMaximum(100000000);

        gridLayout_2->addWidget(kcfg_screensaverUploadLimit, 0, 1, 1, 1);

        label_6 = new QLabel(groupBox_2);
        label_6->setObjectName("label_6");

        gridLayout_2->addWidget(label_6, 1, 0, 1, 1);

        kcfg_screensaverDownloadLimit = new QSpinBox(groupBox_2);
        kcfg_screensaverDownloadLimit->setObjectName("kcfg_screensaverDownloadLimit");
        sizePolicy.setHeightForWidth(kcfg_screensaverDownloadLimit->sizePolicy().hasHeightForWidth());
        kcfg_screensaverDownloadLimit->setSizePolicy(sizePolicy);
        kcfg_screensaverDownloadLimit->setMaximum(100000000);

        gridLayout_2->addWidget(kcfg_screensaverDownloadLimit, 1, 1, 1, 1);


        horizontalLayout->addLayout(gridLayout_2);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);


        verticalLayout_2->addWidget(groupBox_2);

        groupBox = new QGroupBox(BWPrefPage);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 0, 0, 1, 1);

        kcfg_scheduleBackgroundColor = new KColorButton(groupBox);
        kcfg_scheduleBackgroundColor->setObjectName("kcfg_scheduleBackgroundColor");

        gridLayout->addWidget(kcfg_scheduleBackgroundColor, 0, 1, 1, 1);

        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        kcfg_scheduleLineColor = new KColorButton(groupBox);
        kcfg_scheduleLineColor->setObjectName("kcfg_scheduleLineColor");

        gridLayout->addWidget(kcfg_scheduleLineColor, 1, 1, 1, 1);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 2, 0, 1, 1);

        kcfg_itemColor = new KColorButton(groupBox);
        kcfg_itemColor->setObjectName("kcfg_itemColor");

        gridLayout->addWidget(kcfg_itemColor, 2, 1, 1, 1);

        label_5 = new QLabel(groupBox);
        label_5->setObjectName("label_5");

        gridLayout->addWidget(label_5, 3, 0, 1, 1);

        kcfg_suspendedColor = new KColorButton(groupBox);
        kcfg_suspendedColor->setObjectName("kcfg_suspendedColor");

        gridLayout->addWidget(kcfg_suspendedColor, 3, 1, 1, 1);


        verticalLayout_2->addWidget(groupBox);

        verticalSpacer = new QSpacerItem(20, 46, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);


        retranslateUi(BWPrefPage);
        QObject::connect(kcfg_screensaverLimits, &QCheckBox::toggled, kcfg_screensaverUploadLimit, &QSpinBox::setEnabled);
        QObject::connect(kcfg_screensaverLimits, &QCheckBox::toggled, kcfg_screensaverDownloadLimit, &QSpinBox::setEnabled);

        QMetaObject::connectSlotsByName(BWPrefPage);
    } // setupUi

    void retranslateUi(QWidget *BWPrefPage)
    {
        groupBox_2->setTitle(tr2i18n("Special Limits", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_screensaverLimits->setToolTip(tr2i18n("Use these global limits when the screensaver is activated, instead of the ones configured in the network settings.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_screensaverLimits->setText(tr2i18n("Use different speed limits when the screensaver is activated", nullptr));
        label->setText(tr2i18n("Maximum upload speed:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_screensaverUploadLimit->setToolTip(tr2i18n("Global upload limit when the screensaver is activated.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_screensaverUploadLimit->setSpecialValueText(tr2i18n("No limit", nullptr));
        kcfg_screensaverUploadLimit->setSuffix(tr2i18n(" KiB/s", nullptr));
        label_6->setText(tr2i18n("Maximum download speed:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_screensaverDownloadLimit->setToolTip(tr2i18n("Global download limit when the screensaver is activated.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_screensaverDownloadLimit->setSpecialValueText(tr2i18n("No limit", nullptr));
        kcfg_screensaverDownloadLimit->setSuffix(tr2i18n(" KiB/s", nullptr));
        groupBox->setTitle(tr2i18n("Colors", nullptr));
        label_2->setText(tr2i18n("Schedule background color:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_scheduleBackgroundColor->setToolTip(tr2i18n("Color of the schedule background.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_3->setText(tr2i18n("Schedule line color:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_scheduleLineColor->setToolTip(tr2i18n("Color of all lines on the schedule.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_4->setText(tr2i18n("Schedule Item color:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_itemColor->setToolTip(tr2i18n("Color of each normal item on the schedule.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_5->setText(tr2i18n("Suspended schedule item color:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_suspendedColor->setToolTip(tr2i18n("Color of each suspended item on the schedule.", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)BWPrefPage;
    } // retranslateUi

};

namespace Ui {
    class BWPrefPage: public Ui_BWPrefPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BWPREFPAGE_H

