/********************************************************************************
** Form generated from reading UI file 'magnetgeneratorprefwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAGNETGENERATORPREFWIDGET_H
#define UI_MAGNETGENERATORPREFWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_MagnetGeneratorPrefWidget
{
public:
    QVBoxLayout *verticalLayout_x3;
    QGroupBox *groupBox_x2;
    QVBoxLayout *verticalLayout_x2;
    QGridLayout *gridLayout;
    QCheckBox *kcfg_torrenttracker;
    QCheckBox *kcfg_customtracker;
    QLineEdit *kcfg_tr;
    QCheckBox *kcfg_dn;
    QCheckBox *kcfg_onlypublic;
    QCheckBox *kcfg_popup;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *MagnetGeneratorPrefWidget)
    {
        if (MagnetGeneratorPrefWidget->objectName().isEmpty())
            MagnetGeneratorPrefWidget->setObjectName("MagnetGeneratorPrefWidget");
        MagnetGeneratorPrefWidget->resize(459, 317);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(MagnetGeneratorPrefWidget->sizePolicy().hasHeightForWidth());
        MagnetGeneratorPrefWidget->setSizePolicy(sizePolicy);
        MagnetGeneratorPrefWidget->setMinimumSize(QSize(0, 0));
        verticalLayout_x3 = new QVBoxLayout(MagnetGeneratorPrefWidget);
        verticalLayout_x3->setSpacing(6);
        verticalLayout_x3->setContentsMargins(11, 11, 11, 11);
        verticalLayout_x3->setObjectName("verticalLayout_x3");
        groupBox_x2 = new QGroupBox(MagnetGeneratorPrefWidget);
        groupBox_x2->setObjectName("groupBox_x2");
        verticalLayout_x2 = new QVBoxLayout(groupBox_x2);
        verticalLayout_x2->setSpacing(6);
        verticalLayout_x2->setContentsMargins(11, 11, 11, 11);
        verticalLayout_x2->setObjectName("verticalLayout_x2");
        gridLayout = new QGridLayout();
        gridLayout->setSpacing(6);
        gridLayout->setObjectName("gridLayout");
        kcfg_torrenttracker = new QCheckBox(groupBox_x2);
        kcfg_torrenttracker->setObjectName("kcfg_torrenttracker");

        gridLayout->addWidget(kcfg_torrenttracker, 1, 0, 1, 1);

        kcfg_customtracker = new QCheckBox(groupBox_x2);
        kcfg_customtracker->setObjectName("kcfg_customtracker");

        gridLayout->addWidget(kcfg_customtracker, 2, 0, 1, 1);

        kcfg_tr = new QLineEdit(groupBox_x2);
        kcfg_tr->setObjectName("kcfg_tr");

        gridLayout->addWidget(kcfg_tr, 2, 1, 1, 1);

        kcfg_dn = new QCheckBox(groupBox_x2);
        kcfg_dn->setObjectName("kcfg_dn");

        gridLayout->addWidget(kcfg_dn, 3, 0, 1, 1);

        kcfg_onlypublic = new QCheckBox(groupBox_x2);
        kcfg_onlypublic->setObjectName("kcfg_onlypublic");

        gridLayout->addWidget(kcfg_onlypublic, 4, 0, 1, 1);

        kcfg_popup = new QCheckBox(groupBox_x2);
        kcfg_popup->setObjectName("kcfg_popup");

        gridLayout->addWidget(kcfg_popup, 5, 0, 1, 1);


        verticalLayout_x2->addLayout(gridLayout);


        verticalLayout_x3->addWidget(groupBox_x2);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_x3->addItem(spacerItem);


        retranslateUi(MagnetGeneratorPrefWidget);

        QMetaObject::connectSlotsByName(MagnetGeneratorPrefWidget);
    } // setupUi

    void retranslateUi(QWidget *MagnetGeneratorPrefWidget)
    {
        MagnetGeneratorPrefWidget->setWindowTitle(tr2i18n("Magnet Generator Preferences", nullptr));
        groupBox_x2->setTitle(tr2i18n("Magnet Generator", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_torrenttracker->setToolTip(tr2i18n("Grabs a tracker from the torrent file", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_torrenttracker->setText(tr2i18n("Add a tracker from the torrent file", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_customtracker->setToolTip(tr2i18n("Define what tracker to add", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_customtracker->setText(tr2i18n("Add a custom tracker URL", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_tr->setToolTip(tr2i18n("The tracker URL that will be a part of the magnet link", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_dn->setToolTip(tr2i18n("Add the torrent name in the URI", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_dn->setText(tr2i18n("Add name", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_onlypublic->setToolTip(tr2i18n("Only enable on public torrents", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_onlypublic->setText(tr2i18n("Disable the menu item for private torrents", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_popup->setToolTip(tr2i18n("Give feedback in form of a popup", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_popup->setText(tr2i18n("Show popup", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MagnetGeneratorPrefWidget: public Ui_MagnetGeneratorPrefWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MAGNETGENERATORPREFWIDGET_H

