/********************************************************************************
** Form generated from reading UI file 'missingfilesdlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MISSINGFILESDLG_H
#define UI_MISSINGFILESDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_MissingFilesDlg
{
public:
    QVBoxLayout *vboxLayout;
    QLabel *m_text;
    QHBoxLayout *hboxLayout;
    QListWidget *m_file_list;
    QVBoxLayout *vboxLayout1;
    QPushButton *m_recreate;
    QPushButton *m_dnd;
    QPushButton *m_select_new;
    QSpacerItem *spacerItem;
    QPushButton *m_cancel;

    void setupUi(QDialog *MissingFilesDlg)
    {
        if (MissingFilesDlg->objectName().isEmpty())
            MissingFilesDlg->setObjectName("MissingFilesDlg");
        MissingFilesDlg->resize(515, 268);
        vboxLayout = new QVBoxLayout(MissingFilesDlg);
        vboxLayout->setObjectName("vboxLayout");
        m_text = new QLabel(MissingFilesDlg);
        m_text->setObjectName("m_text");

        vboxLayout->addWidget(m_text);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        m_file_list = new QListWidget(MissingFilesDlg);
        m_file_list->setObjectName("m_file_list");

        hboxLayout->addWidget(m_file_list);

        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName("vboxLayout1");
        m_recreate = new QPushButton(MissingFilesDlg);
        m_recreate->setObjectName("m_recreate");

        vboxLayout1->addWidget(m_recreate);

        m_dnd = new QPushButton(MissingFilesDlg);
        m_dnd->setObjectName("m_dnd");

        vboxLayout1->addWidget(m_dnd);

        m_select_new = new QPushButton(MissingFilesDlg);
        m_select_new->setObjectName("m_select_new");

        vboxLayout1->addWidget(m_select_new);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout1->addItem(spacerItem);

        m_cancel = new QPushButton(MissingFilesDlg);
        m_cancel->setObjectName("m_cancel");

        vboxLayout1->addWidget(m_cancel);


        hboxLayout->addLayout(vboxLayout1);


        vboxLayout->addLayout(hboxLayout);


        retranslateUi(MissingFilesDlg);

        QMetaObject::connectSlotsByName(MissingFilesDlg);
    } // setupUi

    void retranslateUi(QDialog *MissingFilesDlg)
    {
        MissingFilesDlg->setWindowTitle(tr2i18n("Files are missing", nullptr));
        m_text->setText(tr2i18n("The following files are missing:", nullptr));
#if QT_CONFIG(tooltip)
        m_recreate->setToolTip(tr2i18n("They are no longer there, recreate them.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_recreate->setText(tr2i18n("Recreate", nullptr));
#if QT_CONFIG(tooltip)
        m_dnd->setToolTip(tr2i18n("Do not download the missing files.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_dnd->setText(tr2i18n("Do Not Download", nullptr));
#if QT_CONFIG(tooltip)
        m_select_new->setToolTip(tr2i18n("The files have been moved to another location, select the new location.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_select_new->setText(tr2i18n("Select New Location", nullptr));
#if QT_CONFIG(tooltip)
        m_cancel->setToolTip(tr2i18n("Cancel, do not start the torrent.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_cancel->setText(tr2i18n("Cancel", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MissingFilesDlg: public Ui_MissingFilesDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MISSINGFILESDLG_H

