/****************************************************************************
** Meta object code from reading C++ file 'mediaplayeractivity.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../ktorrent-26.04.3/plugins/mediaplayer/mediaplayeractivity.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mediaplayeractivity.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2kt19MediaPlayerActivityE_t {};
} // unnamed namespace

template <> constexpr inline auto kt::MediaPlayerActivity::qt_create_metaobjectdata<qt_meta_tag_ZN2kt19MediaPlayerActivityE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "kt::MediaPlayerActivity",
        "play",
        "",
        "MediaFileRef",
        "file",
        "pause",
        "stop",
        "prev",
        "next",
        "enableActions",
        "flags",
        "onSelectionChanged",
        "openVideo",
        "closeVideo",
        "setVideoFullScreen",
        "on",
        "onDoubleClicked",
        "randomPlayActivated",
        "playNextMedia",
        "showVideo",
        "closeTab",
        "currentTabChanged",
        "idx"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'play'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'play'
        QtMocHelpers::SlotData<void(const MediaFileRef &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'pause'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'prev'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'next'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'enableActions'
        QtMocHelpers::SlotData<void(unsigned int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 10 },
        }}),
        // Slot 'onSelectionChanged'
        QtMocHelpers::SlotData<void(const MediaFileRef &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'openVideo'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'closeVideo'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setVideoFullScreen'
        QtMocHelpers::SlotData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'onDoubleClicked'
        QtMocHelpers::SlotData<void(const MediaFileRef &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'randomPlayActivated'
        QtMocHelpers::SlotData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'playNextMedia'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showVideo'
        QtMocHelpers::SlotData<void(bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'closeTab'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'currentTabChanged'
        QtMocHelpers::SlotData<void(int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MediaPlayerActivity, qt_meta_tag_ZN2kt19MediaPlayerActivityE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject kt::MediaPlayerActivity::staticMetaObject = { {
    QMetaObject::SuperData::link<Activity::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt19MediaPlayerActivityE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt19MediaPlayerActivityE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2kt19MediaPlayerActivityE_t>.metaTypes,
    nullptr
} };

void kt::MediaPlayerActivity::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MediaPlayerActivity *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->play(); break;
        case 1: _t->play((*reinterpret_cast<std::add_pointer_t<MediaFileRef>>(_a[1]))); break;
        case 2: _t->pause(); break;
        case 3: _t->stop(); break;
        case 4: _t->prev(); break;
        case 5: _t->next(); break;
        case 6: _t->enableActions((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 7: _t->onSelectionChanged((*reinterpret_cast<std::add_pointer_t<MediaFileRef>>(_a[1]))); break;
        case 8: _t->openVideo(); break;
        case 9: _t->closeVideo(); break;
        case 10: _t->setVideoFullScreen((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->onDoubleClicked((*reinterpret_cast<std::add_pointer_t<MediaFileRef>>(_a[1]))); break;
        case 12: _t->randomPlayActivated((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->playNextMedia(); break;
        case 14: _t->showVideo((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->closeTab(); break;
        case 16: _t->currentTabChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *kt::MediaPlayerActivity::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kt::MediaPlayerActivity::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt19MediaPlayerActivityE_t>.strings))
        return static_cast<void*>(this);
    return Activity::qt_metacast(_clname);
}

int kt::MediaPlayerActivity::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Activity::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    return _id;
}
QT_WARNING_POP
