/****************************************************************************
** Meta object code from reading C++ file 'PlainChartDrawer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../ktorrent-26.04.3/plugins/stats/drawer/PlainChartDrawer.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'PlainChartDrawer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2kt16PlainChartDrawerE_t {};
} // unnamed namespace

template <> constexpr inline auto kt::PlainChartDrawer::qt_create_metaobjectdata<qt_meta_tag_ZN2kt16PlainChartDrawerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "kt::PlainChartDrawer",
        "Zeroed",
        "",
        "ChartDrawer*",
        "showContextMenu",
        "QPoint",
        "rP",
        "renderToImage",
        "addValue",
        "size_t",
        "idx",
        "wgtunit_t",
        "val",
        "upd",
        "addDataSet",
        "ChartDrawerData",
        "Cdd",
        "insertDataSet",
        "removeDataSet",
        "zero",
        "zeroAll",
        "setUnitName",
        "rN",
        "setPen",
        "QPen",
        "setXMax",
        "x",
        "setYMax",
        "y",
        "findSetMax",
        "setUuid",
        "QUuid",
        "rQ",
        "findUuidInSet",
        "int16_t",
        "setMaxMode",
        "MaxMode",
        "mm",
        "getUuid",
        "makeLegendString",
        "setLegend",
        "rL",
        "update",
        "enableAntiAlias",
        "aa",
        "enableBackgroundGrid",
        "bg"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Zeroed'
        QtMocHelpers::SignalData<void(ChartDrawer *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'showContextMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'renderToImage'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addValue'
        QtMocHelpers::SlotData<void(const size_t, const wgtunit_t, const bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 11, 12 }, { QMetaType::Bool, 13 },
        }}),
        // Slot 'addValue'
        QtMocHelpers::SlotData<void(const size_t, const wgtunit_t)>(8, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 11, 12 },
        }}),
        // Slot 'addDataSet'
        QtMocHelpers::SlotData<void(ChartDrawerData)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'insertDataSet'
        QtMocHelpers::SlotData<void(const size_t, ChartDrawerData)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 15, 16 },
        }}),
        // Slot 'removeDataSet'
        QtMocHelpers::SlotData<void(const size_t)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'zero'
        QtMocHelpers::SlotData<void(const size_t)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'zeroAll'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setUnitName'
        QtMocHelpers::SlotData<void(const QString &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'setPen'
        QtMocHelpers::SlotData<void(const size_t, const QPen &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 24, 6 },
        }}),
        // Slot 'setXMax'
        QtMocHelpers::SlotData<void(const wgtunit_t)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 26 },
        }}),
        // Slot 'setYMax'
        QtMocHelpers::SlotData<void(const wgtunit_t)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 28 },
        }}),
        // Slot 'findSetMax'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setUuid'
        QtMocHelpers::SlotData<void(const size_t, const QUuid &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 31, 32 },
        }}),
        // Slot 'findUuidInSet'
        QtMocHelpers::SlotData<int16_t(const QUuid &) const>(33, 2, QMC::AccessPublic, 0x80000000 | 34, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Slot 'setMaxMode'
        QtMocHelpers::SlotData<void(const MaxMode)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Slot 'getUuid'
        QtMocHelpers::SlotData<QUuid(const size_t) const>(38, 2, QMC::AccessPublic, 0x80000000 | 31, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'makeLegendString'
        QtMocHelpers::SlotData<QString()>(39, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'setLegend'
        QtMocHelpers::SlotData<void(const QString &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 41 },
        }}),
        // Slot 'update'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'enableAntiAlias'
        QtMocHelpers::SlotData<void(bool)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 44 },
        }}),
        // Slot 'enableBackgroundGrid'
        QtMocHelpers::SlotData<void(bool)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 46 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PlainChartDrawer, qt_meta_tag_ZN2kt16PlainChartDrawerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject kt::PlainChartDrawer::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt16PlainChartDrawerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt16PlainChartDrawerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2kt16PlainChartDrawerE_t>.metaTypes,
    nullptr
} };

void kt::PlainChartDrawer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlainChartDrawer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Zeroed((*reinterpret_cast<std::add_pointer_t<ChartDrawer*>>(_a[1]))); break;
        case 1: _t->showContextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 2: _t->renderToImage(); break;
        case 3: _t->addValue((*reinterpret_cast<std::add_pointer_t<size_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<wgtunit_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 4: _t->addValue((*reinterpret_cast<std::add_pointer_t<size_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<wgtunit_t>>(_a[2]))); break;
        case 5: _t->addDataSet((*reinterpret_cast<std::add_pointer_t<ChartDrawerData>>(_a[1]))); break;
        case 6: _t->insertDataSet((*reinterpret_cast<std::add_pointer_t<size_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ChartDrawerData>>(_a[2]))); break;
        case 7: _t->removeDataSet((*reinterpret_cast<std::add_pointer_t<size_t>>(_a[1]))); break;
        case 8: _t->zero((*reinterpret_cast<std::add_pointer_t<size_t>>(_a[1]))); break;
        case 9: _t->zeroAll(); break;
        case 10: _t->setUnitName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->setPen((*reinterpret_cast<std::add_pointer_t<size_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPen>>(_a[2]))); break;
        case 12: _t->setXMax((*reinterpret_cast<std::add_pointer_t<wgtunit_t>>(_a[1]))); break;
        case 13: _t->setYMax((*reinterpret_cast<std::add_pointer_t<wgtunit_t>>(_a[1]))); break;
        case 14: _t->findSetMax(); break;
        case 15: _t->setUuid((*reinterpret_cast<std::add_pointer_t<size_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[2]))); break;
        case 16: { int16_t _r = _t->findUuidInSet((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int16_t*>(_a[0]) = std::move(_r); }  break;
        case 17: _t->setMaxMode((*reinterpret_cast<std::add_pointer_t<MaxMode>>(_a[1]))); break;
        case 18: { QUuid _r = _t->getUuid((*reinterpret_cast<std::add_pointer_t<size_t>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QUuid*>(_a[0]) = std::move(_r); }  break;
        case 19: { QString _r = _t->makeLegendString();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->setLegend((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: _t->update(); break;
        case 22: _t->enableAntiAlias((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: _t->enableBackgroundGrid((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PlainChartDrawer::*)(ChartDrawer * )>(_a, &PlainChartDrawer::Zeroed, 0))
            return;
    }
}

const QMetaObject *kt::PlainChartDrawer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kt::PlainChartDrawer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt16PlainChartDrawerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ChartDrawer"))
        return static_cast< ChartDrawer*>(this);
    return QFrame::qt_metacast(_clname);
}

int kt::PlainChartDrawer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 24;
    }
    return _id;
}

// SIGNAL 0
void kt::PlainChartDrawer::Zeroed(ChartDrawer * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
