/****************************************************************************
** Meta object code from reading C++ file 'dbustorrentfilestream.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktorrent-26.04.3/libktcore/dbus/dbustorrentfilestream.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbustorrentfilestream.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2kt21DBusTorrentFileStreamE_t {};
} // unnamed namespace

template <> constexpr inline auto kt::DBusTorrentFileStream::qt_create_metaobjectdata<qt_meta_tag_ZN2kt21DBusTorrentFileStreamE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "kt::DBusTorrentFileStream",
        "D-Bus Interface",
        "org.ktorrent.torrentfilestream",
        "pos",
        "",
        "size",
        "seek",
        "bytesAvailable",
        "path",
        "currentChunk",
        "bt::Uint32",
        "read",
        "maxlen"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'pos'
        QtMocHelpers::SlotData<qint64() const>(3, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::LongLong),
        // Slot 'size'
        QtMocHelpers::SlotData<qint64() const>(5, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::LongLong),
        // Slot 'seek'
        QtMocHelpers::SlotData<bool(qint64)>(6, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::LongLong, 3 },
        }}),
        // Slot 'bytesAvailable'
        QtMocHelpers::SlotData<qint64() const>(7, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::LongLong),
        // Slot 'path'
        QtMocHelpers::SlotData<QString() const>(8, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'currentChunk'
        QtMocHelpers::SlotData<bt::Uint32() const>(9, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 10),
        // Slot 'read'
        QtMocHelpers::SlotData<QByteArray(qint64)>(11, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QByteArray, {{
            { QMetaType::LongLong, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DBusTorrentFileStream, qt_meta_tag_ZN2kt21DBusTorrentFileStreamE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject kt::DBusTorrentFileStream::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt21DBusTorrentFileStreamE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt21DBusTorrentFileStreamE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2kt21DBusTorrentFileStreamE_t>.metaTypes,
    nullptr
} };

void kt::DBusTorrentFileStream::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBusTorrentFileStream *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { qint64 _r = _t->pos();
            if (_a[0]) *reinterpret_cast<qint64*>(_a[0]) = std::move(_r); }  break;
        case 1: { qint64 _r = _t->size();
            if (_a[0]) *reinterpret_cast<qint64*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->seek((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { qint64 _r = _t->bytesAvailable();
            if (_a[0]) *reinterpret_cast<qint64*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->path();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { bt::Uint32 _r = _t->currentChunk();
            if (_a[0]) *reinterpret_cast<bt::Uint32*>(_a[0]) = std::move(_r); }  break;
        case 6: { QByteArray _r = _t->read((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QByteArray*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *kt::DBusTorrentFileStream::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kt::DBusTorrentFileStream::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt21DBusTorrentFileStreamE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int kt::DBusTorrentFileStream::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
