/****************************************************************************
** Meta object code from reading C++ file 'dbusgroup.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktorrent-26.04.3/libktcore/dbus/dbusgroup.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbusgroup.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2kt9DBusGroupE_t {};
} // unnamed namespace

template <> constexpr inline auto kt::DBusGroup::qt_create_metaobjectdata<qt_meta_tag_ZN2kt9DBusGroupE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "kt::DBusGroup",
        "D-Bus Interface",
        "org.ktorrent.group",
        "name",
        "",
        "icon",
        "defaultSaveLocation",
        "setDefaultSaveLocation",
        "dir",
        "defaultMoveOnCompletionLocation",
        "setDefaultMoveOnCompletionLocation",
        "maxShareRatio",
        "setMaxShareRatio",
        "ratio",
        "maxSeedTime",
        "setMaxSeedTime",
        "hours",
        "maxUploadSpeed",
        "setMaxUploadSpeed",
        "speed",
        "maxDownloadSpeed",
        "setMaxDownloadSpeed",
        "onlyApplyOnNewTorrents",
        "setOnlyApplyOnNewTorrents",
        "on"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'name'
        QtMocHelpers::SlotData<QString() const>(3, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'icon'
        QtMocHelpers::SlotData<QString() const>(5, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'defaultSaveLocation'
        QtMocHelpers::SlotData<QString() const>(6, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'setDefaultSaveLocation'
        QtMocHelpers::SlotData<void(const QString &)>(7, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'defaultMoveOnCompletionLocation'
        QtMocHelpers::SlotData<QString() const>(9, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'setDefaultMoveOnCompletionLocation'
        QtMocHelpers::SlotData<void(const QString &)>(10, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'maxShareRatio'
        QtMocHelpers::SlotData<double() const>(11, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Double),
        // Slot 'setMaxShareRatio'
        QtMocHelpers::SlotData<void(double)>(12, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Double, 13 },
        }}),
        // Slot 'maxSeedTime'
        QtMocHelpers::SlotData<double() const>(14, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Double),
        // Slot 'setMaxSeedTime'
        QtMocHelpers::SlotData<void(double)>(15, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Double, 16 },
        }}),
        // Slot 'maxUploadSpeed'
        QtMocHelpers::SlotData<uint() const>(17, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::UInt),
        // Slot 'setMaxUploadSpeed'
        QtMocHelpers::SlotData<void(uint)>(18, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::UInt, 19 },
        }}),
        // Slot 'maxDownloadSpeed'
        QtMocHelpers::SlotData<uint() const>(20, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::UInt),
        // Slot 'setMaxDownloadSpeed'
        QtMocHelpers::SlotData<void(uint)>(21, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::UInt, 19 },
        }}),
        // Slot 'onlyApplyOnNewTorrents'
        QtMocHelpers::SlotData<bool() const>(22, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setOnlyApplyOnNewTorrents'
        QtMocHelpers::SlotData<void(bool)>(23, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DBusGroup, qt_meta_tag_ZN2kt9DBusGroupE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject kt::DBusGroup::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt9DBusGroupE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt9DBusGroupE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2kt9DBusGroupE_t>.metaTypes,
    nullptr
} };

void kt::DBusGroup::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBusGroup *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->name();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->icon();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 2: { QString _r = _t->defaultSaveLocation();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->setDefaultSaveLocation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: { QString _r = _t->defaultMoveOnCompletionLocation();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->setDefaultMoveOnCompletionLocation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: { double _r = _t->maxShareRatio();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->setMaxShareRatio((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 8: { double _r = _t->maxSeedTime();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->setMaxSeedTime((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 10: { uint _r = _t->maxUploadSpeed();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->setMaxUploadSpeed((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 12: { uint _r = _t->maxDownloadSpeed();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->setMaxDownloadSpeed((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 14: { bool _r = _t->onlyApplyOnNewTorrents();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->setOnlyApplyOnNewTorrents((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *kt::DBusGroup::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kt::DBusGroup::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt9DBusGroupE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int kt::DBusGroup::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    return _id;
}
QT_WARNING_POP
