/****************************************************************************
** Meta object code from reading C++ file 'searchprefpage.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../ktorrent-26.04.3/plugins/search/searchprefpage.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'searchprefpage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2kt14SearchPrefPageE_t {};
} // unnamed namespace

template <> constexpr inline auto kt::SearchPrefPage::qt_create_metaobjectdata<qt_meta_tag_ZN2kt14SearchPrefPageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "kt::SearchPrefPage",
        "clearSearchHistory",
        "",
        "customToggled",
        "toggled",
        "addClicked",
        "removeClicked",
        "addDefaultClicked",
        "removeAllClicked",
        "clearHistory",
        "openInExternalToggled",
        "on",
        "selectionChanged",
        "QItemSelection",
        "selected",
        "deselected",
        "downloadJobFinished",
        "KJob*",
        "j",
        "resetDefaultAction"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'clearSearchHistory'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'customToggled'
        QtMocHelpers::SlotData<void(bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Slot 'addClicked'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'removeClicked'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addDefaultClicked'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'removeAllClicked'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'clearHistory'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openInExternalToggled'
        QtMocHelpers::SlotData<void(bool)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'selectionChanged'
        QtMocHelpers::SlotData<void(const QItemSelection &, const QItemSelection &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { 0x80000000 | 13, 15 },
        }}),
        // Slot 'downloadJobFinished'
        QtMocHelpers::SlotData<void(KJob *)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'resetDefaultAction'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SearchPrefPage, qt_meta_tag_ZN2kt14SearchPrefPageE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject kt::SearchPrefPage::staticMetaObject = { {
    QMetaObject::SuperData::link<PrefPageInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt14SearchPrefPageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt14SearchPrefPageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2kt14SearchPrefPageE_t>.metaTypes,
    nullptr
} };

void kt::SearchPrefPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SearchPrefPage *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->clearSearchHistory(); break;
        case 1: _t->customToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->addClicked(); break;
        case 3: _t->removeClicked(); break;
        case 4: _t->addDefaultClicked(); break;
        case 5: _t->removeAllClicked(); break;
        case 6: _t->clearHistory(); break;
        case 7: _t->openInExternalToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->selectionChanged((*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[2]))); break;
        case 9: _t->downloadJobFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 10: _t->resetDefaultAction(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SearchPrefPage::*)()>(_a, &SearchPrefPage::clearSearchHistory, 0))
            return;
    }
}

const QMetaObject *kt::SearchPrefPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kt::SearchPrefPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt14SearchPrefPageE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui_SearchPref"))
        return static_cast< Ui_SearchPref*>(this);
    return PrefPageInterface::qt_metacast(_clname);
}

int kt::SearchPrefPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PrefPageInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void kt::SearchPrefPage::clearSearchHistory()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
