/********************************************************************************
** Form generated from reading UI file 'filtereditor.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FILTEREDITOR_H
#define UI_FILTEREDITOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "keditlistwidget.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_FilterEditor
{
public:
    QVBoxLayout *verticalLayout_4;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QLineEdit *m_name;
    QTabWidget *tabWidget;
    QWidget *tab;
    QVBoxLayout *verticalLayout_2;
    KEditListWidget *m_word_matches;
    QCheckBox *m_reg_exp_syntax;
    QCheckBox *m_all_words_must_match;
    QCheckBox *m_match_case_sensitive;
    QWidget *tab_5;
    QVBoxLayout *verticalLayout_6;
    KEditListWidget *m_exclusion_patterns;
    QCheckBox *m_exclusion_reg_exp;
    QCheckBox *m_exclusion_all_must_match;
    QCheckBox *m_exclusion_case_sensitive;
    QWidget *tab_2;
    QVBoxLayout *verticalLayout;
    QCheckBox *m_use_se_matching;
    QGridLayout *gridLayout_2;
    QLabel *label_3;
    QLineEdit *m_seasons;
    QLabel *label_4;
    QLineEdit *m_episodes;
    QCheckBox *m_se_no_duplicates;
    QSpacerItem *verticalSpacer;
    QWidget *tab_3;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *m_download_matches;
    QCheckBox *m_download_non_matches;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *m_add_to_group;
    QComboBox *m_group;
    QSpacerItem *horizontalSpacer;
    QGridLayout *gridLayout;
    QCheckBox *m_use_custom_download_location;
    KUrlRequester *m_custom_download_location;
    QCheckBox *m_move_on_completion;
    KUrlRequester *m_move_on_completion_location;
    QCheckBox *m_silently;
    QSpacerItem *verticalSpacer_2;
    QWidget *tab_4;
    QVBoxLayout *verticalLayout_5;
    QHBoxLayout *horizontalLayout_5;
    QPushButton *m_test;
    QLabel *label_2;
    QComboBox *m_feed;
    QSpacerItem *horizontalSpacer_2;
    QTreeView *m_test_results;
    QFrame *line;

    void setupUi(QWidget *FilterEditor)
    {
        if (FilterEditor->objectName().isEmpty())
            FilterEditor->setObjectName("FilterEditor");
        FilterEditor->resize(617, 419);
        verticalLayout_4 = new QVBoxLayout(FilterEditor);
        verticalLayout_4->setContentsMargins(0, 0, 0, 0);
        verticalLayout_4->setObjectName("verticalLayout_4");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(FilterEditor);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        m_name = new QLineEdit(FilterEditor);
        m_name->setObjectName("m_name");

        horizontalLayout->addWidget(m_name);


        verticalLayout_4->addLayout(horizontalLayout);

        tabWidget = new QTabWidget(FilterEditor);
        tabWidget->setObjectName("tabWidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        verticalLayout_2 = new QVBoxLayout(tab);
        verticalLayout_2->setObjectName("verticalLayout_2");
        m_word_matches = new KEditListWidget(tab);
        m_word_matches->setObjectName("m_word_matches");
        m_word_matches->setButtons(KEditListWidget::Add|KEditListWidget::Remove);

        verticalLayout_2->addWidget(m_word_matches);

        m_reg_exp_syntax = new QCheckBox(tab);
        m_reg_exp_syntax->setObjectName("m_reg_exp_syntax");

        verticalLayout_2->addWidget(m_reg_exp_syntax);

        m_all_words_must_match = new QCheckBox(tab);
        m_all_words_must_match->setObjectName("m_all_words_must_match");

        verticalLayout_2->addWidget(m_all_words_must_match);

        m_match_case_sensitive = new QCheckBox(tab);
        m_match_case_sensitive->setObjectName("m_match_case_sensitive");

        verticalLayout_2->addWidget(m_match_case_sensitive);

        tabWidget->addTab(tab, QString());
        tab_5 = new QWidget();
        tab_5->setObjectName("tab_5");
        verticalLayout_6 = new QVBoxLayout(tab_5);
        verticalLayout_6->setObjectName("verticalLayout_6");
        m_exclusion_patterns = new KEditListWidget(tab_5);
        m_exclusion_patterns->setObjectName("m_exclusion_patterns");
        m_exclusion_patterns->setButtons(KEditListWidget::Add|KEditListWidget::Remove);

        verticalLayout_6->addWidget(m_exclusion_patterns);

        m_exclusion_reg_exp = new QCheckBox(tab_5);
        m_exclusion_reg_exp->setObjectName("m_exclusion_reg_exp");

        verticalLayout_6->addWidget(m_exclusion_reg_exp);

        m_exclusion_all_must_match = new QCheckBox(tab_5);
        m_exclusion_all_must_match->setObjectName("m_exclusion_all_must_match");

        verticalLayout_6->addWidget(m_exclusion_all_must_match);

        m_exclusion_case_sensitive = new QCheckBox(tab_5);
        m_exclusion_case_sensitive->setObjectName("m_exclusion_case_sensitive");

        verticalLayout_6->addWidget(m_exclusion_case_sensitive);

        tabWidget->addTab(tab_5, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        verticalLayout = new QVBoxLayout(tab_2);
        verticalLayout->setObjectName("verticalLayout");
        m_use_se_matching = new QCheckBox(tab_2);
        m_use_se_matching->setObjectName("m_use_se_matching");

        verticalLayout->addWidget(m_use_se_matching);

        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        label_3 = new QLabel(tab_2);
        label_3->setObjectName("label_3");

        gridLayout_2->addWidget(label_3, 0, 0, 1, 1);

        m_seasons = new QLineEdit(tab_2);
        m_seasons->setObjectName("m_seasons");

        gridLayout_2->addWidget(m_seasons, 0, 1, 1, 1);

        label_4 = new QLabel(tab_2);
        label_4->setObjectName("label_4");

        gridLayout_2->addWidget(label_4, 1, 0, 1, 1);

        m_episodes = new QLineEdit(tab_2);
        m_episodes->setObjectName("m_episodes");

        gridLayout_2->addWidget(m_episodes, 1, 1, 1, 1);


        verticalLayout->addLayout(gridLayout_2);

        m_se_no_duplicates = new QCheckBox(tab_2);
        m_se_no_duplicates->setObjectName("m_se_no_duplicates");

        verticalLayout->addWidget(m_se_no_duplicates);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        tabWidget->addTab(tab_2, QString());
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        verticalLayout_3 = new QVBoxLayout(tab_3);
        verticalLayout_3->setObjectName("verticalLayout_3");
        m_download_matches = new QCheckBox(tab_3);
        m_download_matches->setObjectName("m_download_matches");

        verticalLayout_3->addWidget(m_download_matches);

        m_download_non_matches = new QCheckBox(tab_3);
        m_download_non_matches->setObjectName("m_download_non_matches");

        verticalLayout_3->addWidget(m_download_non_matches);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        m_add_to_group = new QCheckBox(tab_3);
        m_add_to_group->setObjectName("m_add_to_group");

        horizontalLayout_2->addWidget(m_add_to_group);

        m_group = new QComboBox(tab_3);
        m_group->setObjectName("m_group");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_group->sizePolicy().hasHeightForWidth());
        m_group->setSizePolicy(sizePolicy);

        horizontalLayout_2->addWidget(m_group);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        verticalLayout_3->addLayout(horizontalLayout_2);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        m_use_custom_download_location = new QCheckBox(tab_3);
        m_use_custom_download_location->setObjectName("m_use_custom_download_location");

        gridLayout->addWidget(m_use_custom_download_location, 0, 0, 1, 1);

        m_custom_download_location = new KUrlRequester(tab_3);
        m_custom_download_location->setObjectName("m_custom_download_location");

        gridLayout->addWidget(m_custom_download_location, 0, 1, 1, 1);

        m_move_on_completion = new QCheckBox(tab_3);
        m_move_on_completion->setObjectName("m_move_on_completion");

        gridLayout->addWidget(m_move_on_completion, 1, 0, 1, 1);

        m_move_on_completion_location = new KUrlRequester(tab_3);
        m_move_on_completion_location->setObjectName("m_move_on_completion_location");

        gridLayout->addWidget(m_move_on_completion_location, 1, 1, 1, 1);


        verticalLayout_3->addLayout(gridLayout);

        m_silently = new QCheckBox(tab_3);
        m_silently->setObjectName("m_silently");

        verticalLayout_3->addWidget(m_silently);

        verticalSpacer_2 = new QSpacerItem(20, 174, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_2);

        tabWidget->addTab(tab_3, QString());
        tab_4 = new QWidget();
        tab_4->setObjectName("tab_4");
        verticalLayout_5 = new QVBoxLayout(tab_4);
        verticalLayout_5->setObjectName("verticalLayout_5");
        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        m_test = new QPushButton(tab_4);
        m_test->setObjectName("m_test");

        horizontalLayout_5->addWidget(m_test);

        label_2 = new QLabel(tab_4);
        label_2->setObjectName("label_2");

        horizontalLayout_5->addWidget(label_2);

        m_feed = new QComboBox(tab_4);
        m_feed->setObjectName("m_feed");

        horizontalLayout_5->addWidget(m_feed);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_2);


        verticalLayout_5->addLayout(horizontalLayout_5);

        m_test_results = new QTreeView(tab_4);
        m_test_results->setObjectName("m_test_results");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_test_results->sizePolicy().hasHeightForWidth());
        m_test_results->setSizePolicy(sizePolicy1);
        m_test_results->setMaximumSize(QSize(16777215, 16777215));
        m_test_results->setRootIsDecorated(false);

        verticalLayout_5->addWidget(m_test_results);

        tabWidget->addTab(tab_4, QString());

        verticalLayout_4->addWidget(tabWidget);

        line = new QFrame(FilterEditor);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_4->addWidget(line);


        retranslateUi(FilterEditor);
        QObject::connect(m_use_se_matching, &QCheckBox::toggled, m_seasons, &QLineEdit::setEnabled);
        QObject::connect(m_use_se_matching, &QCheckBox::toggled, m_episodes, &QLineEdit::setEnabled);
        QObject::connect(m_add_to_group, &QCheckBox::toggled, m_group, &QComboBox::setEnabled);
        QObject::connect(m_use_custom_download_location, SIGNAL(toggled(bool)), m_custom_download_location, SLOT(setEnabled(bool)));
        QObject::connect(m_use_se_matching, &QCheckBox::toggled, m_se_no_duplicates, &QCheckBox::setEnabled);
        QObject::connect(m_move_on_completion, SIGNAL(toggled(bool)), m_move_on_completion_location, SLOT(setEnabled(bool)));

        tabWidget->setCurrentIndex(4);


        QMetaObject::connectSlotsByName(FilterEditor);
    } // setupUi

    void retranslateUi(QWidget *FilterEditor)
    {
        label->setText(tr2i18n("Name:", nullptr));
#if QT_CONFIG(tooltip)
        m_word_matches->setToolTip(tr2i18n("<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">The string to find in the title of an item. Simple wildcard syntax is supported :</p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"></p>\n"
"<table border=\"0\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px;\" align=\"center\" cellspacing=\"1\" cellpadding=\"2\">\n"
"<tr>\n"
"<td style=\" vertical-align:top;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; color:#000000;\"><span style=\" font-weight:600;\">c</span></p></td>\n"
"<td style=\" vertical-align:top;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; "
                        "margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Any character represents itself apart from those mentioned below. Thus <span style=\" font-weight:600;\">c</span> matches the character <span style=\" font-style:italic;\">c</span>.</p></td></tr>\n"
"<tr>\n"
"<td style=\" vertical-align:top;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; color:#000000;\"><span style=\" font-weight:600;\">?</span></p></td>\n"
"<td style=\" vertical-align:top;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; color:#000000;\">Matches any single character. </p></td></tr>\n"
"<tr>\n"
"<td style=\" vertical-align:top;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; color:#000000;\"><span style=\" font-weight:600;\">*</span></p></td>\n"
"<td style=\" vertical-align:top;\">\n"
"<p style=\" margin-to"
                        "p:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; color:#000000;\">Matches zero or more of any characters.</p></td></tr>\n"
"<tr>\n"
"<td style=\" vertical-align:top;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; color:#000000;\"><span style=\" font-weight:600;\">[...]</span></p></td>\n"
"<td style=\" vertical-align:top;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; color:#000000;\">Sets of characters can be represented in square brackets. Within the character class, like outside, backslash has no special meaning.</p></td></tr></table>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; color:#000000;\">For example the *.torrent will match any item which ends in .torrent. </p>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        m_reg_exp_syntax->setToolTip(tr2i18n("By default strings will use wildcard matching. If you want to use regular expressions, this needs to be enabled.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_reg_exp_syntax->setText(tr2i18n("Strings are regular expressions", nullptr));
        m_all_words_must_match->setText(tr2i18n("Item must match all strings to be included", nullptr));
        m_match_case_sensitive->setText(tr2i18n("Case sensitive matching", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), tr2i18n("String Matching", nullptr));
#if QT_CONFIG(tooltip)
        m_exclusion_patterns->setToolTip(tr2i18n("<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">The string to find in the title of an item. Simple wildcard syntax is supported :</p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"></p>\n"
"<table border=\"0\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px;\" align=\"center\" cellspacing=\"1\" cellpadding=\"2\">\n"
"<tr>\n"
"<td style=\" vertical-align:top;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; color:#000000;\"><span style=\" font-weight:600;\">c</span></p></td>\n"
"<td style=\" vertical-align:top;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; "
                        "margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Any character represents itself apart from those mentioned below. Thus <span style=\" font-weight:600;\">c</span> matches the character <span style=\" font-style:italic;\">c</span>.</p></td></tr>\n"
"<tr>\n"
"<td style=\" vertical-align:top;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; color:#000000;\"><span style=\" font-weight:600;\">?</span></p></td>\n"
"<td style=\" vertical-align:top;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; color:#000000;\">Matches any single character. </p></td></tr>\n"
"<tr>\n"
"<td style=\" vertical-align:top;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; color:#000000;\"><span style=\" font-weight:600;\">*</span></p></td>\n"
"<td style=\" vertical-align:top;\">\n"
"<p style=\" margin-to"
                        "p:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; color:#000000;\">Matches zero or more of any characters.</p></td></tr>\n"
"<tr>\n"
"<td style=\" vertical-align:top;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; color:#000000;\"><span style=\" font-weight:600;\">[...]</span></p></td>\n"
"<td style=\" vertical-align:top;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; color:#000000;\">Sets of characters can be represented in square brackets. Within the character class, like outside, backslash has no special meaning.</p></td></tr></table>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; color:#000000;\">For example the *.torrent will match any item which ends in .torrent. </p>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        m_exclusion_reg_exp->setToolTip(tr2i18n("By default strings will use wildcard matching. If you want to use regular expressions, this needs to be enabled.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_exclusion_reg_exp->setText(tr2i18n("Strings are regular expressions", nullptr));
        m_exclusion_all_must_match->setText(tr2i18n("Item must match all strings to be excluded", nullptr));
        m_exclusion_case_sensitive->setText(tr2i18n("Case sensitive matching", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_5), tr2i18n("Exclusion Patterns", nullptr));
        m_use_se_matching->setText(tr2i18n("Use season and episode matching", nullptr));
        label_3->setText(tr2i18n("Seasons: ", nullptr));
#if QT_CONFIG(tooltip)
        m_seasons->setToolTip(tr2i18n("Specify the seasons to download, multiple seasons can be separated by a , and you can also use ranges by using a -\n"
"\n"
"For example: 1, 3-6, 9\n"
"\n"
"Will download seasons 1, 3, 4, 5, 6 and 9", nullptr));
#endif // QT_CONFIG(tooltip)
        label_4->setText(tr2i18n("Episodes:", nullptr));
#if QT_CONFIG(tooltip)
        m_episodes->setToolTip(tr2i18n("Specify the episodes to download, multiple episodes can be separated by a , and you can also use ranges by using a -\n"
"\n"
"For example: 1, 3-6, 9\n"
"\n"
"Will download episodes 1, 3, 4, 5, 6 and 9", nullptr));
#endif // QT_CONFIG(tooltip)
        m_se_no_duplicates->setText(tr2i18n("Do not download multiple items with the same season and episode", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), tr2i18n("Seasons && Episodes", nullptr));
        m_download_matches->setText(tr2i18n("Download torrents of matching items", nullptr));
        m_download_non_matches->setText(tr2i18n("Download torrents of non matching items", nullptr));
        m_add_to_group->setText(tr2i18n("Add to group:", nullptr));
        m_use_custom_download_location->setText(tr2i18n("Download to:", nullptr));
        m_move_on_completion->setText(tr2i18n("Move when completed to:", nullptr));
        m_silently->setText(tr2i18n("Open torrents silently", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_3), tr2i18n("Options", nullptr));
        m_test->setText(tr2i18n("Test", nullptr));
        label_2->setText(tr2i18n("filter on feed:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_4), tr2i18n("Test", nullptr));
        (void)FilterEditor;
    } // retranslateUi

};

namespace Ui {
    class FilterEditor: public Ui_FilterEditor {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FILTEREDITOR_H

