// This file is generated by kconfig_compiler_kf6 from ktinfowidgetplugin.kcfg.
// All changes you do to this file will be lost.
#ifndef INFOWIDGETPLUGINSETTINGS_H
#define INFOWIDGETPLUGINSETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class InfoWidgetPluginSettings : public KConfigSkeleton
{
  public:

    static InfoWidgetPluginSettings *self();
    ~InfoWidgetPluginSettings() override;

    /**
      Set Show peer view tab in main window
    */
    static
    void setShowPeerView( bool v )
    {
      if (!self()->isShowPeerViewImmutable())
        self()->mShowPeerView = v;
    }

    /**
      Get Show peer view tab in main window
    */
    static
    bool showPeerView()
    {
      return self()->mShowPeerView;
    }

    /**
      Is Show peer view tab in main window Immutable
    */
    static
    bool isShowPeerViewImmutable()
    {
      return self()->isImmutable( QStringLiteral( "showPeerView" ) );
    }

    /**
      Set Show chunk download view tab in main window
    */
    static
    void setShowChunkView( bool v )
    {
      if (!self()->isShowChunkViewImmutable())
        self()->mShowChunkView = v;
    }

    /**
      Get Show chunk download view tab in main window
    */
    static
    bool showChunkView()
    {
      return self()->mShowChunkView;
    }

    /**
      Is Show chunk download view tab in main window Immutable
    */
    static
    bool isShowChunkViewImmutable()
    {
      return self()->isImmutable( QStringLiteral( "showChunkView" ) );
    }

    /**
      Set Show trackers view tab in main window
    */
    static
    void setShowTrackersView( bool v )
    {
      if (!self()->isShowTrackersViewImmutable())
        self()->mShowTrackersView = v;
    }

    /**
      Get Show trackers view tab in main window
    */
    static
    bool showTrackersView()
    {
      return self()->mShowTrackersView;
    }

    /**
      Is Show trackers view tab in main window Immutable
    */
    static
    bool isShowTrackersViewImmutable()
    {
      return self()->isImmutable( QStringLiteral( "showTrackersView" ) );
    }

    /**
      Set showWebSeedsTab
    */
    static
    void setShowWebSeedsTab( bool v )
    {
      if (!self()->isShowWebSeedsTabImmutable())
        self()->mShowWebSeedsTab = v;
    }

    /**
      Get showWebSeedsTab
    */
    static
    bool showWebSeedsTab()
    {
      return self()->mShowWebSeedsTab;
    }

    /**
      Is showWebSeedsTab Immutable
    */
    static
    bool isShowWebSeedsTabImmutable()
    {
      return self()->isImmutable( QStringLiteral( "showWebSeedsTab" ) );
    }

    /**
      Set firstColor
    */
    static
    void setFirstColor( const QColor & v )
    {
      if (!self()->isFirstColorImmutable())
        self()->mFirstColor = v;
    }

    /**
      Get firstColor
    */
    static
    QColor firstColor()
    {
      return self()->mFirstColor;
    }

    /**
      Is firstColor Immutable
    */
    static
    bool isFirstColorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "firstColor" ) );
    }

    /**
      Set lastColor
    */
    static
    void setLastColor( const QColor & v )
    {
      if (!self()->isLastColorImmutable())
        self()->mLastColor = v;
    }

    /**
      Get lastColor
    */
    static
    QColor lastColor()
    {
      return self()->mLastColor;
    }

    /**
      Is lastColor Immutable
    */
    static
    bool isLastColorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "lastColor" ) );
    }

  protected:
    InfoWidgetPluginSettings();
    friend class InfoWidgetPluginSettingsHelper;


    // general
    bool mShowPeerView;
    bool mShowChunkView;
    bool mShowTrackersView;
    bool mShowWebSeedsTab;
    QColor mFirstColor;
    QColor mLastColor;
};

#endif

