/********************************************************************************
** Form generated from reading UI file 'edititemdlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITITEMDLG_H
#define UI_EDITITEMDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTimeEdit>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_EditItemDlg
{
public:
    QVBoxLayout *verticalLayout_3;
    QGroupBox *groupBox_2;
    QHBoxLayout *horizontalLayout_2;
    QHBoxLayout *hboxLayout;
    QLabel *label_3;
    QTimeEdit *m_from;
    QLabel *label_4;
    QTimeEdit *m_to;
    QHBoxLayout *horizontalLayout;
    QLabel *label_5;
    QComboBox *m_start_day;
    QLabel *label_10;
    QComboBox *m_end_day;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_3;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *m_suspended;
    QGridLayout *gridLayout;
    QLabel *label;
    QSpinBox *m_download_limit;
    QLabel *label_2;
    QSpinBox *m_upload_limit;
    QCheckBox *m_screensaver_limits;
    QGridLayout *_2;
    QLabel *label_8;
    QSpinBox *m_ss_download_limit;
    QLabel *label_9;
    QSpinBox *m_ss_upload_limit;
    QGroupBox *groupBox_3;
    QVBoxLayout *verticalLayout;
    QCheckBox *m_set_connection_limits;
    QGridLayout *gridLayout1;
    QLabel *label_7;
    QSpinBox *m_max_conn_per_torrent;
    QLabel *label_6;
    QSpinBox *m_max_conn_global;
    QSpacerItem *verticalSpacer;
    QFrame *line;
    QDialogButtonBox *m_buttonBox;

    void setupUi(QDialog *EditItemDlg)
    {
        if (EditItemDlg->objectName().isEmpty())
            EditItemDlg->setObjectName("EditItemDlg");
        EditItemDlg->resize(852, 419);
        verticalLayout_3 = new QVBoxLayout(EditItemDlg);
        verticalLayout_3->setObjectName("verticalLayout_3");
        groupBox_2 = new QGroupBox(EditItemDlg);
        groupBox_2->setObjectName("groupBox_2");
        horizontalLayout_2 = new QHBoxLayout(groupBox_2);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        label_3 = new QLabel(groupBox_2);
        label_3->setObjectName("label_3");

        hboxLayout->addWidget(label_3);

        m_from = new QTimeEdit(groupBox_2);
        m_from->setObjectName("m_from");

        hboxLayout->addWidget(m_from);

        label_4 = new QLabel(groupBox_2);
        label_4->setObjectName("label_4");

        hboxLayout->addWidget(label_4);

        m_to = new QTimeEdit(groupBox_2);
        m_to->setObjectName("m_to");

        hboxLayout->addWidget(m_to);


        horizontalLayout_2->addLayout(hboxLayout);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label_5 = new QLabel(groupBox_2);
        label_5->setObjectName("label_5");

        horizontalLayout->addWidget(label_5);

        m_start_day = new QComboBox(groupBox_2);
        m_start_day->setObjectName("m_start_day");

        horizontalLayout->addWidget(m_start_day);

        label_10 = new QLabel(groupBox_2);
        label_10->setObjectName("label_10");

        horizontalLayout->addWidget(label_10);

        m_end_day = new QComboBox(groupBox_2);
        m_end_day->setObjectName("m_end_day");

        horizontalLayout->addWidget(m_end_day);


        horizontalLayout_2->addLayout(horizontalLayout);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        verticalLayout_3->addWidget(groupBox_2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        groupBox = new QGroupBox(EditItemDlg);
        groupBox->setObjectName("groupBox");
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        m_suspended = new QCheckBox(groupBox);
        m_suspended->setObjectName("m_suspended");

        verticalLayout_2->addWidget(m_suspended);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(groupBox);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        m_download_limit = new QSpinBox(groupBox);
        m_download_limit->setObjectName("m_download_limit");
        m_download_limit->setMaximum(10000000);

        gridLayout->addWidget(m_download_limit, 0, 1, 1, 1);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        m_upload_limit = new QSpinBox(groupBox);
        m_upload_limit->setObjectName("m_upload_limit");
        m_upload_limit->setMaximum(10000000);

        gridLayout->addWidget(m_upload_limit, 1, 1, 1, 1);


        verticalLayout_2->addLayout(gridLayout);

        m_screensaver_limits = new QCheckBox(groupBox);
        m_screensaver_limits->setObjectName("m_screensaver_limits");

        verticalLayout_2->addWidget(m_screensaver_limits);

        _2 = new QGridLayout();
        _2->setObjectName("_2");
        label_8 = new QLabel(groupBox);
        label_8->setObjectName("label_8");

        _2->addWidget(label_8, 0, 0, 1, 1);

        m_ss_download_limit = new QSpinBox(groupBox);
        m_ss_download_limit->setObjectName("m_ss_download_limit");
        m_ss_download_limit->setMaximum(10000000);

        _2->addWidget(m_ss_download_limit, 0, 1, 1, 1);

        label_9 = new QLabel(groupBox);
        label_9->setObjectName("label_9");

        _2->addWidget(label_9, 1, 0, 1, 1);

        m_ss_upload_limit = new QSpinBox(groupBox);
        m_ss_upload_limit->setObjectName("m_ss_upload_limit");
        m_ss_upload_limit->setMaximum(10000000);

        _2->addWidget(m_ss_upload_limit, 1, 1, 1, 1);


        verticalLayout_2->addLayout(_2);


        horizontalLayout_3->addWidget(groupBox);

        groupBox_3 = new QGroupBox(EditItemDlg);
        groupBox_3->setObjectName("groupBox_3");
        verticalLayout = new QVBoxLayout(groupBox_3);
        verticalLayout->setObjectName("verticalLayout");
        m_set_connection_limits = new QCheckBox(groupBox_3);
        m_set_connection_limits->setObjectName("m_set_connection_limits");

        verticalLayout->addWidget(m_set_connection_limits);

        gridLayout1 = new QGridLayout();
        gridLayout1->setObjectName("gridLayout1");
        label_7 = new QLabel(groupBox_3);
        label_7->setObjectName("label_7");

        gridLayout1->addWidget(label_7, 0, 0, 1, 1);

        m_max_conn_per_torrent = new QSpinBox(groupBox_3);
        m_max_conn_per_torrent->setObjectName("m_max_conn_per_torrent");
        m_max_conn_per_torrent->setMaximum(99999);

        gridLayout1->addWidget(m_max_conn_per_torrent, 0, 1, 1, 1);

        label_6 = new QLabel(groupBox_3);
        label_6->setObjectName("label_6");

        gridLayout1->addWidget(label_6, 1, 0, 1, 1);

        m_max_conn_global = new QSpinBox(groupBox_3);
        m_max_conn_global->setObjectName("m_max_conn_global");
        m_max_conn_global->setMaximum(99999);
        m_max_conn_global->setValue(0);

        gridLayout1->addWidget(m_max_conn_global, 1, 1, 1, 1);


        verticalLayout->addLayout(gridLayout1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        horizontalLayout_3->addWidget(groupBox_3);


        verticalLayout_3->addLayout(horizontalLayout_3);

        line = new QFrame(EditItemDlg);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_3->addWidget(line);

        m_buttonBox = new QDialogButtonBox(EditItemDlg);
        m_buttonBox->setObjectName("m_buttonBox");
        m_buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_3->addWidget(m_buttonBox);


        retranslateUi(EditItemDlg);
        QObject::connect(m_set_connection_limits, &QCheckBox::toggled, m_max_conn_per_torrent, &QSpinBox::setEnabled);
        QObject::connect(m_set_connection_limits, &QCheckBox::toggled, m_max_conn_global, &QSpinBox::setEnabled);

        QMetaObject::connectSlotsByName(EditItemDlg);
    } // setupUi

    void retranslateUi(QDialog *EditItemDlg)
    {
        EditItemDlg->setWindowTitle(tr2i18n("Edit an item", nullptr));
        groupBox_2->setTitle(tr2i18n("Duration", nullptr));
        label_3->setText(tr2i18n("From:", nullptr));
        m_from->setDisplayFormat(tr2i18n("hh:mm", nullptr));
        label_4->setText(tr2i18n("To:", nullptr));
        m_to->setDisplayFormat(tr2i18n("hh:mm", nullptr));
        label_5->setText(tr2i18n("From:", "starting day"));
        label_10->setText(tr2i18n("To:", "ending day"));
        groupBox->setTitle(tr2i18n("Limits", nullptr));
        m_suspended->setText(tr2i18n("Suspend all running torrents", nullptr));
        label->setText(tr2i18n("Download limit:", nullptr));
        m_download_limit->setSpecialValueText(tr2i18n("No limit", nullptr));
        m_download_limit->setSuffix(tr2i18n(" KiB/s", nullptr));
        label_2->setText(tr2i18n("Upload limit:", nullptr));
        m_upload_limit->setSpecialValueText(tr2i18n("No limit", nullptr));
        m_upload_limit->setSuffix(tr2i18n(" KiB/s", nullptr));
        m_screensaver_limits->setText(tr2i18n("When screensaver is activated:", nullptr));
        label_8->setText(tr2i18n("Download limit:", nullptr));
        m_ss_download_limit->setSpecialValueText(tr2i18n("No limit", nullptr));
        m_ss_download_limit->setSuffix(tr2i18n(" KiB/s", nullptr));
        label_9->setText(tr2i18n("Upload limit:", nullptr));
        m_ss_upload_limit->setSpecialValueText(tr2i18n("No limit", nullptr));
        m_ss_upload_limit->setSuffix(tr2i18n(" KiB/s", nullptr));
        groupBox_3->setTitle(tr2i18n("Connection Limits", nullptr));
        m_set_connection_limits->setText(tr2i18n("Set connection limits", nullptr));
        label_7->setText(tr2i18n("Maximum connections per torrent:", nullptr));
        m_max_conn_per_torrent->setSpecialValueText(tr2i18n("No limit", nullptr));
        label_6->setText(tr2i18n("Global connection limit:", nullptr));
        m_max_conn_global->setSpecialValueText(tr2i18n("No limit", nullptr));
    } // retranslateUi

};

namespace Ui {
    class EditItemDlg: public Ui_EditItemDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EDITITEMDLG_H

