/********************************************************************************
** Form generated from reading UI file 'colorpref.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COLORPREF_H
#define UI_COLORPREF_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_ColorPref
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout_2;
    KColorButton *kcfg_stalledTorrentColor;
    KColorButton *kcfg_okTorrentColor;
    QLabel *label;
    QLabel *label_2;
    KColorButton *kcfg_errorTorrentColor;
    QLabel *label_3;
    QGroupBox *kcfg_highlightTorrentNameByTrackerStatus;
    QGridLayout *gridLayout;
    KColorButton *kcfg_okTrackerConnectionColor;
    QLabel *label_4;
    KColorButton *kcfg_warningsTrackerConnectionColor;
    QLabel *label_9;
    QLabel *label_7;
    KColorButton *kcfg_noTrackerConnectionColor;
    QLabel *label_8;
    KColorButton *kcfg_timeoutTrackerConnectionColor;
    QGridLayout *gridLayout_3;
    QLabel *label_6;
    QLabel *label_5;
    KColorButton *kcfg_lowShareRatioColor;
    KColorButton *kcfg_goodShareRatioColor;
    QHBoxLayout *horizontalLayout;
    QPushButton *btnResetColors;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *ColorPref)
    {
        if (ColorPref->objectName().isEmpty())
            ColorPref->setObjectName("ColorPref");
        ColorPref->resize(593, 620);
        verticalLayout = new QVBoxLayout(ColorPref);
        verticalLayout->setObjectName("verticalLayout");
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        kcfg_stalledTorrentColor = new KColorButton(ColorPref);
        kcfg_stalledTorrentColor->setObjectName("kcfg_stalledTorrentColor");

        gridLayout_2->addWidget(kcfg_stalledTorrentColor, 1, 2, 1, 1);

        kcfg_okTorrentColor = new KColorButton(ColorPref);
        kcfg_okTorrentColor->setObjectName("kcfg_okTorrentColor");

        gridLayout_2->addWidget(kcfg_okTorrentColor, 0, 2, 1, 1);

        label = new QLabel(ColorPref);
        label->setObjectName("label");

        gridLayout_2->addWidget(label, 0, 0, 1, 2);

        label_2 = new QLabel(ColorPref);
        label_2->setObjectName("label_2");

        gridLayout_2->addWidget(label_2, 1, 0, 1, 2);

        kcfg_errorTorrentColor = new KColorButton(ColorPref);
        kcfg_errorTorrentColor->setObjectName("kcfg_errorTorrentColor");

        gridLayout_2->addWidget(kcfg_errorTorrentColor, 2, 2, 1, 1);

        label_3 = new QLabel(ColorPref);
        label_3->setObjectName("label_3");

        gridLayout_2->addWidget(label_3, 2, 0, 1, 2);


        verticalLayout->addLayout(gridLayout_2);

        kcfg_highlightTorrentNameByTrackerStatus = new QGroupBox(ColorPref);
        kcfg_highlightTorrentNameByTrackerStatus->setObjectName("kcfg_highlightTorrentNameByTrackerStatus");
        kcfg_highlightTorrentNameByTrackerStatus->setCheckable(true);
        gridLayout = new QGridLayout(kcfg_highlightTorrentNameByTrackerStatus);
        gridLayout->setObjectName("gridLayout");
        kcfg_okTrackerConnectionColor = new KColorButton(kcfg_highlightTorrentNameByTrackerStatus);
        kcfg_okTrackerConnectionColor->setObjectName("kcfg_okTrackerConnectionColor");

        gridLayout->addWidget(kcfg_okTrackerConnectionColor, 0, 2, 1, 1);

        label_4 = new QLabel(kcfg_highlightTorrentNameByTrackerStatus);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 0, 0, 1, 2);

        kcfg_warningsTrackerConnectionColor = new KColorButton(kcfg_highlightTorrentNameByTrackerStatus);
        kcfg_warningsTrackerConnectionColor->setObjectName("kcfg_warningsTrackerConnectionColor");

        gridLayout->addWidget(kcfg_warningsTrackerConnectionColor, 2, 2, 1, 1);

        label_9 = new QLabel(kcfg_highlightTorrentNameByTrackerStatus);
        label_9->setObjectName("label_9");

        gridLayout->addWidget(label_9, 5, 0, 1, 1);

        label_7 = new QLabel(kcfg_highlightTorrentNameByTrackerStatus);
        label_7->setObjectName("label_7");

        gridLayout->addWidget(label_7, 2, 0, 1, 2);

        kcfg_noTrackerConnectionColor = new KColorButton(kcfg_highlightTorrentNameByTrackerStatus);
        kcfg_noTrackerConnectionColor->setObjectName("kcfg_noTrackerConnectionColor");

        gridLayout->addWidget(kcfg_noTrackerConnectionColor, 5, 2, 1, 1);

        label_8 = new QLabel(kcfg_highlightTorrentNameByTrackerStatus);
        label_8->setObjectName("label_8");

        gridLayout->addWidget(label_8, 1, 0, 1, 1);

        kcfg_timeoutTrackerConnectionColor = new KColorButton(kcfg_highlightTorrentNameByTrackerStatus);
        kcfg_timeoutTrackerConnectionColor->setObjectName("kcfg_timeoutTrackerConnectionColor");

        gridLayout->addWidget(kcfg_timeoutTrackerConnectionColor, 1, 2, 1, 1);


        verticalLayout->addWidget(kcfg_highlightTorrentNameByTrackerStatus);

        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName("gridLayout_3");
        label_6 = new QLabel(ColorPref);
        label_6->setObjectName("label_6");

        gridLayout_3->addWidget(label_6, 1, 0, 1, 2);

        label_5 = new QLabel(ColorPref);
        label_5->setObjectName("label_5");

        gridLayout_3->addWidget(label_5, 0, 0, 1, 2);

        kcfg_lowShareRatioColor = new KColorButton(ColorPref);
        kcfg_lowShareRatioColor->setObjectName("kcfg_lowShareRatioColor");

        gridLayout_3->addWidget(kcfg_lowShareRatioColor, 1, 2, 1, 1);

        kcfg_goodShareRatioColor = new KColorButton(ColorPref);
        kcfg_goodShareRatioColor->setObjectName("kcfg_goodShareRatioColor");

        gridLayout_3->addWidget(kcfg_goodShareRatioColor, 0, 2, 1, 1);


        verticalLayout->addLayout(gridLayout_3);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        btnResetColors = new QPushButton(ColorPref);
        btnResetColors->setObjectName("btnResetColors");

        horizontalLayout->addWidget(btnResetColors);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        spacerItem = new QSpacerItem(575, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(spacerItem);


        retranslateUi(ColorPref);

        QMetaObject::connectSlotsByName(ColorPref);
    } // setupUi

    void retranslateUi(QWidget *ColorPref)
    {
#if QT_CONFIG(tooltip)
        kcfg_stalledTorrentColor->setToolTip(tr2i18n("Color to use for torrents when they are stalled or checking data.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_okTorrentColor->setToolTip(tr2i18n("Color to use for torrents while seeding or downloading.", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Torrent is running:", nullptr));
        label_2->setText(tr2i18n("Torrent is stalled or checking data:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_errorTorrentColor->setToolTip(tr2i18n("Color to use for torrents with error status.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_3->setText(tr2i18n("Torrent error:", nullptr));
        kcfg_highlightTorrentNameByTrackerStatus->setTitle(tr2i18n("Additionally highlight torrents based on the status of their trackers (if any)", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_okTrackerConnectionColor->setToolTip(tr2i18n("Color to use when at least one tracker is connected and replied no errors or warnings.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_4->setText(tr2i18n("Some of the trackers are reachable:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_warningsTrackerConnectionColor->setToolTip(tr2i18n("Color to use when the best attempt to connect to tracker results in warning.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_9->setText(tr2i18n("None of the trackers are reachable:", nullptr));
        label_7->setText(tr2i18n("Reachable trackers report warnings:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_noTrackerConnectionColor->setToolTip(tr2i18n("Color to use when all trackers reply with errors or are not found.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_8->setText(tr2i18n("Trackers are timing out:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_timeoutTrackerConnectionColor->setToolTip(tr2i18n("Color to use when the best attempt to connect to tracker results in timeout. Connection will be attempted again later.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_6->setText(tr2i18n("Low share ratio:", nullptr));
        label_5->setText(tr2i18n("Good share ratio:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_lowShareRatioColor->setToolTip(tr2i18n("Color to display share ratio below minimal good value.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_goodShareRatioColor->setToolTip(tr2i18n("Color to display share ratio above minimal good value.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        btnResetColors->setToolTip(tr2i18n("Reset colors to their default values (other settings won't change).", nullptr));
#endif // QT_CONFIG(tooltip)
        btnResetColors->setText(tr2i18n("Reset Colors", nullptr));
        (void)ColorPref;
    } // retranslateUi

};

namespace Ui {
    class ColorPref: public Ui_ColorPref {};
} // namespace Ui

QT_END_NAMESPACE

#endif // COLORPREF_H

