/****************************************************************************
** Meta object code from reading C++ file 'magnetmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktorrent-26.04.3/libktcore/torrent/magnetmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'magnetmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2kt16MagnetDownloaderE_t {};
} // unnamed namespace

template <> constexpr inline auto kt::MagnetDownloader::qt_create_metaobjectdata<qt_meta_tag_ZN2kt16MagnetDownloaderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "kt::MagnetDownloader"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MagnetDownloader, qt_meta_tag_ZN2kt16MagnetDownloaderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject kt::MagnetDownloader::staticMetaObject = { {
    QMetaObject::SuperData::link<bt::MagnetDownloader::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt16MagnetDownloaderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt16MagnetDownloaderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2kt16MagnetDownloaderE_t>.metaTypes,
    nullptr
} };

void kt::MagnetDownloader::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MagnetDownloader *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *kt::MagnetDownloader::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kt::MagnetDownloader::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt16MagnetDownloaderE_t>.strings))
        return static_cast<void*>(this);
    return bt::MagnetDownloader::qt_metacast(_clname);
}

int kt::MagnetDownloader::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = bt::MagnetDownloader::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN2kt12DownloadSlotE_t {};
} // unnamed namespace

template <> constexpr inline auto kt::DownloadSlot::qt_create_metaobjectdata<qt_meta_tag_ZN2kt12DownloadSlotE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "kt::DownloadSlot",
        "timeout",
        "",
        "magnetIdx",
        "onTimeout"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'timeout'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'onTimeout'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DownloadSlot, qt_meta_tag_ZN2kt12DownloadSlotE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject kt::DownloadSlot::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt12DownloadSlotE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt12DownloadSlotE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2kt12DownloadSlotE_t>.metaTypes,
    nullptr
} };

void kt::DownloadSlot::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DownloadSlot *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->timeout((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->onTimeout(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DownloadSlot::*)(int )>(_a, &DownloadSlot::timeout, 0))
            return;
    }
}

const QMetaObject *kt::DownloadSlot::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kt::DownloadSlot::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt12DownloadSlotE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int kt::DownloadSlot::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void kt::DownloadSlot::timeout(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN2kt13MagnetManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto kt::MagnetManager::qt_create_metaobjectdata<qt_meta_tag_ZN2kt13MagnetManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "kt::MagnetManager",
        "metadataDownloaded",
        "",
        "bt::MagnetLink",
        "mlink",
        "data",
        "kt::MagnetLinkLoadOptions",
        "options",
        "updateQueue",
        "bt::Uint32",
        "idx",
        "count",
        "onDownloadFinished",
        "bt::MagnetDownloader*",
        "md",
        "onSlotTimeout",
        "magnetIdx"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'metadataDownloaded'
        QtMocHelpers::SignalData<void(const bt::MagnetLink &, const QByteArray &, const kt::MagnetLinkLoadOptions &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QByteArray, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'updateQueue'
        QtMocHelpers::SignalData<void(bt::Uint32, bt::Uint32)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 9, 11 },
        }}),
        // Slot 'onDownloadFinished'
        QtMocHelpers::SlotData<void(bt::MagnetDownloader *, const QByteArray &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { QMetaType::QByteArray, 5 },
        }}),
        // Slot 'onSlotTimeout'
        QtMocHelpers::SlotData<void(int)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MagnetManager, qt_meta_tag_ZN2kt13MagnetManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject kt::MagnetManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt13MagnetManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt13MagnetManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2kt13MagnetManagerE_t>.metaTypes,
    nullptr
} };

void kt::MagnetManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MagnetManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->metadataDownloaded((*reinterpret_cast<std::add_pointer_t<bt::MagnetLink>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<kt::MagnetLinkLoadOptions>>(_a[3]))); break;
        case 1: _t->updateQueue((*reinterpret_cast<std::add_pointer_t<bt::Uint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bt::Uint32>>(_a[2]))); break;
        case 2: _t->onDownloadFinished((*reinterpret_cast<std::add_pointer_t<bt::MagnetDownloader*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2]))); break;
        case 3: _t->onSlotTimeout((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::MagnetDownloader* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MagnetManager::*)(const bt::MagnetLink & , const QByteArray & , const kt::MagnetLinkLoadOptions & )>(_a, &MagnetManager::metadataDownloaded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MagnetManager::*)(bt::Uint32 , bt::Uint32 )>(_a, &MagnetManager::updateQueue, 1))
            return;
    }
}

const QMetaObject *kt::MagnetManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kt::MagnetManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt13MagnetManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int kt::MagnetManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void kt::MagnetManager::metadataDownloaded(const bt::MagnetLink & _t1, const QByteArray & _t2, const kt::MagnetLinkLoadOptions & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void kt::MagnetManager::updateQueue(bt::Uint32 _t1, bt::Uint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
QT_WARNING_POP
