/********************************************************************************
** Form generated from reading UI file 'DisplaySettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DISPLAYSETTINGS_H
#define UI_DISPLAYSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_DisplaySettingsWgt
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *ColorsGbw;
    QVBoxLayout *vboxLayout1;
    QTabWidget *ColorsTbw;
    QWidget *tab;
    QVBoxLayout *vboxLayout2;
    QVBoxLayout *vboxLayout3;
    QHBoxLayout *hboxLayout;
    QLabel *label_8;
    KColorButton *kcfg_DlSpdColor;
    QHBoxLayout *hboxLayout1;
    QLabel *label_9;
    KColorButton *kcfg_DlAvgColor;
    QHBoxLayout *hboxLayout2;
    QLabel *label_13;
    KColorButton *kcfg_DlLimitColor;
    QSpacerItem *spacerItem;
    QWidget *tab_2;
    QVBoxLayout *vboxLayout4;
    QGridLayout *gridLayout;
    QLabel *label_14;
    KColorButton *kcfg_PrAvgFromLColor;
    QLabel *label_19;
    KColorButton *kcfg_PrAvgToLColor;
    QLabel *label_20;
    KColorButton *kcfg_PrAvgFromSColor;
    QLabel *label_21;
    KColorButton *kcfg_PrFromLColor;
    QLabel *label_22;
    KColorButton *kcfg_PrFromSColor;
    QSpacerItem *spacerItem1;
    QWidget *tab_3;
    QVBoxLayout *vboxLayout5;
    QVBoxLayout *vboxLayout6;
    QHBoxLayout *hboxLayout3;
    QLabel *label_15;
    KColorButton *kcfg_UlSpdColor;
    QHBoxLayout *hboxLayout4;
    QLabel *label_16;
    KColorButton *kcfg_UlAvgColor;
    QHBoxLayout *hboxLayout5;
    QLabel *label_17;
    KColorButton *kcfg_UlLimitColor;
    QSpacerItem *spacerItem2;
    QWidget *tab_4;
    QVBoxLayout *vboxLayout7;
    QGridLayout *gridLayout1;
    QLabel *label_23;
    KColorButton *kcfg_CnLConnColor;
    QLabel *label_24;
    KColorButton *kcfg_CnLSwarmsColor;
    QLabel *label_25;
    KColorButton *kcfg_CnSConnColor;
    QLabel *label_26;
    KColorButton *kcfg_CnSSwarmsColor;
    QLabel *label_27;
    KColorButton *kcfg_CnAvgLConnPerTorrColor;
    QLabel *label_28;
    KColorButton *kcfg_CnAvgSConnPerTorrColor;
    QLabel *label_29;
    KColorButton *kcfg_CnAvgLConnPerRunTorrColor;
    QLabel *label_30;
    KColorButton *kcfg_CnAvgSConnPerRunTorrColor;
    QWidget *tab_5;
    QGridLayout *gridLayout2;
    QVBoxLayout *vboxLayout8;
    QHBoxLayout *hboxLayout6;
    QLabel *label_31;
    KColorButton *kcfg_DhtNodesColor;
    QHBoxLayout *hboxLayout7;
    QLabel *label_32;
    KColorButton *kcfg_DhtTasksColor;
    QSpacerItem *spacerItem3;
    QGroupBox *groupBox_3;
    QVBoxLayout *vboxLayout9;
    QCheckBox *kcfg_AntiAliasing;
    QCheckBox *kcfg_DrawBgdGrid;
    QGridLayout *gridLayout3;
    QLabel *label_18;
    QComboBox *kcfg_WidgetType;
    QLabel *label_33;
    QSpacerItem *spacerItem4;

    void setupUi(QWidget *DisplaySettingsWgt)
    {
        if (DisplaySettingsWgt->objectName().isEmpty())
            DisplaySettingsWgt->setObjectName("DisplaySettingsWgt");
        DisplaySettingsWgt->resize(461, 574);
        vboxLayout = new QVBoxLayout(DisplaySettingsWgt);
        vboxLayout->setObjectName("vboxLayout");
        ColorsGbw = new QGroupBox(DisplaySettingsWgt);
        ColorsGbw->setObjectName("ColorsGbw");
        vboxLayout1 = new QVBoxLayout(ColorsGbw);
        vboxLayout1->setObjectName("vboxLayout1");
        ColorsTbw = new QTabWidget(ColorsGbw);
        ColorsTbw->setObjectName("ColorsTbw");
        tab = new QWidget();
        tab->setObjectName("tab");
        vboxLayout2 = new QVBoxLayout(tab);
        vboxLayout2->setObjectName("vboxLayout2");
        vboxLayout3 = new QVBoxLayout();
        vboxLayout3->setObjectName("vboxLayout3");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        label_8 = new QLabel(tab);
        label_8->setObjectName("label_8");

        hboxLayout->addWidget(label_8);

        kcfg_DlSpdColor = new KColorButton(tab);
        kcfg_DlSpdColor->setObjectName("kcfg_DlSpdColor");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_DlSpdColor->sizePolicy().hasHeightForWidth());
        kcfg_DlSpdColor->setSizePolicy(sizePolicy);
        kcfg_DlSpdColor->setMaximumSize(QSize(64, 32));
        kcfg_DlSpdColor->setAutoFillBackground(true);

        hboxLayout->addWidget(kcfg_DlSpdColor);


        vboxLayout3->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        label_9 = new QLabel(tab);
        label_9->setObjectName("label_9");

        hboxLayout1->addWidget(label_9);

        kcfg_DlAvgColor = new KColorButton(tab);
        kcfg_DlAvgColor->setObjectName("kcfg_DlAvgColor");
        sizePolicy.setHeightForWidth(kcfg_DlAvgColor->sizePolicy().hasHeightForWidth());
        kcfg_DlAvgColor->setSizePolicy(sizePolicy);
        kcfg_DlAvgColor->setMaximumSize(QSize(64, 32));
        kcfg_DlAvgColor->setAutoFillBackground(true);
        kcfg_DlAvgColor->setFlat(false);

        hboxLayout1->addWidget(kcfg_DlAvgColor);


        vboxLayout3->addLayout(hboxLayout1);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setObjectName("hboxLayout2");
        label_13 = new QLabel(tab);
        label_13->setObjectName("label_13");

        hboxLayout2->addWidget(label_13);

        kcfg_DlLimitColor = new KColorButton(tab);
        kcfg_DlLimitColor->setObjectName("kcfg_DlLimitColor");
        sizePolicy.setHeightForWidth(kcfg_DlLimitColor->sizePolicy().hasHeightForWidth());
        kcfg_DlLimitColor->setSizePolicy(sizePolicy);
        kcfg_DlLimitColor->setMaximumSize(QSize(64, 32));
        kcfg_DlLimitColor->setAutoFillBackground(true);
        kcfg_DlLimitColor->setFlat(false);

        hboxLayout2->addWidget(kcfg_DlLimitColor);


        vboxLayout3->addLayout(hboxLayout2);


        vboxLayout2->addLayout(vboxLayout3);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout2->addItem(spacerItem);

        ColorsTbw->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        vboxLayout4 = new QVBoxLayout(tab_2);
        vboxLayout4->setObjectName("vboxLayout4");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label_14 = new QLabel(tab_2);
        label_14->setObjectName("label_14");

        gridLayout->addWidget(label_14, 0, 0, 1, 1);

        kcfg_PrAvgFromLColor = new KColorButton(tab_2);
        kcfg_PrAvgFromLColor->setObjectName("kcfg_PrAvgFromLColor");
        sizePolicy.setHeightForWidth(kcfg_PrAvgFromLColor->sizePolicy().hasHeightForWidth());
        kcfg_PrAvgFromLColor->setSizePolicy(sizePolicy);
        kcfg_PrAvgFromLColor->setMaximumSize(QSize(64, 32));
        kcfg_PrAvgFromLColor->setAutoFillBackground(true);
        kcfg_PrAvgFromLColor->setFlat(false);

        gridLayout->addWidget(kcfg_PrAvgFromLColor, 0, 1, 1, 1);

        label_19 = new QLabel(tab_2);
        label_19->setObjectName("label_19");

        gridLayout->addWidget(label_19, 1, 0, 1, 1);

        kcfg_PrAvgToLColor = new KColorButton(tab_2);
        kcfg_PrAvgToLColor->setObjectName("kcfg_PrAvgToLColor");
        sizePolicy.setHeightForWidth(kcfg_PrAvgToLColor->sizePolicy().hasHeightForWidth());
        kcfg_PrAvgToLColor->setSizePolicy(sizePolicy);
        kcfg_PrAvgToLColor->setMaximumSize(QSize(64, 32));
        kcfg_PrAvgToLColor->setAutoFillBackground(true);
        kcfg_PrAvgToLColor->setFlat(false);

        gridLayout->addWidget(kcfg_PrAvgToLColor, 1, 1, 1, 1);

        label_20 = new QLabel(tab_2);
        label_20->setObjectName("label_20");

        gridLayout->addWidget(label_20, 2, 0, 1, 1);

        kcfg_PrAvgFromSColor = new KColorButton(tab_2);
        kcfg_PrAvgFromSColor->setObjectName("kcfg_PrAvgFromSColor");
        sizePolicy.setHeightForWidth(kcfg_PrAvgFromSColor->sizePolicy().hasHeightForWidth());
        kcfg_PrAvgFromSColor->setSizePolicy(sizePolicy);
        kcfg_PrAvgFromSColor->setMaximumSize(QSize(64, 32));
        kcfg_PrAvgFromSColor->setAutoFillBackground(true);
        kcfg_PrAvgFromSColor->setFlat(false);

        gridLayout->addWidget(kcfg_PrAvgFromSColor, 2, 1, 1, 1);

        label_21 = new QLabel(tab_2);
        label_21->setObjectName("label_21");

        gridLayout->addWidget(label_21, 3, 0, 1, 1);

        kcfg_PrFromLColor = new KColorButton(tab_2);
        kcfg_PrFromLColor->setObjectName("kcfg_PrFromLColor");
        sizePolicy.setHeightForWidth(kcfg_PrFromLColor->sizePolicy().hasHeightForWidth());
        kcfg_PrFromLColor->setSizePolicy(sizePolicy);
        kcfg_PrFromLColor->setMaximumSize(QSize(64, 32));
        kcfg_PrFromLColor->setAutoFillBackground(true);
        kcfg_PrFromLColor->setFlat(false);

        gridLayout->addWidget(kcfg_PrFromLColor, 3, 1, 1, 1);

        label_22 = new QLabel(tab_2);
        label_22->setObjectName("label_22");

        gridLayout->addWidget(label_22, 4, 0, 1, 1);

        kcfg_PrFromSColor = new KColorButton(tab_2);
        kcfg_PrFromSColor->setObjectName("kcfg_PrFromSColor");
        sizePolicy.setHeightForWidth(kcfg_PrFromSColor->sizePolicy().hasHeightForWidth());
        kcfg_PrFromSColor->setSizePolicy(sizePolicy);
        kcfg_PrFromSColor->setMaximumSize(QSize(64, 32));
        kcfg_PrFromSColor->setAutoFillBackground(true);
        kcfg_PrFromSColor->setFlat(false);

        gridLayout->addWidget(kcfg_PrFromSColor, 4, 1, 1, 1);


        vboxLayout4->addLayout(gridLayout);

        spacerItem1 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout4->addItem(spacerItem1);

        ColorsTbw->addTab(tab_2, QString());
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        vboxLayout5 = new QVBoxLayout(tab_3);
        vboxLayout5->setObjectName("vboxLayout5");
        vboxLayout6 = new QVBoxLayout();
        vboxLayout6->setObjectName("vboxLayout6");
        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setObjectName("hboxLayout3");
        label_15 = new QLabel(tab_3);
        label_15->setObjectName("label_15");

        hboxLayout3->addWidget(label_15);

        kcfg_UlSpdColor = new KColorButton(tab_3);
        kcfg_UlSpdColor->setObjectName("kcfg_UlSpdColor");
        sizePolicy.setHeightForWidth(kcfg_UlSpdColor->sizePolicy().hasHeightForWidth());
        kcfg_UlSpdColor->setSizePolicy(sizePolicy);
        kcfg_UlSpdColor->setMaximumSize(QSize(64, 32));
        kcfg_UlSpdColor->setAutoFillBackground(true);
        kcfg_UlSpdColor->setFlat(false);

        hboxLayout3->addWidget(kcfg_UlSpdColor);


        vboxLayout6->addLayout(hboxLayout3);

        hboxLayout4 = new QHBoxLayout();
        hboxLayout4->setObjectName("hboxLayout4");
        label_16 = new QLabel(tab_3);
        label_16->setObjectName("label_16");

        hboxLayout4->addWidget(label_16);

        kcfg_UlAvgColor = new KColorButton(tab_3);
        kcfg_UlAvgColor->setObjectName("kcfg_UlAvgColor");
        sizePolicy.setHeightForWidth(kcfg_UlAvgColor->sizePolicy().hasHeightForWidth());
        kcfg_UlAvgColor->setSizePolicy(sizePolicy);
        kcfg_UlAvgColor->setMaximumSize(QSize(64, 32));
        kcfg_UlAvgColor->setAutoFillBackground(true);
        kcfg_UlAvgColor->setFlat(false);

        hboxLayout4->addWidget(kcfg_UlAvgColor);


        vboxLayout6->addLayout(hboxLayout4);

        hboxLayout5 = new QHBoxLayout();
        hboxLayout5->setObjectName("hboxLayout5");
        label_17 = new QLabel(tab_3);
        label_17->setObjectName("label_17");

        hboxLayout5->addWidget(label_17);

        kcfg_UlLimitColor = new KColorButton(tab_3);
        kcfg_UlLimitColor->setObjectName("kcfg_UlLimitColor");
        sizePolicy.setHeightForWidth(kcfg_UlLimitColor->sizePolicy().hasHeightForWidth());
        kcfg_UlLimitColor->setSizePolicy(sizePolicy);
        kcfg_UlLimitColor->setMaximumSize(QSize(64, 32));
        kcfg_UlLimitColor->setAutoFillBackground(true);
        kcfg_UlLimitColor->setFlat(false);

        hboxLayout5->addWidget(kcfg_UlLimitColor);


        vboxLayout6->addLayout(hboxLayout5);


        vboxLayout5->addLayout(vboxLayout6);

        spacerItem2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout5->addItem(spacerItem2);

        ColorsTbw->addTab(tab_3, QString());
        tab_4 = new QWidget();
        tab_4->setObjectName("tab_4");
        vboxLayout7 = new QVBoxLayout(tab_4);
        vboxLayout7->setObjectName("vboxLayout7");
        gridLayout1 = new QGridLayout();
        gridLayout1->setObjectName("gridLayout1");
        label_23 = new QLabel(tab_4);
        label_23->setObjectName("label_23");

        gridLayout1->addWidget(label_23, 0, 0, 1, 1);

        kcfg_CnLConnColor = new KColorButton(tab_4);
        kcfg_CnLConnColor->setObjectName("kcfg_CnLConnColor");
        sizePolicy.setHeightForWidth(kcfg_CnLConnColor->sizePolicy().hasHeightForWidth());
        kcfg_CnLConnColor->setSizePolicy(sizePolicy);
        kcfg_CnLConnColor->setMaximumSize(QSize(64, 32));
        kcfg_CnLConnColor->setAutoFillBackground(true);
        kcfg_CnLConnColor->setFlat(false);

        gridLayout1->addWidget(kcfg_CnLConnColor, 0, 1, 1, 1);

        label_24 = new QLabel(tab_4);
        label_24->setObjectName("label_24");

        gridLayout1->addWidget(label_24, 1, 0, 1, 1);

        kcfg_CnLSwarmsColor = new KColorButton(tab_4);
        kcfg_CnLSwarmsColor->setObjectName("kcfg_CnLSwarmsColor");
        sizePolicy.setHeightForWidth(kcfg_CnLSwarmsColor->sizePolicy().hasHeightForWidth());
        kcfg_CnLSwarmsColor->setSizePolicy(sizePolicy);
        kcfg_CnLSwarmsColor->setMaximumSize(QSize(64, 32));
        kcfg_CnLSwarmsColor->setAutoFillBackground(true);
        kcfg_CnLSwarmsColor->setFlat(false);

        gridLayout1->addWidget(kcfg_CnLSwarmsColor, 1, 1, 1, 1);

        label_25 = new QLabel(tab_4);
        label_25->setObjectName("label_25");

        gridLayout1->addWidget(label_25, 2, 0, 1, 1);

        kcfg_CnSConnColor = new KColorButton(tab_4);
        kcfg_CnSConnColor->setObjectName("kcfg_CnSConnColor");
        sizePolicy.setHeightForWidth(kcfg_CnSConnColor->sizePolicy().hasHeightForWidth());
        kcfg_CnSConnColor->setSizePolicy(sizePolicy);
        kcfg_CnSConnColor->setMaximumSize(QSize(64, 32));
        kcfg_CnSConnColor->setAutoFillBackground(true);
        kcfg_CnSConnColor->setFlat(false);

        gridLayout1->addWidget(kcfg_CnSConnColor, 2, 1, 1, 1);

        label_26 = new QLabel(tab_4);
        label_26->setObjectName("label_26");

        gridLayout1->addWidget(label_26, 3, 0, 1, 1);

        kcfg_CnSSwarmsColor = new KColorButton(tab_4);
        kcfg_CnSSwarmsColor->setObjectName("kcfg_CnSSwarmsColor");
        sizePolicy.setHeightForWidth(kcfg_CnSSwarmsColor->sizePolicy().hasHeightForWidth());
        kcfg_CnSSwarmsColor->setSizePolicy(sizePolicy);
        kcfg_CnSSwarmsColor->setMaximumSize(QSize(64, 32));
        kcfg_CnSSwarmsColor->setAutoFillBackground(true);
        kcfg_CnSSwarmsColor->setFlat(false);

        gridLayout1->addWidget(kcfg_CnSSwarmsColor, 3, 1, 1, 1);

        label_27 = new QLabel(tab_4);
        label_27->setObjectName("label_27");

        gridLayout1->addWidget(label_27, 4, 0, 1, 1);

        kcfg_CnAvgLConnPerTorrColor = new KColorButton(tab_4);
        kcfg_CnAvgLConnPerTorrColor->setObjectName("kcfg_CnAvgLConnPerTorrColor");
        sizePolicy.setHeightForWidth(kcfg_CnAvgLConnPerTorrColor->sizePolicy().hasHeightForWidth());
        kcfg_CnAvgLConnPerTorrColor->setSizePolicy(sizePolicy);
        kcfg_CnAvgLConnPerTorrColor->setMaximumSize(QSize(64, 32));
        kcfg_CnAvgLConnPerTorrColor->setAutoFillBackground(true);
        kcfg_CnAvgLConnPerTorrColor->setFlat(false);

        gridLayout1->addWidget(kcfg_CnAvgLConnPerTorrColor, 4, 1, 1, 1);

        label_28 = new QLabel(tab_4);
        label_28->setObjectName("label_28");

        gridLayout1->addWidget(label_28, 5, 0, 1, 1);

        kcfg_CnAvgSConnPerTorrColor = new KColorButton(tab_4);
        kcfg_CnAvgSConnPerTorrColor->setObjectName("kcfg_CnAvgSConnPerTorrColor");
        sizePolicy.setHeightForWidth(kcfg_CnAvgSConnPerTorrColor->sizePolicy().hasHeightForWidth());
        kcfg_CnAvgSConnPerTorrColor->setSizePolicy(sizePolicy);
        kcfg_CnAvgSConnPerTorrColor->setMaximumSize(QSize(64, 32));
        kcfg_CnAvgSConnPerTorrColor->setAutoFillBackground(true);
        kcfg_CnAvgSConnPerTorrColor->setFlat(false);

        gridLayout1->addWidget(kcfg_CnAvgSConnPerTorrColor, 5, 1, 1, 1);

        label_29 = new QLabel(tab_4);
        label_29->setObjectName("label_29");

        gridLayout1->addWidget(label_29, 6, 0, 1, 1);

        kcfg_CnAvgLConnPerRunTorrColor = new KColorButton(tab_4);
        kcfg_CnAvgLConnPerRunTorrColor->setObjectName("kcfg_CnAvgLConnPerRunTorrColor");
        sizePolicy.setHeightForWidth(kcfg_CnAvgLConnPerRunTorrColor->sizePolicy().hasHeightForWidth());
        kcfg_CnAvgLConnPerRunTorrColor->setSizePolicy(sizePolicy);
        kcfg_CnAvgLConnPerRunTorrColor->setMaximumSize(QSize(64, 32));
        kcfg_CnAvgLConnPerRunTorrColor->setAutoFillBackground(true);
        kcfg_CnAvgLConnPerRunTorrColor->setFlat(false);

        gridLayout1->addWidget(kcfg_CnAvgLConnPerRunTorrColor, 6, 1, 1, 1);

        label_30 = new QLabel(tab_4);
        label_30->setObjectName("label_30");

        gridLayout1->addWidget(label_30, 7, 0, 1, 1);

        kcfg_CnAvgSConnPerRunTorrColor = new KColorButton(tab_4);
        kcfg_CnAvgSConnPerRunTorrColor->setObjectName("kcfg_CnAvgSConnPerRunTorrColor");
        sizePolicy.setHeightForWidth(kcfg_CnAvgSConnPerRunTorrColor->sizePolicy().hasHeightForWidth());
        kcfg_CnAvgSConnPerRunTorrColor->setSizePolicy(sizePolicy);
        kcfg_CnAvgSConnPerRunTorrColor->setMaximumSize(QSize(64, 32));
        kcfg_CnAvgSConnPerRunTorrColor->setAutoFillBackground(true);
        kcfg_CnAvgSConnPerRunTorrColor->setFlat(false);

        gridLayout1->addWidget(kcfg_CnAvgSConnPerRunTorrColor, 7, 1, 1, 1);


        vboxLayout7->addLayout(gridLayout1);

        ColorsTbw->addTab(tab_4, QString());
        tab_5 = new QWidget();
        tab_5->setObjectName("tab_5");
        gridLayout2 = new QGridLayout(tab_5);
        gridLayout2->setObjectName("gridLayout2");
        vboxLayout8 = new QVBoxLayout();
        vboxLayout8->setObjectName("vboxLayout8");
        hboxLayout6 = new QHBoxLayout();
        hboxLayout6->setObjectName("hboxLayout6");
        label_31 = new QLabel(tab_5);
        label_31->setObjectName("label_31");

        hboxLayout6->addWidget(label_31);

        kcfg_DhtNodesColor = new KColorButton(tab_5);
        kcfg_DhtNodesColor->setObjectName("kcfg_DhtNodesColor");
        sizePolicy.setHeightForWidth(kcfg_DhtNodesColor->sizePolicy().hasHeightForWidth());
        kcfg_DhtNodesColor->setSizePolicy(sizePolicy);
        kcfg_DhtNodesColor->setMaximumSize(QSize(64, 32));
        kcfg_DhtNodesColor->setAutoFillBackground(true);
        kcfg_DhtNodesColor->setFlat(false);

        hboxLayout6->addWidget(kcfg_DhtNodesColor);


        vboxLayout8->addLayout(hboxLayout6);

        hboxLayout7 = new QHBoxLayout();
        hboxLayout7->setObjectName("hboxLayout7");
        label_32 = new QLabel(tab_5);
        label_32->setObjectName("label_32");

        hboxLayout7->addWidget(label_32);

        kcfg_DhtTasksColor = new KColorButton(tab_5);
        kcfg_DhtTasksColor->setObjectName("kcfg_DhtTasksColor");
        sizePolicy.setHeightForWidth(kcfg_DhtTasksColor->sizePolicy().hasHeightForWidth());
        kcfg_DhtTasksColor->setSizePolicy(sizePolicy);
        kcfg_DhtTasksColor->setMaximumSize(QSize(64, 32));
        kcfg_DhtTasksColor->setAutoFillBackground(true);
        kcfg_DhtTasksColor->setFlat(false);

        hboxLayout7->addWidget(kcfg_DhtTasksColor);


        vboxLayout8->addLayout(hboxLayout7);


        gridLayout2->addLayout(vboxLayout8, 0, 0, 1, 1);

        spacerItem3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout2->addItem(spacerItem3, 1, 0, 1, 1);

        ColorsTbw->addTab(tab_5, QString());

        vboxLayout1->addWidget(ColorsTbw);


        vboxLayout->addWidget(ColorsGbw);

        groupBox_3 = new QGroupBox(DisplaySettingsWgt);
        groupBox_3->setObjectName("groupBox_3");
        vboxLayout9 = new QVBoxLayout(groupBox_3);
        vboxLayout9->setObjectName("vboxLayout9");
        kcfg_AntiAliasing = new QCheckBox(groupBox_3);
        kcfg_AntiAliasing->setObjectName("kcfg_AntiAliasing");
        kcfg_AntiAliasing->setChecked(true);

        vboxLayout9->addWidget(kcfg_AntiAliasing);

        kcfg_DrawBgdGrid = new QCheckBox(groupBox_3);
        kcfg_DrawBgdGrid->setObjectName("kcfg_DrawBgdGrid");
        kcfg_DrawBgdGrid->setChecked(false);

        vboxLayout9->addWidget(kcfg_DrawBgdGrid);

        gridLayout3 = new QGridLayout();
        gridLayout3->setObjectName("gridLayout3");
        label_18 = new QLabel(groupBox_3);
        label_18->setObjectName("label_18");

        gridLayout3->addWidget(label_18, 0, 0, 1, 1);

        kcfg_WidgetType = new QComboBox(groupBox_3);
        kcfg_WidgetType->addItem(QString());
        kcfg_WidgetType->addItem(QString());
        kcfg_WidgetType->setObjectName("kcfg_WidgetType");

        gridLayout3->addWidget(kcfg_WidgetType, 0, 1, 1, 1);

        label_33 = new QLabel(groupBox_3);
        label_33->setObjectName("label_33");

        gridLayout3->addWidget(label_33, 1, 1, 1, 1);


        vboxLayout9->addLayout(gridLayout3);


        vboxLayout->addWidget(groupBox_3);

        spacerItem4 = new QSpacerItem(20, 141, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem4);

#if QT_CONFIG(shortcut)
        label_8->setBuddy(kcfg_DlSpdColor);
        label_9->setBuddy(kcfg_DlAvgColor);
        label_13->setBuddy(kcfg_DlLimitColor);
        label_14->setBuddy(kcfg_PrAvgFromLColor);
        label_19->setBuddy(kcfg_PrAvgToLColor);
        label_20->setBuddy(kcfg_PrAvgFromSColor);
        label_21->setBuddy(kcfg_PrFromLColor);
        label_22->setBuddy(kcfg_PrFromSColor);
        label_15->setBuddy(kcfg_UlSpdColor);
        label_16->setBuddy(kcfg_UlAvgColor);
        label_17->setBuddy(kcfg_UlLimitColor);
        label_23->setBuddy(kcfg_CnLConnColor);
        label_24->setBuddy(kcfg_CnLSwarmsColor);
        label_25->setBuddy(kcfg_CnSConnColor);
        label_26->setBuddy(kcfg_CnSSwarmsColor);
        label_27->setBuddy(kcfg_CnAvgLConnPerTorrColor);
        label_28->setBuddy(kcfg_CnAvgSConnPerTorrColor);
        label_29->setBuddy(kcfg_CnAvgLConnPerRunTorrColor);
        label_30->setBuddy(kcfg_CnAvgSConnPerRunTorrColor);
        label_31->setBuddy(kcfg_DhtNodesColor);
        label_32->setBuddy(kcfg_DhtTasksColor);
#endif // QT_CONFIG(shortcut)

        retranslateUi(DisplaySettingsWgt);

        ColorsTbw->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(DisplaySettingsWgt);
    } // setupUi

    void retranslateUi(QWidget *DisplaySettingsWgt)
    {
        ColorsGbw->setTitle(tr2i18n("Colors", nullptr));
        label_8->setText(tr2i18n("Current speed", "Name of a line on download chart"));
        kcfg_DlSpdColor->setText(QString());
        label_9->setText(tr2i18n("Average", "Name of a line on download chart"));
        kcfg_DlAvgColor->setText(QString());
        label_13->setText(tr2i18n("Limit", "Name of a line on download chart"));
        kcfg_DlLimitColor->setText(QString());
        ColorsTbw->setTabText(ColorsTbw->indexOf(tab), tr2i18n("Download", "Chart name"));
        label_14->setText(tr2i18n("Average from leechers", "Name of a line on chart"));
        kcfg_PrAvgFromLColor->setText(QString());
        label_19->setText(tr2i18n("Average to leechers", "Name of a line on chart"));
        kcfg_PrAvgToLColor->setText(QString());
        label_20->setText(tr2i18n("Average from seeds", "Name of a line on chart"));
        kcfg_PrAvgFromSColor->setText(QString());
        label_21->setText(tr2i18n("From leechers", "Name of a line on chart"));
        kcfg_PrFromLColor->setText(QString());
        label_22->setText(tr2i18n("From seeds", "Name of a line on chart"));
        kcfg_PrFromSColor->setText(QString());
        ColorsTbw->setTabText(ColorsTbw->indexOf(tab_2), tr2i18n("Peers", "Chart name"));
        label_15->setText(tr2i18n("Current speed", "Name of a line on upload chart"));
        kcfg_UlSpdColor->setText(QString());
        label_16->setText(tr2i18n("Average", "Name of a line on upload chart"));
        kcfg_UlAvgColor->setText(QString());
        label_17->setText(tr2i18n("Limit", "Name of a line on upload chart"));
        kcfg_UlLimitColor->setText(QString());
        ColorsTbw->setTabText(ColorsTbw->indexOf(tab_3), tr2i18n("Upload", "Chart name"));
        label_23->setText(tr2i18n("Leechers connected", "Name of a line on chart"));
        kcfg_CnLConnColor->setText(QString());
        label_24->setText(tr2i18n("Leechers in swarms", "Name of a line on chart"));
        kcfg_CnLSwarmsColor->setText(QString());
        label_25->setText(tr2i18n("Seeds connected", "Name of a line on chart"));
        kcfg_CnSConnColor->setText(QString());
        label_26->setText(tr2i18n("Seeds in swarms", "Name of a line on chart"));
        kcfg_CnSSwarmsColor->setText(QString());
        label_27->setText(tr2i18n("Average leechers connected per torrent", "Name of a line on chart"));
        kcfg_CnAvgLConnPerTorrColor->setText(QString());
        label_28->setText(tr2i18n("Average seeds connected per torrent", "Name of a line on chart"));
        kcfg_CnAvgSConnPerTorrColor->setText(QString());
        label_29->setText(tr2i18n("Avg. leechers connected per running torr.", "Name of a line on chart"));
        kcfg_CnAvgLConnPerRunTorrColor->setText(QString());
        label_30->setText(tr2i18n("Avg. seeds connected per running torrent", "Name of a line on chart"));
        kcfg_CnAvgSConnPerRunTorrColor->setText(QString());
        ColorsTbw->setTabText(ColorsTbw->indexOf(tab_4), tr2i18n("Connections", "Chart name"));
        label_31->setText(tr2i18n("Nodes", "Name of a line on chart"));
        kcfg_DhtNodesColor->setText(QString());
        label_32->setText(tr2i18n("Tasks", "Name of a line on chart"));
        kcfg_DhtTasksColor->setText(QString());
        ColorsTbw->setTabText(ColorsTbw->indexOf(tab_5), tr2i18n("DHT", "Chart name"));
        groupBox_3->setTitle(tr2i18n("Display", "This is about how things are displayed (colors, etc), not about a screen/display"));
        kcfg_AntiAliasing->setText(tr2i18n("Use anti-aliasing", nullptr));
        kcfg_DrawBgdGrid->setText(tr2i18n("Draw background grid", nullptr));
        label_18->setText(tr2i18n("Widget type:", "@label:listbox"));
        kcfg_WidgetType->setItemText(0, tr2i18n("Native", nullptr));
        kcfg_WidgetType->setItemText(1, tr2i18n("KDE", nullptr));

        label_33->setText(tr2i18n("(plugin reload is needed after change)", nullptr));
        (void)DisplaySettingsWgt;
    } // retranslateUi

};

namespace Ui {
    class DisplaySettingsWgt: public Ui_DisplaySettingsWgt {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DISPLAYSETTINGS_H

