/********************************************************************************
** Form generated from reading UI file 'scanfolderprefpage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SCANFOLDERPREFPAGE_H
#define UI_SCANFOLDERPREFPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ScanFolderPrefPage
{
public:
    QVBoxLayout *vboxLayout;
    QLabel *label;
    QHBoxLayout *hboxLayout;
    QListWidget *m_folders;
    QVBoxLayout *vboxLayout1;
    QPushButton *m_add;
    QPushButton *m_remove;
    QSpacerItem *spacerItem;
    QGroupBox *groupBox;
    QVBoxLayout *vboxLayout2;
    QCheckBox *kcfg_openSilently;
    QCheckBox *kcfg_recursive;
    QCheckBox *kcfg_actionDelete;
    QCheckBox *kcfg_actionMove;
    QHBoxLayout *hboxLayout1;
    QCheckBox *kcfg_addToGroup;
    QComboBox *m_group;

    void setupUi(QWidget *ScanFolderPrefPage)
    {
        if (ScanFolderPrefPage->objectName().isEmpty())
            ScanFolderPrefPage->setObjectName("ScanFolderPrefPage");
        ScanFolderPrefPage->resize(559, 590);
        vboxLayout = new QVBoxLayout(ScanFolderPrefPage);
        vboxLayout->setObjectName("vboxLayout");
        label = new QLabel(ScanFolderPrefPage);
        label->setObjectName("label");

        vboxLayout->addWidget(label);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        m_folders = new QListWidget(ScanFolderPrefPage);
        m_folders->setObjectName("m_folders");

        hboxLayout->addWidget(m_folders);

        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName("vboxLayout1");
        m_add = new QPushButton(ScanFolderPrefPage);
        m_add->setObjectName("m_add");

        vboxLayout1->addWidget(m_add);

        m_remove = new QPushButton(ScanFolderPrefPage);
        m_remove->setObjectName("m_remove");

        vboxLayout1->addWidget(m_remove);

        spacerItem = new QSpacerItem(20, 221, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout1->addItem(spacerItem);


        hboxLayout->addLayout(vboxLayout1);


        vboxLayout->addLayout(hboxLayout);

        groupBox = new QGroupBox(ScanFolderPrefPage);
        groupBox->setObjectName("groupBox");
        vboxLayout2 = new QVBoxLayout(groupBox);
        vboxLayout2->setObjectName("vboxLayout2");
        kcfg_openSilently = new QCheckBox(groupBox);
        kcfg_openSilently->setObjectName("kcfg_openSilently");

        vboxLayout2->addWidget(kcfg_openSilently);

        kcfg_recursive = new QCheckBox(groupBox);
        kcfg_recursive->setObjectName("kcfg_recursive");

        vboxLayout2->addWidget(kcfg_recursive);

        kcfg_actionDelete = new QCheckBox(groupBox);
        kcfg_actionDelete->setObjectName("kcfg_actionDelete");

        vboxLayout2->addWidget(kcfg_actionDelete);

        kcfg_actionMove = new QCheckBox(groupBox);
        kcfg_actionMove->setObjectName("kcfg_actionMove");

        vboxLayout2->addWidget(kcfg_actionMove);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        kcfg_addToGroup = new QCheckBox(groupBox);
        kcfg_addToGroup->setObjectName("kcfg_addToGroup");

        hboxLayout1->addWidget(kcfg_addToGroup);

        m_group = new QComboBox(groupBox);
        m_group->setObjectName("m_group");

        hboxLayout1->addWidget(m_group);


        vboxLayout2->addLayout(hboxLayout1);


        vboxLayout->addWidget(groupBox);


        retranslateUi(ScanFolderPrefPage);
        QObject::connect(kcfg_addToGroup, &QCheckBox::toggled, m_group, &QComboBox::setEnabled);

        QMetaObject::connectSlotsByName(ScanFolderPrefPage);
    } // setupUi

    void retranslateUi(QWidget *ScanFolderPrefPage)
    {
        label->setText(tr2i18n("Folders to scan for torrents:", nullptr));
#if QT_CONFIG(tooltip)
        m_folders->setToolTip(tr2i18n("List of folders which will be scanned for torrents by this plugin.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        m_add->setToolTip(tr2i18n("Add a new folder to be scanned.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_add->setText(tr2i18n("Add Folder", nullptr));
#if QT_CONFIG(tooltip)
        m_remove->setToolTip(tr2i18n("Remove a folder from the list.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_remove->setText(tr2i18n("Remove Folder", nullptr));
        groupBox->setTitle(tr2i18n("Options", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_openSilently->setToolTip(tr2i18n("Open the torrents without asking any questions.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_openSilently->setText(tr2i18n("Open silently", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_recursive->setToolTip(tr2i18n("Scan the folder recursively for torrents. <br/><br/>\n"
"Note: This will not be done for any folder named loaded.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_recursive->setText(tr2i18n("Scan subfolders", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_actionDelete->setToolTip(tr2i18n("When a torrent file has been found and loaded, delete it.<br/><br/>\n"
"Warning: you will permanently lose this file.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_actionDelete->setText(tr2i18n("Remove torrent file after loading", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_actionMove->setToolTip(tr2i18n("When a torrent file is loaded, move it to a subdirectory named loaded. If the folder does not exist, it will be created.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_actionMove->setText(tr2i18n("Move torrent file to loaded directory", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_addToGroup->setToolTip(tr2i18n("Add torrents opened with this plugin to a group.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_addToGroup->setText(tr2i18n("Add torrent to group:", nullptr));
#if QT_CONFIG(tooltip)
        m_group->setToolTip(tr2i18n("Group to add torrents to.", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)ScanFolderPrefPage;
    } // retranslateUi

};

namespace Ui {
    class ScanFolderPrefPage: public Ui_ScanFolderPrefPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SCANFOLDERPREFPAGE_H

