/********************************************************************************
** Form generated from reading UI file 'upnptestwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_UPNPTESTWIDGET_H
#define UI_UPNPTESTWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_UPnPTestWidget
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *hboxLayout;
    QHBoxLayout *hboxLayout1;
    QLabel *label_3;
    QLabel *m_router;
    QPushButton *m_find_routers;
    QTextBrowser *m_text_output;
    QHBoxLayout *horizontalLayout;
    QHBoxLayout *hboxLayout2;
    QLabel *label;
    QSpinBox *m_port;
    QHBoxLayout *hboxLayout3;
    QLabel *label_2;
    QComboBox *m_protocol;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *m_forward;
    QPushButton *m_undo_forward;
    QCheckBox *m_verbose;

    void setupUi(QWidget *UPnPTestWidget)
    {
        if (UPnPTestWidget->objectName().isEmpty())
            UPnPTestWidget->setObjectName("UPnPTestWidget");
        UPnPTestWidget->resize(684, 418);
        verticalLayout = new QVBoxLayout(UPnPTestWidget);
        verticalLayout->setObjectName("verticalLayout");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        label_3 = new QLabel(UPnPTestWidget);
        label_3->setObjectName("label_3");

        hboxLayout1->addWidget(label_3);

        m_router = new QLabel(UPnPTestWidget);
        m_router->setObjectName("m_router");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_router->sizePolicy().hasHeightForWidth());
        m_router->setSizePolicy(sizePolicy);
        m_router->setFrameShape(QFrame::Panel);

        hboxLayout1->addWidget(m_router);


        hboxLayout->addLayout(hboxLayout1);

        m_find_routers = new QPushButton(UPnPTestWidget);
        m_find_routers->setObjectName("m_find_routers");

        hboxLayout->addWidget(m_find_routers);


        verticalLayout->addLayout(hboxLayout);

        m_text_output = new QTextBrowser(UPnPTestWidget);
        m_text_output->setObjectName("m_text_output");

        verticalLayout->addWidget(m_text_output);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setObjectName("hboxLayout2");
        label = new QLabel(UPnPTestWidget);
        label->setObjectName("label");

        hboxLayout2->addWidget(label);

        m_port = new QSpinBox(UPnPTestWidget);
        m_port->setObjectName("m_port");
        m_port->setMinimum(1);
        m_port->setMaximum(65535);
        m_port->setValue(4000);

        hboxLayout2->addWidget(m_port);


        horizontalLayout->addLayout(hboxLayout2);

        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setObjectName("hboxLayout3");
        label_2 = new QLabel(UPnPTestWidget);
        label_2->setObjectName("label_2");

        hboxLayout3->addWidget(label_2);

        m_protocol = new QComboBox(UPnPTestWidget);
        m_protocol->addItem(QString());
        m_protocol->addItem(QString());
        m_protocol->setObjectName("m_protocol");

        hboxLayout3->addWidget(m_protocol);


        horizontalLayout->addLayout(hboxLayout3);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);

        m_forward = new QPushButton(UPnPTestWidget);
        m_forward->setObjectName("m_forward");

        horizontalLayout->addWidget(m_forward);

        m_undo_forward = new QPushButton(UPnPTestWidget);
        m_undo_forward->setObjectName("m_undo_forward");

        horizontalLayout->addWidget(m_undo_forward);

        m_verbose = new QCheckBox(UPnPTestWidget);
        m_verbose->setObjectName("m_verbose");

        horizontalLayout->addWidget(m_verbose);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(UPnPTestWidget);

        QMetaObject::connectSlotsByName(UPnPTestWidget);
    } // setupUi

    void retranslateUi(QWidget *UPnPTestWidget)
    {
        UPnPTestWidget->setWindowTitle(tr2i18n("UPnP Test Application", nullptr));
        label_3->setText(tr2i18n("Router:", nullptr));
        m_router->setText(tr2i18n("No routers found.", nullptr));
        m_find_routers->setText(tr2i18n("Find Routers", nullptr));
        label->setText(tr2i18n("Port:", nullptr));
        label_2->setText(tr2i18n("Protocol:", nullptr));
        m_protocol->setItemText(0, tr2i18n("UDP", nullptr));
        m_protocol->setItemText(1, tr2i18n("TCP", nullptr));

        m_forward->setText(tr2i18n("Forward", nullptr));
        m_undo_forward->setText(tr2i18n("Undo Forward", nullptr));
        m_verbose->setText(tr2i18n("Verbose mode", nullptr));
    } // retranslateUi

};

namespace Ui {
    class UPnPTestWidget: public Ui_UPnPTestWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UPNPTESTWIDGET_H

