/********************************************************************************
** Form generated from reading UI file 'propertiesdlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROPERTIESDLG_H
#define UI_PROPERTIESDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_PropertiesDlg
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *dht;
    QCheckBox *pex;
    QCheckBox *superseeding;
    QCheckBox *move_on_completion_enabled;
    KUrlRequester *move_on_completion_url;
    QFrame *line;
    QDialogButtonBox *m_buttonBox;

    void setupUi(QDialog *PropertiesDlg)
    {
        if (PropertiesDlg->objectName().isEmpty())
            PropertiesDlg->setObjectName("PropertiesDlg");
        PropertiesDlg->resize(406, 247);
        verticalLayout = new QVBoxLayout(PropertiesDlg);
        verticalLayout->setObjectName("verticalLayout");
        dht = new QCheckBox(PropertiesDlg);
        dht->setObjectName("dht");

        verticalLayout->addWidget(dht);

        pex = new QCheckBox(PropertiesDlg);
        pex->setObjectName("pex");

        verticalLayout->addWidget(pex);

        superseeding = new QCheckBox(PropertiesDlg);
        superseeding->setObjectName("superseeding");

        verticalLayout->addWidget(superseeding);

        move_on_completion_enabled = new QCheckBox(PropertiesDlg);
        move_on_completion_enabled->setObjectName("move_on_completion_enabled");

        verticalLayout->addWidget(move_on_completion_enabled);

        move_on_completion_url = new KUrlRequester(PropertiesDlg);
        move_on_completion_url->setObjectName("move_on_completion_url");
        move_on_completion_url->setMode(KFile::Directory|KFile::ExistingOnly|KFile::LocalOnly);

        verticalLayout->addWidget(move_on_completion_url);

        line = new QFrame(PropertiesDlg);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        m_buttonBox = new QDialogButtonBox(PropertiesDlg);
        m_buttonBox->setObjectName("m_buttonBox");
        m_buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(m_buttonBox);


        retranslateUi(PropertiesDlg);

        QMetaObject::connectSlotsByName(PropertiesDlg);
    } // setupUi

    void retranslateUi(QDialog *PropertiesDlg)
    {
        PropertiesDlg->setWindowTitle(tr2i18n("Properties", nullptr));
#if QT_CONFIG(tooltip)
        dht->setToolTip(tr2i18n("DHT is a distributed database which can be used to find more peers for a torrent.", nullptr));
#endif // QT_CONFIG(tooltip)
        dht->setText(tr2i18n("Use DHT to find more peers", nullptr));
#if QT_CONFIG(tooltip)
        pex->setToolTip(tr2i18n("Peer exchange results in more peers being found, by exchanging information about peers with other peers.", nullptr));
#endif // QT_CONFIG(tooltip)
        pex->setText(tr2i18n("Use peer exchange to find more peers", nullptr));
#if QT_CONFIG(tooltip)
        superseeding->setToolTip(tr2i18n("<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Superseeding mode, is a special seeding mode which allows you to achieve much higher seeding efficiencies. This results in less bandwidth used to spread a torrent.</p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Note: </span>This should only be used if the swarm has not fully been established. Once there are multiple active seeders, this mode becomes useless.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        superseeding->setText(tr2i18n("Use superseeding mode for seeding", nullptr));
#if QT_CONFIG(tooltip)
        move_on_completion_enabled->setToolTip(tr2i18n("Move the files of the torrent to a different directory when it has finished downloading.", nullptr));
#endif // QT_CONFIG(tooltip)
        move_on_completion_enabled->setText(tr2i18n("Move when completed to:", nullptr));
#if QT_CONFIG(tooltip)
        move_on_completion_url->setToolTip(tr2i18n("Location to move the files to.", nullptr));
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class PropertiesDlg: public Ui_PropertiesDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROPERTIESDLG_H

