/********************************************************************************
** Form generated from reading UI file 'scanextender.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SCANEXTENDER_H
#define UI_SCANEXTENDER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ScanExtender
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_6;
    QHBoxLayout *horizontalLayout_2;
    QLabel *textLabel2;
    QLabel *chunks_found;
    QHBoxLayout *horizontalLayout_3;
    QLabel *textLabel3;
    QLabel *chunks_failed;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label;
    QLabel *chunks_not_downloaded;
    QHBoxLayout *horizontalLayout_5;
    QLabel *label_2;
    QLabel *chunks_downloaded;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout;
    QProgressBar *progress_bar;
    QPushButton *cancel_button;
    QPushButton *close_button;
    QLabel *error_msg;

    void setupUi(QWidget *ScanExtender)
    {
        if (ScanExtender->objectName().isEmpty())
            ScanExtender->setObjectName("ScanExtender");
        ScanExtender->resize(596, 88);
        verticalLayout = new QVBoxLayout(ScanExtender);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        textLabel2 = new QLabel(ScanExtender);
        textLabel2->setObjectName("textLabel2");
        textLabel2->setWordWrap(false);

        horizontalLayout_2->addWidget(textLabel2);

        chunks_found = new QLabel(ScanExtender);
        chunks_found->setObjectName("chunks_found");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(chunks_found->sizePolicy().hasHeightForWidth());
        chunks_found->setSizePolicy(sizePolicy);
        chunks_found->setMinimumSize(QSize(50, 0));
        chunks_found->setFrameShape(QFrame::NoFrame);
        chunks_found->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        chunks_found->setWordWrap(false);

        horizontalLayout_2->addWidget(chunks_found);


        horizontalLayout_6->addLayout(horizontalLayout_2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        textLabel3 = new QLabel(ScanExtender);
        textLabel3->setObjectName("textLabel3");
        textLabel3->setWordWrap(false);

        horizontalLayout_3->addWidget(textLabel3);

        chunks_failed = new QLabel(ScanExtender);
        chunks_failed->setObjectName("chunks_failed");
        chunks_failed->setMinimumSize(QSize(50, 0));
        chunks_failed->setFrameShape(QFrame::NoFrame);
        chunks_failed->setFrameShadow(QFrame::Plain);
        chunks_failed->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        chunks_failed->setWordWrap(false);

        horizontalLayout_3->addWidget(chunks_failed);


        horizontalLayout_6->addLayout(horizontalLayout_3);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        label = new QLabel(ScanExtender);
        label->setObjectName("label");

        horizontalLayout_4->addWidget(label);

        chunks_not_downloaded = new QLabel(ScanExtender);
        chunks_not_downloaded->setObjectName("chunks_not_downloaded");
        sizePolicy.setHeightForWidth(chunks_not_downloaded->sizePolicy().hasHeightForWidth());
        chunks_not_downloaded->setSizePolicy(sizePolicy);
        chunks_not_downloaded->setMinimumSize(QSize(50, 0));
        chunks_not_downloaded->setFrameShape(QFrame::NoFrame);
        chunks_not_downloaded->setFrameShadow(QFrame::Plain);
        chunks_not_downloaded->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        chunks_not_downloaded->setWordWrap(false);

        horizontalLayout_4->addWidget(chunks_not_downloaded);


        horizontalLayout_6->addLayout(horizontalLayout_4);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        label_2 = new QLabel(ScanExtender);
        label_2->setObjectName("label_2");

        horizontalLayout_5->addWidget(label_2);

        chunks_downloaded = new QLabel(ScanExtender);
        chunks_downloaded->setObjectName("chunks_downloaded");
        chunks_downloaded->setMinimumSize(QSize(50, 0));
        chunks_downloaded->setFrameShape(QFrame::NoFrame);
        chunks_downloaded->setFrameShadow(QFrame::Plain);
        chunks_downloaded->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        chunks_downloaded->setWordWrap(false);

        horizontalLayout_5->addWidget(chunks_downloaded);


        horizontalLayout_6->addLayout(horizontalLayout_5);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout_6);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        progress_bar = new QProgressBar(ScanExtender);
        progress_bar->setObjectName("progress_bar");
        progress_bar->setValue(24);

        horizontalLayout->addWidget(progress_bar);

        cancel_button = new QPushButton(ScanExtender);
        cancel_button->setObjectName("cancel_button");

        horizontalLayout->addWidget(cancel_button);

        close_button = new QPushButton(ScanExtender);
        close_button->setObjectName("close_button");

        horizontalLayout->addWidget(close_button);


        verticalLayout->addLayout(horizontalLayout);

        error_msg = new QLabel(ScanExtender);
        error_msg->setObjectName("error_msg");

        verticalLayout->addWidget(error_msg);


        retranslateUi(ScanExtender);

        QMetaObject::connectSlotsByName(ScanExtender);
    } // setupUi

    void retranslateUi(QWidget *ScanExtender)
    {
        textLabel2->setText(tr2i18n("Found:", nullptr));
#if QT_CONFIG(tooltip)
        chunks_found->setToolTip(tr2i18n("The number of chunks which were not downloaded but have been found anyway.", nullptr));
#endif // QT_CONFIG(tooltip)
        chunks_found->setText(tr2i18n("0", nullptr));
        textLabel3->setText(tr2i18n("Failed:", nullptr));
#if QT_CONFIG(tooltip)
        chunks_failed->setToolTip(tr2i18n("The number of chunks which have been downloaded, and which are not OK.", nullptr));
#endif // QT_CONFIG(tooltip)
        chunks_failed->setText(tr2i18n("0", nullptr));
        label->setText(tr2i18n("Not downloaded:", nullptr));
#if QT_CONFIG(tooltip)
        chunks_not_downloaded->setToolTip(tr2i18n("The number of chunks which have not been downloaded.", nullptr));
#endif // QT_CONFIG(tooltip)
        chunks_not_downloaded->setText(tr2i18n("0", nullptr));
        label_2->setText(tr2i18n("Downloaded:", nullptr));
#if QT_CONFIG(tooltip)
        chunks_downloaded->setToolTip(tr2i18n("The number of chunks which have been downloaded, and which are OK.", nullptr));
#endif // QT_CONFIG(tooltip)
        chunks_downloaded->setText(tr2i18n("0", nullptr));
        progress_bar->setFormat(tr2i18n("%p%", nullptr));
        cancel_button->setText(tr2i18n("Cancel", nullptr));
        close_button->setText(tr2i18n("Close", nullptr));
        error_msg->setText(tr2i18n("Errors:", nullptr));
        (void)ScanExtender;
    } // retranslateUi

};

namespace Ui {
    class ScanExtender: public Ui_ScanExtender {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SCANEXTENDER_H

