/********************************************************************************
** Form generated from reading UI file 'logprefwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LOGPREFWIDGET_H
#define UI_LOGPREFWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_LogPrefWidget
{
public:
    QVBoxLayout *verticalLayout_2;
    QTreeView *m_logging_flags;
    QGroupBox *groupBox_3;
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_useRichText;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QComboBox *kcfg_logWidgetPosition;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_2;
    QSpinBox *kcfg_maxBlockCount;
    QSpacerItem *horizontalSpacer_2;

    void setupUi(QWidget *LogPrefWidget)
    {
        if (LogPrefWidget->objectName().isEmpty())
            LogPrefWidget->setObjectName("LogPrefWidget");
        LogPrefWidget->resize(456, 421);
        verticalLayout_2 = new QVBoxLayout(LogPrefWidget);
        verticalLayout_2->setObjectName("verticalLayout_2");
        m_logging_flags = new QTreeView(LogPrefWidget);
        m_logging_flags->setObjectName("m_logging_flags");
        m_logging_flags->setAlternatingRowColors(true);
        m_logging_flags->setRootIsDecorated(false);

        verticalLayout_2->addWidget(m_logging_flags);

        groupBox_3 = new QGroupBox(LogPrefWidget);
        groupBox_3->setObjectName("groupBox_3");
        verticalLayout = new QVBoxLayout(groupBox_3);
        verticalLayout->setObjectName("verticalLayout");
        kcfg_useRichText = new QCheckBox(groupBox_3);
        kcfg_useRichText->setObjectName("kcfg_useRichText");

        verticalLayout->addWidget(kcfg_useRichText);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(groupBox_3);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        kcfg_logWidgetPosition = new QComboBox(groupBox_3);
        kcfg_logWidgetPosition->addItem(QString());
        kcfg_logWidgetPosition->addItem(QString());
        kcfg_logWidgetPosition->addItem(QString());
        kcfg_logWidgetPosition->setObjectName("kcfg_logWidgetPosition");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_logWidgetPosition->sizePolicy().hasHeightForWidth());
        kcfg_logWidgetPosition->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(kcfg_logWidgetPosition);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_2 = new QLabel(groupBox_3);
        label_2->setObjectName("label_2");

        horizontalLayout_2->addWidget(label_2);

        kcfg_maxBlockCount = new QSpinBox(groupBox_3);
        kcfg_maxBlockCount->setObjectName("kcfg_maxBlockCount");

        horizontalLayout_2->addWidget(kcfg_maxBlockCount);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout_2);


        verticalLayout_2->addWidget(groupBox_3);


        retranslateUi(LogPrefWidget);

        QMetaObject::connectSlotsByName(LogPrefWidget);
    } // setupUi

    void retranslateUi(QWidget *LogPrefWidget)
    {
#if QT_CONFIG(tooltip)
        m_logging_flags->setToolTip(tr2i18n("<html>Double click on the log level to alter it. The possible levels are:\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">All: </span>All messages are shown</p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Important: </span>Only important messages are shown</p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Notice: </span>Only notice and important messages are shown</p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">D"
                        "ebug: </span>Debug, notice and important messages are shown</p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">None:</span> No messages are shown</p></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox_3->setTitle(tr2i18n("Options", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_useRichText->setToolTip(tr2i18n("Whether or not to use rich text or just plain text, for the logging output shown in the logviewer.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_useRichText->setText(tr2i18n("Use rich text for logging output", nullptr));
        label->setText(tr2i18n("Log widget position:", nullptr));
        kcfg_logWidgetPosition->setItemText(0, tr2i18n("Separate activity", nullptr));
        kcfg_logWidgetPosition->setItemText(1, tr2i18n("Dockable widget", nullptr));
        kcfg_logWidgetPosition->setItemText(2, tr2i18n("Torrent activity", nullptr));

        label_2->setText(tr2i18n("Maximum number of visible lines:", nullptr));
        (void)LogPrefWidget;
    } // retranslateUi

};

namespace Ui {
    class LogPrefWidget: public Ui_LogPrefWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LOGPREFWIDGET_H

