/****************************************************************************
** Meta object code from reading C++ file 'dbussettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktorrent-26.04.3/libktcore/dbus/dbussettings.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbussettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2kt12DBusSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto kt::DBusSettings::qt_create_metaobjectdata<qt_meta_tag_ZN2kt12DBusSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "kt::DBusSettings",
        "D-Bus Interface",
        "org.ktorrent.settings",
        "maxDownloads",
        "",
        "setMaxDownloads",
        "val",
        "maxSeeds",
        "setMaxSeeds",
        "startDownloadsOnLowDiskSpace",
        "setStartDownloadsOnLowDiskSpace",
        "maxConnections",
        "setMaxConnections",
        "maxTotalConnections",
        "setMaxTotalConnections",
        "maxUploadRate",
        "setMaxUploadRate",
        "maxDownloadRate",
        "setMaxDownloadRate",
        "maxRatio",
        "setMaxRatio",
        "greenRatio",
        "setGreenRatio",
        "port",
        "setPort",
        "udpTrackerPort",
        "setUdpTrackerPort",
        "showSystemTrayIcon",
        "setShowSystemTrayIcon",
        "showSpeedBarInTrayIcon",
        "setShowSpeedBarInTrayIcon",
        "downloadBandwidth",
        "setDownloadBandwidth",
        "uploadBandwidth",
        "setUploadBandwidth",
        "alwaysMinimizeToSystemTray",
        "setAlwaysMinimizeToSystemTray",
        "showPopups",
        "setShowPopups",
        "keepSeeding",
        "setKeepSeeding",
        "tempDir",
        "setTempDir",
        "useSaveDir",
        "setUseSaveDir",
        "saveDir",
        "setSaveDir",
        "useTorrentCopyDir",
        "setUseTorrentCopyDir",
        "torrentCopyDir",
        "setTorrentCopyDir",
        "useCustomIP",
        "setUseCustomIP",
        "lastSaveDir",
        "setLastSaveDir",
        "customIP",
        "setCustomIP",
        "guiUpdateInterval",
        "setGuiUpdateInterval",
        "dhtSupport",
        "setDhtSupport",
        "dhtPort",
        "setDhtPort",
        "pexEnabled",
        "setPexEnabled",
        "numUploadSlots",
        "setNumUploadSlots",
        "useEncryption",
        "setUseEncryption",
        "allowUnencryptedConnections",
        "setAllowUnencryptedConnections",
        "typeOfService",
        "setTypeOfService",
        "dscp",
        "setDscp",
        "maxConnectingSockets",
        "setMaxConnectingSockets",
        "checkWhenFinished",
        "setCheckWhenFinished",
        "shownColumns",
        "QList<int>",
        "setShownColumns",
        "useKDEProxySettings",
        "setUseKDEProxySettings",
        "httpProxy",
        "setHttpProxy",
        "httpProxyPort",
        "setHttpProxyPort",
        "useProxyForWebSeeds",
        "setUseProxyForWebSeeds",
        "useProxyForTracker",
        "setUseProxyForTracker",
        "socksEnabled",
        "setSocksEnabled",
        "socksProxy",
        "setSocksProxy",
        "socksPort",
        "setSocksPort",
        "socksVersion",
        "setSocksVersion",
        "socksUsePassword",
        "setSocksUsePassword",
        "socksUsername",
        "setSocksUsername",
        "socksPassword",
        "setSocksPassword",
        "diskPrealloc",
        "setDiskPrealloc",
        "fullDiskPrealloc",
        "setFullDiskPrealloc",
        "minDiskSpace",
        "setMinDiskSpace",
        "cpuUsage",
        "setCpuUsage",
        "useCompletedDir",
        "setUseCompletedDir",
        "completedDir",
        "setCompletedDir",
        "maxSeedTime",
        "setMaxSeedTime",
        "networkInterface",
        "setNetworkInterface",
        "openMultipleTorrentsSilently",
        "setOpenMultipleTorrentsSilently",
        "openAllTorrentsSilently",
        "setOpenAllTorrentsSilently",
        "decreasePriorityOfStalledTorrents",
        "setDecreasePriorityOfStalledTorrents",
        "stallTimer",
        "setStallTimer",
        "previewSizeAudio",
        "setPreviewSizeAudio",
        "previewSizeVideo",
        "setPreviewSizeVideo",
        "suppressSleep",
        "setSuppressSleep",
        "manuallyControlTorrents",
        "setManuallyControlTorrents",
        "webseedsEnabled",
        "setWebseedsEnabled",
        "lookUpHostnameOfPeers",
        "setLookUpHostnameOfPeers",
        "utpEnabled",
        "setUtpEnabled",
        "onlyUseUtp",
        "setOnlyUseUtp",
        "primaryTransportProtocol",
        "setPrimaryTransportProtocol",
        "autoRenameSingleFileTorrents",
        "setAutoRenameSingleFileTorrents",
        "numMagnetDownloadingSlots",
        "setNumMagnetDownloadingSlots",
        "requeueMagnets",
        "setRequeueMagnets",
        "requeueMagnetsTime",
        "setRequeueMagnetsTime",
        "showTotalSpeedInTitle",
        "setShowTotalSpeedInTitle",
        "apply"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'maxDownloads'
        QtMocHelpers::SlotData<int()>(3, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setMaxDownloads'
        QtMocHelpers::SlotData<void(int)>(5, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'maxSeeds'
        QtMocHelpers::SlotData<int()>(7, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setMaxSeeds'
        QtMocHelpers::SlotData<void(int)>(8, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'startDownloadsOnLowDiskSpace'
        QtMocHelpers::SlotData<int()>(9, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setStartDownloadsOnLowDiskSpace'
        QtMocHelpers::SlotData<void(int)>(10, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'maxConnections'
        QtMocHelpers::SlotData<int()>(11, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setMaxConnections'
        QtMocHelpers::SlotData<void(int)>(12, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'maxTotalConnections'
        QtMocHelpers::SlotData<int()>(13, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setMaxTotalConnections'
        QtMocHelpers::SlotData<void(int)>(14, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'maxUploadRate'
        QtMocHelpers::SlotData<int()>(15, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setMaxUploadRate'
        QtMocHelpers::SlotData<void(int)>(16, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'maxDownloadRate'
        QtMocHelpers::SlotData<int()>(17, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setMaxDownloadRate'
        QtMocHelpers::SlotData<void(int)>(18, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'maxRatio'
        QtMocHelpers::SlotData<double()>(19, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Double),
        // Slot 'setMaxRatio'
        QtMocHelpers::SlotData<void(double)>(20, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Double, 6 },
        }}),
        // Slot 'greenRatio'
        QtMocHelpers::SlotData<double()>(21, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Double),
        // Slot 'setGreenRatio'
        QtMocHelpers::SlotData<void(double)>(22, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Double, 6 },
        }}),
        // Slot 'port'
        QtMocHelpers::SlotData<int()>(23, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setPort'
        QtMocHelpers::SlotData<void(int)>(24, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'udpTrackerPort'
        QtMocHelpers::SlotData<int()>(25, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setUdpTrackerPort'
        QtMocHelpers::SlotData<void(int)>(26, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'showSystemTrayIcon'
        QtMocHelpers::SlotData<bool()>(27, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setShowSystemTrayIcon'
        QtMocHelpers::SlotData<void(bool)>(28, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'showSpeedBarInTrayIcon'
        QtMocHelpers::SlotData<bool()>(29, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setShowSpeedBarInTrayIcon'
        QtMocHelpers::SlotData<void(bool)>(30, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'downloadBandwidth'
        QtMocHelpers::SlotData<int()>(31, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setDownloadBandwidth'
        QtMocHelpers::SlotData<void(int)>(32, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'uploadBandwidth'
        QtMocHelpers::SlotData<int()>(33, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setUploadBandwidth'
        QtMocHelpers::SlotData<void(int)>(34, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'alwaysMinimizeToSystemTray'
        QtMocHelpers::SlotData<bool()>(35, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setAlwaysMinimizeToSystemTray'
        QtMocHelpers::SlotData<void(bool)>(36, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'showPopups'
        QtMocHelpers::SlotData<bool()>(37, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setShowPopups'
        QtMocHelpers::SlotData<void(bool)>(38, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'keepSeeding'
        QtMocHelpers::SlotData<bool()>(39, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setKeepSeeding'
        QtMocHelpers::SlotData<void(bool)>(40, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'tempDir'
        QtMocHelpers::SlotData<QString()>(41, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'setTempDir'
        QtMocHelpers::SlotData<void(QString)>(42, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'useSaveDir'
        QtMocHelpers::SlotData<bool()>(43, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setUseSaveDir'
        QtMocHelpers::SlotData<void(bool)>(44, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'saveDir'
        QtMocHelpers::SlotData<QString()>(45, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'setSaveDir'
        QtMocHelpers::SlotData<void(QString)>(46, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'useTorrentCopyDir'
        QtMocHelpers::SlotData<bool()>(47, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setUseTorrentCopyDir'
        QtMocHelpers::SlotData<void(bool)>(48, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'torrentCopyDir'
        QtMocHelpers::SlotData<QString()>(49, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'setTorrentCopyDir'
        QtMocHelpers::SlotData<void(QString)>(50, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'useCustomIP'
        QtMocHelpers::SlotData<bool()>(51, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setUseCustomIP'
        QtMocHelpers::SlotData<void(bool)>(52, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'lastSaveDir'
        QtMocHelpers::SlotData<QString()>(53, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'setLastSaveDir'
        QtMocHelpers::SlotData<void(QString)>(54, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'customIP'
        QtMocHelpers::SlotData<QString()>(55, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'setCustomIP'
        QtMocHelpers::SlotData<void(QString)>(56, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'guiUpdateInterval'
        QtMocHelpers::SlotData<int()>(57, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setGuiUpdateInterval'
        QtMocHelpers::SlotData<void(int)>(58, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'dhtSupport'
        QtMocHelpers::SlotData<bool()>(59, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setDhtSupport'
        QtMocHelpers::SlotData<void(bool)>(60, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'dhtPort'
        QtMocHelpers::SlotData<int()>(61, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setDhtPort'
        QtMocHelpers::SlotData<void(int)>(62, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'pexEnabled'
        QtMocHelpers::SlotData<bool()>(63, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setPexEnabled'
        QtMocHelpers::SlotData<void(bool)>(64, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'numUploadSlots'
        QtMocHelpers::SlotData<int()>(65, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setNumUploadSlots'
        QtMocHelpers::SlotData<void(int)>(66, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'useEncryption'
        QtMocHelpers::SlotData<bool()>(67, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setUseEncryption'
        QtMocHelpers::SlotData<void(bool)>(68, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'allowUnencryptedConnections'
        QtMocHelpers::SlotData<bool()>(69, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setAllowUnencryptedConnections'
        QtMocHelpers::SlotData<void(bool)>(70, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'typeOfService'
        QtMocHelpers::SlotData<int()>(71, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setTypeOfService'
        QtMocHelpers::SlotData<void(int)>(72, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'dscp'
        QtMocHelpers::SlotData<int()>(73, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setDscp'
        QtMocHelpers::SlotData<void(int)>(74, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'maxConnectingSockets'
        QtMocHelpers::SlotData<int()>(75, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setMaxConnectingSockets'
        QtMocHelpers::SlotData<void(int)>(76, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'checkWhenFinished'
        QtMocHelpers::SlotData<bool()>(77, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setCheckWhenFinished'
        QtMocHelpers::SlotData<void(bool)>(78, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'shownColumns'
        QtMocHelpers::SlotData<QList<int>()>(79, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 80),
        // Slot 'setShownColumns'
        QtMocHelpers::SlotData<void(QList<int>)>(81, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { 0x80000000 | 80, 6 },
        }}),
        // Slot 'useKDEProxySettings'
        QtMocHelpers::SlotData<bool()>(82, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setUseKDEProxySettings'
        QtMocHelpers::SlotData<void(bool)>(83, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'httpProxy'
        QtMocHelpers::SlotData<QString()>(84, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'setHttpProxy'
        QtMocHelpers::SlotData<void(QString)>(85, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'httpProxyPort'
        QtMocHelpers::SlotData<int()>(86, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setHttpProxyPort'
        QtMocHelpers::SlotData<void(int)>(87, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'useProxyForWebSeeds'
        QtMocHelpers::SlotData<bool()>(88, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setUseProxyForWebSeeds'
        QtMocHelpers::SlotData<void(bool)>(89, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'useProxyForTracker'
        QtMocHelpers::SlotData<bool()>(90, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setUseProxyForTracker'
        QtMocHelpers::SlotData<void(bool)>(91, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'socksEnabled'
        QtMocHelpers::SlotData<bool()>(92, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setSocksEnabled'
        QtMocHelpers::SlotData<void(bool)>(93, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'socksProxy'
        QtMocHelpers::SlotData<QString()>(94, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'setSocksProxy'
        QtMocHelpers::SlotData<void(QString)>(95, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'socksPort'
        QtMocHelpers::SlotData<int()>(96, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setSocksPort'
        QtMocHelpers::SlotData<void(int)>(97, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'socksVersion'
        QtMocHelpers::SlotData<int()>(98, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setSocksVersion'
        QtMocHelpers::SlotData<void(int)>(99, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'socksUsePassword'
        QtMocHelpers::SlotData<bool()>(100, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setSocksUsePassword'
        QtMocHelpers::SlotData<void(bool)>(101, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'socksUsername'
        QtMocHelpers::SlotData<QString()>(102, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'setSocksUsername'
        QtMocHelpers::SlotData<void(QString)>(103, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'socksPassword'
        QtMocHelpers::SlotData<QString()>(104, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'setSocksPassword'
        QtMocHelpers::SlotData<void(QString)>(105, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'diskPrealloc'
        QtMocHelpers::SlotData<bool()>(106, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setDiskPrealloc'
        QtMocHelpers::SlotData<void(bool)>(107, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'fullDiskPrealloc'
        QtMocHelpers::SlotData<bool()>(108, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setFullDiskPrealloc'
        QtMocHelpers::SlotData<void(bool)>(109, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'minDiskSpace'
        QtMocHelpers::SlotData<int()>(110, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setMinDiskSpace'
        QtMocHelpers::SlotData<void(int)>(111, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'cpuUsage'
        QtMocHelpers::SlotData<int()>(112, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setCpuUsage'
        QtMocHelpers::SlotData<void(int)>(113, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'useCompletedDir'
        QtMocHelpers::SlotData<bool()>(114, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setUseCompletedDir'
        QtMocHelpers::SlotData<void(bool)>(115, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'completedDir'
        QtMocHelpers::SlotData<QString()>(116, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'setCompletedDir'
        QtMocHelpers::SlotData<void(QString)>(117, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'maxSeedTime'
        QtMocHelpers::SlotData<double()>(118, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Double),
        // Slot 'setMaxSeedTime'
        QtMocHelpers::SlotData<void(double)>(119, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Double, 6 },
        }}),
        // Slot 'networkInterface'
        QtMocHelpers::SlotData<QString()>(120, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'setNetworkInterface'
        QtMocHelpers::SlotData<void(const QString &)>(121, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'openMultipleTorrentsSilently'
        QtMocHelpers::SlotData<bool()>(122, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setOpenMultipleTorrentsSilently'
        QtMocHelpers::SlotData<void(bool)>(123, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'openAllTorrentsSilently'
        QtMocHelpers::SlotData<bool()>(124, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setOpenAllTorrentsSilently'
        QtMocHelpers::SlotData<void(bool)>(125, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'decreasePriorityOfStalledTorrents'
        QtMocHelpers::SlotData<bool()>(126, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setDecreasePriorityOfStalledTorrents'
        QtMocHelpers::SlotData<void(bool)>(127, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'stallTimer'
        QtMocHelpers::SlotData<int()>(128, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setStallTimer'
        QtMocHelpers::SlotData<void(int)>(129, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'previewSizeAudio'
        QtMocHelpers::SlotData<int()>(130, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setPreviewSizeAudio'
        QtMocHelpers::SlotData<void(int)>(131, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'previewSizeVideo'
        QtMocHelpers::SlotData<int()>(132, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setPreviewSizeVideo'
        QtMocHelpers::SlotData<void(int)>(133, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'suppressSleep'
        QtMocHelpers::SlotData<bool()>(134, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setSuppressSleep'
        QtMocHelpers::SlotData<void(bool)>(135, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'manuallyControlTorrents'
        QtMocHelpers::SlotData<bool()>(136, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setManuallyControlTorrents'
        QtMocHelpers::SlotData<void(bool)>(137, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'webseedsEnabled'
        QtMocHelpers::SlotData<bool()>(138, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setWebseedsEnabled'
        QtMocHelpers::SlotData<void(bool)>(139, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'lookUpHostnameOfPeers'
        QtMocHelpers::SlotData<bool()>(140, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setLookUpHostnameOfPeers'
        QtMocHelpers::SlotData<void(bool)>(141, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'utpEnabled'
        QtMocHelpers::SlotData<bool()>(142, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setUtpEnabled'
        QtMocHelpers::SlotData<void(bool)>(143, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'onlyUseUtp'
        QtMocHelpers::SlotData<bool()>(144, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setOnlyUseUtp'
        QtMocHelpers::SlotData<void(bool)>(145, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'primaryTransportProtocol'
        QtMocHelpers::SlotData<int()>(146, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setPrimaryTransportProtocol'
        QtMocHelpers::SlotData<void(int)>(147, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'autoRenameSingleFileTorrents'
        QtMocHelpers::SlotData<bool()>(148, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setAutoRenameSingleFileTorrents'
        QtMocHelpers::SlotData<void(bool)>(149, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'numMagnetDownloadingSlots'
        QtMocHelpers::SlotData<int()>(150, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setNumMagnetDownloadingSlots'
        QtMocHelpers::SlotData<void(int)>(151, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'requeueMagnets'
        QtMocHelpers::SlotData<bool()>(152, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setRequeueMagnets'
        QtMocHelpers::SlotData<void(bool)>(153, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'requeueMagnetsTime'
        QtMocHelpers::SlotData<int()>(154, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setRequeueMagnetsTime'
        QtMocHelpers::SlotData<void(int)>(155, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'showTotalSpeedInTitle'
        QtMocHelpers::SlotData<bool()>(156, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setShowTotalSpeedInTitle'
        QtMocHelpers::SlotData<void(bool)>(157, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'apply'
        QtMocHelpers::SlotData<void()>(158, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DBusSettings, qt_meta_tag_ZN2kt12DBusSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject kt::DBusSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt12DBusSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt12DBusSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2kt12DBusSettingsE_t>.metaTypes,
    nullptr
} };

void kt::DBusSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBusSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { int _r = _t->maxDownloads();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->setMaxDownloads((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: { int _r = _t->maxSeeds();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->setMaxSeeds((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: { int _r = _t->startDownloadsOnLowDiskSpace();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->setStartDownloadsOnLowDiskSpace((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: { int _r = _t->maxConnections();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->setMaxConnections((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: { int _r = _t->maxTotalConnections();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->setMaxTotalConnections((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: { int _r = _t->maxUploadRate();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->setMaxUploadRate((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: { int _r = _t->maxDownloadRate();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->setMaxDownloadRate((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: { double _r = _t->maxRatio();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->setMaxRatio((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 16: { double _r = _t->greenRatio();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 17: _t->setGreenRatio((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 18: { int _r = _t->port();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->setPort((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: { int _r = _t->udpTrackerPort();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 21: _t->setUdpTrackerPort((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: { bool _r = _t->showSystemTrayIcon();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->setShowSystemTrayIcon((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 24: { bool _r = _t->showSpeedBarInTrayIcon();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->setShowSpeedBarInTrayIcon((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: { int _r = _t->downloadBandwidth();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 27: _t->setDownloadBandwidth((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 28: { int _r = _t->uploadBandwidth();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 29: _t->setUploadBandwidth((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 30: { bool _r = _t->alwaysMinimizeToSystemTray();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 31: _t->setAlwaysMinimizeToSystemTray((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: { bool _r = _t->showPopups();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 33: _t->setShowPopups((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 34: { bool _r = _t->keepSeeding();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 35: _t->setKeepSeeding((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 36: { QString _r = _t->tempDir();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 37: _t->setTempDir((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 38: { bool _r = _t->useSaveDir();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 39: _t->setUseSaveDir((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 40: { QString _r = _t->saveDir();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 41: _t->setSaveDir((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 42: { bool _r = _t->useTorrentCopyDir();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 43: _t->setUseTorrentCopyDir((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 44: { QString _r = _t->torrentCopyDir();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 45: _t->setTorrentCopyDir((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 46: { bool _r = _t->useCustomIP();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 47: _t->setUseCustomIP((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 48: { QString _r = _t->lastSaveDir();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 49: _t->setLastSaveDir((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 50: { QString _r = _t->customIP();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 51: _t->setCustomIP((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 52: { int _r = _t->guiUpdateInterval();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 53: _t->setGuiUpdateInterval((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 54: { bool _r = _t->dhtSupport();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 55: _t->setDhtSupport((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 56: { int _r = _t->dhtPort();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 57: _t->setDhtPort((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 58: { bool _r = _t->pexEnabled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 59: _t->setPexEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 60: { int _r = _t->numUploadSlots();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 61: _t->setNumUploadSlots((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 62: { bool _r = _t->useEncryption();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 63: _t->setUseEncryption((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 64: { bool _r = _t->allowUnencryptedConnections();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 65: _t->setAllowUnencryptedConnections((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 66: { int _r = _t->typeOfService();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 67: _t->setTypeOfService((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 68: { int _r = _t->dscp();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 69: _t->setDscp((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 70: { int _r = _t->maxConnectingSockets();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 71: _t->setMaxConnectingSockets((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 72: { bool _r = _t->checkWhenFinished();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 73: _t->setCheckWhenFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 74: { QList<int> _r = _t->shownColumns();
            if (_a[0]) *reinterpret_cast<QList<int>*>(_a[0]) = std::move(_r); }  break;
        case 75: _t->setShownColumns((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1]))); break;
        case 76: { bool _r = _t->useKDEProxySettings();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 77: _t->setUseKDEProxySettings((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 78: { QString _r = _t->httpProxy();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 79: _t->setHttpProxy((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 80: { int _r = _t->httpProxyPort();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 81: _t->setHttpProxyPort((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 82: { bool _r = _t->useProxyForWebSeeds();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 83: _t->setUseProxyForWebSeeds((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 84: { bool _r = _t->useProxyForTracker();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 85: _t->setUseProxyForTracker((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 86: { bool _r = _t->socksEnabled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 87: _t->setSocksEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 88: { QString _r = _t->socksProxy();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 89: _t->setSocksProxy((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 90: { int _r = _t->socksPort();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 91: _t->setSocksPort((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 92: { int _r = _t->socksVersion();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 93: _t->setSocksVersion((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 94: { bool _r = _t->socksUsePassword();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 95: _t->setSocksUsePassword((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 96: { QString _r = _t->socksUsername();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 97: _t->setSocksUsername((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 98: { QString _r = _t->socksPassword();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 99: _t->setSocksPassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 100: { bool _r = _t->diskPrealloc();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 101: _t->setDiskPrealloc((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 102: { bool _r = _t->fullDiskPrealloc();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 103: _t->setFullDiskPrealloc((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 104: { int _r = _t->minDiskSpace();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 105: _t->setMinDiskSpace((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 106: { int _r = _t->cpuUsage();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 107: _t->setCpuUsage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 108: { bool _r = _t->useCompletedDir();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 109: _t->setUseCompletedDir((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 110: { QString _r = _t->completedDir();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 111: _t->setCompletedDir((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 112: { double _r = _t->maxSeedTime();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 113: _t->setMaxSeedTime((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 114: { QString _r = _t->networkInterface();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 115: _t->setNetworkInterface((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 116: { bool _r = _t->openMultipleTorrentsSilently();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 117: _t->setOpenMultipleTorrentsSilently((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 118: { bool _r = _t->openAllTorrentsSilently();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 119: _t->setOpenAllTorrentsSilently((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 120: { bool _r = _t->decreasePriorityOfStalledTorrents();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 121: _t->setDecreasePriorityOfStalledTorrents((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 122: { int _r = _t->stallTimer();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 123: _t->setStallTimer((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 124: { int _r = _t->previewSizeAudio();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 125: _t->setPreviewSizeAudio((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 126: { int _r = _t->previewSizeVideo();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 127: _t->setPreviewSizeVideo((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 128: { bool _r = _t->suppressSleep();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 129: _t->setSuppressSleep((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 130: { bool _r = _t->manuallyControlTorrents();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 131: _t->setManuallyControlTorrents((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 132: { bool _r = _t->webseedsEnabled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 133: _t->setWebseedsEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 134: { bool _r = _t->lookUpHostnameOfPeers();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 135: _t->setLookUpHostnameOfPeers((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 136: { bool _r = _t->utpEnabled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 137: _t->setUtpEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 138: { bool _r = _t->onlyUseUtp();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 139: _t->setOnlyUseUtp((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 140: { int _r = _t->primaryTransportProtocol();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 141: _t->setPrimaryTransportProtocol((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 142: { bool _r = _t->autoRenameSingleFileTorrents();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 143: _t->setAutoRenameSingleFileTorrents((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 144: { int _r = _t->numMagnetDownloadingSlots();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 145: _t->setNumMagnetDownloadingSlots((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 146: { bool _r = _t->requeueMagnets();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 147: _t->setRequeueMagnets((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 148: { int _r = _t->requeueMagnetsTime();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 149: _t->setRequeueMagnetsTime((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 150: { bool _r = _t->showTotalSpeedInTitle();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 151: _t->setShowTotalSpeedInTitle((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 152: _t->apply(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 75:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
}

const QMetaObject *kt::DBusSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kt::DBusSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt12DBusSettingsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int kt::DBusSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 153)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 153;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 153)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 153;
    }
    return _id;
}
QT_WARNING_POP
