/****************************************************************************
** Meta object code from reading C++ file 'dbus.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktorrent-26.04.3/libktcore/dbus/dbus.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbus.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2kt4DBusE_t {};
} // unnamed namespace

template <> constexpr inline auto kt::DBus::qt_create_metaobjectdata<qt_meta_tag_ZN2kt4DBusE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "kt::DBus",
        "D-Bus Interface",
        "org.ktorrent.core",
        "torrentAdded",
        "",
        "tor",
        "torrentRemoved",
        "finished",
        "torrentStoppedByError",
        "msg",
        "settingsChanged",
        "suspendStateChanged",
        "suspended",
        "torrents",
        "start",
        "info_hash",
        "stop",
        "startAll",
        "stopAll",
        "load",
        "url",
        "group",
        "loadSilently",
        "remove",
        "data_to",
        "removeDelayed",
        "setSuspended",
        "suspend",
        "orderQueue",
        "reindexQueue",
        "groups",
        "addGroup",
        "removeGroup",
        "torrent",
        "name",
        "settings",
        "log",
        "line",
        "numTorrentsRunning",
        "numTorrentsNotRunning",
        "dataDir",
        "bt::TorrentInterface*",
        "tc",
        "groupAdded",
        "Group*",
        "g",
        "groupRemoved",
        "delayedTorrentRemoval"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'torrentAdded'
        QtMocHelpers::SignalData<void(const QString &)>(3, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'torrentRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(6, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'finished'
        QtMocHelpers::SignalData<void(const QString &)>(7, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'torrentStoppedByError'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(8, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 9 },
        }}),
        // Signal 'settingsChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Signal 'suspendStateChanged'
        QtMocHelpers::SignalData<void(bool)>(11, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Slot 'torrents'
        QtMocHelpers::SlotData<QStringList()>(13, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList),
        // Slot 'start'
        QtMocHelpers::SlotData<void(const QString &)>(14, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'stop'
        QtMocHelpers::SlotData<void(const QString &)>(16, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'startAll'
        QtMocHelpers::SlotData<void()>(17, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'stopAll'
        QtMocHelpers::SlotData<void()>(18, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'load'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(19, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
        }}),
        // Slot 'loadSilently'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(22, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
        }}),
        // Slot 'remove'
        QtMocHelpers::SlotData<void(const QString &, bool)>(23, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 15 }, { QMetaType::Bool, 24 },
        }}),
        // Slot 'removeDelayed'
        QtMocHelpers::SlotData<void(const QString &, bool)>(25, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 15 }, { QMetaType::Bool, 24 },
        }}),
        // Slot 'setSuspended'
        QtMocHelpers::SlotData<void(bool)>(26, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Slot 'suspended'
        QtMocHelpers::SlotData<bool()>(12, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'orderQueue'
        QtMocHelpers::SlotData<void()>(28, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'reindexQueue'
        QtMocHelpers::SlotData<void()>(29, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'groups'
        QtMocHelpers::SlotData<QStringList() const>(30, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList),
        // Slot 'addGroup'
        QtMocHelpers::SlotData<bool(const QString &)>(31, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'removeGroup'
        QtMocHelpers::SlotData<bool(const QString &)>(32, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'torrent'
        QtMocHelpers::SlotData<QObject *(const QString &)>(33, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QObjectStar, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'group'
        QtMocHelpers::SlotData<QObject *(const QString &)>(21, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QObjectStar, {{
            { QMetaType::QString, 34 },
        }}),
        // Slot 'settings'
        QtMocHelpers::SlotData<QObject *()>(35, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QObjectStar),
        // Slot 'log'
        QtMocHelpers::SlotData<void(const QString &)>(36, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 37 },
        }}),
        // Slot 'numTorrentsRunning'
        QtMocHelpers::SlotData<uint() const>(38, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::UInt),
        // Slot 'numTorrentsNotRunning'
        QtMocHelpers::SlotData<uint() const>(39, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::UInt),
        // Slot 'dataDir'
        QtMocHelpers::SlotData<QString() const>(40, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'torrentAdded'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *)>(3, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 41, 42 },
        }}),
        // Slot 'torrentRemoved'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *)>(6, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 41, 42 },
        }}),
        // Slot 'finished'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *)>(7, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 41, 42 },
        }}),
        // Slot 'torrentStoppedByError'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *, QString)>(8, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 41, 42 }, { QMetaType::QString, 9 },
        }}),
        // Slot 'groupAdded'
        QtMocHelpers::SlotData<void(Group *)>(43, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 44, 45 },
        }}),
        // Slot 'groupRemoved'
        QtMocHelpers::SlotData<void(Group *)>(46, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 44, 45 },
        }}),
        // Slot 'delayedTorrentRemoval'
        QtMocHelpers::SlotData<void()>(47, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DBus, qt_meta_tag_ZN2kt4DBusE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject kt::DBus::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt4DBusE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt4DBusE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2kt4DBusE_t>.metaTypes,
    nullptr
} };

void kt::DBus::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBus *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->torrentAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->torrentRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->finished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->torrentStoppedByError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->settingsChanged(); break;
        case 5: _t->suspendStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: { QStringList _r = _t->torrents();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->start((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->stop((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->startAll(); break;
        case 10: _t->stopAll(); break;
        case 11: _t->load((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 12: _t->loadSilently((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 13: _t->remove((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 14: _t->removeDelayed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 15: _t->setSuspended((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: { bool _r = _t->suspended();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: _t->orderQueue(); break;
        case 18: _t->reindexQueue(); break;
        case 19: { QStringList _r = _t->groups();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 20: { bool _r = _t->addGroup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 21: { bool _r = _t->removeGroup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 22: { QObject* _r = _t->torrent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = std::move(_r); }  break;
        case 23: { QObject* _r = _t->group((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = std::move(_r); }  break;
        case 24: { QObject* _r = _t->settings();
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = std::move(_r); }  break;
        case 25: _t->log((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 26: { uint _r = _t->numTorrentsRunning();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 27: { uint _r = _t->numTorrentsNotRunning();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 28: { QString _r = _t->dataDir();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 29: _t->torrentAdded((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 30: _t->torrentRemoved((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 31: _t->finished((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 32: _t->torrentStoppedByError((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 33: _t->groupAdded((*reinterpret_cast<std::add_pointer_t<Group*>>(_a[1]))); break;
        case 34: _t->groupRemoved((*reinterpret_cast<std::add_pointer_t<Group*>>(_a[1]))); break;
        case 35: _t->delayedTorrentRemoval(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DBus::*)(const QString & )>(_a, &DBus::torrentAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBus::*)(const QString & )>(_a, &DBus::torrentRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBus::*)(const QString & )>(_a, &DBus::finished, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBus::*)(const QString & , const QString & )>(_a, &DBus::torrentStoppedByError, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBus::*)()>(_a, &DBus::settingsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBus::*)(bool )>(_a, &DBus::suspendStateChanged, 5))
            return;
    }
}

const QMetaObject *kt::DBus::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kt::DBus::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt4DBusE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int kt::DBus::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 36)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 36;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 36)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 36;
    }
    return _id;
}

// SIGNAL 0
void kt::DBus::torrentAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void kt::DBus::torrentRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void kt::DBus::finished(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void kt::DBus::torrentStoppedByError(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void kt::DBus::settingsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void kt::DBus::suspendStateChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
