/****************************************************************************
** Meta object code from reading C++ file 'dbustorrent.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktorrent-26.04.3/libktcore/dbus/dbustorrent.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbustorrent.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2kt11DBusTorrentE_t {};
} // unnamed namespace

template <> constexpr inline auto kt::DBusTorrent::qt_create_metaobjectdata<qt_meta_tag_ZN2kt11DBusTorrentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "kt::DBusTorrent",
        "D-Bus Interface",
        "org.ktorrent.torrent",
        "finished",
        "",
        "tor",
        "stoppedByError",
        "msg",
        "seedingAutoStopped",
        "reason",
        "corruptedDataFound",
        "torrentStopped",
        "infoHash",
        "name",
        "isPrivate",
        "downloadSpeed",
        "uploadSpeed",
        "bytesDownloaded",
        "bytesUploaded",
        "totalSize",
        "bytesLeftToDownload",
        "bytesLeft",
        "bytesToDownload",
        "priority",
        "setPriority",
        "p",
        "setAllowedToStart",
        "on",
        "isAllowedToStart",
        "chunks",
        "chunkSize",
        "chunkDownloaded",
        "idx",
        "seedersConnected",
        "seedersTotal",
        "leechersConnected",
        "leechersTotal",
        "currentTracker",
        "trackers",
        "setTrackerEnabled",
        "tracker_url",
        "enabled",
        "changeTracker",
        "announce",
        "scrape",
        "addTracker",
        "removeTracker",
        "restoreDefaultTrackers",
        "webSeeds",
        "addWebSeed",
        "webseed_url",
        "removeWebSeed",
        "numFiles",
        "dataDir",
        "torDir",
        "pathOnDisk",
        "filePath",
        "file_index",
        "filePathOnDisk",
        "fileSize",
        "filePriority",
        "setFilePriority",
        "prio",
        "firstChunkOfFile",
        "lastChunkOfFile",
        "filePercentage",
        "isMultiMediaFile",
        "setDoNotDownload",
        "dnd",
        "stats",
        "setMaxShareRatio",
        "ratio",
        "maxShareRatio",
        "shareRatio",
        "setMaxSeedTime",
        "hours",
        "maxSeedTime",
        "seedTime",
        "createStream",
        "removeStream",
        "onFinished",
        "bt::TorrentInterface*",
        "onStoppedByError",
        "err",
        "onSeedingAutoStopped",
        "bt::AutoStopReason",
        "onCorruptedDataFound",
        "onTorrentStopped"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'finished'
        QtMocHelpers::SignalData<void(QObject *)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 5 },
        }}),
        // Signal 'stoppedByError'
        QtMocHelpers::SignalData<void(QObject *, const QString &)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 5 }, { QMetaType::QString, 7 },
        }}),
        // Signal 'seedingAutoStopped'
        QtMocHelpers::SignalData<void(QObject *, const QString &)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 5 }, { QMetaType::QString, 9 },
        }}),
        // Signal 'corruptedDataFound'
        QtMocHelpers::SignalData<void(QObject *)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 5 },
        }}),
        // Signal 'torrentStopped'
        QtMocHelpers::SignalData<void(QObject *)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 5 },
        }}),
        // Slot 'infoHash'
        QtMocHelpers::SlotData<QString() const>(12, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'name'
        QtMocHelpers::SlotData<QString() const>(13, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'isPrivate'
        QtMocHelpers::SlotData<bool() const>(14, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'downloadSpeed'
        QtMocHelpers::SlotData<uint() const>(15, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::UInt),
        // Slot 'uploadSpeed'
        QtMocHelpers::SlotData<uint() const>(16, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::UInt),
        // Slot 'bytesDownloaded'
        QtMocHelpers::SlotData<qulonglong() const>(17, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::ULongLong),
        // Slot 'bytesUploaded'
        QtMocHelpers::SlotData<qulonglong() const>(18, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::ULongLong),
        // Slot 'totalSize'
        QtMocHelpers::SlotData<qulonglong() const>(19, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::ULongLong),
        // Slot 'bytesLeftToDownload'
        QtMocHelpers::SlotData<qulonglong() const>(20, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::ULongLong),
        // Slot 'bytesLeft'
        QtMocHelpers::SlotData<qulonglong() const>(21, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::ULongLong),
        // Slot 'bytesToDownload'
        QtMocHelpers::SlotData<qulonglong() const>(22, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::ULongLong),
        // Slot 'priority'
        QtMocHelpers::SlotData<int() const>(23, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'setPriority'
        QtMocHelpers::SlotData<void(int)>(24, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 25 },
        }}),
        // Slot 'setAllowedToStart'
        QtMocHelpers::SlotData<void(bool)>(26, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Slot 'isAllowedToStart'
        QtMocHelpers::SlotData<bool() const>(28, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'chunks'
        QtMocHelpers::SlotData<uint() const>(29, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::UInt),
        // Slot 'chunkSize'
        QtMocHelpers::SlotData<uint() const>(30, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::UInt),
        // Slot 'chunkDownloaded'
        QtMocHelpers::SlotData<bool(uint) const>(31, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::UInt, 32 },
        }}),
        // Slot 'seedersConnected'
        QtMocHelpers::SlotData<uint() const>(33, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::UInt),
        // Slot 'seedersTotal'
        QtMocHelpers::SlotData<uint() const>(34, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::UInt),
        // Slot 'leechersConnected'
        QtMocHelpers::SlotData<uint() const>(35, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::UInt),
        // Slot 'leechersTotal'
        QtMocHelpers::SlotData<uint() const>(36, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::UInt),
        // Slot 'currentTracker'
        QtMocHelpers::SlotData<QString() const>(37, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'trackers'
        QtMocHelpers::SlotData<QStringList() const>(38, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList),
        // Slot 'setTrackerEnabled'
        QtMocHelpers::SlotData<void(const QString &, bool)>(39, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 40 }, { QMetaType::Bool, 41 },
        }}),
        // Slot 'changeTracker'
        QtMocHelpers::SlotData<void(const QString &)>(42, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 40 },
        }}),
        // Slot 'announce'
        QtMocHelpers::SlotData<void()>(43, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'scrape'
        QtMocHelpers::SlotData<void()>(44, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'addTracker'
        QtMocHelpers::SlotData<bool(const QString &)>(45, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 40 },
        }}),
        // Slot 'removeTracker'
        QtMocHelpers::SlotData<bool(const QString &)>(46, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 40 },
        }}),
        // Slot 'restoreDefaultTrackers'
        QtMocHelpers::SlotData<void()>(47, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'webSeeds'
        QtMocHelpers::SlotData<QStringList() const>(48, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList),
        // Slot 'addWebSeed'
        QtMocHelpers::SlotData<bool(const QString &)>(49, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 50 },
        }}),
        // Slot 'removeWebSeed'
        QtMocHelpers::SlotData<bool(const QString &)>(51, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 50 },
        }}),
        // Slot 'numFiles'
        QtMocHelpers::SlotData<uint() const>(52, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::UInt),
        // Slot 'dataDir'
        QtMocHelpers::SlotData<QString() const>(53, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'torDir'
        QtMocHelpers::SlotData<QString() const>(54, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'pathOnDisk'
        QtMocHelpers::SlotData<QString() const>(55, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'filePath'
        QtMocHelpers::SlotData<QString(uint) const>(56, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::UInt, 57 },
        }}),
        // Slot 'filePathOnDisk'
        QtMocHelpers::SlotData<QString(uint) const>(58, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::UInt, 57 },
        }}),
        // Slot 'fileSize'
        QtMocHelpers::SlotData<qulonglong(uint) const>(59, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::ULongLong, {{
            { QMetaType::UInt, 57 },
        }}),
        // Slot 'filePriority'
        QtMocHelpers::SlotData<int(uint) const>(60, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int, {{
            { QMetaType::UInt, 57 },
        }}),
        // Slot 'setFilePriority'
        QtMocHelpers::SlotData<void(uint, int)>(61, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::UInt, 57 }, { QMetaType::Int, 62 },
        }}),
        // Slot 'firstChunkOfFile'
        QtMocHelpers::SlotData<int(uint) const>(63, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int, {{
            { QMetaType::UInt, 57 },
        }}),
        // Slot 'lastChunkOfFile'
        QtMocHelpers::SlotData<int(uint) const>(64, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int, {{
            { QMetaType::UInt, 57 },
        }}),
        // Slot 'filePercentage'
        QtMocHelpers::SlotData<double(uint) const>(65, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Double, {{
            { QMetaType::UInt, 57 },
        }}),
        // Slot 'isMultiMediaFile'
        QtMocHelpers::SlotData<bool(uint) const>(66, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::UInt, 57 },
        }}),
        // Slot 'setDoNotDownload'
        QtMocHelpers::SlotData<void(uint, bool)>(67, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::UInt, 57 }, { QMetaType::Bool, 68 },
        }}),
        // Slot 'stats'
        QtMocHelpers::SlotData<QByteArray() const>(69, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QByteArray),
        // Slot 'setMaxShareRatio'
        QtMocHelpers::SlotData<void(double)>(70, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Double, 71 },
        }}),
        // Slot 'maxShareRatio'
        QtMocHelpers::SlotData<double() const>(72, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Double),
        // Slot 'shareRatio'
        QtMocHelpers::SlotData<double() const>(73, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Double),
        // Slot 'setMaxSeedTime'
        QtMocHelpers::SlotData<void(double)>(74, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Double, 75 },
        }}),
        // Slot 'maxSeedTime'
        QtMocHelpers::SlotData<double() const>(76, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Double),
        // Slot 'seedTime'
        QtMocHelpers::SlotData<double() const>(77, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Double),
        // Slot 'createStream'
        QtMocHelpers::SlotData<bool(uint)>(78, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::UInt, 57 },
        }}),
        // Slot 'removeStream'
        QtMocHelpers::SlotData<bool(uint)>(79, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::UInt, 57 },
        }}),
        // Slot 'onFinished'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *)>(80, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 81, 5 },
        }}),
        // Slot 'onStoppedByError'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *, const QString &)>(82, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 81, 5 }, { QMetaType::QString, 83 },
        }}),
        // Slot 'onSeedingAutoStopped'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *, bt::AutoStopReason)>(84, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 81, 5 }, { 0x80000000 | 85, 9 },
        }}),
        // Slot 'onCorruptedDataFound'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *)>(86, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 81, 5 },
        }}),
        // Slot 'onTorrentStopped'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *)>(87, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 81, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DBusTorrent, qt_meta_tag_ZN2kt11DBusTorrentE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject kt::DBusTorrent::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt11DBusTorrentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt11DBusTorrentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2kt11DBusTorrentE_t>.metaTypes,
    nullptr
} };

void kt::DBusTorrent::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBusTorrent *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->finished((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 1: _t->stoppedByError((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->seedingAutoStopped((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->corruptedDataFound((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 4: _t->torrentStopped((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 5: { QString _r = _t->infoHash();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->name();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->isPrivate();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { uint _r = _t->downloadSpeed();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 9: { uint _r = _t->uploadSpeed();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 10: { qulonglong _r = _t->bytesDownloaded();
            if (_a[0]) *reinterpret_cast<qulonglong*>(_a[0]) = std::move(_r); }  break;
        case 11: { qulonglong _r = _t->bytesUploaded();
            if (_a[0]) *reinterpret_cast<qulonglong*>(_a[0]) = std::move(_r); }  break;
        case 12: { qulonglong _r = _t->totalSize();
            if (_a[0]) *reinterpret_cast<qulonglong*>(_a[0]) = std::move(_r); }  break;
        case 13: { qulonglong _r = _t->bytesLeftToDownload();
            if (_a[0]) *reinterpret_cast<qulonglong*>(_a[0]) = std::move(_r); }  break;
        case 14: { qulonglong _r = _t->bytesLeft();
            if (_a[0]) *reinterpret_cast<qulonglong*>(_a[0]) = std::move(_r); }  break;
        case 15: { qulonglong _r = _t->bytesToDownload();
            if (_a[0]) *reinterpret_cast<qulonglong*>(_a[0]) = std::move(_r); }  break;
        case 16: { int _r = _t->priority();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 17: _t->setPriority((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->setAllowedToStart((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: { bool _r = _t->isAllowedToStart();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 20: { uint _r = _t->chunks();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 21: { uint _r = _t->chunkSize();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 22: { bool _r = _t->chunkDownloaded((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 23: { uint _r = _t->seedersConnected();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 24: { uint _r = _t->seedersTotal();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 25: { uint _r = _t->leechersConnected();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 26: { uint _r = _t->leechersTotal();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 27: { QString _r = _t->currentTracker();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 28: { QStringList _r = _t->trackers();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 29: _t->setTrackerEnabled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 30: _t->changeTracker((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 31: _t->announce(); break;
        case 32: _t->scrape(); break;
        case 33: { bool _r = _t->addTracker((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 34: { bool _r = _t->removeTracker((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 35: _t->restoreDefaultTrackers(); break;
        case 36: { QStringList _r = _t->webSeeds();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 37: { bool _r = _t->addWebSeed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 38: { bool _r = _t->removeWebSeed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 39: { uint _r = _t->numFiles();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 40: { QString _r = _t->dataDir();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 41: { QString _r = _t->torDir();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 42: { QString _r = _t->pathOnDisk();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 43: { QString _r = _t->filePath((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 44: { QString _r = _t->filePathOnDisk((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 45: { qulonglong _r = _t->fileSize((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qulonglong*>(_a[0]) = std::move(_r); }  break;
        case 46: { int _r = _t->filePriority((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 47: _t->setFilePriority((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 48: { int _r = _t->firstChunkOfFile((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 49: { int _r = _t->lastChunkOfFile((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 50: { double _r = _t->filePercentage((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 51: { bool _r = _t->isMultiMediaFile((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 52: _t->setDoNotDownload((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 53: { QByteArray _r = _t->stats();
            if (_a[0]) *reinterpret_cast<QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 54: _t->setMaxShareRatio((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 55: { double _r = _t->maxShareRatio();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 56: { double _r = _t->shareRatio();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 57: _t->setMaxSeedTime((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 58: { double _r = _t->maxSeedTime();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 59: { double _r = _t->seedTime();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 60: { bool _r = _t->createStream((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 61: { bool _r = _t->removeStream((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 62: _t->onFinished((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 63: _t->onStoppedByError((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 64: _t->onSeedingAutoStopped((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bt::AutoStopReason>>(_a[2]))); break;
        case 65: _t->onCorruptedDataFound((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 66: _t->onTorrentStopped((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 62:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 63:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 64:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 65:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 66:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DBusTorrent::*)(QObject * )>(_a, &DBusTorrent::finished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusTorrent::*)(QObject * , const QString & )>(_a, &DBusTorrent::stoppedByError, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusTorrent::*)(QObject * , const QString & )>(_a, &DBusTorrent::seedingAutoStopped, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusTorrent::*)(QObject * )>(_a, &DBusTorrent::corruptedDataFound, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusTorrent::*)(QObject * )>(_a, &DBusTorrent::torrentStopped, 4))
            return;
    }
}

const QMetaObject *kt::DBusTorrent::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kt::DBusTorrent::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt11DBusTorrentE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int kt::DBusTorrent::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 67)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 67;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 67)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 67;
    }
    return _id;
}

// SIGNAL 0
void kt::DBusTorrent::finished(QObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void kt::DBusTorrent::stoppedByError(QObject * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void kt::DBusTorrent::seedingAutoStopped(QObject * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void kt::DBusTorrent::corruptedDataFound(QObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void kt::DBusTorrent::torrentStopped(QObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
