/****************************************************************************
** Meta object code from reading C++ file 'queuemanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktorrent-26.04.3/libktcore/torrent/queuemanager.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'queuemanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2kt12QueueManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto kt::QueueManager::qt_create_metaobjectdata<qt_meta_tag_ZN2kt12QueueManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "kt::QueueManager",
        "queuingNotPossible",
        "",
        "bt::TorrentInterface*",
        "tc",
        "lowDiskSpace",
        "stopped",
        "orderingQueue",
        "queueOrdered",
        "suspendStateChanged",
        "suspended",
        "torrentFinished",
        "torrentAdded",
        "start_torrent",
        "torrentRemoved",
        "torrentsRemoved",
        "QList<bt::TorrentInterface*>&",
        "tors",
        "torrentStopped",
        "onLowDiskSpace",
        "toStop",
        "onOnlineStateChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'queuingNotPossible'
        QtMocHelpers::SignalData<void(bt::TorrentInterface *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'lowDiskSpace'
        QtMocHelpers::SignalData<void(bt::TorrentInterface *, bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 6 },
        }}),
        // Signal 'orderingQueue'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'queueOrdered'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'suspendStateChanged'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Slot 'torrentFinished'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'torrentAdded'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *, bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 13 },
        }}),
        // Slot 'torrentRemoved'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'torrentsRemoved'
        QtMocHelpers::SlotData<void(QList<bt::TorrentInterface*> &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'torrentStopped'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'onLowDiskSpace'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *, bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 20 },
        }}),
        // Slot 'onOnlineStateChanged'
        QtMocHelpers::SlotData<void(bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QueueManager, qt_meta_tag_ZN2kt12QueueManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject kt::QueueManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt12QueueManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt12QueueManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2kt12QueueManagerE_t>.metaTypes,
    nullptr
} };

void kt::QueueManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QueueManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->queuingNotPossible((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 1: _t->lowDiskSpace((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 2: _t->orderingQueue(); break;
        case 3: _t->queueOrdered(); break;
        case 4: _t->suspendStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->torrentFinished((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 6: _t->torrentAdded((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 7: _t->torrentRemoved((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 8: _t->torrentsRemoved((*reinterpret_cast<std::add_pointer_t<QList<bt::TorrentInterface*>&>>(_a[1]))); break;
        case 9: _t->torrentStopped((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 10: _t->onLowDiskSpace((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 11: _t->onOnlineStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QueueManager::*)(bt::TorrentInterface * )>(_a, &QueueManager::queuingNotPossible, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QueueManager::*)(bt::TorrentInterface * , bool )>(_a, &QueueManager::lowDiskSpace, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QueueManager::*)()>(_a, &QueueManager::orderingQueue, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QueueManager::*)()>(_a, &QueueManager::queueOrdered, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QueueManager::*)(bool )>(_a, &QueueManager::suspendStateChanged, 4))
            return;
    }
}

const QMetaObject *kt::QueueManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kt::QueueManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt12QueueManagerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "bt::QueueManagerInterface"))
        return static_cast< bt::QueueManagerInterface*>(this);
    return QObject::qt_metacast(_clname);
}

int kt::QueueManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void kt::QueueManager::queuingNotPossible(bt::TorrentInterface * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void kt::QueueManager::lowDiskSpace(bt::TorrentInterface * _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void kt::QueueManager::orderingQueue()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void kt::QueueManager::queueOrdered()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void kt::QueueManager::suspendStateChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
