/****************************************************************************
** Meta object code from reading C++ file 'scheduleeditor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../ktorrent-26.04.3/plugins/bwscheduler/scheduleeditor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'scheduleeditor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2kt14ScheduleEditorE_t {};
} // unnamed namespace

template <> constexpr inline auto kt::ScheduleEditor::qt_create_metaobjectdata<qt_meta_tag_ZN2kt14ScheduleEditorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "kt::ScheduleEditor",
        "loaded",
        "",
        "Schedule*",
        "ns",
        "scheduleChanged",
        "clear",
        "save",
        "load",
        "addItem",
        "removeItem",
        "editItem",
        "onSelectionChanged",
        "ScheduleItem*",
        "item",
        "itemMoved",
        "start",
        "end",
        "start_day",
        "end_day",
        "enableChecked",
        "on"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'loaded'
        QtMocHelpers::SignalData<void(Schedule *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'scheduleChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clear'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'load'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addItem'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'removeItem'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'editItem'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onSelectionChanged'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'editItem'
        QtMocHelpers::SlotData<void(ScheduleItem *)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'itemMoved'
        QtMocHelpers::SlotData<void(ScheduleItem *, const QTime &, const QTime &, int, int)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { QMetaType::QTime, 16 }, { QMetaType::QTime, 17 }, { QMetaType::Int, 18 },
            { QMetaType::Int, 19 },
        }}),
        // Slot 'enableChecked'
        QtMocHelpers::SlotData<void(bool)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ScheduleEditor, qt_meta_tag_ZN2kt14ScheduleEditorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject kt::ScheduleEditor::staticMetaObject = { {
    QMetaObject::SuperData::link<Activity::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt14ScheduleEditorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt14ScheduleEditorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2kt14ScheduleEditorE_t>.metaTypes,
    nullptr
} };

void kt::ScheduleEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScheduleEditor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->loaded((*reinterpret_cast<std::add_pointer_t<Schedule*>>(_a[1]))); break;
        case 1: _t->scheduleChanged(); break;
        case 2: _t->clear(); break;
        case 3: _t->save(); break;
        case 4: _t->load(); break;
        case 5: _t->addItem(); break;
        case 6: _t->removeItem(); break;
        case 7: _t->editItem(); break;
        case 8: _t->onSelectionChanged(); break;
        case 9: _t->editItem((*reinterpret_cast<std::add_pointer_t<ScheduleItem*>>(_a[1]))); break;
        case 10: _t->itemMoved((*reinterpret_cast<std::add_pointer_t<ScheduleItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QTime>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QTime>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 11: _t->enableChecked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ScheduleEditor::*)(Schedule * )>(_a, &ScheduleEditor::loaded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScheduleEditor::*)()>(_a, &ScheduleEditor::scheduleChanged, 1))
            return;
    }
}

const QMetaObject *kt::ScheduleEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kt::ScheduleEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt14ScheduleEditorE_t>.strings))
        return static_cast<void*>(this);
    return Activity::qt_metacast(_clname);
}

int kt::ScheduleEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Activity::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void kt::ScheduleEditor::loaded(Schedule * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void kt::ScheduleEditor::scheduleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
