/********************************************************************************
** Form generated from reading UI file 'recommendedsettingsdlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RECOMMENDEDSETTINGSDLG_H
#define UI_RECOMMENDEDSETTINGSDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_RecommendedSettingsDlg
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QGridLayout *gridLayout;
    QLabel *label;
    QSpinBox *m_upload_bw;
    QLabel *label_2;
    QSpinBox *m_download_bw;
    QLabel *m_upload_bw_display;
    QLabel *m_download_bw_display;
    QVBoxLayout *verticalLayout;
    QPushButton *m_calculate;
    QSpacerItem *verticalSpacer;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout_3;
    QCheckBox *m_chk_avg_speed_slot;
    QSpinBox *m_avg_speed_slot;
    QCheckBox *m_chk_sim_torrents;
    QSpinBox *m_sim_torrents;
    QCheckBox *m_chk_slots;
    QSpinBox *m_slots;
    QLabel *label_3;
    QHBoxLayout *horizontalLayout_2;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QLabel *label_4;
    QLabel *m_max_upload;
    QLabel *label_5;
    QLabel *m_max_download;
    QLabel *label_7;
    QLabel *m_max_conn_per_torrent;
    QLabel *label_8;
    QLabel *m_max_conn_global;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_3;
    QGridLayout *gridLayout_4;
    QLabel *label_6;
    QLabel *m_upload_slots;
    QLabel *label_14;
    QLabel *m_max_downloads;
    QLabel *label_17;
    QLabel *m_max_seeds;
    QSpacerItem *verticalSpacer_2;
    QFrame *line;
    QDialogButtonBox *m_buttonBox;

    void setupUi(QDialog *RecommendedSettingsDlg)
    {
        if (RecommendedSettingsDlg->objectName().isEmpty())
            RecommendedSettingsDlg->setObjectName("RecommendedSettingsDlg");
        RecommendedSettingsDlg->resize(825, 492);
        verticalLayout_2 = new QVBoxLayout(RecommendedSettingsDlg);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(RecommendedSettingsDlg);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        m_upload_bw = new QSpinBox(RecommendedSettingsDlg);
        m_upload_bw->setObjectName("m_upload_bw");
        m_upload_bw->setMinimum(1);
        m_upload_bw->setMaximum(100000000);
        m_upload_bw->setValue(256);

        gridLayout->addWidget(m_upload_bw, 0, 1, 1, 1);

        label_2 = new QLabel(RecommendedSettingsDlg);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        m_download_bw = new QSpinBox(RecommendedSettingsDlg);
        m_download_bw->setObjectName("m_download_bw");
        m_download_bw->setMinimum(1);
        m_download_bw->setMaximum(100000000);
        m_download_bw->setValue(4000);

        gridLayout->addWidget(m_download_bw, 1, 1, 1, 1);

        m_upload_bw_display = new QLabel(RecommendedSettingsDlg);
        m_upload_bw_display->setObjectName("m_upload_bw_display");

        gridLayout->addWidget(m_upload_bw_display, 0, 2, 1, 1);

        m_download_bw_display = new QLabel(RecommendedSettingsDlg);
        m_download_bw_display->setObjectName("m_download_bw_display");

        gridLayout->addWidget(m_download_bw_display, 1, 2, 1, 1);


        horizontalLayout->addLayout(gridLayout);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        m_calculate = new QPushButton(RecommendedSettingsDlg);
        m_calculate->setObjectName("m_calculate");

        verticalLayout->addWidget(m_calculate);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        horizontalLayout->addLayout(verticalLayout);


        verticalLayout_2->addLayout(horizontalLayout);

        groupBox_3 = new QGroupBox(RecommendedSettingsDlg);
        groupBox_3->setObjectName("groupBox_3");
        gridLayout_3 = new QGridLayout(groupBox_3);
        gridLayout_3->setObjectName("gridLayout_3");
        m_chk_avg_speed_slot = new QCheckBox(groupBox_3);
        m_chk_avg_speed_slot->setObjectName("m_chk_avg_speed_slot");

        gridLayout_3->addWidget(m_chk_avg_speed_slot, 0, 0, 1, 1);

        m_avg_speed_slot = new QSpinBox(groupBox_3);
        m_avg_speed_slot->setObjectName("m_avg_speed_slot");
        m_avg_speed_slot->setMinimum(1);
        m_avg_speed_slot->setMaximum(100000000);
        m_avg_speed_slot->setValue(4);

        gridLayout_3->addWidget(m_avg_speed_slot, 0, 1, 1, 1);

        m_chk_sim_torrents = new QCheckBox(groupBox_3);
        m_chk_sim_torrents->setObjectName("m_chk_sim_torrents");

        gridLayout_3->addWidget(m_chk_sim_torrents, 1, 0, 1, 1);

        m_sim_torrents = new QSpinBox(groupBox_3);
        m_sim_torrents->setObjectName("m_sim_torrents");
        m_sim_torrents->setMinimum(1);
        m_sim_torrents->setMaximum(1000000);
        m_sim_torrents->setValue(2);

        gridLayout_3->addWidget(m_sim_torrents, 1, 1, 1, 1);

        m_chk_slots = new QCheckBox(groupBox_3);
        m_chk_slots->setObjectName("m_chk_slots");

        gridLayout_3->addWidget(m_chk_slots, 2, 0, 1, 1);

        m_slots = new QSpinBox(groupBox_3);
        m_slots->setObjectName("m_slots");
        m_slots->setMinimum(1);
        m_slots->setMaximum(10000);
        m_slots->setValue(3);

        gridLayout_3->addWidget(m_slots, 2, 1, 1, 1);


        verticalLayout_2->addWidget(groupBox_3);

        label_3 = new QLabel(RecommendedSettingsDlg);
        label_3->setObjectName("label_3");

        verticalLayout_2->addWidget(label_3);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        groupBox = new QGroupBox(RecommendedSettingsDlg);
        groupBox->setObjectName("groupBox");
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName("gridLayout_2");
        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");

        gridLayout_2->addWidget(label_4, 0, 0, 1, 1);

        m_max_upload = new QLabel(groupBox);
        m_max_upload->setObjectName("m_max_upload");

        gridLayout_2->addWidget(m_max_upload, 0, 1, 1, 1);

        label_5 = new QLabel(groupBox);
        label_5->setObjectName("label_5");

        gridLayout_2->addWidget(label_5, 1, 0, 1, 1);

        m_max_download = new QLabel(groupBox);
        m_max_download->setObjectName("m_max_download");

        gridLayout_2->addWidget(m_max_download, 1, 1, 1, 1);

        label_7 = new QLabel(groupBox);
        label_7->setObjectName("label_7");

        gridLayout_2->addWidget(label_7, 2, 0, 1, 1);

        m_max_conn_per_torrent = new QLabel(groupBox);
        m_max_conn_per_torrent->setObjectName("m_max_conn_per_torrent");

        gridLayout_2->addWidget(m_max_conn_per_torrent, 2, 1, 1, 1);

        label_8 = new QLabel(groupBox);
        label_8->setObjectName("label_8");

        gridLayout_2->addWidget(label_8, 3, 0, 1, 1);

        m_max_conn_global = new QLabel(groupBox);
        m_max_conn_global->setObjectName("m_max_conn_global");

        gridLayout_2->addWidget(m_max_conn_global, 3, 1, 1, 1);


        horizontalLayout_2->addWidget(groupBox);

        groupBox_2 = new QGroupBox(RecommendedSettingsDlg);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_3 = new QVBoxLayout(groupBox_2);
        verticalLayout_3->setObjectName("verticalLayout_3");
        gridLayout_4 = new QGridLayout();
        gridLayout_4->setObjectName("gridLayout_4");
        label_6 = new QLabel(groupBox_2);
        label_6->setObjectName("label_6");

        gridLayout_4->addWidget(label_6, 0, 0, 1, 1);

        m_upload_slots = new QLabel(groupBox_2);
        m_upload_slots->setObjectName("m_upload_slots");

        gridLayout_4->addWidget(m_upload_slots, 0, 1, 1, 1);

        label_14 = new QLabel(groupBox_2);
        label_14->setObjectName("label_14");

        gridLayout_4->addWidget(label_14, 1, 0, 1, 1);

        m_max_downloads = new QLabel(groupBox_2);
        m_max_downloads->setObjectName("m_max_downloads");

        gridLayout_4->addWidget(m_max_downloads, 1, 1, 1, 1);

        label_17 = new QLabel(groupBox_2);
        label_17->setObjectName("label_17");

        gridLayout_4->addWidget(label_17, 2, 0, 1, 1);

        m_max_seeds = new QLabel(groupBox_2);
        m_max_seeds->setObjectName("m_max_seeds");

        gridLayout_4->addWidget(m_max_seeds, 2, 1, 1, 1);


        verticalLayout_3->addLayout(gridLayout_4);

        verticalSpacer_2 = new QSpacerItem(20, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_2);


        horizontalLayout_2->addWidget(groupBox_2);


        verticalLayout_2->addLayout(horizontalLayout_2);

        line = new QFrame(RecommendedSettingsDlg);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_2->addWidget(line);

        m_buttonBox = new QDialogButtonBox(RecommendedSettingsDlg);
        m_buttonBox->setObjectName("m_buttonBox");
        m_buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel);

        verticalLayout_2->addWidget(m_buttonBox);


        retranslateUi(RecommendedSettingsDlg);

        QMetaObject::connectSlotsByName(RecommendedSettingsDlg);
    } // setupUi

    void retranslateUi(QDialog *RecommendedSettingsDlg)
    {
        RecommendedSettingsDlg->setWindowTitle(tr2i18n("Recommended Settings", nullptr));
        label->setText(tr2i18n("Available upload bandwidth:", nullptr));
        m_upload_bw->setSpecialValueText(tr2i18n(" Kbps", nullptr));
        m_upload_bw->setSuffix(tr2i18n(" kb/s", nullptr));
        label_2->setText(tr2i18n("Available download bandwidth:", nullptr));
        m_download_bw->setSpecialValueText(tr2i18n(" Kbps", nullptr));
        m_download_bw->setSuffix(tr2i18n(" kb/s", nullptr));
        m_upload_bw_display->setText(tr2i18n("(= 32 KiB/s)", nullptr));
        m_download_bw_display->setText(tr2i18n("(= 500 KiB/s)", nullptr));
        m_calculate->setText(tr2i18n("Calculate", nullptr));
        groupBox_3->setTitle(tr2i18n("Preferences", nullptr));
        m_chk_avg_speed_slot->setText(tr2i18n("Average speed per slot:", nullptr));
        m_avg_speed_slot->setSuffix(tr2i18n(" KiB/s", nullptr));
        m_chk_sim_torrents->setText(tr2i18n("Number of torrents you usually download simultaneously:", nullptr));
        m_chk_slots->setText(tr2i18n("Slots per torrent:", nullptr));
        label_3->setText(tr2i18n("Recommended settings:", nullptr));
        groupBox->setTitle(tr2i18n("Network", nullptr));
        label_4->setText(tr2i18n("Maximum upload speed:", nullptr));
        m_max_upload->setText(tr2i18n("TextLabel", "KDE::DoNotExtract"));
        label_5->setText(tr2i18n("Maximum download speed:", nullptr));
        m_max_download->setText(tr2i18n("TextLabel", "KDE::DoNotExtract"));
        label_7->setText(tr2i18n("Maximum connections per torrent:", nullptr));
        m_max_conn_per_torrent->setText(tr2i18n("TextLabel", "KDE::DoNotExtract"));
        label_8->setText(tr2i18n("Global connection limit:", nullptr));
        m_max_conn_global->setText(tr2i18n("TextLabel", "KDE::DoNotExtract"));
        groupBox_2->setTitle(tr2i18n("Queue Manager", nullptr));
        label_6->setText(tr2i18n("Number of upload slots:", nullptr));
        m_upload_slots->setText(tr2i18n("TextLabel", "KDE::DoNotExtract"));
        label_14->setText(tr2i18n("Maximum downloads:", nullptr));
        m_max_downloads->setText(tr2i18n("TextLabel", "KDE::DoNotExtract"));
        label_17->setText(tr2i18n("Maximum seeds:", nullptr));
        m_max_seeds->setText(tr2i18n("TextLabel", "KDE::DoNotExtract"));
    } // retranslateUi

};

namespace Ui {
    class RecommendedSettingsDlg: public Ui_RecommendedSettingsDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // RECOMMENDEDSETTINGSDLG_H

