/********************************************************************************
** Form generated from reading UI file 'grouppolicydlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GROUPPOLICYDLG_H
#define UI_GROUPPOLICYDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_GroupPolicyDlg
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *m_default_location_enabled;
    KUrlRequester *m_default_location;
    QCheckBox *m_default_move_on_completion_enabled;
    KUrlRequester *m_default_move_on_completion_location;
    QGroupBox *groupBox;
    QVBoxLayout *vboxLayout;
    QGridLayout *gridLayout;
    QLabel *label;
    QSpinBox *m_max_download_rate;
    QLabel *label_2;
    QSpinBox *m_max_upload_rate;
    QLabel *label_3;
    QDoubleSpinBox *m_max_seed_time;
    QLabel *label_4;
    QDoubleSpinBox *m_max_share_ratio;
    QCheckBox *m_only_new;
    QDialogButtonBox *buttonBox;
    QFrame *line;

    void setupUi(QWidget *GroupPolicyDlg)
    {
        if (GroupPolicyDlg->objectName().isEmpty())
            GroupPolicyDlg->setObjectName("GroupPolicyDlg");
        GroupPolicyDlg->resize(446, 307);
        verticalLayout = new QVBoxLayout(GroupPolicyDlg);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        m_default_location_enabled = new QCheckBox(GroupPolicyDlg);
        m_default_location_enabled->setObjectName("m_default_location_enabled");

        verticalLayout->addWidget(m_default_location_enabled);

        m_default_location = new KUrlRequester(GroupPolicyDlg);
        m_default_location->setObjectName("m_default_location");

        verticalLayout->addWidget(m_default_location);

        m_default_move_on_completion_enabled = new QCheckBox(GroupPolicyDlg);
        m_default_move_on_completion_enabled->setObjectName("m_default_move_on_completion_enabled");

        verticalLayout->addWidget(m_default_move_on_completion_enabled);

        m_default_move_on_completion_location = new KUrlRequester(GroupPolicyDlg);
        m_default_move_on_completion_location->setObjectName("m_default_move_on_completion_location");

        verticalLayout->addWidget(m_default_move_on_completion_location);

        groupBox = new QGroupBox(GroupPolicyDlg);
        groupBox->setObjectName("groupBox");
        vboxLayout = new QVBoxLayout(groupBox);
        vboxLayout->setObjectName("vboxLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(groupBox);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        m_max_download_rate = new QSpinBox(groupBox);
        m_max_download_rate->setObjectName("m_max_download_rate");
        m_max_download_rate->setMaximum(10000000);

        gridLayout->addWidget(m_max_download_rate, 0, 1, 1, 1);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        m_max_upload_rate = new QSpinBox(groupBox);
        m_max_upload_rate->setObjectName("m_max_upload_rate");
        m_max_upload_rate->setMaximum(10000000);

        gridLayout->addWidget(m_max_upload_rate, 1, 1, 1, 1);

        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 2, 0, 1, 1);

        m_max_seed_time = new QDoubleSpinBox(groupBox);
        m_max_seed_time->setObjectName("m_max_seed_time");
        m_max_seed_time->setMaximum(10000000.000000000000000);
        m_max_seed_time->setSingleStep(0.010000000000000);

        gridLayout->addWidget(m_max_seed_time, 2, 1, 1, 1);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 3, 0, 1, 1);

        m_max_share_ratio = new QDoubleSpinBox(groupBox);
        m_max_share_ratio->setObjectName("m_max_share_ratio");
        m_max_share_ratio->setMaximum(10000000.000000000000000);
        m_max_share_ratio->setSingleStep(0.010000000000000);

        gridLayout->addWidget(m_max_share_ratio, 3, 1, 1, 1);


        vboxLayout->addLayout(gridLayout);

        m_only_new = new QCheckBox(groupBox);
        m_only_new->setObjectName("m_only_new");

        vboxLayout->addWidget(m_only_new);


        verticalLayout->addWidget(groupBox);

        buttonBox = new QDialogButtonBox(GroupPolicyDlg);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);

        line = new QFrame(GroupPolicyDlg);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);


        retranslateUi(GroupPolicyDlg);
        QObject::connect(m_default_location_enabled, SIGNAL(toggled(bool)), m_default_location, SLOT(setEnabled(bool)));
        QObject::connect(m_default_move_on_completion_enabled, SIGNAL(toggled(bool)), m_default_move_on_completion_location, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(GroupPolicyDlg);
    } // setupUi

    void retranslateUi(QWidget *GroupPolicyDlg)
    {
        GroupPolicyDlg->setWindowTitle(tr2i18n("Dialog", nullptr));
#if QT_CONFIG(tooltip)
        m_default_location_enabled->setToolTip(tr2i18n("Default save location for torrents from this group. <br/><br/>This is only used in the file selection dialog, when you change the group, the download location in the dialog will be set to this. You can still override it, if you want to.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_default_location_enabled->setText(tr2i18n("Default save location:", nullptr));
#if QT_CONFIG(tooltip)
        m_default_location->setToolTip(tr2i18n("Default save location for torrents from this group. <br/><br/>This is only used in the file selection dialog, when you change the group, the download location in the dialog will be set to this. You can still override it, if you want to.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_default_move_on_completion_enabled->setText(tr2i18n("Default move when completed location:", nullptr));
#if QT_CONFIG(tooltip)
        m_default_move_on_completion_location->setToolTip(tr2i18n("Default move on completion location for torrents from this group. <br/><br/>This is only used in the file selection dialog, when you change the group, the move when completed location in the dialog will be set to this. You can still override it, if you want to.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        groupBox->setToolTip(tr2i18n("Default settings for torrents which are added to the group.", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox->setTitle(tr2i18n("Torrent Limits", nullptr));
        label->setText(tr2i18n("Maximum download rate:", nullptr));
        m_max_download_rate->setSpecialValueText(tr2i18n("No limit", nullptr));
        m_max_download_rate->setSuffix(tr2i18n(" KiB/s", nullptr));
        label_2->setText(tr2i18n("Maximum upload rate:", nullptr));
        m_max_upload_rate->setSpecialValueText(tr2i18n("No limit", nullptr));
        m_max_upload_rate->setSuffix(tr2i18n(" KiB/s", nullptr));
        label_3->setText(tr2i18n("Maximum seed time:", nullptr));
        m_max_seed_time->setSpecialValueText(tr2i18n("No limit", nullptr));
        m_max_seed_time->setSuffix(tr2i18n(" Hours", nullptr));
        label_4->setText(tr2i18n("Maximum share ratio:", nullptr));
        m_max_share_ratio->setSpecialValueText(tr2i18n("No limit", nullptr));
#if QT_CONFIG(tooltip)
        m_only_new->setToolTip(tr2i18n("When this is enabled, these settings will only be applied when a torrent is added to the group in the file selection dialog or the torrent creation dialog.<p>\n"
"If this is not enabled, the settings will always be applied when you add a torrent to this group. ", nullptr));
#endif // QT_CONFIG(tooltip)
        m_only_new->setText(tr2i18n("Apply settings only for newly opened or created torrents", nullptr));
    } // retranslateUi

};

namespace Ui {
    class GroupPolicyDlg: public Ui_GroupPolicyDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GROUPPOLICYDLG_H

