/********************************************************************************
** Form generated from reading UI file 'basicjobprogresswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BASICJOBPROGRESSWIDGET_H
#define UI_BASICJOBPROGRESSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_BasicJobProgressWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *job_title;
    QLabel *job_description;
    QHBoxLayout *horizontalLayout;
    QProgressBar *progress;
    QLabel *job_speed;
    QLabel *msg;

    void setupUi(QWidget *BasicJobProgressWidget)
    {
        if (BasicJobProgressWidget->objectName().isEmpty())
            BasicJobProgressWidget->setObjectName("BasicJobProgressWidget");
        BasicJobProgressWidget->resize(400, 95);
        verticalLayout = new QVBoxLayout(BasicJobProgressWidget);
        verticalLayout->setObjectName("verticalLayout");
        job_title = new QLabel(BasicJobProgressWidget);
        job_title->setObjectName("job_title");
        QFont font;
        font.setBold(true);
        font.setKerning(true);
        job_title->setFont(font);

        verticalLayout->addWidget(job_title);

        job_description = new QLabel(BasicJobProgressWidget);
        job_description->setObjectName("job_description");

        verticalLayout->addWidget(job_description);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        progress = new QProgressBar(BasicJobProgressWidget);
        progress->setObjectName("progress");
        progress->setValue(24);

        horizontalLayout->addWidget(progress);

        job_speed = new QLabel(BasicJobProgressWidget);
        job_speed->setObjectName("job_speed");
        job_speed->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout->addWidget(job_speed);


        verticalLayout->addLayout(horizontalLayout);

        msg = new QLabel(BasicJobProgressWidget);
        msg->setObjectName("msg");

        verticalLayout->addWidget(msg);


        retranslateUi(BasicJobProgressWidget);

        QMetaObject::connectSlotsByName(BasicJobProgressWidget);
    } // setupUi

    void retranslateUi(QWidget *BasicJobProgressWidget)
    {
        job_title->setText(tr2i18n("TextLabel", "KDE::DoNotExtract"));
        job_description->setText(tr2i18n("TextLabel", "KDE::DoNotExtract"));
        progress->setFormat(tr2i18n("%p%", nullptr));
        job_speed->setText(tr2i18n("TextLabel", "KDE::DoNotExtract"));
        msg->setText(tr2i18n("TextLabel", "KDE::DoNotExtract"));
        (void)BasicJobProgressWidget;
    } // retranslateUi

};

namespace Ui {
    class BasicJobProgressWidget: public Ui_BasicJobProgressWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BASICJOBPROGRESSWIDGET_H

