/********************************************************************************
** Form generated from reading UI file 'proxypref.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROXYPREF_H
#define UI_PROXYPREF_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ProxyPref
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *groupBox_3;
    QVBoxLayout *vboxLayout1;
    QCheckBox *kcfg_useKDEProxySettings;
    QHBoxLayout *hboxLayout;
    QLabel *label_10;
    QLineEdit *kcfg_httpProxy;
    QLabel *label_2;
    QSpinBox *kcfg_httpProxyPort;
    QCheckBox *kcfg_useProxyForWebSeeds;
    QCheckBox *kcfg_useProxyForTracker;
    QGroupBox *groupBox;
    QVBoxLayout *vboxLayout2;
    QCheckBox *kcfg_socksEnabled;
    QHBoxLayout *hboxLayout1;
    QLabel *label_12;
    QLineEdit *kcfg_socksProxy;
    QLabel *label_11;
    QSpinBox *kcfg_socksPort;
    QLabel *label_13;
    QSpinBox *kcfg_socksVersion;
    QCheckBox *kcfg_socksUsePassword;
    QHBoxLayout *hboxLayout2;
    QGridLayout *gridLayout;
    QLabel *label;
    QLineEdit *kcfg_socksUsername;
    QLabel *label_14;
    QLineEdit *kcfg_socksPassword;
    QSpacerItem *spacerItem;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *ProxyPref)
    {
        if (ProxyPref->objectName().isEmpty())
            ProxyPref->setObjectName("ProxyPref");
        ProxyPref->resize(417, 387);
        vboxLayout = new QVBoxLayout(ProxyPref);
        vboxLayout->setObjectName("vboxLayout");
        groupBox_3 = new QGroupBox(ProxyPref);
        groupBox_3->setObjectName("groupBox_3");
        vboxLayout1 = new QVBoxLayout(groupBox_3);
        vboxLayout1->setObjectName("vboxLayout1");
        kcfg_useKDEProxySettings = new QCheckBox(groupBox_3);
        kcfg_useKDEProxySettings->setObjectName("kcfg_useKDEProxySettings");

        vboxLayout1->addWidget(kcfg_useKDEProxySettings);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        label_10 = new QLabel(groupBox_3);
        label_10->setObjectName("label_10");

        hboxLayout->addWidget(label_10);

        kcfg_httpProxy = new QLineEdit(groupBox_3);
        kcfg_httpProxy->setObjectName("kcfg_httpProxy");

        hboxLayout->addWidget(kcfg_httpProxy);

        label_2 = new QLabel(groupBox_3);
        label_2->setObjectName("label_2");

        hboxLayout->addWidget(label_2);

        kcfg_httpProxyPort = new QSpinBox(groupBox_3);
        kcfg_httpProxyPort->setObjectName("kcfg_httpProxyPort");
        kcfg_httpProxyPort->setMinimum(1);
        kcfg_httpProxyPort->setMaximum(65535);
        kcfg_httpProxyPort->setValue(8080);

        hboxLayout->addWidget(kcfg_httpProxyPort);


        vboxLayout1->addLayout(hboxLayout);

        kcfg_useProxyForWebSeeds = new QCheckBox(groupBox_3);
        kcfg_useProxyForWebSeeds->setObjectName("kcfg_useProxyForWebSeeds");

        vboxLayout1->addWidget(kcfg_useProxyForWebSeeds);

        kcfg_useProxyForTracker = new QCheckBox(groupBox_3);
        kcfg_useProxyForTracker->setObjectName("kcfg_useProxyForTracker");

        vboxLayout1->addWidget(kcfg_useProxyForTracker);


        vboxLayout->addWidget(groupBox_3);

        groupBox = new QGroupBox(ProxyPref);
        groupBox->setObjectName("groupBox");
        vboxLayout2 = new QVBoxLayout(groupBox);
        vboxLayout2->setObjectName("vboxLayout2");
        kcfg_socksEnabled = new QCheckBox(groupBox);
        kcfg_socksEnabled->setObjectName("kcfg_socksEnabled");

        vboxLayout2->addWidget(kcfg_socksEnabled);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        label_12 = new QLabel(groupBox);
        label_12->setObjectName("label_12");

        hboxLayout1->addWidget(label_12);

        kcfg_socksProxy = new QLineEdit(groupBox);
        kcfg_socksProxy->setObjectName("kcfg_socksProxy");

        hboxLayout1->addWidget(kcfg_socksProxy);

        label_11 = new QLabel(groupBox);
        label_11->setObjectName("label_11");

        hboxLayout1->addWidget(label_11);

        kcfg_socksPort = new QSpinBox(groupBox);
        kcfg_socksPort->setObjectName("kcfg_socksPort");

        hboxLayout1->addWidget(kcfg_socksPort);

        label_13 = new QLabel(groupBox);
        label_13->setObjectName("label_13");

        hboxLayout1->addWidget(label_13);

        kcfg_socksVersion = new QSpinBox(groupBox);
        kcfg_socksVersion->setObjectName("kcfg_socksVersion");

        hboxLayout1->addWidget(kcfg_socksVersion);


        vboxLayout2->addLayout(hboxLayout1);

        kcfg_socksUsePassword = new QCheckBox(groupBox);
        kcfg_socksUsePassword->setObjectName("kcfg_socksUsePassword");

        vboxLayout2->addWidget(kcfg_socksUsePassword);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setObjectName("hboxLayout2");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(groupBox);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        kcfg_socksUsername = new QLineEdit(groupBox);
        kcfg_socksUsername->setObjectName("kcfg_socksUsername");

        gridLayout->addWidget(kcfg_socksUsername, 0, 1, 1, 1);

        label_14 = new QLabel(groupBox);
        label_14->setObjectName("label_14");

        gridLayout->addWidget(label_14, 1, 0, 1, 1);

        kcfg_socksPassword = new QLineEdit(groupBox);
        kcfg_socksPassword->setObjectName("kcfg_socksPassword");
        kcfg_socksPassword->setEchoMode(QLineEdit::Password);

        gridLayout->addWidget(kcfg_socksPassword, 1, 1, 1, 1);


        hboxLayout2->addLayout(gridLayout);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem);


        vboxLayout2->addLayout(hboxLayout2);


        vboxLayout->addWidget(groupBox);

        spacerItem1 = new QSpacerItem(409, 21, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem1);


        retranslateUi(ProxyPref);
        QObject::connect(kcfg_socksEnabled, &QCheckBox::toggled, kcfg_socksProxy, &QLineEdit::setEnabled);
        QObject::connect(kcfg_socksEnabled, &QCheckBox::toggled, kcfg_socksPort, &QSpinBox::setEnabled);
        QObject::connect(kcfg_socksEnabled, &QCheckBox::toggled, kcfg_socksVersion, &QSpinBox::setEnabled);
        QObject::connect(kcfg_useKDEProxySettings, &QCheckBox::toggled, kcfg_httpProxy, &QLineEdit::setDisabled);
        QObject::connect(kcfg_useKDEProxySettings, &QCheckBox::toggled, kcfg_httpProxyPort, &QSpinBox::setDisabled);
        QObject::connect(kcfg_useKDEProxySettings, &QCheckBox::toggled, kcfg_useProxyForWebSeeds, &QCheckBox::setDisabled);
        QObject::connect(kcfg_useKDEProxySettings, &QCheckBox::toggled, kcfg_useProxyForTracker, &QCheckBox::setDisabled);

        QMetaObject::connectSlotsByName(ProxyPref);
    } // setupUi

    void retranslateUi(QWidget *ProxyPref)
    {
        groupBox_3->setTitle(tr2i18n("HTTP", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_useKDEProxySettings->setToolTip(tr2i18n("Use the HTTP proxy settings configured in the settings of KDE.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_useKDEProxySettings->setText(tr2i18n("Use KDE proxy settings", nullptr));
        label_10->setText(tr2i18n("Proxy:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_httpProxy->setToolTip(tr2i18n("IP address or hostname of the HTTP proxy to use. ", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(tr2i18n("Port:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_httpProxyPort->setToolTip(tr2i18n("Port of the HTTP proxy.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_useProxyForWebSeeds->setToolTip(tr2i18n("Whether or not to use the HTTP proxy for webseed connections.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_useProxyForWebSeeds->setText(tr2i18n("Use proxy for webseed connections", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_useProxyForTracker->setToolTip(tr2i18n("Whether or not to use the HTTP proxy for tracker connections.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_useProxyForTracker->setText(tr2i18n("Use proxy for tracker connections", nullptr));
        groupBox->setTitle(tr2i18n("SOCKS", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_socksEnabled->setToolTip(tr2i18n("<p>Use a SOCKS proxy server for bittorrent connections.</p>\n"
"<p><span style=\" font-weight:600;\">Note: </span>This is not used for tracker connections</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_socksEnabled->setText(tr2i18n("Use a SOCKS proxy server:", nullptr));
        label_12->setText(tr2i18n("Server:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_socksProxy->setToolTip(tr2i18n("IP address or hostname of the SOCKS server.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_11->setText(tr2i18n("Port:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_socksPort->setToolTip(tr2i18n("Port used by the SOCKS server.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_13->setText(tr2i18n("Version:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_socksUsePassword->setToolTip(tr2i18n("If the SOCKS server requires authentication via a username and a password, enable this box.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_socksUsePassword->setText(tr2i18n("Username and password required", nullptr));
        label->setText(tr2i18n("Username:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_socksUsername->setToolTip(tr2i18n("Username for the SOCKS proxy server.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_14->setText(tr2i18n("Password:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_socksPassword->setToolTip(tr2i18n("Password for the SOCKS proxy server.", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)ProxyPref;
    } // retranslateUi

};

namespace Ui {
    class ProxyPref: public Ui_ProxyPref {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROXYPREF_H

