/********************************************************************************
** Form generated from reading UI file 'ipfilterwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IPFILTERWIDGET_H
#define UI_IPFILTERWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_IPFilterWidget
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QLineEdit *m_ip_to_add;
    QPushButton *m_add;
    QListView *m_ip_list;
    QVBoxLayout *verticalLayout_2;
    QPushButton *m_remove;
    QPushButton *m_clear;
    QSpacerItem *verticalSpacer;
    QPushButton *m_open;
    QPushButton *m_save_as;
    QPushButton *m_close;

    void setupUi(QDialog *IPFilterWidget)
    {
        if (IPFilterWidget->objectName().isEmpty())
            IPFilterWidget->setObjectName("IPFilterWidget");
        IPFilterWidget->resize(632, 323);
        gridLayout = new QGridLayout(IPFilterWidget);
        gridLayout->setObjectName("gridLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(IPFilterWidget);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        m_ip_to_add = new QLineEdit(IPFilterWidget);
        m_ip_to_add->setObjectName("m_ip_to_add");
        m_ip_to_add->setClearButtonEnabled(true);

        horizontalLayout->addWidget(m_ip_to_add);


        gridLayout->addLayout(horizontalLayout, 0, 0, 1, 1);

        m_add = new QPushButton(IPFilterWidget);
        m_add->setObjectName("m_add");

        gridLayout->addWidget(m_add, 0, 1, 1, 1);

        m_ip_list = new QListView(IPFilterWidget);
        m_ip_list->setObjectName("m_ip_list");
        m_ip_list->setAlternatingRowColors(true);
        m_ip_list->setSelectionMode(QAbstractItemView::ContiguousSelection);

        gridLayout->addWidget(m_ip_list, 1, 0, 1, 1);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        m_remove = new QPushButton(IPFilterWidget);
        m_remove->setObjectName("m_remove");

        verticalLayout_2->addWidget(m_remove);

        m_clear = new QPushButton(IPFilterWidget);
        m_clear->setObjectName("m_clear");

        verticalLayout_2->addWidget(m_clear);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        m_open = new QPushButton(IPFilterWidget);
        m_open->setObjectName("m_open");

        verticalLayout_2->addWidget(m_open);

        m_save_as = new QPushButton(IPFilterWidget);
        m_save_as->setObjectName("m_save_as");

        verticalLayout_2->addWidget(m_save_as);

        m_close = new QPushButton(IPFilterWidget);
        m_close->setObjectName("m_close");

        verticalLayout_2->addWidget(m_close);


        gridLayout->addLayout(verticalLayout_2, 1, 1, 1, 1);


        retranslateUi(IPFilterWidget);

        QMetaObject::connectSlotsByName(IPFilterWidget);
    } // setupUi

    void retranslateUi(QDialog *IPFilterWidget)
    {
        IPFilterWidget->setWindowTitle(tr2i18n("KTorrent Blacklisted Peers", nullptr));
        label->setText(tr2i18n("Add peer:", nullptr));
#if QT_CONFIG(tooltip)
        m_ip_to_add->setToolTip(tr2i18n("IP addresses must be in the format 'XXX.XXX.XXX.XXX'.\n"
"                                        \n"
"You can also use wildcards like '127.0.0.*' or specify ranges like '200.10.10.0-200.10.10.40'.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_ip_to_add->setText(tr2i18n("127.0.0.1", nullptr));
        m_add->setText(tr2i18n("Add", nullptr));
        m_remove->setText(tr2i18n("Remove", nullptr));
        m_clear->setText(tr2i18n("Clear", nullptr));
        m_open->setText(tr2i18n("Open\342\200\246", nullptr));
        m_save_as->setText(tr2i18n("Save As\342\200\246", nullptr));
        m_close->setText(tr2i18n("Close", nullptr));
    } // retranslateUi

};

namespace Ui {
    class IPFilterWidget: public Ui_IPFilterWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IPFILTERWIDGET_H

