/********************************************************************************
** Form generated from reading UI file 'shutdowndlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SHUTDOWNDLG_H
#define UI_SHUTDOWNDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ShutdownDlg
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *label;
    QComboBox *m_action;
    QLabel *label_2;
    QComboBox *m_time_to_execute;
    QTreeView *m_torrent_list;
    QCheckBox *m_all_rules_must_be_hit;
    QFrame *line;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *ShutdownDlg)
    {
        if (ShutdownDlg->objectName().isEmpty())
            ShutdownDlg->setObjectName("ShutdownDlg");
        ShutdownDlg->resize(400, 300);
        verticalLayout = new QVBoxLayout(ShutdownDlg);
        verticalLayout->setObjectName("verticalLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(ShutdownDlg);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        m_action = new QComboBox(ShutdownDlg);
        m_action->setObjectName("m_action");

        gridLayout->addWidget(m_action, 0, 1, 1, 1);

        label_2 = new QLabel(ShutdownDlg);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        m_time_to_execute = new QComboBox(ShutdownDlg);
        m_time_to_execute->setObjectName("m_time_to_execute");

        gridLayout->addWidget(m_time_to_execute, 1, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        m_torrent_list = new QTreeView(ShutdownDlg);
        m_torrent_list->setObjectName("m_torrent_list");

        verticalLayout->addWidget(m_torrent_list);

        m_all_rules_must_be_hit = new QCheckBox(ShutdownDlg);
        m_all_rules_must_be_hit->setObjectName("m_all_rules_must_be_hit");

        verticalLayout->addWidget(m_all_rules_must_be_hit);

        line = new QFrame(ShutdownDlg);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        buttonBox = new QDialogButtonBox(ShutdownDlg);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(ShutdownDlg);

        QMetaObject::connectSlotsByName(ShutdownDlg);
    } // setupUi

    void retranslateUi(QWidget *ShutdownDlg)
    {
        ShutdownDlg->setWindowTitle(tr2i18n("Shutdown Settings", nullptr));
        label->setText(tr2i18n("Action to execute:", nullptr));
        label_2->setText(tr2i18n("Execute action when:", nullptr));
#if QT_CONFIG(tooltip)
        m_all_rules_must_be_hit->setToolTip(tr2i18n("When enabled, execute the action when all events have happened. When not enabled, execute when any of the above events have happened.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_all_rules_must_be_hit->setText(tr2i18n("All events must have happened", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ShutdownDlg: public Ui_ShutdownDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SHUTDOWNDLG_H

