/********************************************************************************
** Form generated from reading UI file 'advancedpref.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ADVANCEDPREF_H
#define UI_ADVANCEDPREF_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_AdvancedPref
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *kcfg_diskPrealloc;
    QVBoxLayout *vboxLayout;
    QCheckBox *kcfg_fullDiskPrealloc;
    QGroupBox *groupBox_3;
    QHBoxLayout *hboxLayout;
    QGridLayout *gridLayout;
    QLabel *label_5;
    QSpinBox *kcfg_guiUpdateInterval;
    QLabel *label_6;
    QSpinBox *kcfg_cpuUsage;
    QSpacerItem *spacerItem;
    QGroupBox *groupBox_2;
    QHBoxLayout *horizontalLayout_2;
    QGridLayout *GridLayout_1;
    QLabel *label;
    QSpinBox *kcfg_numMagnetDownloadingSlots;
    QCheckBox *kcfg_requeueMagnets;
    QSpinBox *kcfg_requeueMagnetsTime;
    QSpacerItem *horizontalSpacer;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QGridLayout *gridLayout1;
    QLabel *label_2;
    QSpinBox *kcfg_previewSizeAudio;
    QLabel *label_3;
    QSpinBox *kcfg_previewSizeVideo;
    QSpacerItem *spacerItem1;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_4;
    QLineEdit *kcfg_trackerListUrl;
    QCheckBox *kcfg_lookUpHostnameOfPeers;
    QSpacerItem *spacerItem2;

    void setupUi(QWidget *AdvancedPref)
    {
        if (AdvancedPref->objectName().isEmpty())
            AdvancedPref->setObjectName("AdvancedPref");
        AdvancedPref->resize(593, 476);
        verticalLayout_2 = new QVBoxLayout(AdvancedPref);
        verticalLayout_2->setObjectName("verticalLayout_2");
        kcfg_diskPrealloc = new QGroupBox(AdvancedPref);
        kcfg_diskPrealloc->setObjectName("kcfg_diskPrealloc");
        kcfg_diskPrealloc->setCheckable(true);
        kcfg_diskPrealloc->setChecked(false);
        vboxLayout = new QVBoxLayout(kcfg_diskPrealloc);
        vboxLayout->setObjectName("vboxLayout");
        kcfg_fullDiskPrealloc = new QCheckBox(kcfg_diskPrealloc);
        kcfg_fullDiskPrealloc->setObjectName("kcfg_fullDiskPrealloc");

        vboxLayout->addWidget(kcfg_fullDiskPrealloc);


        verticalLayout_2->addWidget(kcfg_diskPrealloc);

        groupBox_3 = new QGroupBox(AdvancedPref);
        groupBox_3->setObjectName("groupBox_3");
        hboxLayout = new QHBoxLayout(groupBox_3);
        hboxLayout->setObjectName("hboxLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label_5 = new QLabel(groupBox_3);
        label_5->setObjectName("label_5");

        gridLayout->addWidget(label_5, 0, 0, 1, 1);

        kcfg_guiUpdateInterval = new QSpinBox(groupBox_3);
        kcfg_guiUpdateInterval->setObjectName("kcfg_guiUpdateInterval");
        kcfg_guiUpdateInterval->setMinimumSize(QSize(100, 0));
        kcfg_guiUpdateInterval->setMinimum(500);
        kcfg_guiUpdateInterval->setMaximum(5000);
        kcfg_guiUpdateInterval->setValue(1000);

        gridLayout->addWidget(kcfg_guiUpdateInterval, 0, 1, 1, 1);

        label_6 = new QLabel(groupBox_3);
        label_6->setObjectName("label_6");

        gridLayout->addWidget(label_6, 1, 0, 1, 1);

        kcfg_cpuUsage = new QSpinBox(groupBox_3);
        kcfg_cpuUsage->setObjectName("kcfg_cpuUsage");
        kcfg_cpuUsage->setMinimum(1);
        kcfg_cpuUsage->setMaximum(250);
        kcfg_cpuUsage->setValue(50);

        gridLayout->addWidget(kcfg_cpuUsage, 1, 1, 1, 1);


        hboxLayout->addLayout(gridLayout);

        spacerItem = new QSpacerItem(111, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);


        verticalLayout_2->addWidget(groupBox_3);

        groupBox_2 = new QGroupBox(AdvancedPref);
        groupBox_2->setObjectName("groupBox_2");
        horizontalLayout_2 = new QHBoxLayout(groupBox_2);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        GridLayout_1 = new QGridLayout();
        GridLayout_1->setObjectName("GridLayout_1");
        label = new QLabel(groupBox_2);
        label->setObjectName("label");

        GridLayout_1->addWidget(label, 0, 0, 1, 1);

        kcfg_numMagnetDownloadingSlots = new QSpinBox(groupBox_2);
        kcfg_numMagnetDownloadingSlots->setObjectName("kcfg_numMagnetDownloadingSlots");
        kcfg_numMagnetDownloadingSlots->setMinimum(1);
        kcfg_numMagnetDownloadingSlots->setMaximum(100);
        kcfg_numMagnetDownloadingSlots->setValue(5);

        GridLayout_1->addWidget(kcfg_numMagnetDownloadingSlots, 0, 1, 1, 1);

        kcfg_requeueMagnets = new QCheckBox(groupBox_2);
        kcfg_requeueMagnets->setObjectName("kcfg_requeueMagnets");

        GridLayout_1->addWidget(kcfg_requeueMagnets, 1, 0, 1, 1);

        kcfg_requeueMagnetsTime = new QSpinBox(groupBox_2);
        kcfg_requeueMagnetsTime->setObjectName("kcfg_requeueMagnetsTime");
        kcfg_requeueMagnetsTime->setMinimum(1);
        kcfg_requeueMagnetsTime->setMaximum(60);
        kcfg_requeueMagnetsTime->setValue(5);

        GridLayout_1->addWidget(kcfg_requeueMagnetsTime, 1, 1, 1, 1);


        horizontalLayout_2->addLayout(GridLayout_1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        verticalLayout_2->addWidget(groupBox_2);

        groupBox = new QGroupBox(AdvancedPref);
        groupBox->setObjectName("groupBox");
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        gridLayout1 = new QGridLayout();
        gridLayout1->setObjectName("gridLayout1");
        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        gridLayout1->addWidget(label_2, 0, 0, 1, 1);

        kcfg_previewSizeAudio = new QSpinBox(groupBox);
        kcfg_previewSizeAudio->setObjectName("kcfg_previewSizeAudio");
        kcfg_previewSizeAudio->setMinimum(16);
        kcfg_previewSizeAudio->setMaximum(100000000);

        gridLayout1->addWidget(kcfg_previewSizeAudio, 0, 1, 1, 1);

        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");

        gridLayout1->addWidget(label_3, 1, 0, 1, 1);

        kcfg_previewSizeVideo = new QSpinBox(groupBox);
        kcfg_previewSizeVideo->setObjectName("kcfg_previewSizeVideo");
        kcfg_previewSizeVideo->setMinimum(16);
        kcfg_previewSizeVideo->setMaximum(100000000);

        gridLayout1->addWidget(kcfg_previewSizeVideo, 1, 1, 1, 1);


        horizontalLayout->addLayout(gridLayout1);

        spacerItem1 = new QSpacerItem(111, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(spacerItem1);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");

        horizontalLayout_3->addWidget(label_4);

        kcfg_trackerListUrl = new QLineEdit(groupBox);
        kcfg_trackerListUrl->setObjectName("kcfg_trackerListUrl");

        horizontalLayout_3->addWidget(kcfg_trackerListUrl);


        verticalLayout->addLayout(horizontalLayout_3);

        kcfg_lookUpHostnameOfPeers = new QCheckBox(groupBox);
        kcfg_lookUpHostnameOfPeers->setObjectName("kcfg_lookUpHostnameOfPeers");

        verticalLayout->addWidget(kcfg_lookUpHostnameOfPeers);


        verticalLayout_2->addWidget(groupBox);

        spacerItem2 = new QSpacerItem(575, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(spacerItem2);


        retranslateUi(AdvancedPref);

        QMetaObject::connectSlotsByName(AdvancedPref);
    } // setupUi

    void retranslateUi(QWidget *AdvancedPref)
    {
#if QT_CONFIG(tooltip)
        kcfg_diskPrealloc->setToolTip(tr2i18n("Whether or not diskspace should be reserved before starting to download a torrent.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_diskPrealloc->setTitle(tr2i18n("Reserve disk space before starting a torrent", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_fullDiskPrealloc->setToolTip(tr2i18n("Instead of doing a quick reservation, do a full reservation. This is slower than the quick way, but avoids fragmentation on the disk.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_fullDiskPrealloc->setText(tr2i18n("Fully reserve disk space (avoids fragmentation)", nullptr));
        groupBox_3->setTitle(tr2i18n("Performance", nullptr));
        label_5->setText(tr2i18n("GUI update interval:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_guiUpdateInterval->setToolTip(tr2i18n("<p>The interval in milliseconds between GUI updates.</p>\n"
"<p><span style=\" font-weight:600;\">Note: </span>Increasing this will decrease CPU usage.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_guiUpdateInterval->setSuffix(tr2i18n(" ms", nullptr));
        label_6->setText(tr2i18n("Network sleep interval:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_cpuUsage->setToolTip(tr2i18n("<p>Amount of time the network threads will sleep when they are speed limited. This has absolutely no effect when there are no speed limits.</p>\n"
"<p><span style=\" font-weight:600;\">Note:</span> The lower this is the more CPU is used. Setting it high can lead to lower speeds in high bandwidth situations. </p>\n"
"<p>For example on an 100 Mbit LAN, if you set a limit of 3000 KiB/s, you might not actually reach this speed when this value is too high. Without a limit you can easily get above 3000 KiB/s on a LAN.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_cpuUsage->setSuffix(tr2i18n(" ms", nullptr));
        groupBox_2->setTitle(tr2i18n("Magnets Queue", nullptr));
        label->setText(tr2i18n("Number of downloading slots:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_numMagnetDownloadingSlots->setToolTip(tr2i18n("Maximum number of concurrent downloading magnets at the same time.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_requeueMagnets->setToolTip(tr2i18n("Whether or not the magnets that are not downloaded after a maximum period of time must be pushed back at the end of the queue.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_requeueMagnets->setText(tr2i18n("Requeue magnets after:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_requeueMagnetsTime->setToolTip(tr2i18n("Maximum time that a magnet can occupy a downloading slot before it will be pushed back in the queue.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_requeueMagnetsTime->setSuffix(tr2i18n(" min", nullptr));
        groupBox->setTitle(tr2i18n("Miscellaneous", nullptr));
        label_2->setText(tr2i18n("Preview size for audio files:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_previewSizeAudio->setToolTip(tr2i18n("<p>The amount of data at the beginning and end of an audio file, which will be prioritized for previewing.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_previewSizeAudio->setSuffix(tr2i18n(" KiB", nullptr));
        label_3->setText(tr2i18n("Preview size for video files:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_previewSizeVideo->setToolTip(tr2i18n("<p>The amount of data at the beginning and end of a video file, which will be prioritized for previewing.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_previewSizeVideo->setSuffix(tr2i18n(" KiB", nullptr));
        label_4->setText(tr2i18n("Tracker list URL:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_trackerListUrl->setToolTip(tr2i18n("URL of the tracker list used when adding a torrent by infohash\n"
"NOTE: Each tracker must be on its own line. Blank lines are ignored.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_lookUpHostnameOfPeers->setToolTip(tr2i18n("Resolve the hostname of each peer. This will result in the hostname of a peer being displayed instead of the IP address. \n"
"\n"
"It can be disabled if you do not like the additional network traffic it generates", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_lookUpHostnameOfPeers->setText(tr2i18n("Resolve hostnames of peers", nullptr));
        (void)AdvancedPref;
    } // retranslateUi

};

namespace Ui {
    class AdvancedPref: public Ui_AdvancedPref {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ADVANCEDPREF_H

