/********************************************************************************
** Form generated from reading UI file 'searchpref.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SEARCHPREF_H
#define UI_SEARCHPREF_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SearchPref
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *hboxLayout;
    QPushButton *m_clear_history;
    QPushButton *m_reset_default_action;
    QSpacerItem *spacerItem;
    QCheckBox *kcfg_restorePreviousSession;
    QCheckBox *kcfg_openInExternal;
    QCheckBox *kcfg_useProxySettings;
    QRadioButton *kcfg_useDefaultBrowser;
    QHBoxLayout *hboxLayout1;
    QRadioButton *kcfg_useCustomBrowser;
    QLineEdit *kcfg_customBrowser;
    QSpacerItem *spacerItem1;
    QGroupBox *groupBox8;
    QHBoxLayout *horizontalLayout;
    QListView *m_engines;
    QVBoxLayout *verticalLayout;
    QPushButton *m_add;
    QPushButton *m_remove;
    QPushButton *m_remove_all;
    QSpacerItem *verticalSpacer;
    QPushButton *m_add_default;

    void setupUi(QWidget *SearchPref)
    {
        if (SearchPref->objectName().isEmpty())
            SearchPref->setObjectName("SearchPref");
        SearchPref->resize(569, 364);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(SearchPref->sizePolicy().hasHeightForWidth());
        SearchPref->setSizePolicy(sizePolicy);
        SearchPref->setMinimumSize(QSize(500, 350));
        verticalLayout_2 = new QVBoxLayout(SearchPref);
        verticalLayout_2->setSpacing(6);
        verticalLayout_2->setContentsMargins(11, 11, 11, 11);
        verticalLayout_2->setObjectName("verticalLayout_2");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        m_clear_history = new QPushButton(SearchPref);
        m_clear_history->setObjectName("m_clear_history");

        hboxLayout->addWidget(m_clear_history);

        m_reset_default_action = new QPushButton(SearchPref);
        m_reset_default_action->setObjectName("m_reset_default_action");

        hboxLayout->addWidget(m_reset_default_action);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);


        verticalLayout_2->addLayout(hboxLayout);

        kcfg_restorePreviousSession = new QCheckBox(SearchPref);
        kcfg_restorePreviousSession->setObjectName("kcfg_restorePreviousSession");

        verticalLayout_2->addWidget(kcfg_restorePreviousSession);

        kcfg_openInExternal = new QCheckBox(SearchPref);
        kcfg_openInExternal->setObjectName("kcfg_openInExternal");

        verticalLayout_2->addWidget(kcfg_openInExternal);

        kcfg_useProxySettings = new QCheckBox(SearchPref);
        kcfg_useProxySettings->setObjectName("kcfg_useProxySettings");

        verticalLayout_2->addWidget(kcfg_useProxySettings);

        kcfg_useDefaultBrowser = new QRadioButton(SearchPref);
        kcfg_useDefaultBrowser->setObjectName("kcfg_useDefaultBrowser");

        verticalLayout_2->addWidget(kcfg_useDefaultBrowser);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName("hboxLayout1");
        kcfg_useCustomBrowser = new QRadioButton(SearchPref);
        kcfg_useCustomBrowser->setObjectName("kcfg_useCustomBrowser");

        hboxLayout1->addWidget(kcfg_useCustomBrowser);

        kcfg_customBrowser = new QLineEdit(SearchPref);
        kcfg_customBrowser->setObjectName("kcfg_customBrowser");

        hboxLayout1->addWidget(kcfg_customBrowser);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem1);


        verticalLayout_2->addLayout(hboxLayout1);

        groupBox8 = new QGroupBox(SearchPref);
        groupBox8->setObjectName("groupBox8");
        horizontalLayout = new QHBoxLayout(groupBox8);
        horizontalLayout->setSpacing(6);
        horizontalLayout->setContentsMargins(11, 11, 11, 11);
        horizontalLayout->setObjectName("horizontalLayout");
        m_engines = new QListView(groupBox8);
        m_engines->setObjectName("m_engines");
        m_engines->setSelectionMode(QAbstractItemView::ExtendedSelection);

        horizontalLayout->addWidget(m_engines);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName("verticalLayout");
        m_add = new QPushButton(groupBox8);
        m_add->setObjectName("m_add");

        verticalLayout->addWidget(m_add);

        m_remove = new QPushButton(groupBox8);
        m_remove->setObjectName("m_remove");

        verticalLayout->addWidget(m_remove);

        m_remove_all = new QPushButton(groupBox8);
        m_remove_all->setObjectName("m_remove_all");

        verticalLayout->addWidget(m_remove_all);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        m_add_default = new QPushButton(groupBox8);
        m_add_default->setObjectName("m_add_default");

        verticalLayout->addWidget(m_add_default);


        horizontalLayout->addLayout(verticalLayout);


        verticalLayout_2->addWidget(groupBox8);


        retranslateUi(SearchPref);

        QMetaObject::connectSlotsByName(SearchPref);
    } // setupUi

    void retranslateUi(QWidget *SearchPref)
    {
        SearchPref->setWindowTitle(tr2i18n("Search Preferences", nullptr));
#if QT_CONFIG(tooltip)
        m_clear_history->setToolTip(tr2i18n("Clear the search history combo boxes.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_clear_history->setText(tr2i18n("Clear Search History", nullptr));
#if QT_CONFIG(tooltip)
        m_reset_default_action->setToolTip(tr2i18n("Reset the default action taken when a torrent is downloaded.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_reset_default_action->setText(tr2i18n("Reset Default Torrent Action", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_restorePreviousSession->setToolTip(tr2i18n("Restore all the active searches of the last session", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_restorePreviousSession->setText(tr2i18n("Restore previous searches", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_openInExternal->setToolTip(tr2i18n("Whether or not to open searches in an external browser.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_openInExternal->setText(tr2i18n("Open searches in external browser", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_useProxySettings->setToolTip(tr2i18n("Whether or not to use the HTTP proxy settings for search.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_useProxySettings->setText(tr2i18n("Use proxy settings for search", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_useDefaultBrowser->setToolTip(tr2i18n("Use the default browser configured in the system settings.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_useDefaultBrowser->setText(tr2i18n("Use default browser", nullptr));
#if QT_CONFIG(shortcut)
        kcfg_useDefaultBrowser->setShortcut(QString());
#endif // QT_CONFIG(shortcut)
#if QT_CONFIG(tooltip)
        kcfg_useCustomBrowser->setToolTip(tr2i18n("Use a custom browser.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_useCustomBrowser->setText(tr2i18n("Custom browser path:", nullptr));
#if QT_CONFIG(shortcut)
        kcfg_useCustomBrowser->setShortcut(QString());
#endif // QT_CONFIG(shortcut)
#if QT_CONFIG(tooltip)
        kcfg_customBrowser->setToolTip(tr2i18n("Path of the custom browser.", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox8->setTitle(tr2i18n("Search Engines", nullptr));
#if QT_CONFIG(tooltip)
        m_add->setToolTip(tr2i18n("Add a new search engine.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_add->setText(tr2i18n("Add", nullptr));
#if QT_CONFIG(tooltip)
        m_remove->setToolTip(tr2i18n("Remove all selected search engines.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_remove->setText(tr2i18n("&Remove", nullptr));
#if QT_CONFIG(tooltip)
        m_remove_all->setToolTip(tr2i18n("Remove all search engines.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_remove_all->setText(tr2i18n("R&emove All", nullptr));
#if QT_CONFIG(tooltip)
        m_add_default->setToolTip(tr2i18n("Add all default search engines.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_add_default->setText(tr2i18n("Add Defau&lt", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SearchPref: public Ui_SearchPref {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SEARCHPREF_H

