// This file is generated by kconfig_compiler_kf6 from ktscanforlostfilesplugin.kcfg.
// All changes you do to this file will be lost.
#ifndef SCANFORLOSTFILESPLUGINSETTINGS_H
#define SCANFORLOSTFILESPLUGINSETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class ScanForLostFilesPluginSettings : public KConfigSkeleton
{
  public:

    static ScanForLostFilesPluginSettings *self();
    ~ScanForLostFilesPluginSettings() override;

    /**
      Set ScanForLostFilesWidgetPosition
    */
    static
    void setScanForLostFilesWidgetPosition( int v )
    {
      if (v < 0)
      {
        qDebug() << "setScanForLostFilesWidgetPosition: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 2)
      {
        qDebug() << "setScanForLostFilesWidgetPosition: value " << v << " is greater than the maximum value of 2";
        v = 2;
      }

      if (!self()->isScanForLostFilesWidgetPositionImmutable())
        self()->mScanForLostFilesWidgetPosition = v;
    }

    /**
      Get ScanForLostFilesWidgetPosition
    */
    static
    int scanForLostFilesWidgetPosition()
    {
      return self()->mScanForLostFilesWidgetPosition;
    }

    /**
      Is ScanForLostFilesWidgetPosition Immutable
    */
    static
    bool isScanForLostFilesWidgetPositionImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ScanForLostFilesWidgetPosition" ) );
    }

  protected:
    ScanForLostFilesPluginSettings();
    friend class ScanForLostFilesPluginSettingsHelper;


    // general
    int mScanForLostFilesWidgetPosition;
};

#endif

