/********************************************************************************
** Form generated from reading UI file 'scanforlostfileswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SCANFORLOSTFILESWIDGET_H
#define UI_SCANFORLOSTFILESWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_ScanForLostFilesWidget
{
public:
    QAction *actionOpen_file;
    QAction *actionDelete_on_disk;
    QAction *actionCopy_to_clipboard;
    QVBoxLayout *vboxLayout;
    QLabel *label;
    KUrlRequester *reqFolder;
    QHBoxLayout *horizontalLayout;
    QPushButton *btnExpandAll;
    QPushButton *btnCollapseAll;
    QSpacerItem *horizontalSpacer_2;
    QProgressBar *progressBar;
    QSpacerItem *horizontalSpacer;
    QPushButton *btnScanFolder;
    QTreeView *treeView;
    QCheckBox *cbShowAllFiles;

    void setupUi(QWidget *ScanForLostFilesWidget)
    {
        if (ScanForLostFilesWidget->objectName().isEmpty())
            ScanForLostFilesWidget->setObjectName("ScanForLostFilesWidget");
        ScanForLostFilesWidget->resize(559, 590);
        actionOpen_file = new QAction(ScanForLostFilesWidget);
        actionOpen_file->setObjectName("actionOpen_file");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("document-open");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        actionOpen_file->setIcon(icon);
        actionDelete_on_disk = new QAction(ScanForLostFilesWidget);
        actionDelete_on_disk->setObjectName("actionDelete_on_disk");
        QIcon icon1;
        iconThemeName = QString::fromUtf8("delete");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        actionDelete_on_disk->setIcon(icon1);
        actionCopy_to_clipboard = new QAction(ScanForLostFilesWidget);
        actionCopy_to_clipboard->setObjectName("actionCopy_to_clipboard");
        QIcon icon2;
        iconThemeName = QString::fromUtf8("edit-copy");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon2 = QIcon::fromTheme(iconThemeName);
        } else {
            icon2.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        actionCopy_to_clipboard->setIcon(icon2);
        vboxLayout = new QVBoxLayout(ScanForLostFilesWidget);
        vboxLayout->setObjectName("vboxLayout");
        label = new QLabel(ScanForLostFilesWidget);
        label->setObjectName("label");

        vboxLayout->addWidget(label);

        reqFolder = new KUrlRequester(ScanForLostFilesWidget);
        reqFolder->setObjectName("reqFolder");

        vboxLayout->addWidget(reqFolder);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        btnExpandAll = new QPushButton(ScanForLostFilesWidget);
        btnExpandAll->setObjectName("btnExpandAll");

        horizontalLayout->addWidget(btnExpandAll);

        btnCollapseAll = new QPushButton(ScanForLostFilesWidget);
        btnCollapseAll->setObjectName("btnCollapseAll");

        horizontalLayout->addWidget(btnCollapseAll);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);

        progressBar = new QProgressBar(ScanForLostFilesWidget);
        progressBar->setObjectName("progressBar");
        progressBar->setMaximum(0);
        progressBar->setValue(0);
        progressBar->setTextVisible(false);

        horizontalLayout->addWidget(progressBar);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        btnScanFolder = new QPushButton(ScanForLostFilesWidget);
        btnScanFolder->setObjectName("btnScanFolder");

        horizontalLayout->addWidget(btnScanFolder);


        vboxLayout->addLayout(horizontalLayout);

        treeView = new QTreeView(ScanForLostFilesWidget);
        treeView->setObjectName("treeView");
        treeView->setSelectionMode(QAbstractItemView::ExtendedSelection);

        vboxLayout->addWidget(treeView);

        cbShowAllFiles = new QCheckBox(ScanForLostFilesWidget);
        cbShowAllFiles->setObjectName("cbShowAllFiles");

        vboxLayout->addWidget(cbShowAllFiles);


        retranslateUi(ScanForLostFilesWidget);

        QMetaObject::connectSlotsByName(ScanForLostFilesWidget);
    } // setupUi

    void retranslateUi(QWidget *ScanForLostFilesWidget)
    {
        actionOpen_file->setText(tr2i18n("Open file", nullptr));
        actionDelete_on_disk->setText(tr2i18n("Delete on disk", nullptr));
#if QT_CONFIG(shortcut)
        actionDelete_on_disk->setShortcut(tr2i18n("Ctrl+Del", nullptr));
#endif // QT_CONFIG(shortcut)
        actionCopy_to_clipboard->setText(tr2i18n("Copy to clipboard", nullptr));
#if QT_CONFIG(shortcut)
        actionCopy_to_clipboard->setShortcut(tr2i18n("Ctrl+C", nullptr));
#endif // QT_CONFIG(shortcut)
        label->setText(tr2i18n("Select folder:", nullptr));
        btnExpandAll->setText(tr2i18n("Expand All", nullptr));
        btnCollapseAll->setText(tr2i18n("Collapse All", nullptr));
        btnScanFolder->setText(tr2i18n("Scan", nullptr));
#if QT_CONFIG(tooltip)
        cbShowAllFiles->setToolTip(tr2i18n("Open the torrents without asking any questions.", nullptr));
#endif // QT_CONFIG(tooltip)
        cbShowAllFiles->setText(tr2i18n("Show all files", nullptr));
        (void)ScanForLostFilesWidget;
    } // retranslateUi

};

namespace Ui {
    class ScanForLostFilesWidget: public Ui_ScanForLostFilesWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SCANFORLOSTFILESWIDGET_H

