/********************************************************************************
** Form generated from reading UI file 'Spd.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SPD_H
#define UI_SPD_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SpdWgt
{
public:
    QHBoxLayout *hboxLayout;
    QGroupBox *DlSpdGbw;
    QGridLayout *gridLayout;
    QGridLayout *gridLayout1;
    QGroupBox *PeersSpdGbw;
    QGridLayout *gridLayout2;
    QGridLayout *gridLayout3;
    QGroupBox *UlSpdGbw;
    QGridLayout *gridLayout4;
    QGridLayout *gridLayout5;

    void setupUi(QWidget *SpdWgt)
    {
        if (SpdWgt->objectName().isEmpty())
            SpdWgt->setObjectName("SpdWgt");
        SpdWgt->resize(555, 221);
        hboxLayout = new QHBoxLayout(SpdWgt);
        hboxLayout->setObjectName("hboxLayout");
        DlSpdGbw = new QGroupBox(SpdWgt);
        DlSpdGbw->setObjectName("DlSpdGbw");
        gridLayout = new QGridLayout(DlSpdGbw);
        gridLayout->setObjectName("gridLayout");
        gridLayout1 = new QGridLayout();
        gridLayout1->setObjectName("gridLayout1");

        gridLayout->addLayout(gridLayout1, 0, 0, 1, 1);


        hboxLayout->addWidget(DlSpdGbw);

        PeersSpdGbw = new QGroupBox(SpdWgt);
        PeersSpdGbw->setObjectName("PeersSpdGbw");
        gridLayout2 = new QGridLayout(PeersSpdGbw);
        gridLayout2->setObjectName("gridLayout2");
        gridLayout3 = new QGridLayout();
        gridLayout3->setObjectName("gridLayout3");

        gridLayout2->addLayout(gridLayout3, 0, 0, 1, 1);


        hboxLayout->addWidget(PeersSpdGbw);

        UlSpdGbw = new QGroupBox(SpdWgt);
        UlSpdGbw->setObjectName("UlSpdGbw");
        gridLayout4 = new QGridLayout(UlSpdGbw);
        gridLayout4->setObjectName("gridLayout4");
        gridLayout5 = new QGridLayout();
        gridLayout5->setObjectName("gridLayout5");

        gridLayout4->addLayout(gridLayout5, 0, 0, 1, 1);


        hboxLayout->addWidget(UlSpdGbw);


        retranslateUi(SpdWgt);

        QMetaObject::connectSlotsByName(SpdWgt);
    } // setupUi

    void retranslateUi(QWidget *SpdWgt)
    {
        SpdWgt->setWindowTitle(tr2i18n("Speed", "@title:window"));
        DlSpdGbw->setTitle(tr2i18n("Download", "Chart name"));
        PeersSpdGbw->setTitle(tr2i18n("Peers", "Chart name"));
        UlSpdGbw->setTitle(tr2i18n("Upload", "Chart name"));
    } // retranslateUi

};

namespace Ui {
    class SpdWgt: public Ui_SpdWgt {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SPD_H

