/********************************************************************************
** Form generated from reading UI file 'networkpref.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NETWORKPREF_H
#define UI_NETWORKPREF_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_NetworkPref
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLabel *label;
    QSpinBox *kcfg_port;
    QLabel *label_2;
    QSpinBox *kcfg_udpTrackerPort;
    QLabel *label_3;
    QSpinBox *kcfg_maxConnections;
    QLabel *label_4;
    QSpinBox *kcfg_maxTotalConnections;
    QLabel *label_6;
    QSpinBox *kcfg_maxDownloadRate;
    QLabel *label_5;
    QSpinBox *kcfg_maxUploadRate;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout1;
    QLabel *label_7;
    QSpinBox *kcfg_dscp;
    QLabel *label_8;
    QSpinBox *kcfg_maxConnectingSockets;
    QLabel *label_9;
    QComboBox *combo_networkInterface;
    QCheckBox *kcfg_utpEnabled;
    QCheckBox *kcfg_onlyUseUtp;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_10;
    QComboBox *kcfg_primaryTransportProtocol;
    QSpacerItem *horizontalSpacer_2;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *m_recommended_settings;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *NetworkPref)
    {
        if (NetworkPref->objectName().isEmpty())
            NetworkPref->setObjectName("NetworkPref");
        NetworkPref->resize(501, 495);
        verticalLayout_2 = new QVBoxLayout(NetworkPref);
        verticalLayout_2->setObjectName("verticalLayout_2");
        groupBox = new QGroupBox(NetworkPref);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(groupBox);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        kcfg_port = new QSpinBox(groupBox);
        kcfg_port->setObjectName("kcfg_port");
        kcfg_port->setMinimum(1);
        kcfg_port->setMaximum(65535);
        kcfg_port->setValue(3000);

        gridLayout->addWidget(kcfg_port, 0, 1, 1, 1);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        kcfg_udpTrackerPort = new QSpinBox(groupBox);
        kcfg_udpTrackerPort->setObjectName("kcfg_udpTrackerPort");
        kcfg_udpTrackerPort->setMinimum(1);
        kcfg_udpTrackerPort->setMaximum(65536);
        kcfg_udpTrackerPort->setValue(4000);

        gridLayout->addWidget(kcfg_udpTrackerPort, 1, 1, 1, 1);

        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 2, 0, 1, 1);

        kcfg_maxConnections = new QSpinBox(groupBox);
        kcfg_maxConnections->setObjectName("kcfg_maxConnections");
        kcfg_maxConnections->setMaximum(99999);

        gridLayout->addWidget(kcfg_maxConnections, 2, 1, 1, 1);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 3, 0, 1, 1);

        kcfg_maxTotalConnections = new QSpinBox(groupBox);
        kcfg_maxTotalConnections->setObjectName("kcfg_maxTotalConnections");
        kcfg_maxTotalConnections->setMaximum(99999);

        gridLayout->addWidget(kcfg_maxTotalConnections, 3, 1, 1, 1);

        label_6 = new QLabel(groupBox);
        label_6->setObjectName("label_6");

        gridLayout->addWidget(label_6, 4, 0, 1, 1);

        kcfg_maxDownloadRate = new QSpinBox(groupBox);
        kcfg_maxDownloadRate->setObjectName("kcfg_maxDownloadRate");
        kcfg_maxDownloadRate->setMaximum(6500000);

        gridLayout->addWidget(kcfg_maxDownloadRate, 4, 1, 1, 1);

        label_5 = new QLabel(groupBox);
        label_5->setObjectName("label_5");

        gridLayout->addWidget(label_5, 5, 0, 1, 1);

        kcfg_maxUploadRate = new QSpinBox(groupBox);
        kcfg_maxUploadRate->setObjectName("kcfg_maxUploadRate");
        kcfg_maxUploadRate->setMaximum(6500000);

        gridLayout->addWidget(kcfg_maxUploadRate, 5, 1, 1, 1);


        verticalLayout_2->addWidget(groupBox);

        groupBox_2 = new QGroupBox(NetworkPref);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout = new QVBoxLayout(groupBox_2);
        verticalLayout->setObjectName("verticalLayout");
        gridLayout1 = new QGridLayout();
        gridLayout1->setObjectName("gridLayout1");
        label_7 = new QLabel(groupBox_2);
        label_7->setObjectName("label_7");

        gridLayout1->addWidget(label_7, 0, 0, 1, 1);

        kcfg_dscp = new QSpinBox(groupBox_2);
        kcfg_dscp->setObjectName("kcfg_dscp");
        kcfg_dscp->setMaximum(63);

        gridLayout1->addWidget(kcfg_dscp, 0, 1, 1, 1);

        label_8 = new QLabel(groupBox_2);
        label_8->setObjectName("label_8");

        gridLayout1->addWidget(label_8, 1, 0, 1, 1);

        kcfg_maxConnectingSockets = new QSpinBox(groupBox_2);
        kcfg_maxConnectingSockets->setObjectName("kcfg_maxConnectingSockets");
        kcfg_maxConnectingSockets->setMinimum(10);
        kcfg_maxConnectingSockets->setMaximum(200);
        kcfg_maxConnectingSockets->setValue(50);

        gridLayout1->addWidget(kcfg_maxConnectingSockets, 1, 1, 1, 1);

        label_9 = new QLabel(groupBox_2);
        label_9->setObjectName("label_9");

        gridLayout1->addWidget(label_9, 2, 0, 1, 1);

        combo_networkInterface = new QComboBox(groupBox_2);
        combo_networkInterface->setObjectName("combo_networkInterface");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(combo_networkInterface->sizePolicy().hasHeightForWidth());
        combo_networkInterface->setSizePolicy(sizePolicy);

        gridLayout1->addWidget(combo_networkInterface, 2, 1, 1, 1);


        verticalLayout->addLayout(gridLayout1);

        kcfg_utpEnabled = new QCheckBox(groupBox_2);
        kcfg_utpEnabled->setObjectName("kcfg_utpEnabled");

        verticalLayout->addWidget(kcfg_utpEnabled);

        kcfg_onlyUseUtp = new QCheckBox(groupBox_2);
        kcfg_onlyUseUtp->setObjectName("kcfg_onlyUseUtp");

        verticalLayout->addWidget(kcfg_onlyUseUtp);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_10 = new QLabel(groupBox_2);
        label_10->setObjectName("label_10");

        horizontalLayout_2->addWidget(label_10);

        kcfg_primaryTransportProtocol = new QComboBox(groupBox_2);
        kcfg_primaryTransportProtocol->addItem(QString());
        kcfg_primaryTransportProtocol->addItem(QString());
        kcfg_primaryTransportProtocol->setObjectName("kcfg_primaryTransportProtocol");

        horizontalLayout_2->addWidget(kcfg_primaryTransportProtocol);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout_2);


        verticalLayout_2->addWidget(groupBox_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        m_recommended_settings = new QPushButton(NetworkPref);
        m_recommended_settings->setObjectName("m_recommended_settings");

        horizontalLayout->addWidget(m_recommended_settings);


        verticalLayout_2->addLayout(horizontalLayout);

        spacerItem = new QSpacerItem(493, 41, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(spacerItem);


        retranslateUi(NetworkPref);

        QMetaObject::connectSlotsByName(NetworkPref);
    } // setupUi

    void retranslateUi(QWidget *NetworkPref)
    {
        groupBox->setTitle(tr2i18n("Ports && Limits", nullptr));
        label->setText(tr2i18n("Port:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_port->setToolTip(tr2i18n("<p>Port used for the bittorrent protocol.</p>\n"
"<p><span style=\" font-weight:600;\">Attention:</span> If you are behind a router, this port needs to be forwarded to accept incoming connections. The UPnP plugin can do this for you.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(tr2i18n("UDP tracker port:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_udpTrackerPort->setToolTip(tr2i18n("<p>Port used for the UDP tracker protocol.</p>\n"
"<p><span style=\" font-weight:600;\">Attention:</span> If you are behind a router, this port needs to be forwarded. The UPnP plugin can do this for you.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_3->setText(tr2i18n("Maximum connections per torrent:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_maxConnections->setToolTip(tr2i18n("The maximum number of connections allowed per torrent.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_maxConnections->setSpecialValueText(tr2i18n("No limit", nullptr));
        label_4->setText(tr2i18n("Global connection limit:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_maxTotalConnections->setToolTip(tr2i18n("The global connection limit for all torrents combined.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_maxTotalConnections->setSpecialValueText(tr2i18n("No limit", nullptr));
        label_6->setText(tr2i18n("Maximum download speed:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_maxDownloadRate->setToolTip(tr2i18n("The maximum download speed in KiB/s.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_maxDownloadRate->setSpecialValueText(tr2i18n("No limit", nullptr));
        kcfg_maxDownloadRate->setSuffix(tr2i18n(" KiB/s", nullptr));
        label_5->setText(tr2i18n("Maximum upload speed:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_maxUploadRate->setToolTip(tr2i18n("The maximum upload speed in KiB/s", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_maxUploadRate->setSpecialValueText(tr2i18n("No limit", nullptr));
        kcfg_maxUploadRate->setSuffix(tr2i18n(" KiB/s", nullptr));
        groupBox_2->setTitle(tr2i18n("Advanced", nullptr));
        label_7->setText(tr2i18n("DSCP value for IP packets:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_dscp->setToolTip(tr2i18n("This value will be filled in the DSCP field of all the IP packets sent for the bittorrent protocol.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_8->setText(tr2i18n("Maximum number of connection setups:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_maxConnectingSockets->setToolTip(tr2i18n("<p>The maximum number of outgoing connections ktorrent will try to set up simultaneously.</p>\n"
"<p>If you are having trouble with ktorrent blocking other internet traffic, try setting this number a bit lower.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_9->setText(tr2i18n("Network interface:", nullptr));
#if QT_CONFIG(tooltip)
        combo_networkInterface->setToolTip(tr2i18n("<p>Which network interface to listen on for incoming connections.</p>\n"
"<p><span style=\"font-weight:600;\">Note: </span>Requires a restart to take effect.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_utpEnabled->setToolTip(tr2i18n("The \302\265Torrent transport protocol runs over UDP and is optimized to not interfere with other traffic, while still using up all unused bandwidth.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_utpEnabled->setText(tr2i18n("Use the \302\265Torrent transport protocol (\302\265TP)", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_onlyUseUtp->setToolTip(tr2i18n("Don't use TCP for bittorrent connections, only use the \302\265TP protocol. This can lead to slower speeds, seeing that not all bittorrent clients support \302\265TP.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_onlyUseUtp->setText(tr2i18n("Only use \302\265TP", nullptr));
        label_10->setText(tr2i18n("Primary transport protocol:", nullptr));
        kcfg_primaryTransportProtocol->setItemText(0, tr2i18n("TCP", nullptr));
        kcfg_primaryTransportProtocol->setItemText(1, tr2i18n("\302\265TP", nullptr));

#if QT_CONFIG(tooltip)
        kcfg_primaryTransportProtocol->setToolTip(tr2i18n("The primary transport protocol to use, when attempting to set up a connection with a peer, this protocol is chosen first.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        m_recommended_settings->setToolTip(tr2i18n("Let KTorrent calculate the recommended settings based upon the bandwidth you have available.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_recommended_settings->setText(tr2i18n("Recommended Settings\342\200\246", nullptr));
        (void)NetworkPref;
    } // retranslateUi

};

namespace Ui {
    class NetworkPref: public Ui_NetworkPref {};
} // namespace Ui

QT_END_NAMESPACE

#endif // NETWORKPREF_H

