/****************************************************************************
** Meta object code from reading C++ file 'torrentactivity.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktorrent-26.04.3/ktorrent/torrentactivity.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'torrentactivity.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2kt15TorrentActivityE_t {};
} // unnamed namespace

template <> constexpr inline auto kt::TorrentActivity::qt_create_metaobjectdata<qt_meta_tag_ZN2kt15TorrentActivityE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "kt::TorrentActivity",
        "currentTorrentChanged",
        "",
        "bt::TorrentInterface*",
        "tc",
        "setGroupViewVisible",
        "visible",
        "onSuspendedStateChanged",
        "suspended",
        "startAllTorrents",
        "stopAllTorrents",
        "suspendQueue",
        "suspend",
        "queueOrdered",
        "addTorrentSelectionToGroup",
        "TorrentGroup*",
        "g"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'currentTorrentChanged'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'setGroupViewVisible'
        QtMocHelpers::SlotData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'onSuspendedStateChanged'
        QtMocHelpers::SlotData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'startAllTorrents'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'stopAllTorrents'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'suspendQueue'
        QtMocHelpers::SlotData<void(bool)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Slot 'queueOrdered'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addTorrentSelectionToGroup'
        QtMocHelpers::SlotData<void(TorrentGroup *)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TorrentActivity, qt_meta_tag_ZN2kt15TorrentActivityE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject kt::TorrentActivity::staticMetaObject = { {
    QMetaObject::SuperData::link<TorrentActivityInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt15TorrentActivityE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt15TorrentActivityE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2kt15TorrentActivityE_t>.metaTypes,
    nullptr
} };

void kt::TorrentActivity::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TorrentActivity *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentTorrentChanged((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 1: _t->setGroupViewVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->onSuspendedStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->startAllTorrents(); break;
        case 4: _t->stopAllTorrents(); break;
        case 5: _t->suspendQueue((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->queueOrdered(); break;
        case 7: _t->addTorrentSelectionToGroup((*reinterpret_cast<std::add_pointer_t<TorrentGroup*>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *kt::TorrentActivity::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kt::TorrentActivity::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt15TorrentActivityE_t>.strings))
        return static_cast<void*>(this);
    return TorrentActivityInterface::qt_metacast(_clname);
}

int kt::TorrentActivity::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TorrentActivityInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
