/********************************************************************************
** Form generated from reading UI file 'addpeersdlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ADDPEERSDLG_H
#define UI_ADDPEERSDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_AddPeersDlg
{
public:
    QVBoxLayout *vboxLayout;
    QLabel *label_3;
    QHBoxLayout *hboxLayout;
    QHBoxLayout *hboxLayout1;
    QLabel *label_2;
    QLineEdit *m_ip;
    QHBoxLayout *hboxLayout2;
    QLabel *label;
    QSpinBox *m_port;
    QFrame *line;
    QHBoxLayout *hboxLayout3;
    QSpacerItem *spacerItem;
    QPushButton *m_add;
    QPushButton *m_close;

    void setupUi(QDialog *AddPeersDlg)
    {
        if (AddPeersDlg->objectName().isEmpty())
            AddPeersDlg->setObjectName("AddPeersDlg");
        AddPeersDlg->resize(423, 144);
        vboxLayout = new QVBoxLayout(AddPeersDlg);
        vboxLayout->setObjectName("vboxLayout");
        label_3 = new QLabel(AddPeersDlg);
        label_3->setObjectName("label_3");
        label_3->setWordWrap(true);

        vboxLayout->addWidget(label_3);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        label_2 = new QLabel(AddPeersDlg);
        label_2->setObjectName("label_2");

        hboxLayout1->addWidget(label_2);

        m_ip = new QLineEdit(AddPeersDlg);
        m_ip->setObjectName("m_ip");

        hboxLayout1->addWidget(m_ip);


        hboxLayout->addLayout(hboxLayout1);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setObjectName("hboxLayout2");
        label = new QLabel(AddPeersDlg);
        label->setObjectName("label");

        hboxLayout2->addWidget(label);

        m_port = new QSpinBox(AddPeersDlg);
        m_port->setObjectName("m_port");
        m_port->setMinimumSize(QSize(50, 0));
        m_port->setMinimum(1);
        m_port->setMaximum(65535);
        m_port->setValue(6881);

        hboxLayout2->addWidget(m_port);


        hboxLayout->addLayout(hboxLayout2);


        vboxLayout->addLayout(hboxLayout);

        line = new QFrame(AddPeersDlg);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        vboxLayout->addWidget(line);

        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setObjectName("hboxLayout3");
        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout3->addItem(spacerItem);

        m_add = new QPushButton(AddPeersDlg);
        m_add->setObjectName("m_add");

        hboxLayout3->addWidget(m_add);

        m_close = new QPushButton(AddPeersDlg);
        m_close->setObjectName("m_close");

        hboxLayout3->addWidget(m_close);


        vboxLayout->addLayout(hboxLayout3);


        retranslateUi(AddPeersDlg);

        QMetaObject::connectSlotsByName(AddPeersDlg);
    } // setupUi

    void retranslateUi(QDialog *AddPeersDlg)
    {
        AddPeersDlg->setWindowTitle(tr2i18n("Dialog", nullptr));
        label_3->setText(tr2i18n("Enter the IP address or hostname and port number of the peer you wish to add:", nullptr));
        label_2->setText(tr2i18n("Peer:", nullptr));
#if QT_CONFIG(tooltip)
        m_ip->setToolTip(tr2i18n("<p>The IP address or hostname of the peer you want to connect to, should be put here.</p>\n"
"<p><span style=\" font-weight:600;\">Note:</span> We accept both IPv4 and IPv6 addresses</p>\n"
"", nullptr));
#endif // QT_CONFIG(tooltip)
        m_ip->setText(tr2i18n("127.0.0.1", nullptr));
        label->setText(tr2i18n("Port:", nullptr));
        m_add->setText(tr2i18n("Add", nullptr));
        m_close->setText(tr2i18n("Close", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AddPeersDlg: public Ui_AddPeersDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ADDPEERSDLG_H

