// This file is generated by kconfig_compiler_kf6 from ktmediaplayerplugin.kcfg.
// All changes you do to this file will be lost.
#ifndef MEDIAPLAYERPLUGINSETTINGS_H
#define MEDIAPLAYERPLUGINSETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class MediaPlayerPluginSettings : public KConfigSkeleton
{
  public:

    static MediaPlayerPluginSettings *self();
    ~MediaPlayerPluginSettings() override;

    /**
      Set skipVideos
    */
    static
    void setSkipVideos( bool v )
    {
      if (!self()->isSkipVideosImmutable())
        self()->mSkipVideos = v;
    }

    /**
      Get skipVideos
    */
    static
    bool skipVideos()
    {
      return self()->mSkipVideos;
    }

    /**
      Is skipVideos Immutable
    */
    static
    bool isSkipVideosImmutable()
    {
      return self()->isImmutable( QStringLiteral( "skipVideos" ) );
    }

    /**
      Set skipIncomplete
    */
    static
    void setSkipIncomplete( bool v )
    {
      if (!self()->isSkipIncompleteImmutable())
        self()->mSkipIncomplete = v;
    }

    /**
      Get skipIncomplete
    */
    static
    bool skipIncomplete()
    {
      return self()->mSkipIncomplete;
    }

    /**
      Is skipIncomplete Immutable
    */
    static
    bool isSkipIncompleteImmutable()
    {
      return self()->isImmutable( QStringLiteral( "skipIncomplete" ) );
    }

  protected:
    MediaPlayerPluginSettings();
    friend class MediaPlayerPluginSettingsHelper;


    // general
    bool mSkipVideos;
    bool mSkipIncomplete;
};

#endif

