// This file is generated by kconfig_compiler_kf6 from ktmagnetgeneratorplugin.kcfg.
// All changes you do to this file will be lost.
#ifndef MAGNETGENERATORPLUGINSETTINGS_H
#define MAGNETGENERATORPLUGINSETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class MagnetGeneratorPluginSettings : public KConfigSkeleton
{
  public:

    static MagnetGeneratorPluginSettings *self();
    ~MagnetGeneratorPluginSettings() override;

    /**
      Set Grabs a tracker from the torrent file
    */
    static
    void setTorrenttracker( bool v )
    {
      if (!self()->isTorrenttrackerImmutable())
        self()->mTorrenttracker = v;
    }

    /**
      Get Grabs a tracker from the torrent file
    */
    static
    bool torrenttracker()
    {
      return self()->mTorrenttracker;
    }

    /**
      Is Grabs a tracker from the torrent file Immutable
    */
    static
    bool isTorrenttrackerImmutable()
    {
      return self()->isImmutable( QStringLiteral( "torrenttracker" ) );
    }

    /**
      Set Toggles if a custom tracker is used
    */
    static
    void setCustomtracker( bool v )
    {
      if (!self()->isCustomtrackerImmutable())
        self()->mCustomtracker = v;
    }

    /**
      Get Toggles if a custom tracker is used
    */
    static
    bool customtracker()
    {
      return self()->mCustomtracker;
    }

    /**
      Is Toggles if a custom tracker is used Immutable
    */
    static
    bool isCustomtrackerImmutable()
    {
      return self()->isImmutable( QStringLiteral( "customtracker" ) );
    }

    /**
      Set The default tracker
    */
    static
    void setTr( const QString & v )
    {
      if (!self()->isTrImmutable())
        self()->mTr = v;
    }

    /**
      Get The default tracker
    */
    static
    QString tr()
    {
      return self()->mTr;
    }

    /**
      Is The default tracker Immutable
    */
    static
    bool isTrImmutable()
    {
      return self()->isImmutable( QStringLiteral( "tr" ) );
    }

    /**
      Set Show dn
    */
    static
    void setDn( bool v )
    {
      if (!self()->isDnImmutable())
        self()->mDn = v;
    }

    /**
      Get Show dn
    */
    static
    bool dn()
    {
      return self()->mDn;
    }

    /**
      Is Show dn Immutable
    */
    static
    bool isDnImmutable()
    {
      return self()->isImmutable( QStringLiteral( "dn" ) );
    }

    /**
      Set Show popup
    */
    static
    void setPopup( bool v )
    {
      if (!self()->isPopupImmutable())
        self()->mPopup = v;
    }

    /**
      Get Show popup
    */
    static
    bool popup()
    {
      return self()->mPopup;
    }

    /**
      Is Show popup Immutable
    */
    static
    bool isPopupImmutable()
    {
      return self()->isImmutable( QStringLiteral( "popup" ) );
    }

    /**
      Set Only enable on public torrents
    */
    static
    void setOnlypublic( bool v )
    {
      if (!self()->isOnlypublicImmutable())
        self()->mOnlypublic = v;
    }

    /**
      Get Only enable on public torrents
    */
    static
    bool onlypublic()
    {
      return self()->mOnlypublic;
    }

    /**
      Is Only enable on public torrents Immutable
    */
    static
    bool isOnlypublicImmutable()
    {
      return self()->isImmutable( QStringLiteral( "onlypublic" ) );
    }

  protected:
    MagnetGeneratorPluginSettings();
    friend class MagnetGeneratorPluginSettingsHelper;


    // general
    bool mTorrenttracker;
    bool mCustomtracker;
    QString mTr;
    bool mDn;
    bool mPopup;
    bool mOnlypublic;
};

#endif

