/****************************************************************************
** Meta object code from reading C++ file 'shutdownruleset.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../ktorrent-26.04.3/plugins/shutdown/shutdownruleset.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'shutdownruleset.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2kt15ShutdownRuleSetE_t {};
} // unnamed namespace

template <> constexpr inline auto kt::ShutdownRuleSet::qt_create_metaobjectdata<qt_meta_tag_ZN2kt15ShutdownRuleSetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "kt::ShutdownRuleSet",
        "shutdown",
        "",
        "standby",
        "lock",
        "suspendToDisk",
        "suspendToRAM",
        "torrentFinished",
        "bt::TorrentInterface*",
        "tc",
        "seedingAutoStopped",
        "bt::AutoStopReason",
        "reason",
        "torrentAdded",
        "torrentRemoved"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'shutdown'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'standby'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lock'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'suspendToDisk'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'suspendToRAM'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'torrentFinished'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'seedingAutoStopped'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *, bt::AutoStopReason)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 11, 12 },
        }}),
        // Slot 'torrentAdded'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'torrentRemoved'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ShutdownRuleSet, qt_meta_tag_ZN2kt15ShutdownRuleSetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject kt::ShutdownRuleSet::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt15ShutdownRuleSetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt15ShutdownRuleSetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2kt15ShutdownRuleSetE_t>.metaTypes,
    nullptr
} };

void kt::ShutdownRuleSet::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ShutdownRuleSet *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->shutdown(); break;
        case 1: _t->standby(); break;
        case 2: _t->lock(); break;
        case 3: _t->suspendToDisk(); break;
        case 4: _t->suspendToRAM(); break;
        case 5: _t->torrentFinished((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 6: _t->seedingAutoStopped((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bt::AutoStopReason>>(_a[2]))); break;
        case 7: _t->torrentAdded((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 8: _t->torrentRemoved((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ShutdownRuleSet::*)()>(_a, &ShutdownRuleSet::shutdown, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShutdownRuleSet::*)()>(_a, &ShutdownRuleSet::standby, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShutdownRuleSet::*)()>(_a, &ShutdownRuleSet::lock, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShutdownRuleSet::*)()>(_a, &ShutdownRuleSet::suspendToDisk, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShutdownRuleSet::*)()>(_a, &ShutdownRuleSet::suspendToRAM, 4))
            return;
    }
}

const QMetaObject *kt::ShutdownRuleSet::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kt::ShutdownRuleSet::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt15ShutdownRuleSetE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int kt::ShutdownRuleSet::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void kt::ShutdownRuleSet::shutdown()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void kt::ShutdownRuleSet::standby()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void kt::ShutdownRuleSet::lock()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void kt::ShutdownRuleSet::suspendToDisk()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void kt::ShutdownRuleSet::suspendToRAM()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
