// This file is generated by kconfig_compiler_kf6 from ktscanfolderplugin.kcfg.
// All changes you do to this file will be lost.
#ifndef SCANFOLDERPLUGINSETTINGS_H
#define SCANFOLDERPLUGINSETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class ScanFolderPluginSettings : public KConfigSkeleton
{
  public:

    static ScanFolderPluginSettings *self();
    ~ScanFolderPluginSettings() override;

    /**
      Set folders
    */
    static
    void setFolders( const QStringList & v )
    {
      if (!self()->isFoldersImmutable())
        self()->mFolders = v;
    }

    /**
      Get folders
    */
    static
    QStringList folders()
    {
      return self()->mFolders;
    }

    /**
      Is folders Immutable
    */
    static
    bool isFoldersImmutable()
    {
      return self()->isImmutable( QStringLiteral( "folders" ) );
    }

    /**
      Set Whether to open torrent silently or not.
    */
    static
    void setOpenSilently( bool v )
    {
      if (!self()->isOpenSilentlyImmutable())
        self()->mOpenSilently = v;
    }

    /**
      Get Whether to open torrent silently or not.
    */
    static
    bool openSilently()
    {
      return self()->mOpenSilently;
    }

    /**
      Is Whether to open torrent silently or not. Immutable
    */
    static
    bool isOpenSilentlyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "openSilently" ) );
    }

    /**
      Set Delete action checked.
    */
    static
    void setActionDelete( bool v )
    {
      if (!self()->isActionDeleteImmutable())
        self()->mActionDelete = v;
    }

    /**
      Get Delete action checked.
    */
    static
    bool actionDelete()
    {
      return self()->mActionDelete;
    }

    /**
      Is Delete action checked. Immutable
    */
    static
    bool isActionDeleteImmutable()
    {
      return self()->isImmutable( QStringLiteral( "actionDelete" ) );
    }

    /**
      Set Move action checked.
    */
    static
    void setActionMove( bool v )
    {
      if (!self()->isActionMoveImmutable())
        self()->mActionMove = v;
    }

    /**
      Get Move action checked.
    */
    static
    bool actionMove()
    {
      return self()->mActionMove;
    }

    /**
      Is Move action checked. Immutable
    */
    static
    bool isActionMoveImmutable()
    {
      return self()->isImmutable( QStringLiteral( "actionMove" ) );
    }

    /**
      Set Scan directories recursively.
    */
    static
    void setRecursive( bool v )
    {
      if (!self()->isRecursiveImmutable())
        self()->mRecursive = v;
    }

    /**
      Get Scan directories recursively.
    */
    static
    bool recursive()
    {
      return self()->mRecursive;
    }

    /**
      Is Scan directories recursively. Immutable
    */
    static
    bool isRecursiveImmutable()
    {
      return self()->isImmutable( QStringLiteral( "recursive" ) );
    }

    /**
      Set addToGroup
    */
    static
    void setAddToGroup( bool v )
    {
      if (!self()->isAddToGroupImmutable())
        self()->mAddToGroup = v;
    }

    /**
      Get addToGroup
    */
    static
    bool addToGroup()
    {
      return self()->mAddToGroup;
    }

    /**
      Is addToGroup Immutable
    */
    static
    bool isAddToGroupImmutable()
    {
      return self()->isImmutable( QStringLiteral( "addToGroup" ) );
    }

    /**
      Set group
    */
    static
    void setGroup( const QString & v )
    {
      if (!self()->isGroupImmutable())
        self()->mGroup = v;
    }

    /**
      Get group
    */
    static
    QString group()
    {
      return self()->mGroup;
    }

    /**
      Is group Immutable
    */
    static
    bool isGroupImmutable()
    {
      return self()->isImmutable( QStringLiteral( "group" ) );
    }

  protected:
    ScanFolderPluginSettings();
    friend class ScanFolderPluginSettingsHelper;


    // general
    QStringList mFolders;
    bool mOpenSilently;
    bool mActionDelete;
    bool mActionMove;
    bool mRecursive;
    bool mAddToGroup;
    QString mGroup;
};

#endif

