/********************************************************************************
** Form generated from reading UI file 'managefiltersdlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MANAGEFILTERSDLG_H
#define UI_MANAGEFILTERSDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ManageFiltersDlg
{
public:
    QVBoxLayout *verticalLayout_4;
    QLabel *m_feed_text;
    QHBoxLayout *horizontalLayout_2;
    QVBoxLayout *verticalLayout_2;
    QLabel *label;
    QListView *m_active_filters;
    QVBoxLayout *verticalLayout;
    QSpacerItem *verticalSpacer;
    QPushButton *m_add;
    QPushButton *m_remove;
    QSpacerItem *verticalSpacer_2;
    QVBoxLayout *verticalLayout_3;
    QLabel *label_2;
    QListView *m_available_filters;
    QHBoxLayout *horizontalLayout;
    QPushButton *m_remove_all;
    QSpacerItem *horizontalSpacer;
    QPushButton *m_new_filter;
    QFrame *line;

    void setupUi(QWidget *ManageFiltersDlg)
    {
        if (ManageFiltersDlg->objectName().isEmpty())
            ManageFiltersDlg->setObjectName("ManageFiltersDlg");
        ManageFiltersDlg->resize(359, 300);
        verticalLayout_4 = new QVBoxLayout(ManageFiltersDlg);
        verticalLayout_4->setContentsMargins(0, 0, 0, 0);
        verticalLayout_4->setObjectName("verticalLayout_4");
        m_feed_text = new QLabel(ManageFiltersDlg);
        m_feed_text->setObjectName("m_feed_text");

        verticalLayout_4->addWidget(m_feed_text);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        label = new QLabel(ManageFiltersDlg);
        label->setObjectName("label");

        verticalLayout_2->addWidget(label);

        m_active_filters = new QListView(ManageFiltersDlg);
        m_active_filters->setObjectName("m_active_filters");

        verticalLayout_2->addWidget(m_active_filters);


        horizontalLayout_2->addLayout(verticalLayout_2);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        m_add = new QPushButton(ManageFiltersDlg);
        m_add->setObjectName("m_add");

        verticalLayout->addWidget(m_add);

        m_remove = new QPushButton(ManageFiltersDlg);
        m_remove->setObjectName("m_remove");

        verticalLayout->addWidget(m_remove);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);


        horizontalLayout_2->addLayout(verticalLayout);

        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName("verticalLayout_3");
        label_2 = new QLabel(ManageFiltersDlg);
        label_2->setObjectName("label_2");

        verticalLayout_3->addWidget(label_2);

        m_available_filters = new QListView(ManageFiltersDlg);
        m_available_filters->setObjectName("m_available_filters");

        verticalLayout_3->addWidget(m_available_filters);


        horizontalLayout_2->addLayout(verticalLayout_3);


        verticalLayout_4->addLayout(horizontalLayout_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        m_remove_all = new QPushButton(ManageFiltersDlg);
        m_remove_all->setObjectName("m_remove_all");

        horizontalLayout->addWidget(m_remove_all);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        m_new_filter = new QPushButton(ManageFiltersDlg);
        m_new_filter->setObjectName("m_new_filter");

        horizontalLayout->addWidget(m_new_filter);


        verticalLayout_4->addLayout(horizontalLayout);

        line = new QFrame(ManageFiltersDlg);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_4->addWidget(line);


        retranslateUi(ManageFiltersDlg);

        QMetaObject::connectSlotsByName(ManageFiltersDlg);
    } // setupUi

    void retranslateUi(QWidget *ManageFiltersDlg)
    {
        ManageFiltersDlg->setWindowTitle(tr2i18n("Manage Filters", nullptr));
        m_feed_text->setText(tr2i18n("Feed:", nullptr));
        label->setText(tr2i18n("Active filters:", nullptr));
        m_add->setText(tr2i18n("Add", nullptr));
        m_remove->setText(tr2i18n("Remove", nullptr));
        label_2->setText(tr2i18n("Available filters:", nullptr));
        m_remove_all->setText(tr2i18n("Remove All", nullptr));
        m_new_filter->setText(tr2i18n("New Filter", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ManageFiltersDlg: public Ui_ManageFiltersDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MANAGEFILTERSDLG_H

