/********************************************************************************
** Form generated from reading UI file 'scanforlostfilesprefpage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SCANFORLOSTFILESPREFPAGE_H
#define UI_SCANFORLOSTFILESPREFPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ScanForLostFilesPrefPage
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QComboBox *kcfg_ScanForLostFilesWidgetPosition;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ScanForLostFilesPrefPage)
    {
        if (ScanForLostFilesPrefPage->objectName().isEmpty())
            ScanForLostFilesPrefPage->setObjectName("ScanForLostFilesPrefPage");
        ScanForLostFilesPrefPage->resize(559, 590);
        verticalLayout = new QVBoxLayout(ScanForLostFilesPrefPage);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(ScanForLostFilesPrefPage);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        kcfg_ScanForLostFilesWidgetPosition = new QComboBox(ScanForLostFilesPrefPage);
        kcfg_ScanForLostFilesWidgetPosition->addItem(QString());
        kcfg_ScanForLostFilesWidgetPosition->addItem(QString());
        kcfg_ScanForLostFilesWidgetPosition->addItem(QString());
        kcfg_ScanForLostFilesWidgetPosition->setObjectName("kcfg_ScanForLostFilesWidgetPosition");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_ScanForLostFilesWidgetPosition->sizePolicy().hasHeightForWidth());
        kcfg_ScanForLostFilesWidgetPosition->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(kcfg_ScanForLostFilesWidgetPosition);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(ScanForLostFilesPrefPage);

        QMetaObject::connectSlotsByName(ScanForLostFilesPrefPage);
    } // setupUi

    void retranslateUi(QWidget *ScanForLostFilesPrefPage)
    {
        label->setText(tr2i18n("Widget position:", nullptr));
        kcfg_ScanForLostFilesWidgetPosition->setItemText(0, tr2i18n("Separate activity", nullptr));
        kcfg_ScanForLostFilesWidgetPosition->setItemText(1, tr2i18n("Dockable widget", nullptr));
        kcfg_ScanForLostFilesWidgetPosition->setItemText(2, tr2i18n("Torrent activity", nullptr));

        (void)ScanForLostFilesPrefPage;
    } // retranslateUi

};

namespace Ui {
    class ScanForLostFilesPrefPage: public Ui_ScanForLostFilesPrefPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SCANFORLOSTFILESPREFPAGE_H

