/********************************************************************************
** Form generated from reading UI file 'downloadorderwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DOWNLOADORDERWIDGET_H
#define UI_DOWNLOADORDERWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_DownloadOrderWidget
{
public:
    QVBoxLayout *verticalLayout_2;
    QLabel *m_top_label;
    QCheckBox *m_custom_order_enabled;
    QHBoxLayout *horizontalLayout_2;
    QToolButton *m_sort_by;
    QLineEdit *m_search_files;
    QHBoxLayout *horizontalLayout;
    QListView *m_order;
    QVBoxLayout *verticalLayout;
    QPushButton *m_move_top;
    QPushButton *m_move_up;
    QPushButton *m_move_down;
    QPushButton *m_move_bottom;
    QSpacerItem *verticalSpacer;
    QFrame *line;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *DownloadOrderWidget)
    {
        if (DownloadOrderWidget->objectName().isEmpty())
            DownloadOrderWidget->setObjectName("DownloadOrderWidget");
        DownloadOrderWidget->resize(623, 517);
        verticalLayout_2 = new QVBoxLayout(DownloadOrderWidget);
        verticalLayout_2->setObjectName("verticalLayout_2");
        m_top_label = new QLabel(DownloadOrderWidget);
        m_top_label->setObjectName("m_top_label");

        verticalLayout_2->addWidget(m_top_label);

        m_custom_order_enabled = new QCheckBox(DownloadOrderWidget);
        m_custom_order_enabled->setObjectName("m_custom_order_enabled");

        verticalLayout_2->addWidget(m_custom_order_enabled);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        m_sort_by = new QToolButton(DownloadOrderWidget);
        m_sort_by->setObjectName("m_sort_by");
        m_sort_by->setContextMenuPolicy(Qt::DefaultContextMenu);
        m_sort_by->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        horizontalLayout_2->addWidget(m_sort_by);

        m_search_files = new QLineEdit(DownloadOrderWidget);
        m_search_files->setObjectName("m_search_files");
        m_search_files->setClearButtonEnabled(true);

        horizontalLayout_2->addWidget(m_search_files);


        verticalLayout_2->addLayout(horizontalLayout_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        m_order = new QListView(DownloadOrderWidget);
        m_order->setObjectName("m_order");

        horizontalLayout->addWidget(m_order);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        m_move_top = new QPushButton(DownloadOrderWidget);
        m_move_top->setObjectName("m_move_top");

        verticalLayout->addWidget(m_move_top);

        m_move_up = new QPushButton(DownloadOrderWidget);
        m_move_up->setObjectName("m_move_up");

        verticalLayout->addWidget(m_move_up);

        m_move_down = new QPushButton(DownloadOrderWidget);
        m_move_down->setObjectName("m_move_down");

        verticalLayout->addWidget(m_move_down);

        m_move_bottom = new QPushButton(DownloadOrderWidget);
        m_move_bottom->setObjectName("m_move_bottom");

        verticalLayout->addWidget(m_move_bottom);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        horizontalLayout->addLayout(verticalLayout);


        verticalLayout_2->addLayout(horizontalLayout);

        line = new QFrame(DownloadOrderWidget);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_2->addWidget(line);

        buttonBox = new QDialogButtonBox(DownloadOrderWidget);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_2->addWidget(buttonBox);


        retranslateUi(DownloadOrderWidget);
        QObject::connect(m_custom_order_enabled, &QCheckBox::toggled, m_order, &QListView::setEnabled);

        QMetaObject::connectSlotsByName(DownloadOrderWidget);
    } // setupUi

    void retranslateUi(QWidget *DownloadOrderWidget)
    {
        DownloadOrderWidget->setWindowTitle(tr2i18n("File Download Order", nullptr));
        m_top_label->setText(tr2i18n("File download order for:", nullptr));
#if QT_CONFIG(tooltip)
        m_custom_order_enabled->setToolTip(tr2i18n("Whether or not to enable a custom download order.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_custom_order_enabled->setText(tr2i18n("Custom file download order enabled", nullptr));
        m_sort_by->setText(tr2i18n("Sort By", nullptr));
        m_search_files->setPlaceholderText(tr2i18n("Search files", nullptr));
#if QT_CONFIG(tooltip)
        m_order->setToolTip(tr2i18n("Order in which to download the files of a torrent. The file at the top will be downloaded first, followed by the second, then the third\342\200\246", nullptr));
#endif // QT_CONFIG(tooltip)
        m_move_top->setText(QString());
        m_move_up->setText(QString());
        m_move_down->setText(QString());
        m_move_bottom->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class DownloadOrderWidget: public Ui_DownloadOrderWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DOWNLOADORDERWIDGET_H

