// This file is generated by kconfig_compiler_kf6 from ktupnpplugin.kcfg.
// All changes you do to this file will be lost.
#ifndef UPNPPLUGINSETTINGS_H
#define UPNPPLUGINSETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class UPnPPluginSettings : public KConfigSkeleton
{
  public:

    static UPnPPluginSettings *self();
    ~UPnPPluginSettings() override;

    /**
      Set Default UPnP device to use
    */
    static
    void setDefaultDevice( const QString & v )
    {
      if (!self()->isDefaultDeviceImmutable())
        self()->mDefaultDevice = v;
    }

    /**
      Get Default UPnP device to use
    */
    static
    QString defaultDevice()
    {
      return self()->mDefaultDevice;
    }

    /**
      Is Default UPnP device to use Immutable
    */
    static
    bool isDefaultDeviceImmutable()
    {
      return self()->isImmutable( QStringLiteral( "defaultDevice" ) );
    }

  protected:
    UPnPPluginSettings();
    friend class UPnPPluginSettingsHelper;


    // general
    QString mDefaultDevice;
};

#endif

