/********************************************************************************
** Form generated from reading UI file 'pastedlgbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PASTEDLGBASE_H
#define UI_PASTEDLGBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_PasteDlgBase
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *textLabel1;
    QLineEdit *m_url;
    QHBoxLayout *horizontalLayout_3;
    QCheckBox *m_silently;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label;
    QComboBox *m_groups;
    QFrame *line;
    QDialogButtonBox *m_buttonBox;

    void setupUi(QDialog *PasteDlgBase)
    {
        if (PasteDlgBase->objectName().isEmpty())
            PasteDlgBase->setObjectName("PasteDlgBase");
        PasteDlgBase->resize(478, 148);
        verticalLayout = new QVBoxLayout(PasteDlgBase);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        textLabel1 = new QLabel(PasteDlgBase);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setWordWrap(false);

        horizontalLayout->addWidget(textLabel1);

        m_url = new QLineEdit(PasteDlgBase);
        m_url->setObjectName("m_url");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_url->sizePolicy().hasHeightForWidth());
        m_url->setSizePolicy(sizePolicy);
        m_url->setMinimumSize(QSize(400, 0));

        horizontalLayout->addWidget(m_url);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        m_silently = new QCheckBox(PasteDlgBase);
        m_silently->setObjectName("m_silently");

        horizontalLayout_3->addWidget(m_silently);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label = new QLabel(PasteDlgBase);
        label->setObjectName("label");

        horizontalLayout_2->addWidget(label);

        m_groups = new QComboBox(PasteDlgBase);
        m_groups->setObjectName("m_groups");

        horizontalLayout_2->addWidget(m_groups);


        horizontalLayout_3->addLayout(horizontalLayout_2);


        verticalLayout->addLayout(horizontalLayout_3);

        line = new QFrame(PasteDlgBase);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        m_buttonBox = new QDialogButtonBox(PasteDlgBase);
        m_buttonBox->setObjectName("m_buttonBox");
        m_buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(m_buttonBox);


        retranslateUi(PasteDlgBase);

        QMetaObject::connectSlotsByName(PasteDlgBase);
    } // setupUi

    void retranslateUi(QDialog *PasteDlgBase)
    {
        PasteDlgBase->setWindowTitle(tr2i18n("Open an URL", nullptr));
        textLabel1->setText(tr2i18n("URL:", nullptr));
        m_silently->setText(tr2i18n("Open silently", nullptr));
        label->setText(tr2i18n("Group:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class PasteDlgBase: public Ui_PasteDlgBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PASTEDLGBASE_H

