/********************************************************************************
** Form generated from reading UI file 'importdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMPORTDIALOG_H
#define UI_IMPORTDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_ImportDialog
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QVBoxLayout *vboxLayout1;
    QLabel *textLabel1;
    QLabel *textLabel2;
    QVBoxLayout *vboxLayout2;
    KUrlRequester *m_torrent_url;
    KUrlRequester *m_data_url;
    QLabel *label;
    QProgressBar *m_progress;
    QFrame *line;
    QHBoxLayout *hboxLayout1;
    QSpacerItem *spacerItem;
    QPushButton *m_import_btn;
    QPushButton *m_cancel_btn;

    void setupUi(QDialog *ImportDialog)
    {
        if (ImportDialog->objectName().isEmpty())
            ImportDialog->setObjectName("ImportDialog");
        ImportDialog->resize(473, 156);
        vboxLayout = new QVBoxLayout(ImportDialog);
        vboxLayout->setSpacing(6);
        vboxLayout->setContentsMargins(11, 11, 11, 11);
        vboxLayout->setObjectName("vboxLayout");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setSpacing(6);
        vboxLayout1->setObjectName("vboxLayout1");
        textLabel1 = new QLabel(ImportDialog);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setMinimumSize(QSize(60, 0));
        textLabel1->setWordWrap(false);

        vboxLayout1->addWidget(textLabel1);

        textLabel2 = new QLabel(ImportDialog);
        textLabel2->setObjectName("textLabel2");
        textLabel2->setMinimumSize(QSize(60, 0));
        textLabel2->setWordWrap(false);

        vboxLayout1->addWidget(textLabel2);


        hboxLayout->addLayout(vboxLayout1);

        vboxLayout2 = new QVBoxLayout();
        vboxLayout2->setSpacing(6);
        vboxLayout2->setObjectName("vboxLayout2");
        m_torrent_url = new KUrlRequester(ImportDialog);
        m_torrent_url->setObjectName("m_torrent_url");

        vboxLayout2->addWidget(m_torrent_url);

        m_data_url = new KUrlRequester(ImportDialog);
        m_data_url->setObjectName("m_data_url");

        vboxLayout2->addWidget(m_data_url);


        hboxLayout->addLayout(vboxLayout2);


        vboxLayout->addLayout(hboxLayout);

        label = new QLabel(ImportDialog);
        label->setObjectName("label");

        vboxLayout->addWidget(label);

        m_progress = new QProgressBar(ImportDialog);
        m_progress->setObjectName("m_progress");
        m_progress->setValue(24);

        vboxLayout->addWidget(m_progress);

        line = new QFrame(ImportDialog);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        vboxLayout->addWidget(line);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName("hboxLayout1");
        spacerItem = new QSpacerItem(61, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem);

        m_import_btn = new QPushButton(ImportDialog);
        m_import_btn->setObjectName("m_import_btn");

        hboxLayout1->addWidget(m_import_btn);

        m_cancel_btn = new QPushButton(ImportDialog);
        m_cancel_btn->setObjectName("m_cancel_btn");

        hboxLayout1->addWidget(m_cancel_btn);


        vboxLayout->addLayout(hboxLayout1);


        retranslateUi(ImportDialog);

        QMetaObject::connectSlotsByName(ImportDialog);
    } // setupUi

    void retranslateUi(QDialog *ImportDialog)
    {
        ImportDialog->setWindowTitle(tr2i18n("Import an existing torrent", nullptr));
        textLabel1->setText(tr2i18n("Torrent:", nullptr));
        textLabel2->setText(tr2i18n("Data:", nullptr));
        label->setText(tr2i18n("Select the torrent file and the data which belongs with it.", nullptr));
        m_progress->setFormat(tr2i18n("%p%", nullptr));
        m_import_btn->setText(tr2i18n("&Import", nullptr));
        m_cancel_btn->setText(tr2i18n("Ca&ncel", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ImportDialog: public Ui_ImportDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IMPORTDIALOG_H

