/********************************************************************************
** Form generated from reading UI file 'statustab.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STATUSTAB_H
#define UI_STATUSTAB_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "availabilitychunkbar.h"
#include "downloadedchunkbar.h"
#include "ksqueezedtextlabel.h"

QT_BEGIN_NAMESPACE

class Ui_StatusTab
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *hdr_info;
    QGridLayout *gridLayout;
    QLabel *label_14;
    QLabel *avg_down_speed;
    QLabel *label_16;
    QLabel *type;
    QSpacerItem *spacerItem;
    QLabel *label_15;
    QLabel *avg_up_speed;
    QLabel *label;
    QLabel *info_hash;
    QLabel *label_17;
    KSqueezedTextLabel *comments;
    QHBoxLayout *hboxLayout;
    QVBoxLayout *vboxLayout;
    QLabel *hdr_chunks;
    QLabel *label_4;
    kt::DownloadedChunkBar *downloaded_bar;
    QLabel *label_5;
    kt::AvailabilityChunkBar *availability_bar;
    QSpacerItem *spacerItem1;
    QFrame *line;
    QVBoxLayout *vboxLayout1;
    QLabel *hdr_sharing;
    QGridLayout *gridLayout1;
    QLabel *label_6;
    QLabel *share_ratio;
    QCheckBox *use_ratio_limit;
    QDoubleSpinBox *ratio_limit;
    QCheckBox *use_time_limit;
    QDoubleSpinBox *time_limit;
    QSpacerItem *spacerItem2;

    void setupUi(QWidget *StatusTab)
    {
        if (StatusTab->objectName().isEmpty())
            StatusTab->setObjectName("StatusTab");
        StatusTab->resize(707, 186);
        verticalLayout = new QVBoxLayout(StatusTab);
        verticalLayout->setObjectName("verticalLayout");
        hdr_info = new QLabel(StatusTab);
        hdr_info->setObjectName("hdr_info");
        QFont font;
        font.setBold(true);
        hdr_info->setFont(font);
        hdr_info->setAutoFillBackground(true);
        hdr_info->setFrameShape(QFrame::NoFrame);
        hdr_info->setFrameShadow(QFrame::Plain);

        verticalLayout->addWidget(hdr_info);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label_14 = new QLabel(StatusTab);
        label_14->setObjectName("label_14");

        gridLayout->addWidget(label_14, 0, 0, 1, 1);

        avg_down_speed = new QLabel(StatusTab);
        avg_down_speed->setObjectName("avg_down_speed");
        avg_down_speed->setMinimumSize(QSize(100, 0));
        avg_down_speed->setFrameShape(QFrame::NoFrame);

        gridLayout->addWidget(avg_down_speed, 0, 1, 1, 1);

        label_16 = new QLabel(StatusTab);
        label_16->setObjectName("label_16");

        gridLayout->addWidget(label_16, 0, 2, 1, 1);

        type = new QLabel(StatusTab);
        type->setObjectName("type");
        type->setMinimumSize(QSize(100, 0));
        type->setFrameShape(QFrame::NoFrame);

        gridLayout->addWidget(type, 0, 3, 1, 1);

        spacerItem = new QSpacerItem(13, 41, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem, 0, 4, 2, 1);

        label_15 = new QLabel(StatusTab);
        label_15->setObjectName("label_15");

        gridLayout->addWidget(label_15, 1, 0, 1, 1);

        avg_up_speed = new QLabel(StatusTab);
        avg_up_speed->setObjectName("avg_up_speed");
        avg_up_speed->setMinimumSize(QSize(50, 0));
        avg_up_speed->setFrameShape(QFrame::NoFrame);

        gridLayout->addWidget(avg_up_speed, 1, 1, 1, 1);

        label = new QLabel(StatusTab);
        label->setObjectName("label");

        gridLayout->addWidget(label, 1, 2, 1, 1);

        info_hash = new QLabel(StatusTab);
        info_hash->setObjectName("info_hash");
        info_hash->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        gridLayout->addWidget(info_hash, 1, 3, 1, 1);

        label_17 = new QLabel(StatusTab);
        label_17->setObjectName("label_17");

        gridLayout->addWidget(label_17, 2, 0, 1, 1);

        comments = new KSqueezedTextLabel(StatusTab);
        comments->setObjectName("comments");
        comments->setMinimumSize(QSize(50, 0));
        comments->setFrameShape(QFrame::NoFrame);
        comments->setText(QString::fromUtf8("KSqueezedTextLabel"));
        comments->setTextInteractionFlags(Qt::LinksAccessibleByKeyboard|Qt::LinksAccessibleByMouse|Qt::TextBrowserInteraction|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        gridLayout->addWidget(comments, 2, 1, 1, 4);


        verticalLayout->addLayout(gridLayout);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        vboxLayout = new QVBoxLayout();
        vboxLayout->setObjectName("vboxLayout");
        hdr_chunks = new QLabel(StatusTab);
        hdr_chunks->setObjectName("hdr_chunks");
        hdr_chunks->setFont(font);
        hdr_chunks->setAutoFillBackground(true);

        vboxLayout->addWidget(hdr_chunks);

        label_4 = new QLabel(StatusTab);
        label_4->setObjectName("label_4");

        vboxLayout->addWidget(label_4);

        downloaded_bar = new kt::DownloadedChunkBar(StatusTab);
        downloaded_bar->setObjectName("downloaded_bar");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(downloaded_bar->sizePolicy().hasHeightForWidth());
        downloaded_bar->setSizePolicy(sizePolicy);
        downloaded_bar->setFrameShape(QFrame::StyledPanel);
        downloaded_bar->setFrameShadow(QFrame::Raised);

        vboxLayout->addWidget(downloaded_bar);

        label_5 = new QLabel(StatusTab);
        label_5->setObjectName("label_5");

        vboxLayout->addWidget(label_5);

        availability_bar = new kt::AvailabilityChunkBar(StatusTab);
        availability_bar->setObjectName("availability_bar");
        sizePolicy.setHeightForWidth(availability_bar->sizePolicy().hasHeightForWidth());
        availability_bar->setSizePolicy(sizePolicy);
        availability_bar->setFrameShape(QFrame::StyledPanel);
        availability_bar->setFrameShadow(QFrame::Raised);

        vboxLayout->addWidget(availability_bar);

        spacerItem1 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem1);


        hboxLayout->addLayout(vboxLayout);

        line = new QFrame(StatusTab);
        line->setObjectName("line");
        line->setFrameShadow(QFrame::Sunken);
        line->setLineWidth(1);
        line->setFrameShape(QFrame::Shape::VLine);

        hboxLayout->addWidget(line);

        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName("vboxLayout1");
        hdr_sharing = new QLabel(StatusTab);
        hdr_sharing->setObjectName("hdr_sharing");
        hdr_sharing->setFont(font);
        hdr_sharing->setAutoFillBackground(true);

        vboxLayout1->addWidget(hdr_sharing);

        gridLayout1 = new QGridLayout();
        gridLayout1->setObjectName("gridLayout1");
        label_6 = new QLabel(StatusTab);
        label_6->setObjectName("label_6");

        gridLayout1->addWidget(label_6, 0, 0, 1, 1);

        share_ratio = new QLabel(StatusTab);
        share_ratio->setObjectName("share_ratio");
        share_ratio->setFrameShape(QFrame::NoFrame);

        gridLayout1->addWidget(share_ratio, 0, 1, 1, 1);

        use_ratio_limit = new QCheckBox(StatusTab);
        use_ratio_limit->setObjectName("use_ratio_limit");

        gridLayout1->addWidget(use_ratio_limit, 1, 0, 1, 1);

        ratio_limit = new QDoubleSpinBox(StatusTab);
        ratio_limit->setObjectName("ratio_limit");
        ratio_limit->setMinimum(0.000000000000000);
        ratio_limit->setMaximum(1000000.000000000000000);
        ratio_limit->setSingleStep(0.010000000000000);
        ratio_limit->setValue(1.500000000000000);

        gridLayout1->addWidget(ratio_limit, 1, 1, 1, 1);

        use_time_limit = new QCheckBox(StatusTab);
        use_time_limit->setObjectName("use_time_limit");

        gridLayout1->addWidget(use_time_limit, 2, 0, 1, 1);

        time_limit = new QDoubleSpinBox(StatusTab);
        time_limit->setObjectName("time_limit");
        time_limit->setMinimum(0.000000000000000);
        time_limit->setMaximum(10000000.000000000000000);
        time_limit->setSingleStep(0.050000000000000);
        time_limit->setValue(72.000000000000000);

        gridLayout1->addWidget(time_limit, 2, 1, 1, 1);


        vboxLayout1->addLayout(gridLayout1);

        spacerItem2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout1->addItem(spacerItem2);


        hboxLayout->addLayout(vboxLayout1);


        verticalLayout->addLayout(hboxLayout);


        retranslateUi(StatusTab);
        QObject::connect(use_ratio_limit, &QCheckBox::toggled, ratio_limit, &QDoubleSpinBox::setEnabled);
        QObject::connect(use_time_limit, &QCheckBox::toggled, time_limit, &QDoubleSpinBox::setEnabled);

        QMetaObject::connectSlotsByName(StatusTab);
    } // setupUi

    void retranslateUi(QWidget *StatusTab)
    {
        hdr_info->setText(tr2i18n("Info", nullptr));
        label_14->setText(tr2i18n("Average down speed:", nullptr));
        avg_down_speed->setText(QString());
        label_16->setText(tr2i18n("Type:", nullptr));
        type->setText(QString());
        label_15->setText(tr2i18n("Average up speed:", nullptr));
        avg_up_speed->setText(QString());
        label->setText(tr2i18n("Info hash:", nullptr));
        info_hash->setText(QString());
        label_17->setText(tr2i18n("Comments:", nullptr));
        hdr_chunks->setText(tr2i18n("Chunks", nullptr));
        label_4->setText(tr2i18n("Downloaded chunks:", nullptr));
        label_5->setText(tr2i18n("Available chunks:", nullptr));
        hdr_sharing->setText(tr2i18n("Sharing", "Noun, as in \"file sharing\""));
        label_6->setText(tr2i18n("Share ratio:", nullptr));
        share_ratio->setText(QString());
        use_ratio_limit->setText(tr2i18n("Ratio limit:", nullptr));
        ratio_limit->setSpecialValueText(tr2i18n("No limit", nullptr));
        use_time_limit->setText(tr2i18n("Time limit:", nullptr));
        time_limit->setSpecialValueText(tr2i18n("No limit", nullptr));
        time_limit->setSuffix(tr2i18n(" Hours", nullptr));
        (void)StatusTab;
    } // retranslateUi

};

namespace Ui {
    class StatusTab: public Ui_StatusTab {};
} // namespace Ui

QT_END_NAMESPACE

#endif // STATUSTAB_H

