/********************************************************************************
** Form generated from reading UI file 'upnpwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_UPNPWIDGET_H
#define UI_UPNPWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_UPnPWidget
{
public:
    QHBoxLayout *horizontalLayout;
    QTreeView *m_devices;
    QVBoxLayout *verticalLayout;
    QPushButton *m_forward;
    QPushButton *m_undo_forward;
    QSpacerItem *verticalSpacer;
    QPushButton *m_rescan;

    void setupUi(QWidget *UPnPWidget)
    {
        if (UPnPWidget->objectName().isEmpty())
            UPnPWidget->setObjectName("UPnPWidget");
        UPnPWidget->resize(600, 151);
        horizontalLayout = new QHBoxLayout(UPnPWidget);
        horizontalLayout->setSpacing(6);
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout->setObjectName("horizontalLayout");
        m_devices = new QTreeView(UPnPWidget);
        m_devices->setObjectName("m_devices");

        horizontalLayout->addWidget(m_devices);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName("verticalLayout");
        m_forward = new QPushButton(UPnPWidget);
        m_forward->setObjectName("m_forward");

        verticalLayout->addWidget(m_forward);

        m_undo_forward = new QPushButton(UPnPWidget);
        m_undo_forward->setObjectName("m_undo_forward");

        verticalLayout->addWidget(m_undo_forward);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        m_rescan = new QPushButton(UPnPWidget);
        m_rescan->setObjectName("m_rescan");

        verticalLayout->addWidget(m_rescan);


        horizontalLayout->addLayout(verticalLayout);


        retranslateUi(UPnPWidget);

        QMetaObject::connectSlotsByName(UPnPWidget);
    } // setupUi

    void retranslateUi(QWidget *UPnPWidget)
    {
        UPnPWidget->setWindowTitle(tr2i18n("UPnP", nullptr));
        m_forward->setText(tr2i18n("Forward", nullptr));
        m_undo_forward->setText(tr2i18n("Undo Forward", nullptr));
        m_rescan->setText(tr2i18n("Rescan", nullptr));
    } // retranslateUi

};

namespace Ui {
    class UPnPWidget: public Ui_UPnPWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UPNPWIDGET_H

