/****************************************************************************
** Meta object code from reading C++ file 'core.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktorrent-26.04.3/ktorrent/core.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'core.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2kt4CoreE_t {};
} // unnamed namespace

template <> constexpr inline auto kt::Core::qt_create_metaobjectdata<qt_meta_tag_ZN2kt4CoreE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "kt::Core",
        "statsUpdated",
        "",
        "maxShareRatioReached",
        "bt::TorrentInterface*",
        "tc",
        "maxSeedTimeReached",
        "corruptedData",
        "queuingNotPossible",
        "canNotStart",
        "bt::TorrentStartResponse",
        "reason",
        "lowDiskSpace",
        "stopped",
        "canNotLoadSilently",
        "msg",
        "dhtNotEnabled",
        "openedSilently",
        "aboutToQuit",
        "startUpdateTimer",
        "update",
        "start",
        "QList<bt::TorrentInterface*>&",
        "todo",
        "stop",
        "remove",
        "data_to",
        "pause",
        "aboutToBeStarted",
        "bool&",
        "ret",
        "checkMissingFiles",
        "enqueueTorrentOverMaxRatio",
        "doDataCheck",
        "auto_import",
        "onLowDiskSpace",
        "applySettings",
        "updateGuiPlugins",
        "onStatusChanged",
        "onMetadataDownloaded",
        "bt::MagnetLink",
        "mlink",
        "data",
        "kt::MagnetLinkLoadOptions",
        "options",
        "torrentFinished",
        "slotStoppedByError",
        "torrentSeedAutoStopped",
        "bt::AutoStopReason",
        "downloadFinished",
        "KJob*",
        "job",
        "downloadFinishedSilently",
        "emitCorruptedData",
        "autoCheckData",
        "delayedRemove",
        "delayedStart",
        "beforeQueueReorder",
        "afterQueueReorder",
        "customGroupChanged",
        "onExit"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'statsUpdated'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maxShareRatioReached'
        QtMocHelpers::SignalData<void(bt::TorrentInterface *)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'maxSeedTimeReached'
        QtMocHelpers::SignalData<void(bt::TorrentInterface *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'corruptedData'
        QtMocHelpers::SignalData<void(bt::TorrentInterface *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'queuingNotPossible'
        QtMocHelpers::SignalData<void(bt::TorrentInterface *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'canNotStart'
        QtMocHelpers::SignalData<void(bt::TorrentInterface *, bt::TorrentStartResponse)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 10, 11 },
        }}),
        // Signal 'lowDiskSpace'
        QtMocHelpers::SignalData<void(bt::TorrentInterface *, bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { QMetaType::Bool, 13 },
        }}),
        // Signal 'canNotLoadSilently'
        QtMocHelpers::SignalData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Signal 'dhtNotEnabled'
        QtMocHelpers::SignalData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Signal 'openedSilently'
        QtMocHelpers::SignalData<void(bt::TorrentInterface *)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'aboutToQuit'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'startUpdateTimer'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'update'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'start'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'start'
        QtMocHelpers::SlotData<void(QList<bt::TorrentInterface*> &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'stop'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'stop'
        QtMocHelpers::SlotData<void(QList<bt::TorrentInterface*> &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'remove'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *, bool)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { QMetaType::Bool, 26 },
        }}),
        // Slot 'remove'
        QtMocHelpers::SlotData<void(QList<bt::TorrentInterface*> &, bool)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { QMetaType::Bool, 26 },
        }}),
        // Slot 'pause'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'pause'
        QtMocHelpers::SlotData<void(QList<bt::TorrentInterface*> &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'aboutToBeStarted'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *, bool &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 29, 30 },
        }}),
        // Slot 'checkMissingFiles'
        QtMocHelpers::SlotData<bool(bt::TorrentInterface *)>(31, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'enqueueTorrentOverMaxRatio'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'doDataCheck'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *, bool)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { QMetaType::Bool, 34 },
        }}),
        // Slot 'doDataCheck'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *)>(33, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'onLowDiskSpace'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *, bool)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { QMetaType::Bool, 13 },
        }}),
        // Slot 'applySettings'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateGuiPlugins'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onStatusChanged'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'onMetadataDownloaded'
        QtMocHelpers::SlotData<void(const bt::MagnetLink &, const QByteArray &, const kt::MagnetLinkLoadOptions &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 40, 41 }, { QMetaType::QByteArray, 42 }, { 0x80000000 | 43, 44 },
        }}),
        // Slot 'torrentFinished'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'slotStoppedByError'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *, QString)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { QMetaType::QString, 15 },
        }}),
        // Slot 'torrentSeedAutoStopped'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *, bt::AutoStopReason)>(47, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 48, 11 },
        }}),
        // Slot 'downloadFinished'
        QtMocHelpers::SlotData<void(KJob *)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 50, 51 },
        }}),
        // Slot 'downloadFinishedSilently'
        QtMocHelpers::SlotData<void(KJob *)>(52, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 50, 51 },
        }}),
        // Slot 'emitCorruptedData'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'autoCheckData'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'delayedRemove'
        QtMocHelpers::SlotData<void(bt::TorrentInterface *)>(55, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'delayedStart'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'beforeQueueReorder'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'afterQueueReorder'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'customGroupChanged'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onExit'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Core, qt_meta_tag_ZN2kt4CoreE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject kt::Core::staticMetaObject = { {
    QMetaObject::SuperData::link<CoreInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt4CoreE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt4CoreE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2kt4CoreE_t>.metaTypes,
    nullptr
} };

void kt::Core::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Core *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->statsUpdated(); break;
        case 1: _t->maxShareRatioReached((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 2: _t->maxSeedTimeReached((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 3: _t->corruptedData((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 4: _t->queuingNotPossible((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 5: _t->canNotStart((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bt::TorrentStartResponse>>(_a[2]))); break;
        case 6: _t->lowDiskSpace((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 7: _t->canNotLoadSilently((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->dhtNotEnabled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->openedSilently((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 10: _t->aboutToQuit(); break;
        case 11: _t->startUpdateTimer(); break;
        case 12: _t->update(); break;
        case 13: _t->start((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 14: _t->start((*reinterpret_cast<std::add_pointer_t<QList<bt::TorrentInterface*>&>>(_a[1]))); break;
        case 15: _t->stop((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 16: _t->stop((*reinterpret_cast<std::add_pointer_t<QList<bt::TorrentInterface*>&>>(_a[1]))); break;
        case 17: _t->remove((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 18: _t->remove((*reinterpret_cast<std::add_pointer_t<QList<bt::TorrentInterface*>&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 19: _t->pause((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 20: _t->pause((*reinterpret_cast<std::add_pointer_t<QList<bt::TorrentInterface*>&>>(_a[1]))); break;
        case 21: _t->aboutToBeStarted((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[2]))); break;
        case 22: { bool _r = _t->checkMissingFiles((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->enqueueTorrentOverMaxRatio((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 24: _t->doDataCheck((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 25: _t->doDataCheck((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 26: _t->onLowDiskSpace((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 27: _t->applySettings(); break;
        case 28: _t->updateGuiPlugins(); break;
        case 29: _t->onStatusChanged((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 30: _t->onMetadataDownloaded((*reinterpret_cast<std::add_pointer_t<bt::MagnetLink>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<kt::MagnetLinkLoadOptions>>(_a[3]))); break;
        case 31: _t->torrentFinished((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 32: _t->slotStoppedByError((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 33: _t->torrentSeedAutoStopped((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bt::AutoStopReason>>(_a[2]))); break;
        case 34: _t->downloadFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 35: _t->downloadFinishedSilently((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 36: _t->emitCorruptedData((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 37: _t->autoCheckData((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 38: _t->delayedRemove((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 39: _t->delayedStart(); break;
        case 40: _t->beforeQueueReorder(); break;
        case 41: _t->afterQueueReorder(); break;
        case 42: _t->customGroupChanged(); break;
        case 43: _t->onExit(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 36:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 38:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Core::*)()>(_a, &Core::statsUpdated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(bt::TorrentInterface * )>(_a, &Core::maxShareRatioReached, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(bt::TorrentInterface * )>(_a, &Core::maxSeedTimeReached, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(bt::TorrentInterface * )>(_a, &Core::corruptedData, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(bt::TorrentInterface * )>(_a, &Core::queuingNotPossible, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(bt::TorrentInterface * , bt::TorrentStartResponse )>(_a, &Core::canNotStart, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(bt::TorrentInterface * , bool )>(_a, &Core::lowDiskSpace, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(const QString & )>(_a, &Core::canNotLoadSilently, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(const QString & )>(_a, &Core::dhtNotEnabled, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(bt::TorrentInterface * )>(_a, &Core::openedSilently, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)()>(_a, &Core::aboutToQuit, 10))
            return;
    }
}

const QMetaObject *kt::Core::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kt::Core::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt4CoreE_t>.strings))
        return static_cast<void*>(this);
    return CoreInterface::qt_metacast(_clname);
}

int kt::Core::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = CoreInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    }
    return _id;
}

// SIGNAL 0
void kt::Core::statsUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void kt::Core::maxShareRatioReached(bt::TorrentInterface * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void kt::Core::maxSeedTimeReached(bt::TorrentInterface * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void kt::Core::corruptedData(bt::TorrentInterface * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void kt::Core::queuingNotPossible(bt::TorrentInterface * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void kt::Core::canNotStart(bt::TorrentInterface * _t1, bt::TorrentStartResponse _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void kt::Core::lowDiskSpace(bt::TorrentInterface * _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void kt::Core::canNotLoadSilently(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void kt::Core::dhtNotEnabled(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void kt::Core::openedSilently(bt::TorrentInterface * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void kt::Core::aboutToQuit()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
