/********************************************************************************
** Form generated from reading UI file 'Conns.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONNS_H
#define UI_CONNS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ConnsWgt
{
public:
    QHBoxLayout *hboxLayout;
    QGroupBox *ConnsGbw;
    QGridLayout *gridLayout;
    QGridLayout *gridLayout1;
    QGroupBox *DhtGbw;
    QGridLayout *gridLayout2;
    QGridLayout *gridLayout3;

    void setupUi(QWidget *ConnsWgt)
    {
        if (ConnsWgt->objectName().isEmpty())
            ConnsWgt->setObjectName("ConnsWgt");
        ConnsWgt->resize(545, 251);
        hboxLayout = new QHBoxLayout(ConnsWgt);
        hboxLayout->setObjectName("hboxLayout");
        ConnsGbw = new QGroupBox(ConnsWgt);
        ConnsGbw->setObjectName("ConnsGbw");
        gridLayout = new QGridLayout(ConnsGbw);
        gridLayout->setObjectName("gridLayout");
        gridLayout1 = new QGridLayout();
        gridLayout1->setObjectName("gridLayout1");

        gridLayout->addLayout(gridLayout1, 0, 0, 1, 1);


        hboxLayout->addWidget(ConnsGbw);

        DhtGbw = new QGroupBox(ConnsWgt);
        DhtGbw->setObjectName("DhtGbw");
        gridLayout2 = new QGridLayout(DhtGbw);
        gridLayout2->setObjectName("gridLayout2");
        gridLayout3 = new QGridLayout();
        gridLayout3->setObjectName("gridLayout3");

        gridLayout2->addLayout(gridLayout3, 0, 0, 1, 1);


        hboxLayout->addWidget(DhtGbw);


        retranslateUi(ConnsWgt);

        QMetaObject::connectSlotsByName(ConnsWgt);
    } // setupUi

    void retranslateUi(QWidget *ConnsWgt)
    {
        ConnsWgt->setWindowTitle(tr2i18n("Connections", nullptr));
        ConnsGbw->setTitle(tr2i18n("Connections", "Chart name"));
        DhtGbw->setTitle(tr2i18n("DHT", "Chart name"));
    } // retranslateUi

};

namespace Ui {
    class ConnsWgt: public Ui_ConnsWgt {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONNS_H

