/********************************************************************************
** Form generated from reading UI file 'mediacontroller.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MEDIACONTROLLER_H
#define UI_MEDIACONTROLLER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "seekslider.h"
#include "volumeslider.h"

QT_BEGIN_NAMESPACE

class Ui_MediaController
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QToolButton *prev;
    QToolButton *play;
    QToolButton *pause;
    QToolButton *stop;
    QToolButton *next;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer_2;
    kt::VolumeSlider *volume;
    QLabel *info_label;
    kt::SeekSlider *seek_slider;

    void setupUi(QWidget *MediaController)
    {
        if (MediaController->objectName().isEmpty())
            MediaController->setObjectName("MediaController");
        MediaController->resize(687, 80);
        verticalLayout = new QVBoxLayout(MediaController);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        prev = new QToolButton(MediaController);
        prev->setObjectName("prev");
        prev->setIconSize(QSize(32, 32));

        horizontalLayout_2->addWidget(prev);

        play = new QToolButton(MediaController);
        play->setObjectName("play");
        play->setIconSize(QSize(32, 32));

        horizontalLayout_2->addWidget(play);

        pause = new QToolButton(MediaController);
        pause->setObjectName("pause");
        pause->setIconSize(QSize(32, 32));

        horizontalLayout_2->addWidget(pause);

        stop = new QToolButton(MediaController);
        stop->setObjectName("stop");
        stop->setIconSize(QSize(32, 32));

        horizontalLayout_2->addWidget(stop);

        next = new QToolButton(MediaController);
        next->setObjectName("next");
        next->setIconSize(QSize(32, 32));
        next->setAutoRaise(false);

        horizontalLayout_2->addWidget(next);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);

        volume = new kt::VolumeSlider(MediaController);
        volume->setObjectName("volume");
        volume->setOrientation(Qt::Horizontal);

        horizontalLayout->addWidget(volume);


        horizontalLayout_2->addLayout(horizontalLayout);


        verticalLayout->addLayout(horizontalLayout_2);

        info_label = new QLabel(MediaController);
        info_label->setObjectName("info_label");
        info_label->setText(QString::fromUtf8("TextLabel"));
        info_label->setAlignment(Qt::AlignCenter);

        verticalLayout->addWidget(info_label);

        seek_slider = new kt::SeekSlider(MediaController);
        seek_slider->setObjectName("seek_slider");
        seek_slider->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(seek_slider);


        retranslateUi(MediaController);

        QMetaObject::connectSlotsByName(MediaController);
    } // setupUi

    void retranslateUi(QWidget *MediaController)
    {
        prev->setText(tr2i18n("...", nullptr));
        play->setText(tr2i18n("...", nullptr));
        pause->setText(tr2i18n("...", nullptr));
        stop->setText(tr2i18n("...", nullptr));
        next->setText(tr2i18n("...", nullptr));
        (void)MediaController;
    } // retranslateUi

};

namespace Ui {
    class MediaController: public Ui_MediaController {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MEDIACONTROLLER_H

