/****************************************************************************
** Meta object code from reading C++ file 'view.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktorrent-26.04.3/ktorrent/view/view.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'view.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2kt4ViewE_t {};
} // unnamed namespace

template <> constexpr inline auto kt::View::qt_create_metaobjectdata<qt_meta_tag_ZN2kt4ViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "kt::View",
        "currentTorrentChanged",
        "",
        "bt::TorrentInterface*",
        "tc",
        "torrentSelectionChanged",
        "editingItem",
        "on",
        "setFilterString",
        "filter",
        "update",
        "startTorrents",
        "forceStartTorrents",
        "stopTorrents",
        "pauseTorrents",
        "removeTorrents",
        "removeTorrentsAndData",
        "startAllTorrents",
        "stopAllTorrents",
        "checkData",
        "addPeers",
        "manualAnnounce",
        "previewTorrents",
        "openDataDir",
        "openTorDir",
        "removeFromGroup",
        "scrape",
        "moveData",
        "showProperties",
        "renameTorrent",
        "showMenu",
        "QPoint",
        "pos",
        "showHeaderMenu",
        "onHeaderMenuItemTriggered",
        "QAction*",
        "act",
        "onCurrentItemChanged",
        "QModelIndex",
        "current",
        "previous",
        "onSelectionChanged",
        "QItemSelection",
        "selected",
        "deselected",
        "onDoubleClicked",
        "index",
        "onCurrentGroupChanged",
        "kt::Group*",
        "g",
        "onGroupRenamed",
        "Group*",
        "onGroupRemoved",
        "onGroupAdded",
        "addToGroupItemTriggered",
        "copyTorrentURL",
        "speedLimits",
        "exportTorrent",
        "addToNewGroup"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentTorrentChanged'
        QtMocHelpers::SignalData<void(bt::TorrentInterface *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'torrentSelectionChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'editingItem'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Slot 'setFilterString'
        QtMocHelpers::SlotData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'update'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'startTorrents'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'forceStartTorrents'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stopTorrents'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pauseTorrents'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeTorrents'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeTorrentsAndData'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'startAllTorrents'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stopAllTorrents'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'checkData'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addPeers'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'manualAnnounce'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'previewTorrents'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openDataDir'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openTorDir'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeFromGroup'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'scrape'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'moveData'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showProperties'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'renameTorrent'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Slot 'showHeaderMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Slot 'onHeaderMenuItemTriggered'
        QtMocHelpers::SlotData<void(QAction *)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 35, 36 },
        }}),
        // Slot 'onCurrentItemChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 38, 39 }, { 0x80000000 | 38, 40 },
        }}),
        // Slot 'onSelectionChanged'
        QtMocHelpers::SlotData<void(const QItemSelection &, const QItemSelection &)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 42, 43 }, { 0x80000000 | 42, 44 },
        }}),
        // Slot 'onDoubleClicked'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 38, 46 },
        }}),
        // Slot 'onCurrentGroupChanged'
        QtMocHelpers::SlotData<void(kt::Group *)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 48, 49 },
        }}),
        // Slot 'onGroupRenamed'
        QtMocHelpers::SlotData<void(Group *)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 51, 49 },
        }}),
        // Slot 'onGroupRemoved'
        QtMocHelpers::SlotData<void(Group *)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 51, 49 },
        }}),
        // Slot 'onGroupAdded'
        QtMocHelpers::SlotData<void(Group *)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 51, 49 },
        }}),
        // Slot 'addToGroupItemTriggered'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copyTorrentURL'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'speedLimits'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'exportTorrent'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addToNewGroup'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<View, qt_meta_tag_ZN2kt4ViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject kt::View::staticMetaObject = { {
    QMetaObject::SuperData::link<QTreeView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt4ViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt4ViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2kt4ViewE_t>.metaTypes,
    nullptr
} };

void kt::View::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<View *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentTorrentChanged((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 1: _t->torrentSelectionChanged(); break;
        case 2: _t->editingItem((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->setFilterString((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->update(); break;
        case 5: _t->startTorrents(); break;
        case 6: _t->forceStartTorrents(); break;
        case 7: _t->stopTorrents(); break;
        case 8: _t->pauseTorrents(); break;
        case 9: _t->removeTorrents(); break;
        case 10: _t->removeTorrentsAndData(); break;
        case 11: _t->startAllTorrents(); break;
        case 12: _t->stopAllTorrents(); break;
        case 13: _t->checkData(); break;
        case 14: _t->addPeers(); break;
        case 15: _t->manualAnnounce(); break;
        case 16: _t->previewTorrents(); break;
        case 17: _t->openDataDir(); break;
        case 18: _t->openTorDir(); break;
        case 19: _t->removeFromGroup(); break;
        case 20: _t->scrape(); break;
        case 21: _t->moveData(); break;
        case 22: _t->showProperties(); break;
        case 23: _t->renameTorrent(); break;
        case 24: _t->showMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 25: _t->showHeaderMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 26: _t->onHeaderMenuItemTriggered((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 27: _t->onCurrentItemChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 28: _t->onSelectionChanged((*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[2]))); break;
        case 29: _t->onDoubleClicked((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 30: _t->onCurrentGroupChanged((*reinterpret_cast<std::add_pointer_t<kt::Group*>>(_a[1]))); break;
        case 31: _t->onGroupRenamed((*reinterpret_cast<std::add_pointer_t<Group*>>(_a[1]))); break;
        case 32: _t->onGroupRemoved((*reinterpret_cast<std::add_pointer_t<Group*>>(_a[1]))); break;
        case 33: _t->onGroupAdded((*reinterpret_cast<std::add_pointer_t<Group*>>(_a[1]))); break;
        case 34: _t->addToGroupItemTriggered(); break;
        case 35: _t->copyTorrentURL(); break;
        case 36: _t->speedLimits(); break;
        case 37: _t->exportTorrent(); break;
        case 38: _t->addToNewGroup(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QItemSelection >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (View::*)(bt::TorrentInterface * )>(_a, &View::currentTorrentChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (View::*)()>(_a, &View::torrentSelectionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (View::*)(bool )>(_a, &View::editingItem, 2))
            return;
    }
}

const QMetaObject *kt::View::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kt::View::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt4ViewE_t>.strings))
        return static_cast<void*>(this);
    return QTreeView::qt_metacast(_clname);
}

int kt::View::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 39)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 39;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 39)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 39;
    }
    return _id;
}

// SIGNAL 0
void kt::View::currentTorrentChanged(bt::TorrentInterface * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void kt::View::torrentSelectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void kt::View::editingItem(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
