// This file is generated by kconfig_compiler_kf6 from ktscanforlostfilesplugin.kcfg.
// All changes you do to this file will be lost.

#include "scanforlostfilespluginsettings.h"

#include <qglobal.h>
#include <QFile>

class ScanForLostFilesPluginSettingsHelper
{
  public:
    ScanForLostFilesPluginSettingsHelper() noexcept : q(nullptr) {}
    ~ScanForLostFilesPluginSettingsHelper() noexcept { delete q; q = nullptr; }
    ScanForLostFilesPluginSettingsHelper(const ScanForLostFilesPluginSettingsHelper&) = delete;
    ScanForLostFilesPluginSettingsHelper& operator=(const ScanForLostFilesPluginSettingsHelper&) = delete;
    ScanForLostFilesPluginSettings *q;
};
Q_GLOBAL_STATIC(ScanForLostFilesPluginSettingsHelper, s_globalScanForLostFilesPluginSettings)
ScanForLostFilesPluginSettings *ScanForLostFilesPluginSettings::self()
{
  if (!s_globalScanForLostFilesPluginSettings()->q) {
    new ScanForLostFilesPluginSettings;
    s_globalScanForLostFilesPluginSettings()->q->read();
  }

  return s_globalScanForLostFilesPluginSettings()->q;
}

ScanForLostFilesPluginSettings::ScanForLostFilesPluginSettings( )
  : KConfigSkeleton( QStringLiteral( "ktscanforlostfilespluginrc" ) )
{
  Q_ASSERT(!s_globalScanForLostFilesPluginSettings()->q);
  s_globalScanForLostFilesPluginSettings()->q = this;
  setCurrentGroup( QStringLiteral( "general" ) );

  KConfigSkeleton::ItemInt  *itemScanForLostFilesWidgetPosition;
  itemScanForLostFilesWidgetPosition = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "ScanForLostFilesWidgetPosition" ), mScanForLostFilesWidgetPosition, 0 );
  itemScanForLostFilesWidgetPosition->setMinValue(0);
  itemScanForLostFilesWidgetPosition->setMaxValue(2);
  addItem( itemScanForLostFilesWidgetPosition, QStringLiteral( "ScanForLostFilesWidgetPosition" ) );
}

ScanForLostFilesPluginSettings::~ScanForLostFilesPluginSettings()
{
  if (s_globalScanForLostFilesPluginSettings.exists() && !s_globalScanForLostFilesPluginSettings.isDestroyed()) {
    s_globalScanForLostFilesPluginSettings()->q = nullptr;
  }
}

