/********************************************************************************
** Form generated from reading UI file 'qmpref.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QMPREF_H
#define UI_QMPREF_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_QMPref
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_manuallyControlTorrents;
    QGroupBox *m_qm_group_box;
    QVBoxLayout *vboxLayout;
    QGridLayout *gridLayout;
    QLabel *label_11;
    QSpinBox *kcfg_maxDownloads;
    QLabel *label_10;
    QSpinBox *kcfg_maxSeeds;
    QLabel *label_12;
    QComboBox *kcfg_startDownloadsOnLowDiskSpace;
    QLabel *label_13;
    QSpinBox *kcfg_minDiskSpace;
    QCheckBox *kcfg_decreasePriorityOfStalledTorrents;
    QSpinBox *kcfg_stallTimer;
    QGroupBox *groupBox_2;
    QGridLayout *gl;
    QCheckBox *kcfg_keepSeeding;
    QLabel *label_7;
    QSpinBox *kcfg_numUploadSlots;
    QLabel *label_8;
    QDoubleSpinBox *kcfg_maxRatio;
    QLabel *label_9;
    QDoubleSpinBox *kcfg_maxSeedTime;
    QLabel *label_2;
    QDoubleSpinBox *kcfg_greenRatio;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *QMPref)
    {
        if (QMPref->objectName().isEmpty())
            QMPref->setObjectName("QMPref");
        QMPref->resize(635, 483);
        verticalLayout = new QVBoxLayout(QMPref);
        verticalLayout->setObjectName("verticalLayout");
        kcfg_manuallyControlTorrents = new QCheckBox(QMPref);
        kcfg_manuallyControlTorrents->setObjectName("kcfg_manuallyControlTorrents");

        verticalLayout->addWidget(kcfg_manuallyControlTorrents);

        m_qm_group_box = new QGroupBox(QMPref);
        m_qm_group_box->setObjectName("m_qm_group_box");
        vboxLayout = new QVBoxLayout(m_qm_group_box);
        vboxLayout->setObjectName("vboxLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label_11 = new QLabel(m_qm_group_box);
        label_11->setObjectName("label_11");

        gridLayout->addWidget(label_11, 0, 0, 1, 1);

        kcfg_maxDownloads = new QSpinBox(m_qm_group_box);
        kcfg_maxDownloads->setObjectName("kcfg_maxDownloads");
        kcfg_maxDownloads->setMaximum(99999);

        gridLayout->addWidget(kcfg_maxDownloads, 0, 1, 1, 1);

        label_10 = new QLabel(m_qm_group_box);
        label_10->setObjectName("label_10");

        gridLayout->addWidget(label_10, 1, 0, 1, 1);

        kcfg_maxSeeds = new QSpinBox(m_qm_group_box);
        kcfg_maxSeeds->setObjectName("kcfg_maxSeeds");
        kcfg_maxSeeds->setMaximum(99999);

        gridLayout->addWidget(kcfg_maxSeeds, 1, 1, 1, 1);

        label_12 = new QLabel(m_qm_group_box);
        label_12->setObjectName("label_12");

        gridLayout->addWidget(label_12, 2, 0, 1, 1);

        kcfg_startDownloadsOnLowDiskSpace = new QComboBox(m_qm_group_box);
        kcfg_startDownloadsOnLowDiskSpace->addItem(QString());
        kcfg_startDownloadsOnLowDiskSpace->addItem(QString());
        kcfg_startDownloadsOnLowDiskSpace->addItem(QString());
        kcfg_startDownloadsOnLowDiskSpace->setObjectName("kcfg_startDownloadsOnLowDiskSpace");

        gridLayout->addWidget(kcfg_startDownloadsOnLowDiskSpace, 2, 1, 1, 1);

        label_13 = new QLabel(m_qm_group_box);
        label_13->setObjectName("label_13");

        gridLayout->addWidget(label_13, 3, 0, 1, 1);

        kcfg_minDiskSpace = new QSpinBox(m_qm_group_box);
        kcfg_minDiskSpace->setObjectName("kcfg_minDiskSpace");
        kcfg_minDiskSpace->setMinimum(1);
        kcfg_minDiskSpace->setMaximum(999999999);
        kcfg_minDiskSpace->setValue(100);

        gridLayout->addWidget(kcfg_minDiskSpace, 3, 1, 1, 1);

        kcfg_decreasePriorityOfStalledTorrents = new QCheckBox(m_qm_group_box);
        kcfg_decreasePriorityOfStalledTorrents->setObjectName("kcfg_decreasePriorityOfStalledTorrents");

        gridLayout->addWidget(kcfg_decreasePriorityOfStalledTorrents, 4, 0, 1, 1);

        kcfg_stallTimer = new QSpinBox(m_qm_group_box);
        kcfg_stallTimer->setObjectName("kcfg_stallTimer");
        kcfg_stallTimer->setMinimum(1);
        kcfg_stallTimer->setMaximum(1000000);

        gridLayout->addWidget(kcfg_stallTimer, 4, 1, 1, 1);


        vboxLayout->addLayout(gridLayout);


        verticalLayout->addWidget(m_qm_group_box);

        groupBox_2 = new QGroupBox(QMPref);
        groupBox_2->setObjectName("groupBox_2");
        gl = new QGridLayout(groupBox_2);
        gl->setObjectName("gl");
        kcfg_keepSeeding = new QCheckBox(groupBox_2);
        kcfg_keepSeeding->setObjectName("kcfg_keepSeeding");

        gl->addWidget(kcfg_keepSeeding, 0, 0, 1, 2);

        label_7 = new QLabel(groupBox_2);
        label_7->setObjectName("label_7");

        gl->addWidget(label_7, 1, 0, 1, 1);

        kcfg_numUploadSlots = new QSpinBox(groupBox_2);
        kcfg_numUploadSlots->setObjectName("kcfg_numUploadSlots");
        kcfg_numUploadSlots->setMinimum(2);
        kcfg_numUploadSlots->setMaximum(100);
        kcfg_numUploadSlots->setValue(2);

        gl->addWidget(kcfg_numUploadSlots, 1, 2, 1, 1);

        label_8 = new QLabel(groupBox_2);
        label_8->setObjectName("label_8");

        gl->addWidget(label_8, 2, 0, 1, 1);

        kcfg_maxRatio = new QDoubleSpinBox(groupBox_2);
        kcfg_maxRatio->setObjectName("kcfg_maxRatio");
        kcfg_maxRatio->setSingleStep(0.010000000000000);
        kcfg_maxRatio->setValue(1.500000000000000);

        gl->addWidget(kcfg_maxRatio, 2, 2, 1, 1);

        label_9 = new QLabel(groupBox_2);
        label_9->setObjectName("label_9");

        gl->addWidget(label_9, 3, 0, 1, 1);

        kcfg_maxSeedTime = new QDoubleSpinBox(groupBox_2);
        kcfg_maxSeedTime->setObjectName("kcfg_maxSeedTime");
        kcfg_maxSeedTime->setMaximum(65000000.000000000000000);
        kcfg_maxSeedTime->setSingleStep(0.050000000000000);
        kcfg_maxSeedTime->setValue(0.000000000000000);

        gl->addWidget(kcfg_maxSeedTime, 3, 2, 1, 1);

        label_2 = new QLabel(groupBox_2);
        label_2->setObjectName("label_2");

        gl->addWidget(label_2, 4, 0, 1, 1);

        kcfg_greenRatio = new QDoubleSpinBox(groupBox_2);
        kcfg_greenRatio->setObjectName("kcfg_greenRatio");
        kcfg_greenRatio->setSingleStep(0.010000000000000);
        kcfg_greenRatio->setValue(1.500000000000000);

        gl->addWidget(kcfg_greenRatio, 4, 2, 1, 1);


        verticalLayout->addWidget(groupBox_2);

        spacerItem = new QSpacerItem(547, 31, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(spacerItem);


        retranslateUi(QMPref);
        QObject::connect(kcfg_decreasePriorityOfStalledTorrents, &QCheckBox::toggled, kcfg_stallTimer, &QSpinBox::setEnabled);
        QObject::connect(kcfg_manuallyControlTorrents, &QCheckBox::toggled, kcfg_maxDownloads, &QSpinBox::setDisabled);
        QObject::connect(kcfg_manuallyControlTorrents, &QCheckBox::toggled, kcfg_maxSeeds, &QSpinBox::setDisabled);
        QObject::connect(kcfg_manuallyControlTorrents, &QCheckBox::toggled, kcfg_decreasePriorityOfStalledTorrents, &QCheckBox::setDisabled);

        QMetaObject::connectSlotsByName(QMPref);
    } // setupUi

    void retranslateUi(QWidget *QMPref)
    {
#if QT_CONFIG(tooltip)
        kcfg_manuallyControlTorrents->setToolTip(tr2i18n("When enabled, the queue manager will be totally disabled, allowing you to fully control all torrents manually.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_manuallyControlTorrents->setText(tr2i18n("Control torrents manually", nullptr));
        m_qm_group_box->setTitle(tr2i18n("Queue Manager", nullptr));
        label_11->setText(tr2i18n("Maximum downloads:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_maxDownloads->setToolTip(tr2i18n("The maximum number of simultaneous downloads the queue manager will run.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_maxDownloads->setSpecialValueText(tr2i18n("No limit", nullptr));
        label_10->setText(tr2i18n("Maximum seeds:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_maxSeeds->setToolTip(tr2i18n("The maximum number of simultaneous seeds the queue manager will run.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_maxSeeds->setSpecialValueText(tr2i18n("No limit", nullptr));
        label_12->setText(tr2i18n("When diskspace is running low:", nullptr));
        kcfg_startDownloadsOnLowDiskSpace->setItemText(0, tr2i18n("Don't start torrents", nullptr));
        kcfg_startDownloadsOnLowDiskSpace->setItemText(1, tr2i18n("Ask if torrents can be started", nullptr));
        kcfg_startDownloadsOnLowDiskSpace->setItemText(2, tr2i18n("Start torrents", nullptr));

#if QT_CONFIG(tooltip)
        kcfg_startDownloadsOnLowDiskSpace->setToolTip(tr2i18n("What to do when the diskspace is running low and the queue manager wants to start a torrent.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_13->setText(tr2i18n("Stop torrents when free disk space is lower than:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_minDiskSpace->setToolTip(tr2i18n("When the free diskspace drops below this value, stop all torrents downloading.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_minDiskSpace->setSuffix(tr2i18n(" MiB", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_decreasePriorityOfStalledTorrents->setToolTip(tr2i18n("<p>With this enabled, the queue manager will decrease the priority of a torrent which has been stalled for too long. </p>\n"
"<p>This will allow the queue manager to run other torrents, when a torrent is doing nothing.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_decreasePriorityOfStalledTorrents->setText(tr2i18n("Decrease priority of torrents which are stalled for more than:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_stallTimer->setToolTip(tr2i18n("<p>Time used for the stall timer. When a torrent is stalled longer than this, its priority will be decreased.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox_2->setTitle(tr2i18n("Seeding", "@title:group Options regarding Seeding"));
#if QT_CONFIG(tooltip)
        kcfg_keepSeeding->setToolTip(tr2i18n("When a download is finished, continue seeding it. If this is disabled, the torrent will be stopped.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_keepSeeding->setText(tr2i18n("Keep seeding after download is finished", nullptr));
        label_7->setText(tr2i18n("Number of upload slots:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_numUploadSlots->setToolTip(tr2i18n("The number of upload slots, this determines the number of peers you can upload to simultaneously for one torrent.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_8->setText(tr2i18n("Default maximum share ratio:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_maxRatio->setToolTip(tr2i18n("<p>The maximum share ratio, if this value is reached seeding will be stopped. This is only applied to newly opened torrents, existing torrents will not be affected by changing this.</p>\n"
"<p><span style=\" font-weight:600;\">Attention: </span>This is not used when downloading, only when seeding.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_maxRatio->setSpecialValueText(tr2i18n("No limit", nullptr));
        label_9->setText(tr2i18n("Default maximum seed time:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_maxSeedTime->setToolTip(tr2i18n("The maximum seed time in hours. Once you reach this time, the torrent will be stopped. This is only applied to newly opened torrents, existing torrents will not be affected by changing this.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_maxSeedTime->setSpecialValueText(tr2i18n("No limit", nullptr));
#if QT_CONFIG(tooltip)
        label_2->setToolTip(tr2i18n("Value at which the share ratio will be displayed with a green color. Lower ratios will be displayed in red. Colors can be changed in color settings.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(tr2i18n("Minimum good share ratio:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_greenRatio->setToolTip(tr2i18n("Value at which the share ratio will be displayed with a green color. Lower ratios will be displayed in red. Colors can be changed in color settings.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_greenRatio->setSpecialValueText(tr2i18n("No limit", nullptr));
        (void)QMPref;
    } // retranslateUi

};

namespace Ui {
    class QMPref: public Ui_QMPref {};
} // namespace Ui

QT_END_NAMESPACE

#endif // QMPREF_H

