/********************************************************************************
** Form generated from reading UI file 'feedwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FEEDWIDGET_H
#define UI_FEEDWIDGET_H

#include <QtCore/QVariant>
#include <QtWebEngineWidgets/QWebEngineView>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ksqueezedtextlabel.h"

QT_BEGIN_NAMESPACE

class Ui_FeedWidget
{
public:
    QVBoxLayout *verticalLayout_3;
    QSplitter *m_splitter;
    QWidget *layoutWidget;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label;
    KSqueezedTextLabel *m_url;
    QHBoxLayout *horizontalLayout;
    QLabel *label_2;
    KSqueezedTextLabel *m_status;
    QLabel *label_4;
    KSqueezedTextLabel *m_active_filters;
    QHBoxLayout *horizontalLayout_5;
    QTreeView *m_item_list;
    QVBoxLayout *verticalLayout;
    QPushButton *m_download;
    QPushButton *m_refresh;
    QLabel *label_refresh_rate;
    QSpinBox *m_refresh_rate;
    QLabel *m_feed_last_updated;
    QSpacerItem *verticalSpacer;
    QPushButton *m_cookies;
    QPushButton *m_filters;
    QWebEngineView *m_item_view;

    void setupUi(QWidget *FeedWidget)
    {
        if (FeedWidget->objectName().isEmpty())
            FeedWidget->setObjectName("FeedWidget");
        FeedWidget->resize(867, 511);
        verticalLayout_3 = new QVBoxLayout(FeedWidget);
        verticalLayout_3->setObjectName("verticalLayout_3");
        m_splitter = new QSplitter(FeedWidget);
        m_splitter->setObjectName("m_splitter");
        m_splitter->setOrientation(Qt::Orientation::Vertical);
        layoutWidget = new QWidget(m_splitter);
        layoutWidget->setObjectName("layoutWidget");
        verticalLayout_2 = new QVBoxLayout(layoutWidget);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label = new QLabel(layoutWidget);
        label->setObjectName("label");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);

        horizontalLayout_2->addWidget(label);

        m_url = new KSqueezedTextLabel(layoutWidget);
        m_url->setObjectName("m_url");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_url->sizePolicy().hasHeightForWidth());
        m_url->setSizePolicy(sizePolicy1);
        m_url->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByKeyboard|Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextBrowserInteraction|Qt::TextInteractionFlag::TextSelectableByKeyboard|Qt::TextInteractionFlag::TextSelectableByMouse);

        horizontalLayout_2->addWidget(m_url);


        verticalLayout_2->addLayout(horizontalLayout_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label_2 = new QLabel(layoutWidget);
        label_2->setObjectName("label_2");
        sizePolicy.setHeightForWidth(label_2->sizePolicy().hasHeightForWidth());
        label_2->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(label_2);

        m_status = new KSqueezedTextLabel(layoutWidget);
        m_status->setObjectName("m_status");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(m_status->sizePolicy().hasHeightForWidth());
        m_status->setSizePolicy(sizePolicy2);

        horizontalLayout->addWidget(m_status);

        label_4 = new QLabel(layoutWidget);
        label_4->setObjectName("label_4");

        horizontalLayout->addWidget(label_4);

        m_active_filters = new KSqueezedTextLabel(layoutWidget);
        m_active_filters->setObjectName("m_active_filters");

        horizontalLayout->addWidget(m_active_filters);


        verticalLayout_2->addLayout(horizontalLayout);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        m_item_list = new QTreeView(layoutWidget);
        m_item_list->setObjectName("m_item_list");
        m_item_list->setRootIsDecorated(false);
        m_item_list->setUniformRowHeights(true);
        m_item_list->setSortingEnabled(false);
        m_item_list->setAllColumnsShowFocus(true);

        horizontalLayout_5->addWidget(m_item_list);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        m_download = new QPushButton(layoutWidget);
        m_download->setObjectName("m_download");

        verticalLayout->addWidget(m_download);

        m_refresh = new QPushButton(layoutWidget);
        m_refresh->setObjectName("m_refresh");

        verticalLayout->addWidget(m_refresh);

        label_refresh_rate = new QLabel(layoutWidget);
        label_refresh_rate->setObjectName("label_refresh_rate");

        verticalLayout->addWidget(label_refresh_rate);

        m_refresh_rate = new QSpinBox(layoutWidget);
        m_refresh_rate->setObjectName("m_refresh_rate");
        m_refresh_rate->setMinimum(1);
        m_refresh_rate->setMaximum(10000);
        m_refresh_rate->setValue(60);

        verticalLayout->addWidget(m_refresh_rate);

        m_feed_last_updated = new QLabel(layoutWidget);
        m_feed_last_updated->setObjectName("m_feed_last_updated");
        m_feed_last_updated->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextSelectableByMouse);

        verticalLayout->addWidget(m_feed_last_updated);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        m_cookies = new QPushButton(layoutWidget);
        m_cookies->setObjectName("m_cookies");

        verticalLayout->addWidget(m_cookies);

        m_filters = new QPushButton(layoutWidget);
        m_filters->setObjectName("m_filters");

        verticalLayout->addWidget(m_filters);


        horizontalLayout_5->addLayout(verticalLayout);


        verticalLayout_2->addLayout(horizontalLayout_5);

        m_splitter->addWidget(layoutWidget);
        m_item_view = new QWebEngineView(m_splitter);
        m_item_view->setObjectName("m_item_view");
        m_splitter->addWidget(m_item_view);

        verticalLayout_3->addWidget(m_splitter);

#if QT_CONFIG(shortcut)
        label_refresh_rate->setBuddy(m_refresh_rate);
#endif // QT_CONFIG(shortcut)

        retranslateUi(FeedWidget);

        QMetaObject::connectSlotsByName(FeedWidget);
    } // setupUi

    void retranslateUi(QWidget *FeedWidget)
    {
        label->setText(tr2i18n("URL:", nullptr));
        m_url->setText(tr2i18n("KSqueezedTextLabel", "KDE::DoNotExtract"));
        label_2->setText(tr2i18n("Status:", nullptr));
        m_status->setText(tr2i18n("KSqueezedTextLabel", "KDE::DoNotExtract"));
        label_4->setText(tr2i18n("Active Filters:", nullptr));
        m_download->setText(tr2i18n("Download", nullptr));
        m_refresh->setText(tr2i18n("Refresh", nullptr));
        label_refresh_rate->setText(tr2i18n("Refresh every:", nullptr));
#if QT_CONFIG(tooltip)
        m_refresh_rate->setToolTip(tr2i18n("Time between automatic refreshes of the feed.", nullptr));
#endif // QT_CONFIG(tooltip)
        m_refresh_rate->setSuffix(tr2i18n(" minutes", nullptr));
#if QT_CONFIG(tooltip)
        m_feed_last_updated->setToolTip(tr2i18n("Last successful update of the selected feed", nullptr));
#endif // QT_CONFIG(tooltip)
        m_cookies->setText(tr2i18n("Cookies", nullptr));
        m_filters->setText(tr2i18n("Filters", nullptr));
        (void)FeedWidget;
    } // retranslateUi

};

namespace Ui {
    class FeedWidget: public Ui_FeedWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FEEDWIDGET_H

