/********************************************************************************
** Form generated from reading UI file 'Settings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGS_H
#define UI_SETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_StatsSettingsWgt
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *UpdateGbw;
    QGridLayout *gridLayout;
    QLabel *label;
    QSpinBox *kcfg_UpdateEveryGuiUpdates;
    QHBoxLayout *hboxLayout;
    QLabel *label_2;
    QLabel *UpdMsLbl;
    QLabel *label_3;
    QSpinBox *kcfg_DataGatherIval;
    QLabel *label_4;
    QGroupBox *groupBox;
    QGridLayout *gridLayout1;
    QLabel *label_6;
    QSpinBox *kcfg_DlSpdSamples;
    QLabel *label_11;
    QSpinBox *kcfg_ConnsSamples;
    QLabel *label_7;
    QSpinBox *kcfg_PeersSpdSamples;
    QLabel *label_10;
    QSpinBox *kcfg_UlSpdSamples;
    QSpinBox *kcfg_DhtSpdSamples;
    QLabel *label_12;
    QGroupBox *MaxModeGbw;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *hboxLayout1;
    QLabel *label_5;
    QComboBox *kcfg_MaxMode;
    QGroupBox *groupBox_2;
    QVBoxLayout *vboxLayout2;
    QCheckBox *kcfg_ShowSeedsInSwarms;
    QCheckBox *kcfg_ShowLeechersInSwarms;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *StatsSettingsWgt)
    {
        if (StatsSettingsWgt->objectName().isEmpty())
            StatsSettingsWgt->setObjectName("StatsSettingsWgt");
        StatsSettingsWgt->resize(418, 480);
        vboxLayout = new QVBoxLayout(StatsSettingsWgt);
        vboxLayout->setObjectName("vboxLayout");
        UpdateGbw = new QGroupBox(StatsSettingsWgt);
        UpdateGbw->setObjectName("UpdateGbw");
        gridLayout = new QGridLayout(UpdateGbw);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(UpdateGbw);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        kcfg_UpdateEveryGuiUpdates = new QSpinBox(UpdateGbw);
        kcfg_UpdateEveryGuiUpdates->setObjectName("kcfg_UpdateEveryGuiUpdates");
        kcfg_UpdateEveryGuiUpdates->setMinimum(1);
        kcfg_UpdateEveryGuiUpdates->setMaximum(999999999);
        kcfg_UpdateEveryGuiUpdates->setValue(2);

        gridLayout->addWidget(kcfg_UpdateEveryGuiUpdates, 0, 1, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        label_2 = new QLabel(UpdateGbw);
        label_2->setObjectName("label_2");

        hboxLayout->addWidget(label_2);

        UpdMsLbl = new QLabel(UpdateGbw);
        UpdMsLbl->setObjectName("UpdMsLbl");

        hboxLayout->addWidget(UpdMsLbl);


        gridLayout->addLayout(hboxLayout, 0, 2, 1, 1);

        label_3 = new QLabel(UpdateGbw);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        kcfg_DataGatherIval = new QSpinBox(UpdateGbw);
        kcfg_DataGatherIval->setObjectName("kcfg_DataGatherIval");
        kcfg_DataGatherIval->setMinimum(250);
        kcfg_DataGatherIval->setMaximum(999999999);
        kcfg_DataGatherIval->setSingleStep(250);
        kcfg_DataGatherIval->setValue(750);

        gridLayout->addWidget(kcfg_DataGatherIval, 1, 1, 1, 1);

        label_4 = new QLabel(UpdateGbw);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 1, 2, 1, 1);


        vboxLayout->addWidget(UpdateGbw);

        groupBox = new QGroupBox(StatsSettingsWgt);
        groupBox->setObjectName("groupBox");
        gridLayout1 = new QGridLayout(groupBox);
        gridLayout1->setObjectName("gridLayout1");
        label_6 = new QLabel(groupBox);
        label_6->setObjectName("label_6");

        gridLayout1->addWidget(label_6, 0, 0, 1, 1);

        kcfg_DlSpdSamples = new QSpinBox(groupBox);
        kcfg_DlSpdSamples->setObjectName("kcfg_DlSpdSamples");
        kcfg_DlSpdSamples->setAccelerated(true);
        kcfg_DlSpdSamples->setMinimum(3);
        kcfg_DlSpdSamples->setMaximum(999999999);
        kcfg_DlSpdSamples->setValue(192);

        gridLayout1->addWidget(kcfg_DlSpdSamples, 0, 1, 1, 1);

        label_11 = new QLabel(groupBox);
        label_11->setObjectName("label_11");

        gridLayout1->addWidget(label_11, 0, 2, 1, 1);

        kcfg_ConnsSamples = new QSpinBox(groupBox);
        kcfg_ConnsSamples->setObjectName("kcfg_ConnsSamples");
        kcfg_ConnsSamples->setAccelerated(true);
        kcfg_ConnsSamples->setMinimum(3);
        kcfg_ConnsSamples->setMaximum(999999999);
        kcfg_ConnsSamples->setValue(384);

        gridLayout1->addWidget(kcfg_ConnsSamples, 0, 3, 1, 1);

        label_7 = new QLabel(groupBox);
        label_7->setObjectName("label_7");

        gridLayout1->addWidget(label_7, 1, 0, 1, 1);

        kcfg_PeersSpdSamples = new QSpinBox(groupBox);
        kcfg_PeersSpdSamples->setObjectName("kcfg_PeersSpdSamples");
        kcfg_PeersSpdSamples->setAccelerated(true);
        kcfg_PeersSpdSamples->setMinimum(3);
        kcfg_PeersSpdSamples->setMaximum(999999999);
        kcfg_PeersSpdSamples->setValue(192);

        gridLayout1->addWidget(kcfg_PeersSpdSamples, 1, 1, 1, 1);

        label_10 = new QLabel(groupBox);
        label_10->setObjectName("label_10");

        gridLayout1->addWidget(label_10, 2, 0, 1, 1);

        kcfg_UlSpdSamples = new QSpinBox(groupBox);
        kcfg_UlSpdSamples->setObjectName("kcfg_UlSpdSamples");
        kcfg_UlSpdSamples->setAccelerated(true);
        kcfg_UlSpdSamples->setMinimum(3);
        kcfg_UlSpdSamples->setMaximum(999999999);
        kcfg_UlSpdSamples->setValue(192);

        gridLayout1->addWidget(kcfg_UlSpdSamples, 2, 1, 1, 1);

        kcfg_DhtSpdSamples = new QSpinBox(groupBox);
        kcfg_DhtSpdSamples->setObjectName("kcfg_DhtSpdSamples");
        kcfg_DhtSpdSamples->setAccelerated(true);
        kcfg_DhtSpdSamples->setMinimum(3);
        kcfg_DhtSpdSamples->setMaximum(999999999);
        kcfg_DhtSpdSamples->setValue(384);

        gridLayout1->addWidget(kcfg_DhtSpdSamples, 1, 3, 1, 1);

        label_12 = new QLabel(groupBox);
        label_12->setObjectName("label_12");

        gridLayout1->addWidget(label_12, 1, 2, 1, 1);


        vboxLayout->addWidget(groupBox);

        MaxModeGbw = new QGroupBox(StatsSettingsWgt);
        MaxModeGbw->setObjectName("MaxModeGbw");
        vboxLayout1 = new QVBoxLayout(MaxModeGbw);
        vboxLayout1->setObjectName("vboxLayout1");
        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        label_5 = new QLabel(MaxModeGbw);
        label_5->setObjectName("label_5");
        label_5->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        hboxLayout1->addWidget(label_5);

        kcfg_MaxMode = new QComboBox(MaxModeGbw);
        kcfg_MaxMode->addItem(QString());
        kcfg_MaxMode->addItem(QString());
        kcfg_MaxMode->setObjectName("kcfg_MaxMode");

        hboxLayout1->addWidget(kcfg_MaxMode);


        vboxLayout1->addLayout(hboxLayout1);


        vboxLayout->addWidget(MaxModeGbw);

        groupBox_2 = new QGroupBox(StatsSettingsWgt);
        groupBox_2->setObjectName("groupBox_2");
        vboxLayout2 = new QVBoxLayout(groupBox_2);
        vboxLayout2->setObjectName("vboxLayout2");
        kcfg_ShowSeedsInSwarms = new QCheckBox(groupBox_2);
        kcfg_ShowSeedsInSwarms->setObjectName("kcfg_ShowSeedsInSwarms");

        vboxLayout2->addWidget(kcfg_ShowSeedsInSwarms);

        kcfg_ShowLeechersInSwarms = new QCheckBox(groupBox_2);
        kcfg_ShowLeechersInSwarms->setObjectName("kcfg_ShowLeechersInSwarms");

        vboxLayout2->addWidget(kcfg_ShowLeechersInSwarms);


        vboxLayout->addWidget(groupBox_2);

        spacerItem = new QSpacerItem(410, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem);

#if QT_CONFIG(shortcut)
        label->setBuddy(kcfg_UpdateEveryGuiUpdates);
        label_2->setBuddy(kcfg_UpdateEveryGuiUpdates);
        label_3->setBuddy(kcfg_DataGatherIval);
        label_4->setBuddy(kcfg_DataGatherIval);
        label_6->setBuddy(kcfg_DlSpdSamples);
        label_11->setBuddy(kcfg_ConnsSamples);
        label_7->setBuddy(kcfg_PeersSpdSamples);
        label_10->setBuddy(kcfg_UlSpdSamples);
        label_12->setBuddy(kcfg_DhtSpdSamples);
        label_5->setBuddy(kcfg_MaxMode);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_UpdateEveryGuiUpdates, kcfg_DataGatherIval);
        QWidget::setTabOrder(kcfg_DataGatherIval, kcfg_DlSpdSamples);
        QWidget::setTabOrder(kcfg_DlSpdSamples, kcfg_PeersSpdSamples);
        QWidget::setTabOrder(kcfg_PeersSpdSamples, kcfg_UlSpdSamples);
        QWidget::setTabOrder(kcfg_UlSpdSamples, kcfg_ConnsSamples);
        QWidget::setTabOrder(kcfg_ConnsSamples, kcfg_DhtSpdSamples);
        QWidget::setTabOrder(kcfg_DhtSpdSamples, kcfg_MaxMode);
        QWidget::setTabOrder(kcfg_MaxMode, kcfg_ShowSeedsInSwarms);
        QWidget::setTabOrder(kcfg_ShowSeedsInSwarms, kcfg_ShowLeechersInSwarms);

        retranslateUi(StatsSettingsWgt);

        kcfg_MaxMode->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(StatsSettingsWgt);
    } // setupUi

    void retranslateUi(QWidget *StatsSettingsWgt)
    {
        StatsSettingsWgt->setWindowTitle(tr2i18n("Settings", nullptr));
        UpdateGbw->setTitle(tr2i18n("Update", "@title:group"));
        label->setText(tr2i18n("Update charts every", "Continues with: [number field] GUI updates"));
        label_2->setText(tr2i18n("GUI updates", "Continuation of: Update charts every [number field]"));
        UpdMsLbl->setText(QString());
        label_3->setText(tr2i18n("Gather data every", "Continues with: [number field] milliseconds"));
        label_4->setText(tr2i18n("milliseconds", "Continuation of: Gather data every [number field]"));
        groupBox->setTitle(tr2i18n("Measurements counts", nullptr));
        label_6->setText(tr2i18n("Download", "Chart name"));
        label_11->setText(tr2i18n("Connections", "Chart name"));
        label_7->setText(tr2i18n("Peers", "Chart name"));
        label_10->setText(tr2i18n("Upload", "Chart name"));
        label_12->setText(tr2i18n("DHT", "Chart name"));
        MaxModeGbw->setTitle(tr2i18n("Maximum", nullptr));
        label_5->setText(tr2i18n("Maximum speed scale mode: ", "@label:listbox"));
        kcfg_MaxMode->setItemText(0, tr2i18n("Maximum ever achieved", nullptr));
        kcfg_MaxMode->setItemText(1, tr2i18n("Maximum visible on chart", nullptr));

        groupBox_2->setTitle(tr2i18n("Peers connections", "@title:group"));
        kcfg_ShowSeedsInSwarms->setText(tr2i18n("Show seeds in swarms", nullptr));
        kcfg_ShowLeechersInSwarms->setText(tr2i18n("Show leechers in swarms", nullptr));
    } // retranslateUi

};

namespace Ui {
    class StatsSettingsWgt: public Ui_StatsSettingsWgt {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGS_H

