/****************************************************************************
** Meta object code from reading C++ file 'fileselectdlg.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktorrent-26.04.3/ktorrent/dialogs/fileselectdlg.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fileselectdlg.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2kt13FileSelectDlgE_t {};
} // unnamed namespace

template <> constexpr inline auto kt::FileSelectDlg::qt_create_metaobjectdata<qt_meta_tag_ZN2kt13FileSelectDlgE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "kt::FileSelectDlg",
        "reject",
        "",
        "accept",
        "selectAll",
        "selectNone",
        "invertSelection",
        "updateSizeLabels",
        "groupActivated",
        "idx",
        "fileTree",
        "on",
        "fileList",
        "setShowFileTree",
        "setFilter",
        "filter",
        "updateExistingFiles",
        "moveCompletedToggled",
        "createHistoryMenu",
        "QMenu*",
        "urls",
        "Func",
        "slot",
        "clearDownloadLocationHistory",
        "clearMoveOnCompletionLocationHistory",
        "downloadLocationHistoryTriggered",
        "QAction*",
        "act",
        "moveOnCompletionLocationHistoryTriggered",
        "downloadLocationChanged",
        "path"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'reject'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'accept'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'selectAll'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'selectNone'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'invertSelection'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'updateSizeLabels'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'groupActivated'
        QtMocHelpers::SlotData<void(int)>(8, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Slot 'fileTree'
        QtMocHelpers::SlotData<void(bool)>(10, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'fileList'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'setShowFileTree'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'setFilter'
        QtMocHelpers::SlotData<void(const QString &)>(14, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'updateExistingFiles'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'moveCompletedToggled'
        QtMocHelpers::SlotData<void(bool)>(17, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'createHistoryMenu'
        QtMocHelpers::SlotData<QMenu *(const QStringList &, Func)>(18, 2, QMC::AccessProtected, 0x80000000 | 19, {{
            { QMetaType::QStringList, 20 }, { 0x80000000 | 21, 22 },
        }}),
        // Slot 'clearDownloadLocationHistory'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'clearMoveOnCompletionLocationHistory'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'downloadLocationHistoryTriggered'
        QtMocHelpers::SlotData<void(QAction *)>(25, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'moveOnCompletionLocationHistoryTriggered'
        QtMocHelpers::SlotData<void(QAction *)>(28, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'downloadLocationChanged'
        QtMocHelpers::SlotData<void(const QString &)>(29, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 30 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FileSelectDlg, qt_meta_tag_ZN2kt13FileSelectDlgE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject kt::FileSelectDlg::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt13FileSelectDlgE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt13FileSelectDlgE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2kt13FileSelectDlgE_t>.metaTypes,
    nullptr
} };

void kt::FileSelectDlg::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FileSelectDlg *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->reject(); break;
        case 1: _t->accept(); break;
        case 2: _t->selectAll(); break;
        case 3: _t->selectNone(); break;
        case 4: _t->invertSelection(); break;
        case 5: _t->updateSizeLabels(); break;
        case 6: _t->groupActivated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->fileTree((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->fileList((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->setShowFileTree((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->setFilter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->updateExistingFiles(); break;
        case 12: _t->moveCompletedToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: { QMenu* _r = _t->createHistoryMenu((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Func>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QMenu**>(_a[0]) = std::move(_r); }  break;
        case 14: _t->clearDownloadLocationHistory(); break;
        case 15: _t->clearMoveOnCompletionLocationHistory(); break;
        case 16: _t->downloadLocationHistoryTriggered((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 17: _t->moveOnCompletionLocationHistoryTriggered((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 18: _t->downloadLocationChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *kt::FileSelectDlg::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kt::FileSelectDlg::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2kt13FileSelectDlgE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui_FileSelectDlg"))
        return static_cast< Ui_FileSelectDlg*>(this);
    return QDialog::qt_metacast(_clname);
}

int kt::FileSelectDlg::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    return _id;
}
QT_WARNING_POP
