/********************************************************************************
** Form generated from reading UI file 'torrentcreatordlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TORRENTCREATORDLG_H
#define UI_TORRENTCREATORDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_TorrentCreatorDlg
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    KUrlRequester *m_url;
    QHBoxLayout *horizontalLayout_2;
    QRadioButton *m_selectDirectory;
    QRadioButton *m_selectFile;
    QGroupBox *m_options;
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QLabel *label_2;
    QComboBox *m_chunk_size;
    QCheckBox *m_start_seeding;
    QCheckBox *m_private;
    QCheckBox *m_dht;
    QHBoxLayout *hboxLayout1;
    QLabel *label_6;
    QComboBox *m_group;
    QTabWidget *m_tabs;
    QWidget *m_tracker_tab;
    QGridLayout *gridLayout;
    QLineEdit *m_tracker;
    QPushButton *m_add_tracker;
    QListWidget *m_tracker_list;
    QVBoxLayout *vboxLayout1;
    QPushButton *m_remove_tracker;
    QPushButton *m_move_up;
    QPushButton *m_move_down;
    QSpacerItem *spacerItem;
    QWidget *m_dht_tab;
    QGridLayout *gridLayout1;
    QHBoxLayout *hboxLayout2;
    QLabel *label_3;
    QLineEdit *m_node;
    QLabel *label_4;
    QSpinBox *m_port;
    QPushButton *m_add_node;
    QTreeWidget *m_node_list;
    QVBoxLayout *vboxLayout2;
    QPushButton *m_remove_node;
    QSpacerItem *spacerItem1;
    QWidget *tab_2;
    QGridLayout *gridLayout2;
    QLineEdit *m_webseed;
    QPushButton *m_add_webseed;
    QListWidget *m_webseed_list;
    QVBoxLayout *vboxLayout3;
    QPushButton *m_remove_webseed;
    QSpacerItem *spacerItem2;
    QHBoxLayout *hboxLayout3;
    QLabel *label_5;
    QLineEdit *m_comments;
    QProgressBar *m_progress;
    QFrame *line;
    QDialogButtonBox *m_buttonBox;

    void setupUi(QDialog *TorrentCreatorDlg)
    {
        if (TorrentCreatorDlg->objectName().isEmpty())
            TorrentCreatorDlg->setObjectName("TorrentCreatorDlg");
        TorrentCreatorDlg->resize(474, 646);
        verticalLayout = new QVBoxLayout(TorrentCreatorDlg);
        verticalLayout->setObjectName("verticalLayout");
        groupBox = new QGroupBox(TorrentCreatorDlg);
        groupBox->setObjectName("groupBox");
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        m_url = new KUrlRequester(groupBox);
        m_url->setObjectName("m_url");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_url->sizePolicy().hasHeightForWidth());
        m_url->setSizePolicy(sizePolicy);
        m_url->setMinimumSize(QSize(0, 0));

        verticalLayout_2->addWidget(m_url);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        m_selectDirectory = new QRadioButton(groupBox);
        m_selectDirectory->setObjectName("m_selectDirectory");

        horizontalLayout_2->addWidget(m_selectDirectory);

        m_selectFile = new QRadioButton(groupBox);
        m_selectFile->setObjectName("m_selectFile");

        horizontalLayout_2->addWidget(m_selectFile);


        verticalLayout_2->addLayout(horizontalLayout_2);


        verticalLayout->addWidget(groupBox);

        m_options = new QGroupBox(TorrentCreatorDlg);
        m_options->setObjectName("m_options");
        vboxLayout = new QVBoxLayout(m_options);
        vboxLayout->setObjectName("vboxLayout");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        label_2 = new QLabel(m_options);
        label_2->setObjectName("label_2");

        hboxLayout->addWidget(label_2);

        m_chunk_size = new QComboBox(m_options);
        m_chunk_size->addItem(QString());
        m_chunk_size->addItem(QString());
        m_chunk_size->addItem(QString());
        m_chunk_size->addItem(QString());
        m_chunk_size->addItem(QString());
        m_chunk_size->addItem(QString());
        m_chunk_size->addItem(QString());
        m_chunk_size->addItem(QString());
        m_chunk_size->addItem(QString());
        m_chunk_size->addItem(QString());
        m_chunk_size->setObjectName("m_chunk_size");

        hboxLayout->addWidget(m_chunk_size);


        vboxLayout->addLayout(hboxLayout);

        m_start_seeding = new QCheckBox(m_options);
        m_start_seeding->setObjectName("m_start_seeding");
        m_start_seeding->setChecked(true);

        vboxLayout->addWidget(m_start_seeding);

        m_private = new QCheckBox(m_options);
        m_private->setObjectName("m_private");

        vboxLayout->addWidget(m_private);

        m_dht = new QCheckBox(m_options);
        m_dht->setObjectName("m_dht");

        vboxLayout->addWidget(m_dht);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        label_6 = new QLabel(m_options);
        label_6->setObjectName("label_6");

        hboxLayout1->addWidget(label_6);

        m_group = new QComboBox(m_options);
        m_group->setObjectName("m_group");

        hboxLayout1->addWidget(m_group);


        vboxLayout->addLayout(hboxLayout1);


        verticalLayout->addWidget(m_options);

        m_tabs = new QTabWidget(TorrentCreatorDlg);
        m_tabs->setObjectName("m_tabs");
        m_tracker_tab = new QWidget();
        m_tracker_tab->setObjectName("m_tracker_tab");
        gridLayout = new QGridLayout(m_tracker_tab);
        gridLayout->setObjectName("gridLayout");
        m_tracker = new QLineEdit(m_tracker_tab);
        m_tracker->setObjectName("m_tracker");

        gridLayout->addWidget(m_tracker, 0, 0, 1, 1);

        m_add_tracker = new QPushButton(m_tracker_tab);
        m_add_tracker->setObjectName("m_add_tracker");

        gridLayout->addWidget(m_add_tracker, 0, 1, 1, 1);

        m_tracker_list = new QListWidget(m_tracker_tab);
        m_tracker_list->setObjectName("m_tracker_list");

        gridLayout->addWidget(m_tracker_list, 1, 0, 1, 1);

        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName("vboxLayout1");
        m_remove_tracker = new QPushButton(m_tracker_tab);
        m_remove_tracker->setObjectName("m_remove_tracker");

        vboxLayout1->addWidget(m_remove_tracker);

        m_move_up = new QPushButton(m_tracker_tab);
        m_move_up->setObjectName("m_move_up");

        vboxLayout1->addWidget(m_move_up);

        m_move_down = new QPushButton(m_tracker_tab);
        m_move_down->setObjectName("m_move_down");

        vboxLayout1->addWidget(m_move_down);

        spacerItem = new QSpacerItem(20, 91, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout1->addItem(spacerItem);


        gridLayout->addLayout(vboxLayout1, 1, 1, 1, 1);

        m_tabs->addTab(m_tracker_tab, QString());
        m_dht_tab = new QWidget();
        m_dht_tab->setObjectName("m_dht_tab");
        gridLayout1 = new QGridLayout(m_dht_tab);
        gridLayout1->setObjectName("gridLayout1");
        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setObjectName("hboxLayout2");
        label_3 = new QLabel(m_dht_tab);
        label_3->setObjectName("label_3");

        hboxLayout2->addWidget(label_3);

        m_node = new QLineEdit(m_dht_tab);
        m_node->setObjectName("m_node");

        hboxLayout2->addWidget(m_node);

        label_4 = new QLabel(m_dht_tab);
        label_4->setObjectName("label_4");

        hboxLayout2->addWidget(label_4);

        m_port = new QSpinBox(m_dht_tab);
        m_port->setObjectName("m_port");
        m_port->setMinimum(1);
        m_port->setMaximum(65535);
        m_port->setValue(6881);

        hboxLayout2->addWidget(m_port);


        gridLayout1->addLayout(hboxLayout2, 0, 0, 1, 1);

        m_add_node = new QPushButton(m_dht_tab);
        m_add_node->setObjectName("m_add_node");

        gridLayout1->addWidget(m_add_node, 0, 1, 1, 1);

        m_node_list = new QTreeWidget(m_dht_tab);
        m_node_list->setObjectName("m_node_list");
        m_node_list->setRootIsDecorated(false);
        m_node_list->setAllColumnsShowFocus(true);

        gridLayout1->addWidget(m_node_list, 1, 0, 1, 1);

        vboxLayout2 = new QVBoxLayout();
        vboxLayout2->setObjectName("vboxLayout2");
        m_remove_node = new QPushButton(m_dht_tab);
        m_remove_node->setObjectName("m_remove_node");

        vboxLayout2->addWidget(m_remove_node);

        spacerItem1 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout2->addItem(spacerItem1);


        gridLayout1->addLayout(vboxLayout2, 1, 1, 1, 1);

        m_tabs->addTab(m_dht_tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        gridLayout2 = new QGridLayout(tab_2);
        gridLayout2->setObjectName("gridLayout2");
        m_webseed = new QLineEdit(tab_2);
        m_webseed->setObjectName("m_webseed");

        gridLayout2->addWidget(m_webseed, 0, 0, 1, 1);

        m_add_webseed = new QPushButton(tab_2);
        m_add_webseed->setObjectName("m_add_webseed");

        gridLayout2->addWidget(m_add_webseed, 0, 1, 1, 1);

        m_webseed_list = new QListWidget(tab_2);
        m_webseed_list->setObjectName("m_webseed_list");

        gridLayout2->addWidget(m_webseed_list, 1, 0, 1, 1);

        vboxLayout3 = new QVBoxLayout();
        vboxLayout3->setObjectName("vboxLayout3");
        m_remove_webseed = new QPushButton(tab_2);
        m_remove_webseed->setObjectName("m_remove_webseed");

        vboxLayout3->addWidget(m_remove_webseed);

        spacerItem2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout3->addItem(spacerItem2);


        gridLayout2->addLayout(vboxLayout3, 1, 1, 1, 1);

        m_tabs->addTab(tab_2, QString());

        verticalLayout->addWidget(m_tabs);

        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setObjectName("hboxLayout3");
        label_5 = new QLabel(TorrentCreatorDlg);
        label_5->setObjectName("label_5");

        hboxLayout3->addWidget(label_5);

        m_comments = new QLineEdit(TorrentCreatorDlg);
        m_comments->setObjectName("m_comments");

        hboxLayout3->addWidget(m_comments);


        verticalLayout->addLayout(hboxLayout3);

        m_progress = new QProgressBar(TorrentCreatorDlg);
        m_progress->setObjectName("m_progress");
        m_progress->setEnabled(false);
        m_progress->setValue(24);

        verticalLayout->addWidget(m_progress);

        line = new QFrame(TorrentCreatorDlg);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        m_buttonBox = new QDialogButtonBox(TorrentCreatorDlg);
        m_buttonBox->setObjectName("m_buttonBox");
        m_buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(m_buttonBox);


        retranslateUi(TorrentCreatorDlg);

        m_chunk_size->setCurrentIndex(4);
        m_tabs->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(TorrentCreatorDlg);
    } // setupUi

    void retranslateUi(QDialog *TorrentCreatorDlg)
    {
        TorrentCreatorDlg->setWindowTitle(tr2i18n("Create a torrent", nullptr));
        groupBox->setTitle(tr2i18n("File or directory to create torrent from:", nullptr));
        m_selectDirectory->setText(tr2i18n("Select Directory", nullptr));
        m_selectFile->setText(tr2i18n("Select File", nullptr));
        m_options->setTitle(tr2i18n("Options", nullptr));
        label_2->setText(tr2i18n("Size of each chunk:", nullptr));
        m_chunk_size->setItemText(0, tr2i18n("32 KiB", nullptr));
        m_chunk_size->setItemText(1, tr2i18n("64 KiB", nullptr));
        m_chunk_size->setItemText(2, tr2i18n("128 KiB", nullptr));
        m_chunk_size->setItemText(3, tr2i18n("256 KiB", nullptr));
        m_chunk_size->setItemText(4, tr2i18n("512 KiB", nullptr));
        m_chunk_size->setItemText(5, tr2i18n("1 MiB", nullptr));
        m_chunk_size->setItemText(6, tr2i18n("2 MiB", nullptr));
        m_chunk_size->setItemText(7, tr2i18n("4 MiB", nullptr));
        m_chunk_size->setItemText(8, tr2i18n("8 MiB", nullptr));
        m_chunk_size->setItemText(9, tr2i18n("16 MiB", nullptr));

        m_start_seeding->setText(tr2i18n("Start seeding", nullptr));
        m_private->setText(tr2i18n("Private torrent (DHT not allowed)", nullptr));
        m_dht->setText(tr2i18n("Decentralized (DHT only)", nullptr));
        label_6->setText(tr2i18n("Add torrent to group:", nullptr));
        m_add_tracker->setText(tr2i18n("Add", nullptr));
        m_remove_tracker->setText(tr2i18n("Remove", nullptr));
        m_move_up->setText(tr2i18n("Move Up", nullptr));
        m_move_down->setText(tr2i18n("Move Down", nullptr));
        m_tabs->setTabText(m_tabs->indexOf(m_tracker_tab), tr2i18n("Trackers", nullptr));
        label_3->setText(tr2i18n("Node:", nullptr));
        label_4->setText(tr2i18n("Port:", nullptr));
        m_add_node->setText(tr2i18n("Add", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = m_node_list->headerItem();
        ___qtreewidgetitem->setText(1, tr2i18n("Port", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("IP or Hostname", nullptr));
        m_remove_node->setText(tr2i18n("Remove", nullptr));
        m_tabs->setTabText(m_tabs->indexOf(m_dht_tab), tr2i18n("DHT Nodes", nullptr));
        m_add_webseed->setText(tr2i18n("Add", nullptr));
        m_remove_webseed->setText(tr2i18n("Remove", nullptr));
        m_tabs->setTabText(m_tabs->indexOf(tab_2), tr2i18n("Web Seeds", nullptr));
        label_5->setText(tr2i18n("Comments:", nullptr));
        m_progress->setFormat(tr2i18n("%p%", nullptr));
    } // retranslateUi

};

namespace Ui {
    class TorrentCreatorDlg: public Ui_TorrentCreatorDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TORRENTCREATORDLG_H

