/********************************************************************************
** Form generated from reading UI file 'convertdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONVERTDIALOG_H
#define UI_CONVERTDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ConvertDialog
{
public:
    QVBoxLayout *vboxLayout;
    QLabel *textLabel1;
    QLabel *m_msg;
    QProgressBar *m_progress_bar;
    QFrame *line;
    QHBoxLayout *hboxLayout;
    QSpacerItem *spacerItem;
    QPushButton *m_cancel;

    void setupUi(QDialog *ConvertDialog)
    {
        if (ConvertDialog->objectName().isEmpty())
            ConvertDialog->setObjectName("ConvertDialog");
        ConvertDialog->resize(421, 145);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ConvertDialog->sizePolicy().hasHeightForWidth());
        ConvertDialog->setSizePolicy(sizePolicy);
        ConvertDialog->setModal(true);
        vboxLayout = new QVBoxLayout(ConvertDialog);
        vboxLayout->setSpacing(6);
        vboxLayout->setContentsMargins(11, 11, 11, 11);
        vboxLayout->setObjectName("vboxLayout");
        textLabel1 = new QLabel(ConvertDialog);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setTextFormat(Qt::AutoText);
        textLabel1->setScaledContents(false);
        textLabel1->setAlignment(Qt::AlignVCenter);
        textLabel1->setWordWrap(true);
        textLabel1->setIndent(-2);

        vboxLayout->addWidget(textLabel1);

        m_msg = new QLabel(ConvertDialog);
        m_msg->setObjectName("m_msg");
        m_msg->setWordWrap(false);

        vboxLayout->addWidget(m_msg);

        m_progress_bar = new QProgressBar(ConvertDialog);
        m_progress_bar->setObjectName("m_progress_bar");
        m_progress_bar->setValue(24);

        vboxLayout->addWidget(m_progress_bar);

        line = new QFrame(ConvertDialog);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        vboxLayout->addWidget(line);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);

        m_cancel = new QPushButton(ConvertDialog);
        m_cancel->setObjectName("m_cancel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_cancel->sizePolicy().hasHeightForWidth());
        m_cancel->setSizePolicy(sizePolicy1);

        hboxLayout->addWidget(m_cancel);


        vboxLayout->addLayout(hboxLayout);


        retranslateUi(ConvertDialog);

        QMetaObject::connectSlotsByName(ConvertDialog);
    } // setupUi

    void retranslateUi(QDialog *ConvertDialog)
    {
        ConvertDialog->setWindowTitle(tr2i18n("Converting\342\200\246", nullptr));
        textLabel1->setText(tr2i18n("Converting block list to KTorrent format. This might take some time.", nullptr));
        m_msg->setText(QString());
        m_progress_bar->setFormat(tr2i18n("%p%", nullptr));
        m_cancel->setText(tr2i18n("C&ancel", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ConvertDialog: public Ui_ConvertDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONVERTDIALOG_H

